@@ -1,51 +1,51 @@
 /*
- *
- *    OPEN-XCHANGE legal information
- *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
- *
- *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- */
+*
+*    OPEN-XCHANGE legal information
+*
+*    All intellectual property rights in the Software are protected by
+*    international copyright laws.
+*
+*
+*    In some countries OX, OX Open-Xchange, open xchange and OXtender
+*    as well as the corresponding Logos OX Open-Xchange and OX are registered
+*    trademarks.
+*    The use of the Logos is not covered by the GNU General Public License.
+*    Instead, you are allowed to use these Logos according to the terms and
+*    conditions of the Creative Commons License, Version 2.5, Attribution,
+*    Non-commercial, ShareAlike, and the interpretation of the term
+*    Non-commercial applicable to the aforementioned license is published
+*    on the web site http://www.open-xchange.com/EN/legal/index.html.
+*
+*    Please make sure that third-party modules and libraries are used
+*    according to their respective licenses.
+*
+*    Any modifications to this package must retain all copyright notices
+*    of the original copyright holder(s) for the original code used.
+*
+*    After any such modifications, the original and derivative code shall remain
+*    under the copyright of the copyright holder(s) and/or original author(s)per
+*    the Attribution and Assignment Agreement that can be located at
+*    http://www.open-xchange.com/EN/developer/. The contributing author shall be
+*    given Attribution for the derivative code and a license granting use.
+*
+*     Copyright (C) 2016 OX Software GmbH
+*     Mail: info@open-xchange.com
+*
+*
+*     This program is free software; you can redistribute it and/or modify it
+*     under the terms of the GNU General Public License, Version 2 as published
+*     by the Free Software Foundation.
+*
+*     This program is distributed in the hope that it will be useful, but
+*     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+*     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+*     for more details.
+*
+*     You should have received a copy of the GNU General Public License along
+*     with this program; if not, write to the Free Software Foundation, Inc., 59
+*     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+*
+*/
 package com.openexchange.office.backup.distributed;
 
 import java.util.Collection;
@@ -57,11 +57,16 @@ import java.util.Set;
 import java.util.UUID;
 
 import org.apache.commons.lang.Validate;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import org.springframework.beans.factory.InitializingBean;
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.stereotype.Service;
 
+import com.hazelcast.core.HazelcastInstance;
 import com.openexchange.exception.OXException;
 import com.openexchange.filemanagement.ManagedFileManagement;
-import com.openexchange.log.Log;
-import com.openexchange.office.hazelcast.doc.DocumentResourcesDirectory;
+import com.openexchange.office.hazelcast.core.doc.DocumentResourcesDirectory;
 import com.openexchange.office.imagemgr.Resource;
 import com.openexchange.office.tools.directory.DocRestoreID;
 import com.openexchange.office.tools.directory.DocumentResources;
@@ -69,8 +74,6 @@ import com.openexchange.office.tools.directory.IStreamIDCollection;
 import com.openexchange.office.tools.monitoring.RestoreDocEvent;
 import com.openexchange.office.tools.monitoring.RestoreDocEventType;
 import com.openexchange.office.tools.monitoring.Statistics;
-import com.openexchange.office.tools.osgi.ServiceLookupRegistry;
-import com.openexchange.server.ServiceLookup;
 
 /**
  * Manages the document resources a document references images and
@@ -80,35 +83,35 @@ import com.openexchange.server.ServiceLookup;
  * @since 7.8.1
  *
  */
-public class DistributedDocumentResourceManager implements IDistributedManageFileCollection {
+@Service
+public class DistributedDocumentResourceManager implements IDistributedManageFileCollection, InitializingBean {
 
-    @SuppressWarnings("deprecation")
-    static private final org.apache.commons.logging.Log LOG = Log.loggerFor(DistributedDocumentStreamManager.class);
-    private final ManagedFileManagement fileManager;
-    private final DocumentResourcesDirectory globalDocumentResourcesMap;
+    static private final Logger LOG = LoggerFactory.getLogger(DistributedDocumentResourceManager.class);
+        
     private final HashMap<DocRestoreID, DocumentResources> docResourcesMap = new HashMap<DocRestoreID, DocumentResources>();
-    private final String uniqueSingletonID;
-    private final String uniqueID;
-    private final DistributedManagedFileLocker locker;
+    private final String uniqueID = UUID.randomUUID().toString();
+    
+    @Autowired
+    private DocumentResourcesDirectory globalDocumentResourcesMap;
+    
+    @Autowired
+    private ManagedFileManagement fileManager;
+    
+    @Autowired
+    private DistributedManagedFileLocker locker;
+    
+    @Autowired
+    private HazelcastInstance hzInstance;
+    
+    @Autowired
+    private Statistics statistics;
 
-    /**
-     * Initializes a DistributedDocumentStreamManager
-     *
-     * @param services the service lookup to be used for this instance
-     */
-    public DistributedDocumentResourceManager(final ServiceLookup servicesDEPRECATED, final DocumentResourcesDirectory globalDocumentResourcesMap, final String uniqueSingletonID) {
-        Validate.notNull(globalDocumentResourcesMap);
+    @Override
+	public void afterPropertiesSet() throws Exception {
+        locker.addCollectionToLock(this);    	
+	}
 
-        fileManager = ServiceLookupRegistry.get().getService(ManagedFileManagement.class);
-        locker = DistributedManagedFileLocker.get();
-        this.globalDocumentResourcesMap = globalDocumentResourcesMap;
-        this.uniqueSingletonID = uniqueSingletonID;
-        this.uniqueID = UUID.randomUUID().toString();
-
-        locker.addCollectionToLock(this);
-    }
-
-    public boolean addResourceRef(final DocRestoreID docRestoreID, final Resource resource) {
+	public boolean addResourceRef(final DocRestoreID docRestoreID, final Resource resource) {
         Validate.notNull(docRestoreID);
         Validate.notNull(resource);
 
@@ -121,7 +124,7 @@ public class DistributedDocumentResourceManager implements IDistributedManageFil
                 final long timeStamp = new Date().getTime();
                 final Set<String> resources = new HashSet<String>();
 
-                docResources = new DocumentResources(docRestoreID, timeStamp, uniqueSingletonID, resources);
+                docResources = new DocumentResources(docRestoreID, timeStamp, hzInstance.getCluster().getLocalMember().getUuid(), resources);
             }
 
             if (null != docResources) {
@@ -200,7 +203,7 @@ public class DistributedDocumentResourceManager implements IDistributedManageFil
 
             if (null != docResources) {
                 globalDocumentResourcesMap.remove(docRestoreID);
-                Statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.MANAGED_FILES_CURRENT_DEC));
+                statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.MANAGED_FILES_CURRENT_DEC));
             }
 
             // remove the resource ids from our local map
@@ -311,9 +314,4 @@ public class DistributedDocumentResourceManager implements IDistributedManageFil
     public String getUniqueID() {
         return this.uniqueID;
     }
-
-    public void dispose() {
-        DistributedManagedFileLocker.destroy();
-    }
-
 }
