@@ -28,7 +28,7 @@
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
-*     Copyright (C) 2016-2020 OX Software GmbH
+*     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
@@ -56,21 +56,21 @@ import java.util.HashSet;
 import java.util.Set;
 import java.util.UUID;
 
-import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.commons.lang.Validate;
+import org.springframework.beans.factory.InitializingBean;
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.stereotype.Service;
 
 import com.openexchange.exception.OXException;
 import com.openexchange.filemanagement.ManagedFile;
 import com.openexchange.filemanagement.ManagedFileManagement;
-import com.openexchange.log.Log;
+import com.openexchange.office.tools.common.IOHelper;
 import com.openexchange.office.tools.directory.DocRestoreID;
 import com.openexchange.office.tools.directory.IStreamIDCollection;
 import com.openexchange.office.tools.monitoring.RestoreDocEvent;
 import com.openexchange.office.tools.monitoring.RestoreDocEventType;
 import com.openexchange.office.tools.monitoring.Statistics;
-import com.openexchange.office.tools.osgi.ServiceLookupRegistry;
-import com.openexchange.server.ServiceLookup;
 
 /**
  * Manages the document specific streams in a distributed managed file manager.
@@ -79,33 +79,32 @@ import com.openexchange.server.ServiceLookup;
  * @author Carsten Driesner
  * @since 7.8.1
  */
-public class DistributedDocumentStreamManager implements IDistributedManageFileCollection {
+@Service
+public class DistributedDocumentStreamManager implements IDistributedManageFileCollection, InitializingBean {
 
-    @SuppressWarnings("deprecation")
-    static private final org.apache.commons.logging.Log LOG = Log.loggerFor(DistributedDocumentStreamManager.class);
     private static final String DOC_STREAM_PREFIX = "office:doc-stream:";
     private static final String OPS_STREAM_PREFIX = "office:ops-stream:";
-    private final String uniqueSingletonID;
-    private final ManagedFileManagement fileManager;
+    
+    @Autowired
+    private ManagedFileManagement fileManager;
+    
+    @Autowired
+    private DistributedManagedFileLocker locker;
+
+    @Autowired
+    private GCManagedFiles gcManagedFiles;
+    
+    @Autowired
+    private Statistics statistics;
+    
     private final HashMap<DocRestoreID, DocStreams> docStreamsMap = new HashMap<DocRestoreID, DocStreams>();
-    private final DistributedManagedFileLocker locker;
-    private final GCManagedFiles gcManagedFiles;
-    private final String uniqueID;
+        
+    private final String uniqueID = UUID.randomUUID().toString();
 
-    /**
-     * Initializes a DistributedDocumentStreamManager
-     *
-     * @param services the service lookup to be used for this instance
-     */
-    public DistributedDocumentStreamManager(final ServiceLookup servicesDEPRECATED, final GCManagedFiles gcManagedFiles, final String uniqueSingletonID) {
-        fileManager = ServiceLookupRegistry.get().getService(ManagedFileManagement.class);
-        locker = DistributedManagedFileLocker.get();
-        this.gcManagedFiles = gcManagedFiles;
-        this.uniqueSingletonID = uniqueSingletonID;
-        this.uniqueID = UUID.randomUUID().toString();
-
-        locker.addCollectionToLock(this);
-    }
+    @Override
+	public void afterPropertiesSet() throws Exception {
+        locker.addCollectionToLock(this);		
+	}
 
     /**
      * Determine if the DistributedDocumentStreamManager has a control structure for
@@ -181,10 +180,10 @@ public class DistributedDocumentStreamManager implements IDistributedManageFileC
             final DocStreams docStreams = docStreamsMap.remove(docRestoreID);
             if (null != docStreams) {
                 if (StringUtils.isNotEmpty(docStreams.getDocStreamID())) {
-                    Statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.MANAGED_FILES_CURRENT_DEC));
+                    statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.MANAGED_FILES_CURRENT_DEC));
                 }
                 if (StringUtils.isNotEmpty(docStreams.getOpsStreamID())) {
-                    Statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.MANAGED_FILES_CURRENT_DEC));
+                    statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.MANAGED_FILES_CURRENT_DEC));
                 }
             }
         }
@@ -245,17 +244,6 @@ public class DistributedDocumentStreamManager implements IDistributedManageFileC
         return uniqueID;
     }
 
-    /**
-     * Disposes this instance which means that the internal data structures
-     * remove state data and frees as much memory as possible.
-     */
-    public void dispose() {
-        DistributedManagedFileLocker.destroy();
-        synchronized(docStreamsMap) {
-            docStreamsMap.clear();
-        }
-    }
-
     /**
      *
      * @param docResourceID
@@ -290,7 +278,7 @@ public class DistributedDocumentStreamManager implements IDistributedManageFileC
             // add now obsolete managed file id to the gc
             gcManagedFiles.addObseleteManagedFileId(obsoleteStreamID);
         }
-        IOUtils.closeQuietly(inStream);
+        IOHelper.closeQuietly(inStream);
 
         return uniqueStreamID;
     }
