@@ -28,7 +28,7 @@
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
-*     Copyright (C) 2016-2020 OX Software GmbH
+*     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
@@ -48,22 +48,24 @@
 */
 package com.openexchange.office.backup.manager.impl;
 
-import java.lang.ref.WeakReference;
-import java.util.HashMap;
 import java.util.LinkedList;
 import java.util.List;
-import java.util.Map;
 import java.util.Queue;
 import java.util.stream.Collectors;
+
 import org.apache.commons.collections.CollectionUtils;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+import org.springframework.beans.factory.DisposableBean;
+import org.springframework.beans.factory.InitializingBean;
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.stereotype.Service;
 
 import com.openexchange.office.message.OperationHelper;
+import com.openexchange.office.tools.common.json.JSONHelper;
 import com.openexchange.office.tools.directory.DocRestoreID;
-import com.openexchange.office.tools.json.JSONHelper;
 import com.openexchange.office.tools.monitoring.Statistics;
 
 /**
@@ -71,7 +73,8 @@ import com.openexchange.office.tools.monitoring.Statistics;
  * @author <a href="mailto:carsten.driesner@open-xchange.com">Carsten Driesner</a>
  * @since 7.10.0
  */
-public class AsyncBackupWorker {
+@Service
+public class AsyncBackupWorker implements InitializingBean, DisposableBean {
     private static final Logger log = LoggerFactory.getLogger(AsyncBackupWorker.class);
 
     private static final String WRITEBACK_THREAD_NAME = ("com.openexchange.office.backup.DocumentBackupManager.AsyncBackupWorker"); 
@@ -79,19 +82,21 @@ public class AsyncBackupWorker {
 
     private final Queue<OperationDocData> pendingDocData = new LinkedList<OperationDocData>();
     private Thread writeBackThread;
-    private final WeakReference<StoreOperationData> storeOperationDataProcessor;
+    
+    @Autowired
+    private StoreOperationData storeOperationDataProcessor;
+    
+    @Autowired
+    private Statistics statistics;
 
     /**
      * Initializes a new AsyncBackupWorker instance which used a thread-based
      * background processing - to combine operations collected for a document
      * and write them into managed files.
      *
-     * @param services
-     * @param storeOperationData
-     */
-	public AsyncBackupWorker(final StoreOperationData storeOpsData) {
-		this.storeOperationDataProcessor = new WeakReference<StoreOperationData>(storeOpsData);
-
+	*/
+	@Override
+	public void afterPropertiesSet() throws Exception {
 		writeBackThread = new Thread() {
 
             @Override
@@ -117,13 +122,10 @@ public class AsyncBackupWorker {
                                 if (null == currOpsDocData)
                                     break;
 
-                                final StoreOperationData storeOperationData = storeOperationDataProcessor.get();
-                                if (null != storeOperationData) {
-        	                        // store the pending operations to hazelcast/distributed managed file
-        	                        storeOperationData.storePendingOperationsToDocumentState(
-        	                            currOpsDocData.getID(), currOpsDocData.getOperations(), currOpsDocData.getOSN());
-        	                        countStored += Math.max(0, (countBefore - countAfter));
-                                }
+    	                        // store the pending operations to hazelcast/distributed managed file
+                                storeOperationDataProcessor.storePendingOperationsToDocumentState(
+    	                            currOpsDocData.getID(), currOpsDocData.getOperations(), currOpsDocData.getOSN());
+    	                        countStored += Math.max(0, (countBefore - countAfter));
 
                                 // make sure that we bail out as soon as possible after being interrupted
                                 if (Thread.interrupted())
@@ -139,8 +141,8 @@ public class AsyncBackupWorker {
                         }
 
                         final long runTime = Math.max(0, (System.currentTimeMillis() - timeStart));
-                        Statistics.get().setRestoreDocOpsMsgStored(countStored);
-                        Statistics.get().setRestoreDocMsgStoredTime(runTime);
+                        statistics.setRestoreDocOpsMsgStored(countStored);
+                        statistics.setRestoreDocMsgStoredTime(runTime);
 
                         inactiveTime = calcInactivityTime(runTime, 1000, WRITEBACK_OPERATIONS_TIMER_PERIOD);
                 	} catch (InterruptedException e) {
@@ -159,6 +161,8 @@ public class AsyncBackupWorker {
         log.trace("AsyncBackupWorker thread created");
 	}
 
+
+
 	/**
 	 * Appends
 	 * @param docResId a DocRestoreID instance which references a document restore instances - must not be null
@@ -175,7 +179,8 @@ public class AsyncBackupWorker {
 	/**
 	 *
 	 */
-	public void dispose() {
+	@Override
+	public void destroy() throws Exception {
 		log.trace("AsyncBackupWorker.dispose() called");
 
 		synchronized (pendingDocData) {
