@@ -28,7 +28,7 @@
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
-*     Copyright (C) 2016-2020 OX Software GmbH
+*     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
@@ -53,32 +53,37 @@ import java.util.Map;
 import java.util.Set;
 import java.util.Timer;
 import java.util.TimerTask;
-import java.util.concurrent.atomic.AtomicReference;
+
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import org.springframework.beans.factory.DisposableBean;
+import org.springframework.beans.factory.InitializingBean;
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.stereotype.Service;
 
 import com.openexchange.exception.ExceptionUtils;
-import com.openexchange.log.Log;
 import com.openexchange.office.backup.manager.DocumentBackupController;
-import com.openexchange.office.hazelcast.doc.DocumentDirectory;
+import com.openexchange.office.hazelcast.core.doc.DocumentDirectory;
 import com.openexchange.office.tools.directory.DocRestoreID;
 import com.openexchange.office.tools.directory.DocumentState;
-import com.openexchange.server.ServiceLookup;
 
-public class CleanupBackupDocTask {
-    @SuppressWarnings("deprecation")
-    static private final org.apache.commons.logging.Log LOG = Log.loggerFor(CleanupBackupDocTask.class);
+@Service
+public class CleanupBackupDocTask implements InitializingBean, DisposableBean {
+    static private final Logger LOG = LoggerFactory.getLogger(CleanupBackupDocTask.class);
 
     private static final long CLEANUP_BACKUP_DOCUMENTS_TIMER_PERIOD = 300000; // 5 minutes
     private static final long MAX_IDLE_TIME = 4 * 60 * 60 * 1000; // 4h
-    private static final AtomicReference<CleanupBackupDocTask> REF = new AtomicReference<CleanupBackupDocTask>();
     private Timer timer = new Timer("com.openexchange.office.backup.CleanupBackupTask");
     private TimerTask timerTask = null;
 
-    /**
-     * Initializes a new {@link ResourceLocker}.
-     */
-    public CleanupBackupDocTask(final ServiceLookup servicesDEPRECATED, final DocumentBackupController documentBackupController, final DocumentDirectory documentDir) {
-        super();
-
+    @Autowired
+    private DocumentBackupController documentBackupController;
+    
+    @Autowired
+    private DocumentDirectory documentDir;
+    
+	@Override
+	public void afterPropertiesSet() throws Exception {
         // create the task to touch the held resources at at specified interval
         timerTask = new TimerTask() {
 
@@ -127,7 +132,8 @@ public class CleanupBackupDocTask {
         timer.schedule(timerTask, CLEANUP_BACKUP_DOCUMENTS_TIMER_PERIOD, CLEANUP_BACKUP_DOCUMENTS_TIMER_PERIOD);
     }
 
-    public void dispose() {
+    @Override
+	public void destroy() throws Exception {
         final Timer aTimer = timer;
 
         if (aTimer != null) {
