@@ -28,7 +28,7 @@
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
-*     Copyright (C) 2016-2020 OX Software GmbH
+*     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
@@ -57,37 +57,36 @@ import java.nio.charset.Charset;
 import java.util.Date;
 import java.util.HashSet;
 import java.util.Set;
-import java.util.concurrent.atomic.AtomicReference;
 
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.commons.lang.Validate;
 import org.json.JSONArray;
 import org.json.JSONException;
+import org.springframework.beans.factory.InitializingBean;
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.stereotype.Service;
 
-import com.openexchange.exception.ExceptionUtils;
 import com.openexchange.exception.OXException;
 import com.openexchange.log.Log;
 import com.openexchange.office.backup.distributed.DistributedDocumentResourceManager;
 import com.openexchange.office.backup.distributed.DistributedDocumentStreamManager;
 import com.openexchange.office.backup.manager.DocumentBackupController;
 import com.openexchange.office.backup.manager.DocumentRestoreData;
-import com.openexchange.office.hazelcast.access.HazelcastAccess;
-import com.openexchange.office.hazelcast.doc.DocumentDirectory;
-import com.openexchange.office.hazelcast.doc.DocumentResourcesDirectory;
+import com.openexchange.office.hazelcast.core.doc.DocumentDirectory;
 import com.openexchange.office.imagemgr.IResourceManager;
 import com.openexchange.office.imagemgr.IResourceManagerFactory;
 import com.openexchange.office.imagemgr.Resource;
+import com.openexchange.office.tools.annotation.RegisteredService;
+import com.openexchange.office.tools.common.error.ErrorCode;
+import com.openexchange.office.tools.common.json.JSONHelper;
 import com.openexchange.office.tools.directory.DocRestoreID;
 import com.openexchange.office.tools.directory.DocumentState;
 import com.openexchange.office.tools.directory.IStreamIDCollection;
-import com.openexchange.office.tools.error.ErrorCode;
-import com.openexchange.office.tools.json.JSONHelper;
 import com.openexchange.office.tools.monitoring.RestoreDocEvent;
 import com.openexchange.office.tools.monitoring.RestoreDocEventType;
 import com.openexchange.office.tools.monitoring.Statistics;
-import com.openexchange.office.tools.osgi.ServiceLookupRegistry;
-import com.openexchange.server.ServiceLookup;
+import com.openexchange.office.tools.service.caching.HazelcastUuidHelper;
 
 /**
  * Central class to control storing and retrieving document restore data
@@ -97,74 +96,43 @@ import com.openexchange.server.ServiceLookup;
  * @since 7.8.1
  *
  */
+@Service
+@RegisteredService(registeredClass=DocumentBackupController.class)
 @SuppressWarnings("deprecation")
-public class DocumentBackupManager implements DocumentBackupController, StoreOperationData {
+public class DocumentBackupManager implements DocumentBackupController, StoreOperationData, InitializingBean {
 
     static private final org.apache.commons.logging.Log LOG = Log.loggerFor(DocumentBackupManager.class);
-
+    
 	private static final int OSN_UNDEFINED = -1;
-    private static final AtomicReference<DocumentBackupManager> REF = new AtomicReference<DocumentBackupManager>();
+    
+    @Autowired
+    private IResourceManagerFactory resourceManagerFactory;    
+    
+    @Autowired
 	private DocumentDirectory documentDir;
-	private final AsyncBackupWorker backupWriter;
+    
+    @Autowired
+	private AsyncBackupWorker backupWriter;
+    
+    @Autowired
+	private DistributedDocumentStreamManager distributedDocumentStreamManager;
+	
+    @Autowired
+	private DistributedDocumentResourceManager distributedDocumentResourceManager;
+
+    @Autowired
+    private Statistics statistics;
+
+	//--------------------------------------------------------------------------------------------------------
 	private final Object sync = new Object();
-	private final DistributedDocumentStreamManager distributedDocumentStreamManager;
-	private final DistributedDocumentResourceManager distributedDocumentResourceManager;
-	private final CleanupBackupDocTask cleanupTask;
-	private final GCObsoleteStreams gcObsoleteManagedFiles;
-	private final String uniqueInstanceID;
+	
+	private String uniqueInstanceID;
 
-	/**
-	 * Creates a DocumentBackupManager instance.
-	 *
-	 * @param serviceLookup
-	 */
-	private DocumentBackupManager(final ServiceLookup serviceLookupDEPRECATED, final DocumentDirectory docDir, final DocumentResourcesDirectory docResDir, final String uniqueInstanceID) throws Exception {
-		gcObsoleteManagedFiles = new GCObsoleteStreams();
-	    distributedDocumentStreamManager = new DistributedDocumentStreamManager(null, gcObsoleteManagedFiles, uniqueInstanceID);
-	    distributedDocumentResourceManager = new DistributedDocumentResourceManager(null, docResDir, uniqueInstanceID);
-	    cleanupTask = new CleanupBackupDocTask(null, this, docDir);	    
-		documentDir = docDir;
-		backupWriter = new AsyncBackupWorker(this);
-		this.uniqueInstanceID = uniqueInstanceID;
-    }
-
-	/**
-	 * Initializes the singleton.
-	 *
-	 * @param serviceLookup
-	 */
-	public static void init(final ServiceLookup serviceLookupDEPRECATED, final DocumentDirectory docDir, final DocumentResourcesDirectory docResDir) throws Exception {
-	    String uuid = null;
-	    try {
-	        uuid = HazelcastAccess.getLocalMember().getUuid();
-	    } catch (OXException e) {
-	        LOG.error("RT2: Please check package installation. Retrieving the Hazelcast local member not possible!",  e);
-	    }
-
-		REF.compareAndSet(null, new DocumentBackupManager(null, docDir, docResDir, uuid));
+	@Override
+	public void afterPropertiesSet() throws Exception {
+		this.uniqueInstanceID = HazelcastUuidHelper.getNodeUuidAsStr();
 	}
-
-	/**
-	 * Disposes the singleton, which resets memory consuming members.
-	 */
-	public static void destroy() {
-		final DocumentBackupManager docDataManager = REF.getAndSet(null);
-
-		if (null != docDataManager) {
-			docDataManager.dispose();
-		}
-	}
-
-	/**
-	 * Returns the one and only DocumentDataManager instance.
-	 *
-	 * @return the one and only DocumentDataManager instance or null, if not
-	 * initialized.
-	 */
-	public static final DocumentBackupManager get() {
-		return REF.get();
-	}
-
+		
 	/**
 	 * Registers a new document state in the global document state directory
 	 * managed by Hazelcast.
@@ -204,8 +172,8 @@ public class DocumentBackupManager implements DocumentBackupController, StoreOpe
                 // store the backup managed file in the global hazelcast structures
                 storedDocState.setManagedDocFileId(managedDocFileId);
 
-                Statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.NEW_DOC));
-                Statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.MANAGED_FILES_CURRENT_INC));
+                statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.NEW_DOC));
+                statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.MANAGED_FILES_CURRENT_INC));
 			} else {
 				LOG.debug("RT connection: Document Restore overwrites entry for " + docRestoreId.toString() + " at " + System.currentTimeMillis());
 
@@ -228,7 +196,7 @@ public class DocumentBackupManager implements DocumentBackupController, StoreOpe
                 storedDocState.setFileName(fileName);
                 storedDocState.setMimeType(mimeType);
 
-                Statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.MANAGED_FILES_CURRENT_INC));
+                statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.MANAGED_FILES_CURRENT_INC));
 			}
 
 			// register this node instance as responsible and set document as active with current time stamp
@@ -340,7 +308,7 @@ public class DocumentBackupManager implements DocumentBackupController, StoreOpe
 			try {
 				if (documentDir != null) {
 					documentDir.remove(docRestoreId);
-					Statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.REMOVED_DOC));
+					statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.REMOVED_DOC));
 				}
     		} catch (OXException e) {
                 LOG.warn("RT2: Exception caught trying to remove timed out hazeclast document structure, docResId=" + docRestoreId, e);
@@ -441,11 +409,10 @@ public class DocumentBackupManager implements DocumentBackupController, StoreOpe
                     }
 
                     // we always need a resource manager, but it can contain no resources
-                    final IResourceManager resManager = ServiceLookupRegistry.get().getService(IResourceManagerFactory.class).createInstance();
+                    final IResourceManager resManager = resourceManagerFactory.createInstance(docRestoreId.toString());
                     if ((null != resManager) && (null != docResources) && (!docResources.isEmpty())) {
                         for (final String managedResId : docResources) {
-                        	IResourceManager resourceManager = ServiceLookupRegistry.get().getService(IResourceManagerFactory.class).createInstance();
-                            final Resource managedResource = resourceManager.createManagedResource(managedResId);
+                            final Resource managedResource = resManager.createManagedResource(managedResId);
                             resManager.addResource(managedResource);
                         }
                     }
@@ -548,7 +515,7 @@ public class DocumentBackupManager implements DocumentBackupController, StoreOpe
 	                    // store the backup managed file via distributed managed file management
 	                    storedDocState.setManagedOpsFileId(managedOpsFileId);
 
-	                    Statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.MANAGED_FILES_CURRENT_INC));
+	                    statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.MANAGED_FILES_CURRENT_INC));
                     } catch (Exception e) {
                         LOG.warn("RT2: Couldn't update document operation stream", e);
                         return false;
@@ -571,7 +538,7 @@ public class DocumentBackupManager implements DocumentBackupController, StoreOpe
                     // store the backup managed file via distributed managed file management
                     storedDocState.setManagedOpsFileId(managedOpsFileId);
 
-                    Statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.MANAGED_FILES_CURRENT_INC));
+                    statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.MANAGED_FILES_CURRENT_INC));
                 } catch (Exception e) {
                     LOG.warn("RT2: Couldn't create document operation stream", e);
                     return false;
@@ -638,25 +605,4 @@ public class DocumentBackupManager implements DocumentBackupController, StoreOpe
     public String getUniqueInstanceID() {
         return this.uniqueInstanceID;
     }
-
-	/**
-	 * Removes references to memory consuming objects.
-	 */
-	private void dispose() {
-		synchronized(sync) {
-			try {
-				gcObsoleteManagedFiles.dispose();
-				backupWriter.dispose();
-                cleanupTask.dispose();
-				documentDir = null;
-				distributedDocumentResourceManager.dispose();
-				distributedDocumentStreamManager.dispose();
-            } catch (Throwable e) {
-                ExceptionUtils.handleThrowable(e);
-				// do nothing - we just remove references and call methods
-                LOG.warn("RT2: Exception caught while reset members for dispose", e);
-			}
-		}
-	}
-
 }
