@@ -28,7 +28,7 @@
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
-*     Copyright (C) 2016-2020 OX Software GmbH
+*     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
@@ -55,22 +55,33 @@ import java.util.concurrent.ConcurrentLinkedQueue;
 import org.apache.commons.lang.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+import org.springframework.beans.factory.DisposableBean;
+import org.springframework.beans.factory.InitializingBean;
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.stereotype.Service;
 
 import com.openexchange.filemanagement.ManagedFileManagement;
 import com.openexchange.office.backup.distributed.GCManagedFiles;
 import com.openexchange.office.tools.monitoring.RestoreDocEvent;
 import com.openexchange.office.tools.monitoring.RestoreDocEventType;
 import com.openexchange.office.tools.monitoring.Statistics;
-import com.openexchange.office.tools.osgi.ServiceLookupRegistry;
 
-public class GCObsoleteStreams implements GCManagedFiles {
-    private static final long GC_TIMEOUT_FOR_ENTRY = 30000;
+@Service
+public class GCObsoleteStreams implements GCManagedFiles, InitializingBean, DisposableBean {
+    
+	private static final Logger log = LoggerFactory.getLogger(AsyncBackupWorker.class);
+	
+	private static final long GC_TIMEOUT_FOR_ENTRY = 30000;
 	private static final String THREAD_NAME = "com.openexchange.office.backup.GCObsoleteStreams";
 
-    private static final Logger log = LoggerFactory.getLogger(AsyncBackupWorker.class);
-
+    @Autowired
+    private ManagedFileManagement managedFileManagementService;
+    
+    @Autowired
+    private Statistics statistics;    
+    
     private final Queue<GCObsoleteStreamEntry> gcManagedFileIds = new ConcurrentLinkedQueue<>();
-    private final ManagedFileManagement managedFileManagementService;
+    
     private Thread gcTaskThread;
 
     /**
@@ -78,9 +89,8 @@ public class GCObsoleteStreams implements GCManagedFiles {
      * background processing-to remove obsolete managed files.
      *
      */
-	public GCObsoleteStreams() {
-        managedFileManagementService = ServiceLookupRegistry.get().getService(ManagedFileManagement.class);
-
+	@Override
+	public void afterPropertiesSet() throws Exception {
         gcTaskThread = new Thread() {
 
             @Override
@@ -110,7 +120,7 @@ public class GCObsoleteStreams implements GCManagedFiles {
         	                            managedFileManagementService.removeByID(managedFileId);
         	                            gcManagedFileIds.poll();
         	
-        	                            Statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.MANAGED_FILES_CURRENT_DEC));
+        	                            statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.MANAGED_FILES_CURRENT_DEC));
         	                        } else {
         	                            allTimeupRemoved = true;
         	                        }
@@ -133,9 +143,9 @@ public class GCObsoleteStreams implements GCManagedFiles {
 
                         final long nTimeUsed = System.currentTimeMillis() - timeStart;
 
-                        Statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.MANAGED_FILES_LAST_CYCLE_TIME, nTimeUsed));
-                        Statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.MANAGED_FILES_LAST_CYCLE_REMOVED, nCount));
-                        Statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.MANAGED_FILES_TO_BE_REMOVED, gcManagedFileIds.size()));
+                        statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.MANAGED_FILES_LAST_CYCLE_TIME, nTimeUsed));
+                        statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.MANAGED_FILES_LAST_CYCLE_REMOVED, nCount));
+                        statistics.handleRestoreDocEvent(new RestoreDocEvent(RestoreDocEventType.MANAGED_FILES_TO_BE_REMOVED, gcManagedFileIds.size()));
 
                         log.trace("GCObsoleteStreams garbage collected {} managed files in {} milliseconds", nCount, (Math.abs(System.currentTimeMillis() - timeStart)));
 
@@ -152,28 +162,14 @@ public class GCObsoleteStreams implements GCManagedFiles {
         gcTaskThread.setDaemon(true);
         gcTaskThread.setPriority(Thread.NORM_PRIORITY - 1);
         gcTaskThread.start();
-
-        log.trace("GCObsoleteStreams thread created");
-    }
-
-	/**
-	 * Adds a managed file id to be removed by garbage collector.
-	 *
-	 * @param fileId a managed file id - empty strings or null will be ignored
-	 */
-	public void addObseleteManagedFileId(String fileId) {
-		if (StringUtils.isNotEmpty(fileId)) {
-
-			final GCObsoleteStreamEntry entry = new GCObsoleteStreamEntry(fileId);
-			gcManagedFileIds.add(entry);
-		}
-	}
+	}	
 
 	/**
 	 * Removes pending jobs to be processed and stop the background
 	 * processing. 
-	 */
-	public void dispose() {
+	 */	
+	@Override
+	public void destroy() throws Exception {
 		log.trace("GCObsoleteStreams.dispose() called");
 
 	    gcManagedFileIds.clear();
@@ -193,4 +189,17 @@ public class GCObsoleteStreams implements GCManagedFiles {
 	    }
 	}
 
+	/**
+	 * Adds a managed file id to be removed by garbage collector.
+	 *
+	 * @param fileId a managed file id - empty strings or null will be ignored
+	 */
+	public void addObseleteManagedFileId(String fileId) {
+		if (StringUtils.isNotEmpty(fileId)) {
+
+			final GCObsoleteStreamEntry entry = new GCObsoleteStreamEntry(fileId);
+			gcManagedFileIds.add(entry);
+		}
+	}
+
 }
