@@ -28,7 +28,7 @@
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
-*     Copyright (C) 2016-2020 OX Software GmbH
+*     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
@@ -51,7 +51,7 @@ package com.openexchange.office.document;
 
 import org.apache.commons.lang3.StringUtils;
 
-import com.openexchange.office.tools.user.UserData;
+import com.openexchange.office.tools.common.user.UserData;
 
 public class DocContextLogger {
 
@@ -66,7 +66,7 @@ public class DocContextLogger {
         return buf.toString();
     }
 
-    public static String getContextStringWithDoc(boolean debugInfo, final String sUserId, final UserData userData, final OXDocument oxDoc) {
+    public static String getContextStringWithDoc(boolean debugInfo, final String sUserId, final UserData userData, final OXDocumentImpl oxDoc) {
         final String idString = sUserId;
         final String folderId = ((null != userData) ? StringUtils.isEmpty(userData.getFolderId()) ? "???" : userData.getFolderId() : "???");
         final String fileId = ((null != userData) ? StringUtils.isEmpty(userData.getFileId()) ? "???" : userData.getFileId() : "???");
@@ -75,7 +75,7 @@ public class DocContextLogger {
         return getContextStringWithDoc(debugInfo, idString, folderId, fileId, fileName);
     }
 
-    public static String getContextStringWithDoc(boolean debugInfo, final String sUserId, final String folder_id, final String file_id, final OXDocument oxDoc) {
+    public static String getContextStringWithDoc(boolean debugInfo, final String sUserId, final String folder_id, final String file_id, final OXDocumentImpl oxDoc) {
         final String idString = sUserId;
         final String folderId = StringUtils.isEmpty(folder_id) ? "???" : folder_id;
         final String fileId = StringUtils.isEmpty(file_id) ? "???" : file_id;
