@@ -384,11 +384,11 @@ public class CTLineChart extends NoBarDirChart {
     }
 
     @Override
-    public void setStacking(String stacking) {
+    public void setStacking(String stacking, String defaultStacking) {
         if(grouping==null) {
             grouping = new CTGrouping();
         }
-        grouping.setVal(STGrouping.fromValue(stacking));
+        grouping.setVal(STGrouping.fromValue(stacking, defaultStacking));
 
     }
 }
