@@ -28,7 +28,6 @@ import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import org.docx4j.Child;
 import org.docx4j.dml.CTBlipFillProperties;
 import org.docx4j.dml.CTNonVisualDrawingProps;
 import org.docx4j.dml.CTNonVisualPictureProperties;
@@ -37,6 +36,7 @@ import org.docx4j.dml.CTShapeStyle;
 import org.docx4j.dml.CTTransform2D;
 import org.docx4j.dml.IPicture;
 import org.docx4j.dml.ITransform2DAccessor;
+import com.openexchange.office.filter.core.component.Child;
 
 /**
  * <p>Java class for CT_Picture complex type.
