@@ -4,8 +4,8 @@ import org.docx4j.openpackaging.exceptions.Docx4JException;
 import org.docx4j.openpackaging.parts.relationships.RelationshipsPart;
 import org.docx4j.relationships.Relationship;
 
-import com.openexchange.office.FilterException;
-import com.openexchange.office.FilterException.ErrorCode;
+import com.openexchange.office.filter.api.FilterException;
+import com.openexchange.office.filter.api.FilterException.ErrorCode;
 
 public class PackageRelsUtil {  
 	
