@@ -236,7 +236,7 @@ public class Save {
 			}
 			throw new Docx4JException("Failed to save package", e);
 	    }
-	    log.info("...Done!" );
+	    log.debug("...Done!" );
 		return true;
 	}
 
