@@ -21,15 +21,11 @@
 
 package org.docx4j.openpackaging.packages;
 
-import java.io.BufferedInputStream;
-import java.io.FileInputStream;
+import java.io.ByteArrayInputStream;
 import java.io.FileNotFoundException;
 import java.io.FileOutputStream;
 import java.io.IOException;
-import java.io.InputStream;
 import java.util.HashMap;
-import java.util.Iterator;
-import java.util.TreeSet;
 import org.apache.commons.io.IOUtils;
 import org.apache.poi.poifs.crypt.Decryptor;
 import org.apache.poi.poifs.crypt.EncryptionInfo;
@@ -50,8 +46,7 @@ import org.docx4j.openpackaging.parts.Part;
 import org.docx4j.openpackaging.parts.PartName;
 import org.docx4j.openpackaging.parts.Parts;
 import org.docx4j.openpackaging.parts.relationships.Namespaces;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
+import com.openexchange.office.filter.core.MarkupId;
 
 
 /**
@@ -61,8 +56,6 @@ import org.slf4j.LoggerFactory;
  */
 public class OpcPackage extends Base {
 
-	private static Logger log = LoggerFactory.getLogger(OpcPackage.class);
-
     private boolean lowMemoryAbort = false;
 
     public boolean isLowMemoryAbort() {
@@ -73,23 +66,20 @@ public class OpcPackage extends Base {
         lowMemoryAbort = true;
     }
 
-    private int markupIdCurrent = 4000000;
-    private TreeSet<Integer> markupIdSet = new TreeSet<Integer>();
-
-    public int getNextMarkupId() {
-        final Iterator<Integer> markupIdIter = markupIdSet.tailSet(markupIdCurrent++).iterator();
-        while(markupIdIter.hasNext()) {
-            final Integer next = markupIdIter.next();
-            if(markupIdCurrent < next.intValue()) {
-                return markupIdCurrent;
-            }
-            markupIdCurrent++;
-        }
-        return markupIdCurrent;
+    public MarkupId markupId = new MarkupId(4000000);
+    public Integer getNextMarkupId() {
+        return markupId.getNextMarkupId();
+    }
+    public void addMarkupId(Integer id) {
+        markupId.addMarkupId(id);
     }
 
-    public void setMarkupId(Integer id) {
-        markupIdSet.add(id);
+    public MarkupId paraId = new MarkupId(4000000);
+    public Integer getNextParaId() {
+        return paraId.getNextMarkupId();
+    }
+    public void addParaId(Integer id) {
+        paraId.addMarkupId(id);
     }
 
     private int successfulAppliedOperations = 0;
@@ -225,40 +215,6 @@ public class OpcPackage extends Base {
 
 	protected DocPropsCustomPart docPropsCustomPart;
 
-	/**
-	 * Convenience method to create a WordprocessingMLPackage
-	 * or PresentationMLPackage
-	 * from an existing File (.docx/.docxm, .ppxtx or Flat OPC .xml).
-     *
-	 * @param docxFile
-	 *            The docx file
-	 */
-	public static OpcPackage load(final java.io.File docxFile, boolean XMLReadOnly) throws Docx4JException {
-		return load(docxFile, null, XMLReadOnly);
-	}
-
-	/**
-	 * Convenience method to create a WordprocessingMLPackage
-	 * or PresentationMLPackage
-	 * from an existing File (.docx/.docxm, .ppxtx or Flat OPC .xml).
-     *
-	 * @param docxFile
-	 *            The docx file
-	 * @param password
-	 *            The password, if the file is password protected (compound)
-	 *
-	 * @Since 2.8.0
-	 */
-	public static OpcPackage load(final java.io.File docxFile, String password, boolean XMLReadOnly) throws Docx4JException {
-
-		try {
-			return OpcPackage.load(new FileInputStream(docxFile), password, XMLReadOnly);
-		} catch (final FileNotFoundException e) {
-			OpcPackage.log.error(e.getMessage(), e);
-			throw new Docx4JException("Couldn't load file from " + docxFile.getAbsolutePath(), e);
-		}
-	}
-
 	/**
 	 * Convenience method to create a WordprocessingMLPackage
 	 * or PresentationMLPackage
@@ -269,7 +225,7 @@ public class OpcPackage extends Base {
 	 * @param inputStream
 	 *            The docx file
 	 */
-	public static OpcPackage load(final InputStream inputStream, boolean XMLReadOnly) throws Docx4JException {
+	public static OpcPackage load(final ByteArrayInputStream inputStream, boolean XMLReadOnly) throws Docx4JException {
 		return load(inputStream, "", XMLReadOnly);
 	}
 
@@ -287,15 +243,12 @@ public class OpcPackage extends Base {
 	 *
 	 * @Since 2.8.0
 	 */
-	public static OpcPackage load(final InputStream inputStream, String password, boolean XMLReadOnly) throws Docx4JException {
-		//try to detect the type of file using a bufferedinputstream
-		final BufferedInputStream bis = new BufferedInputStream(inputStream);
-		bis.mark(0);
+	public static OpcPackage load(final ByteArrayInputStream inputStream, String password, boolean XMLReadOnly) throws Docx4JException {
 		final byte[] firstTwobytes=new byte[2];
 		int read=0;
 		try {
-			read = bis.read(firstTwobytes);
-			bis.reset();
+			read = inputStream.read(firstTwobytes);
+			inputStream.reset();
 		} catch (final IOException e) {
 			throw new Docx4JException("Error reading from the stream", e);
 		}
@@ -303,15 +256,15 @@ public class OpcPackage extends Base {
 			throw new Docx4JException("Error reading from the stream (no bytes available)");
 		}
 		if (firstTwobytes[0]=='P' && firstTwobytes[1]=='K') { // 50 4B
-			return OpcPackage.load(bis, Filetype.ZippedPackage, null, XMLReadOnly);
+			return OpcPackage.load(inputStream, Filetype.ZippedPackage, null, XMLReadOnly);
 		} else if  (firstTwobytes[0]==(byte)0xD0 && firstTwobytes[1]==(byte)0xCF) {
 			// password protected docx is a compound file, with signature D0 CF 11 E0 A1 B1 1A E1
 			log.info("Detected compound file");
-			return OpcPackage.load(bis, Filetype.Compound, password, XMLReadOnly);
+			return OpcPackage.load(inputStream, Filetype.Compound, password, XMLReadOnly);
 		} else {
 			//Assume..
 			log.info("Assuming Flat OPC XML");
-			return OpcPackage.load(bis, Filetype.FlatOPC, null, XMLReadOnly);
+			return OpcPackage.load(inputStream, Filetype.FlatOPC, null, XMLReadOnly);
 		}
 	}
 
@@ -326,7 +279,7 @@ public class OpcPackage extends Base {
 	 *
 	 * @Since 2.8.0
 	 */
-	public static OpcPackage load(final InputStream is, Filetype type, String password, boolean XMLReadOnly)
+	public static OpcPackage load(final ByteArrayInputStream is, Filetype type, String password, boolean XMLReadOnly)
 		throws Docx4JException {
 
 		if (type.equals(Filetype.ZippedPackage)){
@@ -343,7 +296,7 @@ public class OpcPackage extends Base {
 		        Decryptor d = Decryptor.getInstance(info);
 		        d.verifyPassword(password);
 
-				InputStream is2 = d.getDataStream(fs);
+				ByteArrayInputStream is2 = new ByteArrayInputStream(IOUtils.toByteArray(d.getDataStream(fs)));
 	            final ZipPartStore partLoader = new ZipPartStore(is2, XMLReadOnly);
 	            final Load3 loader = new Load3(partLoader);
 	            return loader.get();
