@@ -22,12 +22,8 @@ package org.docx4j.openpackaging.parts;
 import org.docx4j.docProps.coverPageProps.CoverPageProperties;
 import org.docx4j.jaxb.Context;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
-import org.docx4j.openpackaging.parts.opendope.JaxbCustomXmlDataStoragePart;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
 
-
-public class DocPropsCoverPagePart extends JaxbCustomXmlDataStoragePart<CoverPageProperties> {
+public class DocPropsCoverPagePart extends JaxbXmlPart<CoverPageProperties> {
 
 	/*
 		<CoverPageProperties xmlns="http://schemas.microsoft.com/office/2006/coverPageProps">
@@ -40,8 +36,6 @@ public class DocPropsCoverPagePart extends JaxbCustomXmlDataStoragePart<CoverPag
 		</CoverPageProperties>
 	 */
 
-	private static Logger log = LoggerFactory.getLogger(DocPropsCoverPagePart.class);
-
 	public DocPropsCoverPagePart(PartName partName) throws InvalidFormatException {
 		super(partName);
 		init();
@@ -49,17 +43,15 @@ public class DocPropsCoverPagePart extends JaxbCustomXmlDataStoragePart<CoverPag
 
 
 	public void init() {
-
 		// Used if this Part is added to [Content_Types].xml
 		setContentType(new  org.docx4j.openpackaging.contenttype.ContentType(
-				org.docx4j.openpackaging.contenttype.ContentTypes.OFFICEDOCUMENT_CUSTOMXML_DATASTORAGE));
+			org.docx4j.openpackaging.contenttype.ContentTypes.OFFICEDOCUMENT_CUSTOMXML_DATASTORAGE));
 
 		// Used when this Part is added to a rels
 		setRelationshipType("http://schemas.microsoft.com/\u201a\u00c4\u00e5office/\u201a\u00c4\u00e52006/\u201a\u00c4\u00e5coverPageProps"); // hardcoding Namespaces.PROPERTIES_COVERPAGE for ease of integration in MergeDocx
 
 		setJAXBContext(Context.getJc());
 	}
-
 }
 
 
