@@ -122,6 +122,12 @@ public class Namespaces {
 	public final static String COMMENTS =
 		"http://schemas.openxmlformats.org/officeDocument/2006/relationships/comments";
 
+	public final static String COMMENTS_IDS =
+	    "http://schemas.microsoft.com/office/2016/09/relationships/commentsIds";
+
+    public final static String COMMENTS_EX =
+        "http://schemas.microsoft.com/office/2011/relationships/commentsExtended";
+
 	public final static String AF =
 		"http://schemas.openxmlformats.org/officeDocument/2006/relationships/aFChunk";
 
@@ -346,5 +352,9 @@ public class Namespaces {
 	public final static String XFORMS = "http://www.w3.org/2002/xforms";
 
 	public final static String XML_SCHEMA = "http://www.w3.org/2001/XMLSchema";
+	
+	// /xl/threadedComments/threadedComment1.xml"
+    public final static String SPREADSHEETML_THREADED_COMMENTS = "http://schemas.microsoft.com/office/2017/10/relationships/threadedComment";
 
+    public final static String SPREADSHEET_PERSONS = "http://schemas.microsoft.com/office/2017/10/relationships/person";
 }
