@@ -21,14 +21,9 @@
 
 package org.docx4j.w14;
 
-import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import com.openexchange.office.filter.core.component.Child;
-
-
 
 /**
  * <p>Java class for CT_GradientFillProperties complex type.
@@ -56,14 +51,11 @@ import com.openexchange.office.filter.core.component.Child;
     "lin",
     "path"
 })
-public class CTGradientFillProperties implements Child
+public class CTGradientFillProperties
 {
-
     protected CTGradientStopList gsLst;
     protected CTLinearShadeProperties lin;
     protected CTPathShadeProperties path;
-    @XmlTransient
-    private Object parent;
 
     /**
      * Gets the value of the gsLst property.
@@ -136,31 +128,4 @@ public class CTGradientFillProperties implements Child
     public void setPath(CTPathShadeProperties value) {
         this.path = value;
     }
-
-    /**
-     * Gets the parent object in the object tree representing the unmarshalled xml document.
-     * 
-     * @return
-     *     The parent object.
-     */
-    public Object getParent() {
-        return this.parent;
-    }
-
-    public void setParent(Object parent) {
-        this.parent = parent;
-    }
-
-    /**
-     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-     * 
-     * @param parent
-     *     The parent object in the object tree.
-     * @param unmarshaller
-     *     The unmarshaller that generated the instance.
-     */
-    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-        setParent(parent);
-    }
-
 }
