@@ -21,15 +21,10 @@
 
 package org.docx4j.w14; 
 
-import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import com.openexchange.office.filter.core.component.Child;
-
-
 
 /**
  * <p>Java class for CT_Shadow complex type.
@@ -63,9 +58,8 @@ import com.openexchange.office.filter.core.component.Child;
     "srgbClr",
     "schemeClr"
 })
-public class CTShadow implements Child
+public class CTShadow implements Cloneable
 {
-
     protected CTSRgbColor srgbClr;
     protected CTSchemeColor schemeClr;
     @XmlAttribute(name = "blurRad", namespace = "http://schemas.microsoft.com/office/word/2010/wordml")
@@ -84,8 +78,6 @@ public class CTShadow implements Child
     protected Integer ky;
     @XmlAttribute(name = "algn", namespace = "http://schemas.microsoft.com/office/word/2010/wordml")
     protected STRectAlignment algn;
-    @XmlTransient
-    private Object parent;
 
     /**
      * Gets the value of the srgbClr property.
@@ -327,30 +319,14 @@ public class CTShadow implements Child
         this.algn = value;
     }
 
-    /**
-     * Gets the parent object in the object tree representing the unmarshalled xml document.
-     * 
-     * @return
-     *     The parent object.
-     */
-    public Object getParent() {
-        return this.parent;
+    @Override
+    public CTShadow clone() {
+        try {
+            final CTShadow clone = (CTShadow)super.clone();
+            // TODO: deep copy of CTSRgbColor and CTSchemeColor
+            return clone;
+        } catch (CloneNotSupportedException e) {
+            return null;
+        }
     }
-
-    public void setParent(Object parent) {
-        this.parent = parent;
-    }
-
-    /**
-     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-     * 
-     * @param parent
-     *     The parent object in the object tree.
-     * @param unmarshaller
-     *     The unmarshaller that generated the instance.
-     */
-    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-        setParent(parent);
-    }
-
 }
