@@ -21,16 +21,11 @@
 
 package org.docx4j.w14; 
 
-import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
 import org.docx4j.wml.CTEmpty;
-import com.openexchange.office.filter.core.component.Child;
-
-
 
 /**
  * <p>Java class for CT_TextOutlineEffect complex type.
@@ -67,9 +62,8 @@ import com.openexchange.office.filter.core.component.Child;
     "bevel",
     "miter"
 })
-public class CTTextOutlineEffect implements Child
+public class CTTextOutlineEffect implements Cloneable
 {
-
     protected CTEmpty noFill;
     protected CTSolidColorFillProperties solidFill;
     protected CTGradientFillProperties gradFill;
@@ -85,8 +79,6 @@ public class CTTextOutlineEffect implements Child
     protected STCompoundLine cmpd;
     @XmlAttribute(name = "algn", namespace = "http://schemas.microsoft.com/office/word/2010/wordml")
     protected STPenAlignment algn;
-    @XmlTransient
-    private Object parent;
 
     /**
      * Gets the value of the noFill property.
@@ -352,30 +344,12 @@ public class CTTextOutlineEffect implements Child
         this.algn = value;
     }
 
-    /**
-     * Gets the parent object in the object tree representing the unmarshalled xml document.
-     * 
-     * @return
-     *     The parent object.
-     */
-    public Object getParent() {
-        return this.parent;
+    @Override
+    public CTTextOutlineEffect clone() {
+        try {   // TODO: deep copy
+            return (CTTextOutlineEffect)super.clone();
+        } catch (CloneNotSupportedException e) {
+            return null;
+        }
     }
-
-    public void setParent(Object parent) {
-        this.parent = parent;
-    }
-
-    /**
-     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-     * 
-     * @param parent
-     *     The parent object in the object tree.
-     * @param unmarshaller
-     *     The unmarshaller that generated the instance.
-     */
-    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-        setParent(parent);
-    }
-
 }
