@@ -33,9 +33,10 @@ import javax.xml.bind.annotation.XmlElementRefs;
 import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import org.docx4j.Child;
 import org.docx4j.math.CTOMath;
 import org.docx4j.math.CTOMathPara;
+import com.openexchange.office.filter.core.IContentAccessor;
+import com.openexchange.office.filter.core.component.Child;
 
 
 /**
@@ -67,7 +68,7 @@ import org.docx4j.math.CTOMathPara;
 })
 @XmlRootElement(name = "smartTag")
 public class CTSmartTagRun
-    implements Child, ContentAccessor
+    implements Child, IContentAccessor
 {
 
     protected CTSmartTagPr smartTagPr;
