@@ -27,7 +27,6 @@ import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlType;
 
-
 /**
  * <p>Java class for anonymous complex type.
  * 
@@ -56,7 +55,7 @@ import javax.xml.bind.annotation.XmlType;
 @XmlAccessorType(XmlAccessType.FIELD)
 @XmlType(name = "")
 @XmlRootElement(name = "rFonts")
-public class RFonts {
+public class RFonts implements Cloneable {
 
     @XmlAttribute(name = "hint", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
     protected STHint hint;
@@ -292,4 +291,71 @@ public class RFonts {
     public void setCstheme(STTheme value) {
         this.cstheme = value;
     }
+
+    @Override
+    public RFonts clone() {
+        try {
+            return (RFonts)super.clone();
+        } catch (CloneNotSupportedException e) {
+            return null;
+        }
+    }
+
+    @Override
+    public int hashCode() {
+        final int prime = 31;
+        int result = 1;
+        result = prime * result + ((ascii == null) ? 0 : ascii.hashCode());
+        result = prime * result + ((asciiTheme == null) ? 0 : asciiTheme.hashCode());
+        result = prime * result + ((cs == null) ? 0 : cs.hashCode());
+        result = prime * result + ((cstheme == null) ? 0 : cstheme.hashCode());
+        result = prime * result + ((eastAsia == null) ? 0 : eastAsia.hashCode());
+        result = prime * result + ((eastAsiaTheme == null) ? 0 : eastAsiaTheme.hashCode());
+        result = prime * result + ((hAnsi == null) ? 0 : hAnsi.hashCode());
+        result = prime * result + ((hAnsiTheme == null) ? 0 : hAnsiTheme.hashCode());
+        result = prime * result + ((hint == null) ? 0 : hint.hashCode());
+        return result;
+    }
+
+    @Override
+    public boolean equals(Object obj) {
+        if (this == obj)
+            return true;
+        if (obj == null)
+            return false;
+        if (getClass() != obj.getClass())
+            return false;
+        RFonts other = (RFonts) obj;
+        if (ascii == null) {
+            if (other.ascii != null)
+                return false;
+        } else if (!ascii.equals(other.ascii))
+            return false;
+        if (asciiTheme != other.asciiTheme)
+            return false;
+        if (cs == null) {
+            if (other.cs != null)
+                return false;
+        } else if (!cs.equals(other.cs))
+            return false;
+        if (cstheme != other.cstheme)
+            return false;
+        if (eastAsia == null) {
+            if (other.eastAsia != null)
+                return false;
+        } else if (!eastAsia.equals(other.eastAsia))
+            return false;
+        if (eastAsiaTheme != other.eastAsiaTheme)
+            return false;
+        if (hAnsi == null) {
+            if (other.hAnsi != null)
+                return false;
+        } else if (!hAnsi.equals(other.hAnsi))
+            return false;
+        if (hAnsiTheme != other.hAnsiTheme)
+            return false;
+        if (hint != other.hint)
+            return false;
+        return true;
+    }
 }
