@@ -39,7 +39,7 @@ import org.docx4j.w15.CTSdtRepeatedSection;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import org.docx4j.Child;
+import com.openexchange.office.filter.core.component.Child;
 import org.docx4j.XmlUtils;
 
 /**
