@@ -28,9 +28,10 @@ import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import org.docx4j.Child;
-import org.docx4j.IndexedNodeList;
 import org.docx4j.jaxb.Context;
+import com.openexchange.office.filter.core.IContentAccessor;
+import com.openexchange.office.filter.core.DLList;
+import com.openexchange.office.filter.core.component.Child;
 
 
 /**
@@ -72,7 +73,7 @@ public class SdtRun implements SdtElement, Child
     private boolean sdtContentCreated = false;
 
     @Override
-    public IndexedNodeList<Object> getContent() {
+    public DLList<Object> getContent() {
         if(sdtContent==null) {
             sdtContent = Context.getWmlObjectFactory().createCTSdtContentRun();
             sdtContentCreated = true;
@@ -136,7 +137,7 @@ public class SdtRun implements SdtElement, Child
      *     {@link CTSdtContentRun }
      *
      */
-    public ContentAccessor getSdtContent() {
+    public IContentAccessor getSdtContent() {
         return sdtContent;
     }
 
@@ -187,7 +188,7 @@ public class SdtRun implements SdtElement, Child
     public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
         setParent(parent);
         if(sdtContent!=null) {
-            final IndexedNodeList<Object> childList = getContent();
+            final DLList<Object> childList = getContent();
             for(int i=0; i<childList.size(); i++) {
                 Object child = childList.get(i);
                 if(child instanceof Child) {
