@@ -21,7 +21,6 @@
 
 package org.docx4j.wml;
 
-import java.math.BigInteger;
 import java.util.ArrayList;
 import java.util.List;
 import javax.xml.bind.annotation.XmlAccessType;
@@ -29,6 +28,8 @@ import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlType;
+import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
+import org.docx4j.adapter.LongAdapter;
 
 
 /**
@@ -803,9 +804,8 @@ public class Style {
     public boolean isDefault() {
         if (_default == null) {
             return false;
-        } else {
-            return _default;
         }
+        return _default;
     }
 
     /**
@@ -1115,17 +1115,18 @@ public class Style {
     public static class UiPriority {
 
         @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", required = true)
-        protected BigInteger val;
+        @XmlJavaTypeAdapter(LongAdapter.class)
+        protected Long val;
 
         /**
          * Gets the value of the val property.
          *
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *
          */
-        public BigInteger getVal() {
+        public Long getVal() {
             return val;
         }
 
@@ -1134,10 +1135,10 @@ public class Style {
          *
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *
          */
-        public void setVal(BigInteger value) {
+        public void setVal(Long value) {
             this.val = value;
         }
     }
