@@ -35,7 +35,7 @@ import javax.xml.bind.annotation.XmlSchemaType;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
 import org.xlsx4j.jaxb.Context;
-import com.openexchange.office.filter.core.spreadsheet.SmlUtils;
+import com.openexchange.office.filter.core.spreadsheet.CellRef;
 
 
 /**
@@ -421,7 +421,7 @@ public class Row
         final List<Cell> cells = getListArray();
         for(Cell cell:cells) {
         	// we have to convert cell column into cell.R
-    		cell.setR(SmlUtils.getCellRef(cell.getColumn(), getRow()));
+    		cell.setR(CellRef.getCellRef(cell.getColumn(), getRow()));
         }
     }
 
@@ -446,7 +446,7 @@ public class Row
         	// converting cell.R to column
         	final String r = cell.getR();
         	if(r!=null) {
-        		currentColumn = SmlUtils.createCellRef(r).getColumn();
+        		currentColumn = CellRef.createCellRef(r).getColumn();
         	}
         	cell.setColumn(currentColumn++);
         	final CTCellFormula f = cell.getF();
