@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -208,6 +208,8 @@ public enum OCKey {
     DEFAULT_TEXT_LIST_STYLES("defaultTextListStyles", null),
     DESCENDING("descending", null),
     DESCRIPTION("description", null),
+    DISPLAY_NAME("displayName", null),
+    DIR("dir", null),
     DOCUMENT("document", null),
     DONE("done", null),
     DRAWING("drawing", "dr"),
@@ -287,6 +289,7 @@ public enum OCKey {
     HEAD_END_TYPE("headEndType", null),
     HEAD_END_WIDTH("headEndWidth", null),
     HEADER_ROW("headerRow", null),
+    HEADERS("headers", null),
     HEIGHT("height", null),
     HIDDEN("hidden", null),
     HIDE_BUTTON("hideButton", null),
@@ -382,6 +385,7 @@ public enum OCKey {
     MAX_R("maxR", null),
     MAX_X("maxX", null),
     MAX_Y("maxY", null),
+    MENTION_ID("mentionId", null),
     MENTIONS("mentions", null),
     MERGE_VERT("mergeVert", null),
     MERGED("merged", null),
@@ -398,6 +402,7 @@ public enum OCKey {
     MR("mr", null),
     NAME("name", "n"),
     NAMES("names", null),
+    NEW_NAME("newName", null),
     NBC("nbc", null),
     NBS("nbs", null),
     NC("nc", null),
@@ -421,6 +426,8 @@ public enum OCKey {
     NUMBER_FORMAT("numberFormat", null),
     OFF_X("offX", null),
     OFF_Y("offY", null),
+    OLDINDEX("oldindex", null),
+    OLDTARGET("oldtarget", null),
     ONLY_MARKER("onlyMarker", null),
     OP("op", null),
     OPL("opl", null),
@@ -443,6 +450,7 @@ public enum OCKey {
     PARA_STYLE("paraStyle", null),
     PARAGRAPH("paragraph", "pa"),
     PARENT("parent", null),
+    PARENTTARGET("parenttarget", null),
     PARENT_ID("parentId", null),
     PATH_FILL_BOTTOM("pathFillBottom", null),
     PATH_FILL_LEFT("pathFillLeft", null),
