@@ -28,7 +28,7 @@
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
-*     Copyright (C) 2016-2020 OX Software GmbH
+*     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
@@ -50,10 +50,11 @@ package com.openexchange.office.filter.core;
 
 import org.apache.commons.lang3.StringUtils;
 import org.apache.commons.lang3.Validate;
-import com.openexchange.office.tools.logging.v2.ELogLevel;
-import com.openexchange.office.tools.logging.v2.impl.Logger;
+import org.slf4j.Logger;
+import org.slf4j.event.Level;
+
 import com.openexchange.office.filter.api.FilterException;
-import com.openexchange.office.tools.error.ErrorCode;
+import com.openexchange.office.tools.common.error.ErrorCode;
 
 
 /**
@@ -136,20 +137,20 @@ public class FilterExceptionToErrorCode {
      *          should be determined
      * @return the log-level that should be used for logging this exception
      */
-    static public ELogLevel determineLogLevel(final FilterException e) {
-        ELogLevel logLevel;
+    static public Level determineLogLevel(final FilterException e) {
+        Level logLevel;
 
         // filter exception should at most be logged on WARN level
         switch (e.getErrorcode()) {
-            case CRITICAL_ERROR: logLevel = ELogLevel.E_WARNING; break;
-            case WRONG_PASSWORD: logLevel = ELogLevel.E_INFO; break;
-            case UNSUPPORTED_ENCRYPTION_USED: logLevel = ELogLevel.E_INFO; break;
-            case COMPLEXITY_TOO_HIGH: logLevel = ELogLevel.E_INFO; break;
-            case MEMORY_USAGE_TOO_HIGH: logLevel = ELogLevel.E_WARNING; break;
-            case MEMORY_USAGE_MIN_FREE_HEAP_SPACE_REACHED: logLevel = ELogLevel.E_WARNING; break;
-            case STRICT_OOXML_NOT_SUPPORTED: logLevel = ELogLevel.E_INFO; break;
-            case FEATURE_NOT_SUPPORTED: logLevel = ELogLevel.E_INFO; break;
-            default: logLevel = ELogLevel.E_WARNING; break;
+            case CRITICAL_ERROR: logLevel = Level.WARN; break;
+            case WRONG_PASSWORD: logLevel = Level.INFO; break;
+            case UNSUPPORTED_ENCRYPTION_USED: logLevel = Level.INFO; break;
+            case COMPLEXITY_TOO_HIGH: logLevel = Level.INFO; break;
+            case MEMORY_USAGE_TOO_HIGH: logLevel = Level.WARN; break;
+            case MEMORY_USAGE_MIN_FREE_HEAP_SPACE_REACHED: logLevel = Level.WARN; break;
+            case STRICT_OOXML_NOT_SUPPORTED: logLevel = Level.INFO; break;
+            case FEATURE_NOT_SUPPORTED: logLevel = Level.INFO; break;
+            default: logLevel = Level.WARN; break;
         }
 
         return logLevel;
@@ -163,7 +164,7 @@ public class FilterExceptionToErrorCode {
      * @param message the message to be logged.
      * @param e the filter exception
      */
-    static public void log(final Logger logger, ELogLevel level, final String logText, final String context, FilterException e) {
+    static public void log(final Logger logger, Level level, final String logText, final String context, FilterException e) {
         Validate.notNull(logger);
 
         // add filter exception type
@@ -171,8 +172,7 @@ public class FilterExceptionToErrorCode {
         if(e.getErrorcode() == com.openexchange.office.filter.api.FilterException.ErrorCode.COMPLEXITY_TOO_HIGH) {
             e = null;   // we don't want a stack and we don't want the text "If you write an issue ..."
             out.append("Complexity of document is too hight.");
-        }
-        else {
+        } else {
             out.append(" Type: " + e.getErrorcode().toString());
 
             // add optional document context information with the appeal to attach a document to reproduce the issue
@@ -182,6 +182,13 @@ public class FilterExceptionToErrorCode {
         }
 
         final String message = out.toString();
-        logger.forLevel(level).withError(e).withMessage(message).log();
+        switch (level) {
+        	case TRACE: logger.trace(message, e); break;
+        	case DEBUG: logger.debug(message, e); break;
+        	case WARN: logger.warn(message, e); break;
+        	case ERROR: logger.error(message, e); break;
+        	case INFO: logger.info(message, e); break;
+        default: logger.warn(message, e); break;
+        }
     }
 }
