@@ -62,7 +62,7 @@ public class ChartSeries extends AttributeSet {
         }
 
         op.putSafe(OCKey.ATTRS.value(), attrs);
-        op.putSafe(OCKey.NAME.value(), OCValue.INSERT_CHART_DATA_SERIES.value());
+        op.putSafe(OCKey.NAME.value(), OCValue.INSERT_CHART_SERIES.value());
 
         operationQueue.put(op);
     }
