@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -197,4 +197,26 @@ public class CUtil {
         component.splitStart(startComponent, SplitMode.DELETE);
         component.delete((endComponent-startComponent)+1);
     }
+
+    public static String componentToString(IComponent<?> c) {
+        final StringBuffer stringBuffer = new StringBuffer();
+        componentToString(c, stringBuffer);
+        return stringBuffer.toString();
+    }
+
+    private static void componentToString(IComponent<?> c, StringBuffer stringBuffer) {
+        stringBuffer.append(c.simpleName());
+        IComponent<?> childComponent = c.getChildComponent(0);
+        if(childComponent!=null) {
+            stringBuffer.append('(');
+            while(childComponent!=null) {
+                componentToString(childComponent, stringBuffer);
+                childComponent = childComponent.getNextComponent();
+                if(childComponent!=null) {
+                    stringBuffer.append(',');
+                }
+            }
+            stringBuffer.append(')');
+        }
+    }
 }
