@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -89,6 +89,7 @@ public abstract class ComponentContext<OpDoc extends OperationDocument> implemen
         parentContext = p;
     }
 
+    @Override
     public DLNode<Object> getNode() {
         return node;
     }
@@ -108,7 +109,7 @@ public abstract class ComponentContext<OpDoc extends OperationDocument> implemen
     }
 
     @Override
-    public abstract Component<OpDoc> getNextChildComponent(ComponentContext<OpDoc> previousChildContext, Component<OpDoc> previousChildComponent);
+    public abstract IComponent<OpDoc> getNextChildComponent(ComponentContext<OpDoc> previousChildContext, IComponent<OpDoc> previousChildComponent);
 
     public ComponentContext<OpDoc> getRootContext() {
         ComponentContext<OpDoc> rootContext;
