@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,7 +49,10 @@
 
 package com.openexchange.office.filter.core.component;
 
+import java.util.Set;
 import org.json.JSONArray;
+import org.json.JSONObject;
+import com.openexchange.office.filter.core.DLNode;
 import com.openexchange.office.filter.core.OperationDocument;
 
 public interface IComponent<OpDoc extends OperationDocument> extends IComponentContext<OpDoc> {
@@ -58,17 +61,29 @@ public interface IComponent<OpDoc extends OperationDocument> extends IComponentC
 
     public int getComponentNumber();
 
+    public void setComponentNumber(int componentNumber);
+
     public int getNextComponentNumber();
 
-    public Component<OpDoc> getNextComponent();
+    public ComponentContext<OpDoc> getContextChild(Set<Class<?>> parentContextList);
 
-    public Component<OpDoc> getComponent(int positionCount);
+    public IComponent<OpDoc> insertChildComponent(int number, JSONObject attrs, ComponentType type) throws Exception;
 
-    public Component<OpDoc> getComponent(JSONArray position, int positionCount);
+    public IComponent<OpDoc> insertChildComponent(ComponentContext<OpDoc> parentContext, DLNode<Object> contextNode, int number, IComponent<OpDoc> child, ComponentType type, JSONObject attrs) throws Exception;
 
-    public Component<OpDoc> getParentComponent();
+    public void applyAttrsFromJSON(JSONObject attrs) throws Exception;
 
-    public Component<OpDoc> getChildComponent(int number);
+    public IComponent<OpDoc> getNextComponent();
+
+    public IComponent<OpDoc> getComponent(int positionCount);
+
+    public IComponent<OpDoc> getComponent(JSONArray position, int positionCount);
+
+    public IComponent<OpDoc> getParentComponent();
+
+    public IComponent<OpDoc> getChildComponent(int number);
 
     public void delete(int count);
+
+    public abstract String simpleName();
 }
