@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,14 +49,17 @@
 
 package com.openexchange.office.filter.core.component;
 
+import com.openexchange.office.filter.core.DLNode;
 import com.openexchange.office.filter.core.OperationDocument;
 import com.openexchange.office.filter.core.SplitMode;
 
 public interface IComponentContext<OpDoc extends OperationDocument> {
 
+    public DLNode<Object> getNode();
+
     public ComponentContext<OpDoc> getParentContext();
 
-    public abstract Component<OpDoc> getNextChildComponent(ComponentContext<OpDoc> previousChildContext, Component<OpDoc> previousChildComponent);
+    public abstract IComponent<OpDoc> getNextChildComponent(ComponentContext<OpDoc> previousChildContext, IComponent<OpDoc> previousChildComponent);
 
     public void splitStart(int n, SplitMode splitMode);
 
