@@ -25,7 +25,6 @@ import java.io.File;
 import java.io.InputStream;
 import java.util.HashMap;
 import org.json.JSONArray;
-import org.json.JSONException;
 import org.json.JSONObject;
 import org.odftoolkit.odfdom.pkg.MediaType;
 import org.odftoolkit.odfdom.pkg.OdfFileDom;
@@ -34,18 +33,19 @@ import org.w3c.dom.Document;
 import org.xml.sax.SAXException;
 import com.openexchange.office.filter.odf.OdfOperationDoc;
 import com.openexchange.office.filter.odf.draw.DrawFrame;
+import com.openexchange.office.filter.odf.odp.dom.DrawingPage;
+import com.openexchange.office.filter.odf.odp.dom.JsonOperationConsumer;
+import com.openexchange.office.filter.odf.odp.dom.JsonOperationProducer;
+import com.openexchange.office.filter.odf.odp.dom.MasterPage;
+import com.openexchange.office.filter.odf.odp.dom.Page;
+import com.openexchange.office.filter.odf.odp.dom.PresentationContent;
+import com.openexchange.office.filter.odf.odp.dom.PresentationStyles;
+import com.openexchange.office.filter.odf.odp.dom.components.RootComponent;
 import com.openexchange.office.filter.odf.styles.StyleFamily;
 import com.openexchange.office.filter.odf.styles.StyleGraphic;
 import com.openexchange.office.filter.odf.styles.StyleManager;
 import com.openexchange.office.filter.odf.styles.StylePresentation;
 import com.openexchange.office.filter.odf.styles.TextListStyle;
-import com.openexchange.office.filter.odp.dom.DrawingPage;
-import com.openexchange.office.filter.odp.dom.JsonOperationConsumer;
-import com.openexchange.office.filter.odp.dom.JsonOperationProducer;
-import com.openexchange.office.filter.odp.dom.MasterPage;
-import com.openexchange.office.filter.odp.dom.Page;
-import com.openexchange.office.filter.odp.dom.PresentationContent;
-import com.openexchange.office.filter.odp.dom.PresentationStyles;
 
 public class OdfPresentationDocument extends OdfDocument {
 
@@ -76,7 +76,11 @@ public class OdfPresentationDocument extends OdfDocument {
 	        return (MasterPage)page;
 	    }
 	    else if(page instanceof DrawingPage) {
-	        return (MasterPage)((PresentationContent)getContentDom()).getRootComponent(operationDocument, ((DrawingPage)page).getMasterPageName()).getNextChildComponent(null, null).getObject();
+	        final RootComponent rootComponent = ((PresentationContent)getContentDom()).getRootComponent(operationDocument, ((DrawingPage)page).getMasterPageName());
+	        if(rootComponent!=null && rootComponent.getObject()!=null) {
+	            return (MasterPage)rootComponent.getNextChildComponent(null, null).getObject();
+	        }
+            return (MasterPage)getStyleManager().getMasterStyles().getContent().getLast();
 	    }
 	    return null;
 	}
