@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,7 +55,7 @@ import org.json.JSONObject;
 import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.core.DLList;
 import com.openexchange.office.filter.core.DLNode;
-import com.openexchange.office.filter.odt.dom.Annotation;
+import com.openexchange.office.filter.odf.odt.dom.Annotation;
 
 public class Authors {
 
