@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,10 +50,16 @@
 package com.openexchange.office.filter.odf;
 
 import java.io.InputStream;
+
 import org.odftoolkit.odfdom.pkg.OdfPackage;
+import org.springframework.stereotype.Service;
+
 import com.openexchange.office.filter.api.DocumentProperties;
 import com.openexchange.office.filter.api.IExporter;
 import com.openexchange.office.imagemgr.IResourceManager;
+import com.openexchange.office.tools.annotation.RegisteredService;
+import com.openexchange.office.tools.common.osgi.context.OsgiBundleContextAndActivator;
+import com.openexchange.office.tools.common.osgi.context.OsgiBundleContextAware;
 import com.openexchange.session.Session;
 
 /**
@@ -61,7 +67,11 @@ import com.openexchange.session.Session;
  *
  * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
  */
-public class Exporter implements IExporter {
+@Service
+@RegisteredService
+public class Exporter implements IExporter, OsgiBundleContextAware {
+
+	private OsgiBundleContextAndActivator bundleCtx;
 
     /**
      * Initializes a new {@link Exporter}.
@@ -81,15 +91,23 @@ public class Exporter implements IExporter {
     public InputStream createDocument(Session session, InputStream documentStm, String mergeOperations, IResourceManager resourceManager,  DocumentProperties documentProperties, boolean createFinalDocument) {
         InputStream document = null;
         try(OdfOperationDoc odtOperationDocument = new OdfOperationDoc(session, resourceManager, documentProperties)) {
+        	bundleCtx.prepareObject(odtOperationDocument);
             odtOperationDocument.setCreateFinalDocument(createFinalDocument);
             odtOperationDocument.loadDocument(documentStm);
             odtOperationDocument.updateDocumentProperties();
-            odtOperationDocument.applyOperations(mergeOperations);
-            document = odtOperationDocument.debugSave(mergeOperations);
+            if(mergeOperations!=null) {
+                odtOperationDocument.applyOperations(mergeOperations);
+            }
+            document = odtOperationDocument.save();
         }
         catch(Throwable e) {
             OdfOperationDoc.rethrowFilterException(e, (OdfPackage)null);
         }
         return document;
     }
+
+	@Override
+	public void setApplicationContext(OsgiBundleContextAndActivator bundleCtx) {
+		this.bundleCtx = bundleCtx;
+	}
 }
