@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,11 +51,17 @@ package com.openexchange.office.filter.odf;
 
 import java.io.InputStream;
 import java.util.Map;
+
 import org.json.JSONObject;
 import org.odftoolkit.odfdom.pkg.OdfPackage;
+import org.springframework.beans.factory.annotation.Autowired;
+
 import com.openexchange.office.filter.api.DocumentProperties;
 import com.openexchange.office.filter.api.IImporter;
 import com.openexchange.office.filter.api.IPartImporter;
+import com.openexchange.office.tools.common.osgi.context.OsgiBundleContextAndActivator;
+import com.openexchange.office.tools.common.osgi.context.OsgiBundleContextAware;
+import com.openexchange.office.tools.service.config.ConfigurationHelper;
 import com.openexchange.session.Session;
 
 /**
@@ -63,10 +69,13 @@ import com.openexchange.session.Session;
  *
  * @author <a href="mailto:svante.schubert@open-xchange.com">Svante Schubert</a>
  */
-abstract public class Importer implements IImporter, IPartImporter {
+abstract public class Importer implements IImporter, IPartImporter, OsgiBundleContextAware {
 
-    //final ServiceLookup services;
+	@Autowired
+    private ConfigurationHelper configurationHelper;
 
+	protected OsgiBundleContextAndActivator bundleCtx;
+	
     /**
      * Initializes a new {@link Importer}.
      */
@@ -83,6 +92,7 @@ abstract public class Importer implements IImporter, IPartImporter {
 
         JSONObject operations = null;
         try (OdfOperationDoc odfdomDocument = new OdfOperationDoc(session, null, documentProperties)) {
+        	bundleCtx.prepareObject(odfdomDocument);
             odfdomDocument.loadDocument(inputDocumentStm);
             operations = odfdomDocument.getOperations();
         }
@@ -96,6 +106,7 @@ abstract public class Importer implements IImporter, IPartImporter {
 	public void initPartitioning(Session session, InputStream inputDocument, DocumentProperties documentProperties) {
 
 	    try(OdfOperationDoc odfdomDocument = new OdfOperationDoc(session, null, documentProperties)) {
+	    	bundleCtx.prepareObject(odfdomDocument);
             odfdomDocument.loadDocument(inputDocument);
             documentProperties.put(DocumentProperties.PROP_DOCUMENT, odfdomDocument);
     		odfdomDocument.initPartitioning(documentProperties);
@@ -126,6 +137,7 @@ abstract public class Importer implements IImporter, IPartImporter {
 	public Map<String, Object> getActivePart(DocumentProperties documentProperties) {
         Map<String, Object> metaData = null;
 	    final OdfOperationDoc operationDocument = (OdfOperationDoc)documentProperties.get(DocumentProperties.PROP_DOCUMENT);
+	    bundleCtx.injectDependencies(operationDocument);
 	    try {
             operationDocument.registerMemoryListener();
 	        metaData = operationDocument.getActivePart(documentProperties);
@@ -155,4 +167,9 @@ abstract public class Importer implements IImporter, IPartImporter {
         }
         return metaData;
 	}
+
+	@Override
+	public void setApplicationContext(OsgiBundleContextAndActivator bundleCtx) {
+		this.bundleCtx = bundleCtx;
+	}
 }
