@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,6 +58,7 @@ import java.util.Map;
 import java.util.zip.ZipEntry;
 import java.util.zip.ZipInputStream;
 import java.util.zip.ZipOutputStream;
+
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -70,7 +71,9 @@ import org.odftoolkit.odfdom.pkg.OdfFileDom;
 import org.odftoolkit.odfdom.pkg.OdfPackage;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+import org.springframework.beans.factory.InitializingBean;
 import org.xml.sax.SAXException;
+
 import com.openexchange.exception.ExceptionUtils;
 import com.openexchange.office.filter.api.DocumentProperties;
 import com.openexchange.office.filter.api.FilterException;
@@ -78,11 +81,10 @@ import com.openexchange.office.filter.api.FilterException.ErrorCode;
 import com.openexchange.office.filter.core.DocumentComplexity;
 import com.openexchange.office.filter.core.NotSupportedMediaTypeException;
 import com.openexchange.office.filter.core.OperationDocument;
+import com.openexchange.office.filter.odf.ods.dom.SpreadsheetContent;
 import com.openexchange.office.filter.odf.styles.DocumentStyles;
-import com.openexchange.office.filter.ods.dom.SpreadsheetContent;
 import com.openexchange.office.imagemgr.IResourceManager;
 import com.openexchange.office.tools.common.memory.MemoryObserver;
-import com.openexchange.office.tools.config.ConfigurationHelper;
 import com.openexchange.session.Session;
 
 /**
@@ -90,7 +92,7 @@ import com.openexchange.session.Session;
  * from the Toolkit.
  *
  */
-public class OdfOperationDoc extends OperationDocument {
+public class OdfOperationDoc extends OperationDocument implements InitializingBean {
 
 	private static final Logger LOG = LoggerFactory.getLogger(OdfOperationDoc.class);
     private static final String STATUS_ID_FILE = "oxoffice/extendedData.json";
@@ -116,19 +118,35 @@ public class OdfOperationDoc extends OperationDocument {
     public OdfOperationDoc(Session session, IResourceManager resourceManager, DocumentProperties _documentProperties) {
         super(session, resourceManager, _documentProperties);
 
-		registerMemoryListener();
-
-		mSaveDebugOperations = Boolean.parseBoolean(ConfigurationHelper.getOfficeConfigurationValue(null, session, MODULE + DEBUG_OPERATIONS, "false"));
-        documentProperties.put(MAX_TABLE_COLUMNS, ConfigurationHelper.getIntegerOfficeConfigurationValue(null, session, MODULE + MAX_TABLE_COLUMNS, 15));
-        documentProperties.put(MAX_TABLE_ROWS, ConfigurationHelper.getIntegerOfficeConfigurationValue(null, session, MODULE + MAX_TABLE_ROWS, 1500));
-        documentProperties.put(MAX_TABLE_CELLS, ConfigurationHelper.getIntegerOfficeConfigurationValue(null, session, MODULE + MAX_TABLE_CELLS, 1500));
-        documentProperties.put(MAX_SHEETS, ConfigurationHelper.getIntegerOfficeConfigurationValue(null, session, SPREADSHEET + MAX_SHEETS, 256));
     }
 
-    final public void loadDocument(InputStream _inputStream) {
+    @Override
+	public void afterPropertiesSet() throws Exception {
+
+		registerMemoryListener();
+
+		if (configurationHelper != null) {
+			mSaveDebugOperations = Boolean.parseBoolean(configurationHelper.getOfficeConfigurationValue(session, MODULE + DEBUG_OPERATIONS, "false"));
+	        documentProperties.put(MAX_TABLE_COLUMNS, configurationHelper.getIntegerOfficeConfigurationValue(session, MODULE + MAX_TABLE_COLUMNS, 15));
+	        documentProperties.put(MAX_TABLE_ROWS, configurationHelper.getIntegerOfficeConfigurationValue(session, MODULE + MAX_TABLE_ROWS, 1500));
+	        documentProperties.put(MAX_TABLE_CELLS, configurationHelper.getIntegerOfficeConfigurationValue(session, MODULE + MAX_TABLE_CELLS, 1500));
+	        documentProperties.put(MAX_SHEETS, configurationHelper.getIntegerOfficeConfigurationValue(session, SPREADSHEET + MAX_SHEETS, 256));
+		} else {
+			mSaveDebugOperations = false;
+	        documentProperties.put(MAX_TABLE_COLUMNS, 15);
+	        documentProperties.put(MAX_TABLE_ROWS, 1500);
+	        documentProperties.put(MAX_TABLE_CELLS, 1500);
+	        documentProperties.put(MAX_SHEETS, 256);
+		}
+	}
+
+	final public void loadDocument(InputStream _inputStream) {
         try {
             // complexity check... TODO: distinguish between odt and odf
-            final long maxAllowedXmlSizeMatchingComplexity = ConfigurationHelper.getIntegerOfficeConfigurationValue(null, session, "//spreadsheet/maxCells", 500000) * 100;
+        	long maxAllowedXmlSizeMatchingComplexity = 50000000;
+        	if (configurationHelper != null) {
+        		maxAllowedXmlSizeMatchingComplexity = configurationHelper.getIntegerOfficeConfigurationValue(session, "//spreadsheet/maxCells", 500000) * 100;
+        	}
             final long maxAllowedXmlSizeMatchingMemory = MemoryObserver.calcMaxHeapSize(50) / FACTOR_FOR_REQUIRED_HEAPSPACE;
             final InputStream inputStream = DocumentComplexity.checkDocumentComplexity(_inputStream, maxAllowedXmlSizeMatchingComplexity, maxAllowedXmlSizeMatchingMemory);
 
@@ -194,11 +212,7 @@ public class OdfOperationDoc extends OperationDocument {
         }
     }
 
-    final public InputStream save() throws FilterException {
-        return debugSave(null);
-    }
-
-    final public InputStream debugSave(String debugOperations) {
+    final public InputStream save() {
         InputStream inputStream = null;
         try {
             inputStream = mDocument.getPackage().getInputStream();
