@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -68,11 +68,11 @@ import com.openexchange.office.filter.odf.AttributesImpl;
 import com.openexchange.office.filter.odf.Namespaces;
 import com.openexchange.office.filter.odf.OdfOperationDoc;
 import com.openexchange.office.filter.odf.OpAttrs;
+import com.openexchange.office.filter.odf.odt.dom.TextField;
 import com.openexchange.office.filter.odf.styles.NumberStyleBase;
 import com.openexchange.office.filter.odf.styles.StyleBase;
 import com.openexchange.office.filter.odf.styles.StyleFamily;
 import com.openexchange.office.filter.odf.styles.StyleManager;
-import com.openexchange.office.filter.odt.dom.TextField;
 
 public class TextFieldComponent extends TextSpan_Base {
 
