@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -60,17 +60,17 @@ import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.core.DLList;
 import com.openexchange.office.filter.core.DLNode;
 import com.openexchange.office.filter.core.SplitMode;
-import com.openexchange.office.filter.core.component.Component;
 import com.openexchange.office.filter.core.component.ComponentContext;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.odf.Namespaces;
 import com.openexchange.office.filter.odf.OdfOperationDoc;
 import com.openexchange.office.filter.odf.OpAttrs;
+import com.openexchange.office.filter.odf.odt.dom.Hyperlink;
+import com.openexchange.office.filter.odf.odt.dom.Paragraph;
+import com.openexchange.office.filter.odf.odt.dom.TextSpan;
 import com.openexchange.office.filter.odf.styles.StyleBase;
 import com.openexchange.office.filter.odf.styles.StyleFamily;
 import com.openexchange.office.filter.odf.styles.StyleManager;
-import com.openexchange.office.filter.odt.dom.Hyperlink;
-import com.openexchange.office.filter.odt.dom.Paragraph;
-import com.openexchange.office.filter.odt.dom.TextSpan;
 
 public abstract class TextSpan_Base extends OdfComponent {
 
@@ -138,7 +138,7 @@ public abstract class TextSpan_Base extends OdfComponent {
     }
 
 	@Override
-	public Component<OdfOperationDoc> getNextChildComponent(ComponentContext<OdfOperationDoc> previousChildContext, Component<OdfOperationDoc> previousChildComponent) {
+	public IComponent<OdfOperationDoc> getNextChildComponent(ComponentContext<OdfOperationDoc> previousChildContext, IComponent<OdfOperationDoc> previousChildComponent) {
 		return null;
 	}
 
