@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -247,6 +247,8 @@ public class DrawFrame extends Shape {
                 }
                 if(presentationClass!=null) {
                     attributes.setValue(Namespaces.PRESENTATION, "class", "presentation:class", presentationClass);
+                    // Fix bug DOCS-2144 Color Part
+                    isPresentationStyle = true;
                 }
             }
             final Object userTransformed = presentationProps.opt("userTransformed");
