@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -63,15 +63,15 @@ import com.openexchange.office.filter.core.PresentationObjectTitles;
 import com.openexchange.office.filter.odf.ElementNSWriter;
 import com.openexchange.office.filter.odf.SaxContextHandler;
 import com.openexchange.office.filter.odf.UnknownContentHandler;
+import com.openexchange.office.filter.odf.odp.dom.PresentationStyles;
+import com.openexchange.office.filter.odf.ods.dom.chart.ChartContent;
+import com.openexchange.office.filter.odf.odt.dom.Paragraph;
+import com.openexchange.office.filter.odf.odt.dom.Text;
+import com.openexchange.office.filter.odf.odt.dom.TextList;
+import com.openexchange.office.filter.odf.odt.dom.TextListItem;
+import com.openexchange.office.filter.odf.odt.dom.TextSpan;
 import com.openexchange.office.filter.odf.table.Table;
 import com.openexchange.office.filter.odf.table.TableHandler;
-import com.openexchange.office.filter.odp.dom.PresentationStyles;
-import com.openexchange.office.filter.ods.dom.chart.ChartContent;
-import com.openexchange.office.filter.odt.dom.Paragraph;
-import com.openexchange.office.filter.odt.dom.Text;
-import com.openexchange.office.filter.odt.dom.TextList;
-import com.openexchange.office.filter.odt.dom.TextListItem;
-import com.openexchange.office.filter.odt.dom.TextSpan;
 
 public class DrawFrameHandler extends SaxContextHandler {
 
