@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -90,7 +90,7 @@ public class DrawImage implements IDrawing {
 
 	private final DrawFrame drawFrame;
 	private final AttributesImpl attributes;
-    private final DLList<Object> childs = new DLList<>();
+    private final DLList<Object> childs = new DLList<Object>();
 
 	public DrawImage(DrawFrame drawFrame) {
 		this.drawFrame = drawFrame;
