@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -68,7 +68,7 @@ import com.openexchange.office.filter.odf.Namespaces;
 import com.openexchange.office.filter.odf.OdfOperationDoc;
 import com.openexchange.office.filter.odf.OpAttrs;
 import com.openexchange.office.filter.odf.SaxContextHandler;
-import com.openexchange.office.filter.ods.dom.chart.ChartContent;
+import com.openexchange.office.filter.odf.ods.dom.chart.ChartContent;
 
 public class DrawObject implements IDrawing {
 
