@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -70,13 +70,13 @@ import com.openexchange.office.filter.odf.Namespaces;
 import com.openexchange.office.filter.odf.OdfOperationDoc;
 import com.openexchange.office.filter.odf.OpAttrs;
 import com.openexchange.office.filter.odf.SaxContextHandler;
+import com.openexchange.office.filter.odf.odt.dom.TextContentHelper;
 import com.openexchange.office.filter.odf.properties.GraphicProperties;
 import com.openexchange.office.filter.odf.styles.IGraphicProperties;
 import com.openexchange.office.filter.odf.styles.StyleBase;
 import com.openexchange.office.filter.odf.styles.StyleFamily;
 import com.openexchange.office.filter.odf.styles.StyleGraphic;
 import com.openexchange.office.filter.odf.styles.StyleManager;
-import com.openexchange.office.filter.odt.dom.TextContentHelper;
 
 public class Shape implements IDrawing, INodeAccessor {
 
@@ -230,7 +230,7 @@ public class Shape implements IDrawing, INodeAccessor {
             Transformer.initialize(operationDocument, this);
         }
         final StyleManager styleManager = operationDocument.getDocument().getStyleManager();
-	    final StyleBase styleBase = styleManager.getStyleBaseClone(StyleFamily.GRAPHIC, getStyleName(), contentAutoStyle);
+	    final StyleBase styleBase = styleManager.getStyleBaseClone(attributes.containsKey("presentation:style-name") ? StyleFamily.PRESENTATION: StyleFamily.GRAPHIC, getStyleName(), contentAutoStyle);
 	    styleManager.applyAttrs(styleBase, contentAutoStyle, attrs);
 	    if(this instanceof ConnectorShape) {
 	        final JSONObject _attrs = new JSONObject(1);
@@ -258,8 +258,8 @@ public class Shape implements IDrawing, INodeAccessor {
                     if(defaultAutoResizeHeight) {
                         _shapeAttrs.put(OCKey.AUTO_RESIZE_HEIGHT.value(), Boolean.FALSE);
                     }
-                    if(defaultAutoResizeHeight) {
-                        _shapeAttrs.put(OCKey.WORD_WRAP.value(), Boolean.TRUE);
+                    if(defaultWordWrap) {
+                        _shapeAttrs.put(OCKey.WORD_WRAP.value() , Boolean.TRUE);
                     }
                     styleBase.applyAttrs(styleManager, _attrs);
 	            }
