@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,9 +58,9 @@ import org.xml.sax.Attributes;
 import com.openexchange.office.filter.odf.ElementNSWriter;
 import com.openexchange.office.filter.odf.SaxContextHandler;
 import com.openexchange.office.filter.odf.UnknownContentHandler;
-import com.openexchange.office.filter.odt.dom.SectionEndMarker;
-import com.openexchange.office.filter.odt.dom.SectionStartMarker;
-import com.openexchange.office.filter.odt.dom.TextContentHelper;
+import com.openexchange.office.filter.odf.odt.dom.SectionEndMarker;
+import com.openexchange.office.filter.odf.odt.dom.SectionStartMarker;
+import com.openexchange.office.filter.odf.odt.dom.TextContentHelper;
 
 public class StyleHeaderFooterHandler extends SaxContextHandler {
 
