@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -132,14 +132,14 @@ public class StyleManager {
 	 */
 	protected class FamilyStyles {
 
-		private final HashMap<StyleFamily, HashMap<String, DLNode<Object>>> stylesByFamily = new HashMap<>();
+		private final HashMap<StyleFamily, HashMap<String, DLNode<Object>>> stylesByFamily = new HashMap<StyleFamily, HashMap<String, DLNode<Object>>>();
 
 		// adds the style, family and name is taken from the style
 		public void addStyle(DLNode<Object> styleBaseNode) {
 			final StyleBase styleBase = (StyleBase)styleBaseNode.getData();
 			HashMap<String, DLNode<Object>> familyMap = stylesByFamily.get(styleBase.getFamily());
 			if(familyMap==null) {
-				familyMap = new HashMap<>();
+				familyMap = new HashMap<String, DLNode<Object>>();
 				stylesByFamily.put(styleBase.getFamily(), familyMap);
 			}
 			familyMap.put(styleBase.getName(), styleBaseNode);
@@ -166,10 +166,10 @@ public class StyleManager {
 		}
 	}
 
-	private final HashMap<StyleBase, String> allStyles = new HashMap<>();
+	private final HashMap<StyleBase, String> allStyles = new HashMap<StyleBase, String>();
 
     public void addStyle(StyleBase styleBase) {
-        final DLNode<Object> styleBaseNode = new DLNode<>(styleBase);
+        final DLNode<Object> styleBaseNode = new DLNode<Object>(styleBase);
         if(styleBase.isMasterStyle()) {
             masterStyles.getContent().addNode(styleBaseNode);
             familyMasterStyles.addStyle(styleBaseNode);
@@ -384,7 +384,7 @@ public class StyleManager {
 	    final HashMap<String, DLNode<Object>> stylesByFamily = (content ? familyAutomaticStylesContent : familyAutomaticStylesMaster).getStylesByFamily(StyleFamily.LIST_STYLE);
 		if(stylesByFamily!=null) {
 			final Iterator<DLNode<Object>> styleIter = stylesByFamily.values().iterator();
-			final HashSet<String> createdStyles = new HashSet<>();
+			final HashSet<String> createdStyles = new HashSet<String>();
 			while(styleIter.hasNext()) {
 				final StyleBase style = (StyleBase)styleIter.next().getData();
 				if(style.getFamily()==StyleFamily.LIST_STYLE) {
@@ -712,7 +712,7 @@ public class StyleManager {
         // if a new style is applied, then we need to merge each parent auto style first
         final Object oStyleId = attrs.opt(OCKey.STYLE_ID.value());
         if(oStyleId!=null) {
-            final List<StyleBase> parentAutoStyles = new ArrayList<>();
+            final List<StyleBase> parentAutoStyles = new ArrayList<StyleBase>();
             StyleBase p = styleBase;
             do {
                 final StyleBase parentStyle = findParentAutoStyle(p, parentAutoStyles);
@@ -740,8 +740,8 @@ public class StyleManager {
     }
 
     // we will never change existing autostyles, so it is safe to cache used autoStyle attributes
-	private final HashMap<String, HashMap<String, Object>> cachedAutoStyleMasterAttributes = new HashMap<>();
-	private final HashMap<String, HashMap<String, Object>> cachedAutoStyleContentAttributes = new HashMap<>();
+	private final HashMap<String, HashMap<String, Object>> cachedAutoStyleMasterAttributes = new HashMap<String, HashMap<String, Object>>();
+	private final HashMap<String, HashMap<String, Object>> cachedAutoStyleContentAttributes = new HashMap<String, HashMap<String, Object>>();;
 
 	public void createAutoStyleAttributes(OpAttrs destAttrs, String styleId, StyleFamily family, boolean contentStyle) {
 
@@ -752,7 +752,7 @@ public class StyleManager {
 			StyleBase style = getAutoStyle(styleId, family, contentStyle);
 			if(style!=null) {
 		        final OpAttrs attrs = new OpAttrs();
-				final Stack<StyleBase> autoStyleStack = new Stack<>();
+				final Stack<StyleBase> autoStyleStack = new Stack<StyleBase>();
 				HashMap<String, Object> cachedStyle = null;
 				while(style!=null) {
 					// only adding autoStyles to the stack which are not already cached
@@ -776,7 +776,7 @@ public class StyleManager {
 				while(!autoStyleStack.isEmpty()) {	// copy attributes from autostyles that not have been cached already
 					style = autoStyleStack.pop();
 					style.createAttrs(this, attrs);
-					cachedStyle = new HashMap<>();
+					cachedStyle = new HashMap<String, Object>();
 					deepCopy(attrs, cachedStyle);
 					cachedAutoStyles.put(style.getName(), cachedStyle);
 				}
@@ -788,8 +788,8 @@ public class StyleManager {
 		}
 	}
 
-	private final HashMap<String, HashMap<String, Object>> cachedParagraphPropertiesMaster = new HashMap<>();
-	private final HashMap<String, HashMap<String, Object>> cachedParagraphPropertiesContent = new HashMap<>();
+	private final HashMap<String, HashMap<String, Object>> cachedParagraphPropertiesMaster = new HashMap<String, HashMap<String, Object>>();
+	private final HashMap<String, HashMap<String, Object>> cachedParagraphPropertiesContent = new HashMap<String, HashMap<String, Object>>();;
 
 	public void collectAllParagraphPropertiesFromStyle(OpAttrs destAttrs, String styleId, StyleFamily family, boolean contentStyle) {
 
@@ -800,7 +800,7 @@ public class StyleManager {
 			StyleBase style = getAutoStyle(styleId, family, contentStyle);
 			if(style!=null) {
                 final OpAttrs attrs = new OpAttrs();
-				final Stack<StyleBase> styleStack = new Stack<>();
+				final Stack<StyleBase> styleStack = new Stack<StyleBase>();
 				HashMap<String, Object> cacheHit = null;
 				while(style!=null) {
 					// only adding autoStyles to the stack which are not already cached
@@ -819,7 +819,7 @@ public class StyleManager {
 					if(style instanceof IParagraphProperties) {
 						final ParagraphProperties paragraphProperties = ((IParagraphProperties)style).getParagraphProperties();
 						paragraphProperties.createAttrs(this, contentStyle, attrs);
-						cacheHit = new HashMap<>();
+						cacheHit = new HashMap<String, Object>();
 						deepCopy(attrs, cacheHit);
 						cachedProperties.put(style.getName(), cacheHit);
 					}
@@ -829,8 +829,8 @@ public class StyleManager {
 		}
 	}
 
-	private final HashMap<String, HashMap<String, Object>> cachedTextPropertiesMaster = new HashMap<>();
-	private final HashMap<String, HashMap<String, Object>> cachedTextPropertiesContent = new HashMap<>();
+	private final HashMap<String, HashMap<String, Object>> cachedTextPropertiesMaster = new HashMap<String, HashMap<String, Object>>();
+	private final HashMap<String, HashMap<String, Object>> cachedTextPropertiesContent = new HashMap<String, HashMap<String, Object>>();;
 
 	public void collectAllTextPropertiesFromStyle(OpAttrs destAttrs, String styleId, StyleFamily family, boolean contentStyle) {
 
@@ -841,7 +841,7 @@ public class StyleManager {
 			StyleBase style = getAutoStyle(styleId, family, contentStyle);
 			if(style!=null) {
                 final OpAttrs attrs = new OpAttrs();
-				final Stack<StyleBase> styleStack = new Stack<>();
+				final Stack<StyleBase> styleStack = new Stack<StyleBase>();
 				HashMap<String, Object> cacheHit = null;
 				while(style!=null) {
 					// only adding autoStyles to the stack which are not already cached
@@ -860,7 +860,7 @@ public class StyleManager {
 					if(style instanceof ITextProperties) {
 						final TextProperties TextProperties = ((ITextProperties)style).getTextProperties();
 						TextProperties.createAttrs(this, contentStyle, attrs);
-						cacheHit = new HashMap<>();
+						cacheHit = new HashMap<String, Object>();
 						deepCopy(attrs, cacheHit);
 						cachedProperties.put(style.getName(), cacheHit);
 					}
@@ -870,8 +870,8 @@ public class StyleManager {
 		}
 	}
 
-	private final HashMap<String, HashMap<String, Object>> cachedDrawingPropertiesMaster = new HashMap<>();
-	private final HashMap<String, HashMap<String, Object>> cachedDrawingPropertiesContent = new HashMap<>();
+	private final HashMap<String, HashMap<String, Object>> cachedDrawingPropertiesMaster = new HashMap<String, HashMap<String, Object>>();
+	private final HashMap<String, HashMap<String, Object>> cachedDrawingPropertiesContent = new HashMap<String, HashMap<String, Object>>();;
 
 	public void collectAllGraphicPropertiesFromStyle(OpAttrs destAttrs, String styleId, StyleFamily family, boolean contentStyle, boolean applyDefaultStyle) {
 
@@ -882,7 +882,7 @@ public class StyleManager {
 			StyleBase style = getAutoStyle(styleId, family, contentStyle);
 			if(style!=null) {
                 final OpAttrs attrs = new OpAttrs();
-				final Stack<StyleBase> styleStack = new Stack<>();
+				final Stack<StyleBase> styleStack = new Stack<StyleBase>();
 				HashMap<String, Object> cacheHit = null;
 				while(style!=null) {
 					// only adding autoStyles to the stack which are not already cached
@@ -909,7 +909,7 @@ public class StyleManager {
 					if(style instanceof IGraphicProperties) {
 						final GraphicProperties graphicProperties = ((IGraphicProperties)style).getGraphicProperties();
 						graphicProperties.createAttrs(this, contentStyle, attrs);
-						cacheHit = new HashMap<>();
+						cacheHit = new HashMap<String, Object>();
 						deepCopy(attrs, cacheHit);
 						cachedProperties.put(style.getName(), cacheHit);
 					}
@@ -920,14 +920,14 @@ public class StyleManager {
 	}
 
     // we will never change existing autostyles, so it is safe to cache used autoStyle attributes
-    private final HashMap<String, HashMap<String, Object>> cachedPresentationTemplateAttributes = new HashMap<>();
+    private final HashMap<String, HashMap<String, Object>> cachedPresentationTemplateAttributes = new HashMap<String, HashMap<String, Object>>();
 
     public void createPresentationTemplateStyle(OpAttrs destAttrs, String styleId) {
         if(styleId!=null&&!styleId.isEmpty()) {
             StyleBase style = getStyle(styleId, StyleFamily.TABLE_CELL, false);
             if(style instanceof StyleTableCell) {
                 final OpAttrs attrs = new OpAttrs();
-                final Stack<StyleBase> styleStack = new Stack<>();
+                final Stack<StyleBase> styleStack = new Stack<StyleBase>();
                 HashMap<String, Object> cachedStyle = null;
                 while(style!=null) {
                     // only adding autoStyles to the stack which are not already cached
@@ -944,7 +944,7 @@ public class StyleManager {
                 while(!styleStack.isEmpty()) {  // copy attributes from autostyles that not have been cached already
                     style = styleStack.pop();
                     style.createAttrs(this, attrs);
-                    cachedStyle = new HashMap<>();
+                    cachedStyle = new HashMap<String, Object>();
                     deepCopy(attrs, cachedStyle);
                     cachedPresentationTemplateAttributes.put(style.getName(), cachedStyle);
                 }
@@ -954,14 +954,14 @@ public class StyleManager {
     }
 
     // we will never change existing autostyles, so it is safe to cache used autoStyle attributes
-    private final HashMap<String, HashMap<String, Object>> cachedPresentationAttributes = new HashMap<>();
+    private final HashMap<String, HashMap<String, Object>> cachedPresentationAttributes = new HashMap<String, HashMap<String, Object>>();
 
     public void createPresentationStyle(OpAttrs destAttrs, String styleId, boolean isContentStyle) {
         if(styleId!=null&&!styleId.isEmpty()) {
             StyleBase style = getStyle(styleId, StyleFamily.PRESENTATION, isContentStyle);
             if(style instanceof StylePresentation) {
                 final OpAttrs attrs = new OpAttrs();
-                final Stack<StyleBase> styleStack = new Stack<>();
+                final Stack<StyleBase> styleStack = new Stack<StyleBase>();
                 HashMap<String, Object> cachedStyle = null;
                 while(style!=null) {
                     // only adding autoStyles to the stack which are not already cached
@@ -978,7 +978,7 @@ public class StyleManager {
                 while(!styleStack.isEmpty()) {  // copy attributes from autostyles that not have been cached already
                     style = styleStack.pop();
                     style.createAttrs(this, attrs);
-                    cachedStyle = new HashMap<>();
+                    cachedStyle = new HashMap<String, Object>();
                     deepCopy(attrs, cachedStyle);
                     cachedPresentationAttributes.put(style.getName(), cachedStyle);
                 }
@@ -1119,7 +1119,7 @@ public class StyleManager {
                 }
             }
         }
-    	final ArrayList<String> partArray = new ArrayList<>();
+    	final ArrayList<String> partArray = new ArrayList<String>();
     	String numberFormatCode = code;
         while(numberFormatCode.contains(";")) {
             int partStart = numberFormatCode.lastIndexOf(";", numberFormatCode.length());
@@ -1279,7 +1279,7 @@ public class StyleManager {
 				return;
 			}
 			if(styleStack==null) {
-				styleStack = new Stack<>();
+				styleStack = new Stack<StyleBase>();
 			}
 			styleStack.push(parent);
 
@@ -1540,25 +1540,25 @@ public class StyleManager {
         return tableCellStyle;
     }
 
-    private HashSet<String> usedLanguages = new HashSet<>();
+    private HashSet<String> usedLanguages = new HashSet<String>();
 
     public Set<String> getUsedLanguages() {
         return usedLanguages;
     }
 
-    private HashSet<String> usedLanguagesEA = new HashSet<>();
+    private HashSet<String> usedLanguagesEA = new HashSet<String>();
 
     public Set<String> getUsedLanguagesEA() {
         return usedLanguagesEA;
     }
 
-    private HashSet<String> usedLanguagesBidi = new HashSet<>();
+    private HashSet<String> usedLanguagesBidi = new HashSet<String>();
 
     public Set<String> getUsedLanguagesBidi() {
         return usedLanguagesBidi;
     }
 
-    private final HashMap<String, String> listItemStyleIds = new HashMap<>();
+    private final HashMap<String, String> listItemStyleIds = new HashMap<String, String>();
 
     public HashMap<String, String> getListItemStyleIds() {
         return listItemStyleIds;
