@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -102,7 +102,7 @@ import com.openexchange.office.filter.api.OCValue;
 import com.openexchange.office.filter.core.IContentAccessor;
 import com.openexchange.office.filter.core.DocumentComplexity;
 import com.openexchange.office.filter.core.component.CUtil;
-import com.openexchange.office.filter.core.component.Component;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 import com.openexchange.office.filter.ooxml.docx.components.ParagraphComponent;
 import com.openexchange.office.filter.ooxml.docx.components.RootComponent;
@@ -409,7 +409,8 @@ public class DocxOperationDocument extends OfficeOpenXMLOperationDocument {
                             applyOperationHelper.updateComplexField(op.getJSONArray(OCKey.START.value()), op.optString(OCKey.INSTRUCTION.value(), null), op.optJSONObject(OCKey.ATTRS.value()));
                             break;
                         }
-                        case DELETE_LIST_STYLE:
+                        case DELETE_TARGET_COMMENT :
+                        case DELETE_LIST_STYLE :
                             // PASSTHROUGH INTENDED
                         case NO_OP : {
                             break;
@@ -743,7 +744,7 @@ public class DocxOperationDocument extends OfficeOpenXMLOperationDocument {
         }
     }
 
-    private void removeRSids(Component<OfficeOpenXMLOperationDocument> c) {
+    private void removeRSids(IComponent<OfficeOpenXMLOperationDocument> c) {
         while(c!=null) {
             removeRSids(c.getNextChildComponent(null, null));
             if(c instanceof ParagraphComponent) {
