@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,11 +50,17 @@
 package com.openexchange.office.filter.ooxml.docx;
 
 import java.io.InputStream;
+
+import org.springframework.stereotype.Service;
 import org.xlsx4j.jaxb.Context;
+
 import com.openexchange.office.filter.api.DocumentProperties;
 import com.openexchange.office.filter.api.IExporter;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 import com.openexchange.office.imagemgr.IResourceManager;
+import com.openexchange.office.tools.annotation.RegisteredService;
+import com.openexchange.office.tools.common.osgi.context.OsgiBundleContextAndActivator;
+import com.openexchange.office.tools.common.osgi.context.OsgiBundleContextAware;
 import com.openexchange.session.Session;
 
 
@@ -63,8 +69,12 @@ import com.openexchange.session.Session;
  *
  * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
  */
-public class Exporter implements IExporter {
+@Service
+@RegisteredService
+public class Exporter implements IExporter, OsgiBundleContextAware {
 
+	private OsgiBundleContextAndActivator bundleCtx;
+	
     /**
      * Initializes a new {@link Exporter}.
      */
@@ -80,6 +90,7 @@ public class Exporter implements IExporter {
     public InputStream createDocument(Session session, InputStream documentStm, String applyOperations, IResourceManager resourceManager, DocumentProperties documentProperties, boolean createFinalDocument) {
         InputStream document = null;
         try(DocxOperationDocument operationDocument = new DocxOperationDocument(session, resourceManager, documentProperties)) {
+        	bundleCtx.prepareObject(operationDocument);
             operationDocument.loadDocument(documentStm, false);
             operationDocument.setCreateFinalDocument(createFinalDocument);
             operationDocument.updateDocumentProperties();
@@ -91,4 +102,9 @@ public class Exporter implements IExporter {
         }
         return document;
     }
+
+	@Override
+	public void setApplicationContext(OsgiBundleContextAndActivator bundleCtx) {
+		this.bundleCtx = bundleCtx;
+	}
 }
