@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,13 +51,19 @@ package com.openexchange.office.filter.ooxml.docx;
 
 import java.io.InputStream;
 import java.util.Map;
+
 import org.apache.commons.io.IOUtils;
 import org.docx4j.jaxb.Context;
 import org.json.JSONObject;
+import org.springframework.stereotype.Service;
+
 import com.openexchange.office.filter.api.DocumentProperties;
 import com.openexchange.office.filter.api.IImporter;
 import com.openexchange.office.filter.api.IPartImporter;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
+import com.openexchange.office.tools.annotation.RegisteredService;
+import com.openexchange.office.tools.common.osgi.context.OsgiBundleContextAndActivator;
+import com.openexchange.office.tools.common.osgi.context.OsgiBundleContextAware;
 import com.openexchange.session.Session;
 
 /**
@@ -65,8 +71,12 @@ import com.openexchange.session.Session;
  *
  * @author <a href="mailto:sven.jacobi@open-xchange.com">Sven Jacobi</a>
  */
-public class Importer implements IImporter, IPartImporter {
+@Service
+@RegisteredService
+public class Importer implements IImporter, IPartImporter, OsgiBundleContextAware {
 
+	private OsgiBundleContextAndActivator bundleCtx;
+	
     /**
      * Initializes a new {@link Importer}.
      */
@@ -83,6 +93,7 @@ public class Importer implements IImporter, IPartImporter {
         boolean debugGetDefaultDocument = false;
         if(debugGetDefaultDocument) {   // just a simple helper method to store our in memory created
             try(DocxOperationDocument emptyDoc = new DocxOperationDocument(null, null, documentProperties)) {
+            	bundleCtx.prepareObject(emptyDoc);
                 emptyDoc.createPackage();
                 emptyDoc.writeFile("/tmp/default.oxt");    // template documents...
             }
@@ -93,6 +104,7 @@ public class Importer implements IImporter, IPartImporter {
 
         JSONObject operations = null;
         try(DocxOperationDocument operationDocument = new DocxOperationDocument(session, null, documentProperties)) {
+        	bundleCtx.prepareObject(operationDocument);
             operationDocument.loadDocument(inputDocumentStm, true);
             operations = operationDocument.getOperations();
         }
@@ -106,6 +118,7 @@ public class Importer implements IImporter, IPartImporter {
     public InputStream getDefaultDocument(InputStream templateDocument, DocumentProperties documentProperties) {
         InputStream defaultDocument = null;
         try(DocxOperationDocument operationDocument = new DocxOperationDocument(null, null, documentProperties)) {
+        	bundleCtx.prepareObject(operationDocument);
             if(templateDocument!=null) {
                 operationDocument.loadDocument(templateDocument, false);
             }
@@ -127,6 +140,7 @@ public class Importer implements IImporter, IPartImporter {
 	@Override
 	public void initPartitioning(Session session, InputStream inputDocument, DocumentProperties documentProperties) {
 	    try(DocxOperationDocument operationDocument = new DocxOperationDocument(session, null, documentProperties)) {
+	    	bundleCtx.prepareObject(operationDocument);
 	        operationDocument.loadDocument(inputDocument, true);
 	        documentProperties.put(DocumentProperties.PROP_DOCUMENT, operationDocument);
 	    }
@@ -185,4 +199,9 @@ public class Importer implements IImporter, IPartImporter {
         }
 	    return metaData;
 	}
+
+	@Override
+	public void setApplicationContext(OsgiBundleContextAndActivator bundleCtx) {
+		this.bundleCtx = bundleCtx;
+	}
 }
