@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,8 +59,9 @@ import com.openexchange.office.filter.core.DLNode;
 import com.openexchange.office.filter.core.IContentAccessor;
 import com.openexchange.office.filter.core.DLList;
 import com.openexchange.office.filter.core.SplitMode;
-import com.openexchange.office.filter.core.component.Component;
 import com.openexchange.office.filter.core.component.ComponentContext;
+import com.openexchange.office.filter.core.component.ComponentType;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 import com.openexchange.office.filter.ooxml.components.OfficeOpenXMLComponent;
 import com.openexchange.office.filter.ooxml.docx.DocxOperationDocument;
@@ -81,7 +82,7 @@ public abstract class DocxComponent extends OfficeOpenXMLComponent {
     }
 
     @Override
-    public Component<OfficeOpenXMLOperationDocument> insertChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> parentContext, DLNode<Object> contextNode, int number, Component<OfficeOpenXMLOperationDocument> child, Component.Type type, JSONObject attrs) {
+    public IComponent<OfficeOpenXMLOperationDocument> insertChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> parentContext, DLNode<Object> contextNode, int number, IComponent<OfficeOpenXMLOperationDocument> child, ComponentType type, JSONObject attrs) {
     	return null;
     }
 
@@ -90,7 +91,7 @@ public abstract class DocxComponent extends OfficeOpenXMLComponent {
     	final ComponentContext<OfficeOpenXMLOperationDocument> contextChild = getContextChild(null);
 
     	final int endComponent = (getComponentNumber()+count)-1;
-    	Component<OfficeOpenXMLOperationDocument> component = this;
+    	IComponent<OfficeOpenXMLOperationDocument> component = this;
         while(true) {
             if(component instanceof CommentReferenceComponent) {
                 final CommentsPart commentsPart = ((DocxOperationDocument)operationDocument).getCommentsPart(false);
