@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -88,8 +88,10 @@ import com.openexchange.office.filter.core.IContentAccessor;
 import com.openexchange.office.filter.core.DLList;
 import com.openexchange.office.filter.core.SplitMode;
 import com.openexchange.office.filter.core.component.Child;
-import com.openexchange.office.filter.core.component.Component;
 import com.openexchange.office.filter.core.component.ComponentContext;
+import com.openexchange.office.filter.core.component.ComponentType;
+import com.openexchange.office.filter.core.component.IComponent;
+import com.openexchange.office.filter.core.component.IComponentContext;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 import com.openexchange.office.filter.ooxml.components.OfficeOpenXMLComponent;
 import com.openexchange.office.filter.ooxml.components.IParagraph;
@@ -108,13 +110,13 @@ public class ParagraphComponent extends DocxComponent implements IParagraph {
     }
 
     @Override
-	public Component<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, Component<OfficeOpenXMLOperationDocument> previousChildComponent) {
+	public IComponent<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, IComponent<OfficeOpenXMLOperationDocument> previousChildComponent) {
         final DLNode<Object> paragraphNode = getNode();
         final DLList<Object> nodeList = (DLList<Object>)((IContentAccessor)paragraphNode.getData()).getContent();
         final int nextComponentNumber = previousChildComponent!=null?previousChildComponent.getNextComponentNumber():0;
         DLNode<Object> childNode = previousChildContext!=null ? previousChildContext.getNode().getNext() : nodeList.getFirstNode();
 
-        Component<OfficeOpenXMLOperationDocument> nextComponent = null;
+        IComponent<OfficeOpenXMLOperationDocument> nextComponent = null;
         for(; nextComponent==null&&childNode!=null; childNode = childNode.getNext()) {
             final Object o = getContentModel(childNode, paragraphNode.getData());
             if(o instanceof R) {
@@ -161,7 +163,7 @@ public class ParagraphComponent extends DocxComponent implements IParagraph {
         return nextComponent;
     }
     @Override
-    public Component<OfficeOpenXMLOperationDocument> insertChildComponent(int textPosition, JSONObject attrs, Component.Type childType) throws Exception {
+    public IComponent<OfficeOpenXMLOperationDocument> insertChildComponent(int textPosition, JSONObject attrs, ComponentType childType) throws Exception {
 
         switch(childType) {
             case TAB : return insertChildWithTextRun(Context.getWmlObjectFactory().createRTab(), textPosition, attrs);
@@ -169,10 +171,10 @@ public class ParagraphComponent extends DocxComponent implements IParagraph {
             case HARDBREAK_PAGE :
             case HARDBREAK_COLUMN : {
                 final Child newChild = Context.getWmlObjectFactory().createBr();
-                if(childType==Type.HARDBREAK_PAGE) {
+                if(childType==ComponentType.HARDBREAK_PAGE) {
                     ((Br)newChild).setType(STBrType.PAGE);
                 }
-                else if(childType==Type.HARDBREAK_COLUMN) {
+                else if(childType==ComponentType.HARDBREAK_COLUMN) {
                     ((Br)newChild).setType(STBrType.COLUMN);
                 }
                 return insertChildWithTextRun(newChild, textPosition, attrs);
@@ -182,10 +184,10 @@ public class ParagraphComponent extends DocxComponent implements IParagraph {
             case COMPLEX_FIELD_END : {
             	final Child newChild = Context.getWmlObjectFactory().createFldChar();
             	((FldChar)newChild).setFldCharType(STFldCharType.BEGIN);
-            	if(childType==Type.COMPLEX_FIELD_END) {
+            	if(childType==ComponentType.COMPLEX_FIELD_END) {
                 	((FldChar)newChild).setFldCharType(STFldCharType.END);
             	}
-            	else if(childType==Type.COMPLEX_FIELD_SEPARATE) {
+            	else if(childType==ComponentType.COMPLEX_FIELD_SEPARATE) {
                 	((FldChar)newChild).setFldCharType(STFldCharType.SEPARATE);
             	}
             	else {
@@ -214,12 +216,12 @@ public class ParagraphComponent extends DocxComponent implements IParagraph {
         }
     }
 
-    private Component<OfficeOpenXMLOperationDocument> insertChildWithTextRun(Child newChild, int textPosition, JSONObject attrs) throws Exception {
+    private IComponent<OfficeOpenXMLOperationDocument> insertChildWithTextRun(Child newChild, int textPosition, JSONObject attrs) throws Exception {
 
         final P paragraph = (P)getObject();
         final DLList<Object> paragraphContent = paragraph.getContent();
 
-        Component<OfficeOpenXMLOperationDocument> childComponent = getNextChildComponent(null, null);
+        IComponent<OfficeOpenXMLOperationDocument> childComponent = getNextChildComponent(null, null);
         if(childComponent!=null) {
             if(textPosition>0) {
                 childComponent = childComponent.getComponent(textPosition-1);
@@ -276,12 +278,12 @@ public class ParagraphComponent extends DocxComponent implements IParagraph {
         return childComponent;
     }
 
-    private Component<OfficeOpenXMLOperationDocument> insertChildWithoutTextRun(Child newChild, int textPosition, JSONObject attrs) throws Exception {
+    private IComponent<OfficeOpenXMLOperationDocument> insertChildWithoutTextRun(Child newChild, int textPosition, JSONObject attrs) throws Exception {
 
         final P paragraph = (P)getObject();
         final DLList<Object> paragraphContent = paragraph.getContent();
 
-        Component<OfficeOpenXMLOperationDocument> childComponent = getNextChildComponent(null, null);
+        IComponent<OfficeOpenXMLOperationDocument> childComponent = getNextChildComponent(null, null);
         if(childComponent!=null) {
             if(textPosition>0) {
                 childComponent = childComponent.getComponent(textPosition-1);
@@ -593,7 +595,7 @@ public class ParagraphComponent extends DocxComponent implements IParagraph {
             final ParaRPr paraRPr = pPr.getRPr(false);
             if(paraRPr!=null) {
             	// only creating paragraph character attributes if there are no childs with character attributes elements #35344#, #35571#
-                Component<OfficeOpenXMLOperationDocument> childComponent = getNextChildComponent(null, null);
+                IComponent<OfficeOpenXMLOperationDocument> childComponent = getNextChildComponent(null, null);
                 while(childComponent!=null) {
                     if(childComponent instanceof TextRun_Base) {
                         break;
@@ -684,8 +686,8 @@ public class ParagraphComponent extends DocxComponent implements IParagraph {
         	paragraph.setModified(true);
 
             IText t = null;
-            Component<OfficeOpenXMLOperationDocument> childComponent = getNextChildComponent(null, null);
-            Component<OfficeOpenXMLOperationDocument> cRet = null;
+            IComponent<OfficeOpenXMLOperationDocument> childComponent = getNextChildComponent(null, null);
+            IComponent<OfficeOpenXMLOperationDocument> cRet = null;
 
             if(childComponent!=null) {
             	if(textPosition>0) {
@@ -769,7 +771,7 @@ public class ParagraphComponent extends DocxComponent implements IParagraph {
     	final P paragraph = (P)getObject();
 
         RPr lastRPr = null;
-        Component<OfficeOpenXMLOperationDocument> component = getNextChildComponent(null, null);
+        IComponent<OfficeOpenXMLOperationDocument> component = getNextChildComponent(null, null);
     	while(component!=null&&component.getNextComponentNumber()<=textPosition) {
     		if(component instanceof TextRun_Base) {
     			lastRPr = ((TextRun_Base)component).getTextRun().getRPr();
@@ -800,7 +802,7 @@ public class ParagraphComponent extends DocxComponent implements IParagraph {
         while(component!=null) {
             if(textPosition>=component.getComponentNumber()&&textPosition<component.getNextComponentNumber()) {
                 boolean skipSdt = false;
-                ComponentContext<OfficeOpenXMLOperationDocument> childContext = component;
+                IComponentContext<OfficeOpenXMLOperationDocument> childContext = component;
                 ComponentContext<OfficeOpenXMLOperationDocument> parentContext = component.getParentContext();
                 while(!(childContext instanceof ParagraphComponent)) {
                     if(parentContext instanceof SdtParagraphContext) {
@@ -849,7 +851,7 @@ public class ParagraphComponent extends DocxComponent implements IParagraph {
 
     @Override
     public void mergeParagraph() {
-    	final Component<OfficeOpenXMLOperationDocument> nextParagraphComponent = getNextComponent();
+    	final IComponent<OfficeOpenXMLOperationDocument> nextParagraphComponent = getNextComponent();
     	if(nextParagraphComponent instanceof ParagraphComponent) {
         	final P paragraph = (P)getObject();
         	final DLList<Object> sourceContent = ((P)nextParagraphComponent.getObject()).getContent();
