@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,8 +51,9 @@ package com.openexchange.office.filter.ooxml.docx.components;
 
 import org.json.JSONObject;
 import com.openexchange.office.filter.core.DLNode;
-import com.openexchange.office.filter.core.component.Component;
 import com.openexchange.office.filter.core.component.ComponentContext;
+import com.openexchange.office.filter.core.component.ComponentType;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 import com.openexchange.office.filter.ooxml.components.OfficeOpenXMLComponent;
 import com.openexchange.office.filter.ooxml.components.IShape;
@@ -85,7 +86,7 @@ public class ShapeComponent extends DocxComponent implements IShapeProvider, ISh
 	    return next!=null?new ShapeComponent(getOperationDocument(), next, getComponentNumber()+1):null;
 	}
 	@Override
-	public Component<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, Component<OfficeOpenXMLOperationDocument> previousChildComponent) {
+	public IComponent<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, IComponent<OfficeOpenXMLOperationDocument> previousChildComponent) {
 	    final Object child = shape.getChild();
 	    if(child instanceof IShape) {
 	        return new ShapeComponent(getOperationDocument(), (IShape)child, 0);
@@ -96,10 +97,10 @@ public class ShapeComponent extends DocxComponent implements IShapeProvider, ISh
 	    return null;
 	}
 	@Override
-	public Component<OfficeOpenXMLOperationDocument> insertChildComponent(int number, JSONObject attrs, Component.Type type) throws Exception {
+	public IComponent<OfficeOpenXMLOperationDocument> insertChildComponent(int number, JSONObject attrs, ComponentType type) throws Exception {
 
 	    final Object child = shape.insertChild(number, type);
-	    Component<OfficeOpenXMLOperationDocument> childComponent = null;
+	    IComponent<OfficeOpenXMLOperationDocument> childComponent = null;
 	    if(child instanceof IShape) {
             childComponent = new ShapeComponent(getOperationDocument(), (IShape)child, number);
         }
