@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,8 +51,9 @@ package com.openexchange.office.filter.ooxml.docx.components;
 
 import org.json.JSONObject;
 import com.openexchange.office.filter.core.DLNode;
-import com.openexchange.office.filter.core.component.Component;
 import com.openexchange.office.filter.core.component.ComponentContext;
+import com.openexchange.office.filter.core.component.ComponentType;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 import com.openexchange.office.filter.ooxml.components.OfficeOpenXMLComponent;
 import com.openexchange.office.filter.ooxml.components.IShapeType;
@@ -69,12 +70,12 @@ public class ShapeComponent_Root extends TextRun_Base implements IShapeType {
     }
 
     @Override
-	public Component<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, Component<OfficeOpenXMLOperationDocument> previousChildComponent) {
+	public IComponent<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, IComponent<OfficeOpenXMLOperationDocument> previousChildComponent) {
 	    return shapeComponent!=null?shapeComponent.getNextChildComponent(previousChildContext, previousChildComponent):null;
 	}
 
     @Override
-    public Component<OfficeOpenXMLOperationDocument> insertChildComponent(int number, JSONObject attrs, Component.Type type) throws Exception {
+    public IComponent<OfficeOpenXMLOperationDocument> insertChildComponent(int number, JSONObject attrs, ComponentType type) throws Exception {
 	    return shapeComponent!=null?shapeComponent.insertChildComponent(number, attrs, type):null;
 	}
 
