@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,11 +49,8 @@
 
 package com.openexchange.office.filter.ooxml.docx.components;
 
-import javax.xml.bind.JAXBException;
 import org.docx4j.XmlUtils;
 import org.docx4j.jaxb.Context;
-import org.docx4j.openpackaging.exceptions.InvalidFormatException;
-import org.docx4j.openpackaging.exceptions.PartUnrecognisedException;
 import org.docx4j.wml.CTTblGridChange;
 import org.docx4j.wml.CTTblPrBase;
 import org.docx4j.wml.CTTblPrBase.TblStyle;
@@ -78,8 +75,8 @@ import com.openexchange.office.filter.core.DLNode;
 import com.openexchange.office.filter.core.IContentAccessor;
 import com.openexchange.office.filter.core.DLList;
 import com.openexchange.office.filter.core.component.Child;
-import com.openexchange.office.filter.core.component.Component;
 import com.openexchange.office.filter.core.component.ComponentContext;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 import com.openexchange.office.filter.ooxml.components.OfficeOpenXMLComponent;
 import com.openexchange.office.filter.ooxml.components.ITable;
@@ -93,13 +90,13 @@ public class TableComponent extends DocxComponent implements ITable {
         super(parentContext, _node, _componentNumber);
     }
     @Override
-	public Component<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, Component<OfficeOpenXMLOperationDocument> previousChildComponent) {
+	public IComponent<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, IComponent<OfficeOpenXMLOperationDocument> previousChildComponent) {
         final DLNode<Object> tblNode = getNode();
         final DLList<Object> nodeList = (DLList<Object>)((IContentAccessor)tblNode.getData()).getContent();
         final int nextComponentNumber = previousChildComponent!=null?previousChildComponent.getNextComponentNumber():0;
         DLNode<Object> childNode = previousChildContext!=null ? previousChildContext.getNode().getNext() : nodeList.getFirstNode();
 
-        Component<OfficeOpenXMLOperationDocument> nextComponent = null;
+        IComponent<OfficeOpenXMLOperationDocument> nextComponent = null;
         for(; nextComponent==null&&childNode!=null; childNode = childNode.getNext()) {
             final Object o = getContentModel(childNode, tblNode.getData());
             if(o instanceof Tr) {
@@ -168,7 +165,7 @@ public class TableComponent extends DocxComponent implements ITable {
         			}
         			// removed / inserted changetracking has to be applied to each row
         			if(((JSONObject)changes).opt(OCKey.INSERTED.value())!=null||((JSONObject)changes).opt(OCKey.REMOVED.value())!=null) {
-        			    Component<OfficeOpenXMLOperationDocument> trComponent = getNextChildComponent(null, null);
+        			    IComponent<OfficeOpenXMLOperationDocument> trComponent = getNextChildComponent(null, null);
         				while(trComponent!=null) {
         					trComponent.applyAttrsFromJSON(attrs);
         					trComponent = trComponent.getNextComponent();
@@ -206,12 +203,12 @@ public class TableComponent extends DocxComponent implements ITable {
         int rowWidth = 0;
         boolean useCellWidth = true;
 
-        Component<OfficeOpenXMLOperationDocument> rowComponent = getNextChildComponent(null, null);
+        IComponent<OfficeOpenXMLOperationDocument> rowComponent = getNextChildComponent(null, null);
         while(rowComponent!=null) {
             rows++;
             // check, if table cells in the first row have a width defined (in "dxa")
             if (rows == 1) {
-                Component<OfficeOpenXMLOperationDocument> cellComponent = rowComponent.getNextChildComponent(null, null);
+                IComponent<OfficeOpenXMLOperationDocument> cellComponent = rowComponent.getNextChildComponent(null, null);
                 while(cellComponent!=null) {
                     columns++;
                     final TcPr cellProperties = ((Tc)cellComponent.getObject()).getTcPr(false);
@@ -323,7 +320,7 @@ public class TableComponent extends DocxComponent implements ITable {
     	final TrComponent trReferenceRow = referenceRow!=-1 ? (TrComponent)getChildComponent(referenceRow) : null;
     	final Tbl tbl = (Tbl)getObject();
         final DLList<Object> tblContent = tbl.getContent();
-        final Component<OfficeOpenXMLOperationDocument> oldTr = getChildComponent(destinationRowComponent);
+        final IComponent<OfficeOpenXMLOperationDocument> oldTr = getChildComponent(destinationRowComponent);
         DLNode<Object> referenceNode = oldTr!=null?oldTr.getNode():null;
 
         for(int i = 0; i<count; i++) {
@@ -374,7 +371,7 @@ public class TableComponent extends DocxComponent implements ITable {
             }
         }
         if(attrs!=null) {
-            Component<OfficeOpenXMLOperationDocument> c = getNextChildComponent(null, null).getComponent(destinationRowComponent);
+            IComponent<OfficeOpenXMLOperationDocument> c = getNextChildComponent(null, null).getComponent(destinationRowComponent);
 	        for(int i=0; i<count; i++) {
 	        	c.applyAttrsFromJSON(attrs);
 	        	c = c.getNextComponent();
@@ -478,7 +475,7 @@ public class TableComponent extends DocxComponent implements ITable {
     public void deleteColumns(int gridStart, int gridEnd)
     	throws JSONException {
 
-	    Component<OfficeOpenXMLOperationDocument> trComponent = getNextChildComponent(null, null);
+	    IComponent<OfficeOpenXMLOperationDocument> trComponent = getNextChildComponent(null, null);
         while(trComponent!=null) {
         	DLNode<Object> startNode = null;
         	DLNode<Object> endNode = null;
