@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -64,8 +64,8 @@ import com.openexchange.office.filter.core.IContentAccessor;
 import com.openexchange.office.filter.core.DLList;
 import com.openexchange.office.filter.core.SplitMode;
 import com.openexchange.office.filter.core.component.Child;
-import com.openexchange.office.filter.core.component.Component;
 import com.openexchange.office.filter.core.component.ComponentContext;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 import com.openexchange.office.filter.ooxml.docx.DocxOperationDocument;
 import com.openexchange.office.filter.ooxml.docx.tools.Character;
@@ -85,13 +85,13 @@ public class TextRun_Base extends DocxComponent implements ITextRunState {
     }
 
     @Override
-	public Component<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, Component<OfficeOpenXMLOperationDocument> previousChildComponent) {
+	public IComponent<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, IComponent<OfficeOpenXMLOperationDocument> previousChildComponent) {
 		return null;
 	}
 
     @Override
     public void delete(int count) {
-        if(componentNumber==0&&getNextComponent()==null) {
+        if(getComponentNumber()==0&&getNextComponent()==null) {
             textRunStateContext.getParagraph().getPPr(true).setRPr(ParaRPr.cloneFromRPrBase( textRunStateContext.getTextRun().getRPr()));
         }
         DLNode<Object> hyperlinkNode = textRunStateContext.getHyperlinkNode(false);
@@ -161,6 +161,17 @@ public class TextRun_Base extends DocxComponent implements ITextRunState {
 		}
 	}
 
+	private ComponentContext<OfficeOpenXMLOperationDocument> getContext(Class<?> contextClass) {
+        ComponentContext<OfficeOpenXMLOperationDocument> parentContext = getParentContext();
+        while(!(parentContext instanceof IComponent)&&(parentContext!=null)) {
+            if(parentContext.getClass()==contextClass) {
+                return parentContext;
+            }
+            parentContext = parentContext.getParentContext();
+        }
+        return null;
+    }
+
 	private static void combineWithNextHyperlink(DLNode<Object> hyperlinkNode) {
 		final IContentAccessor hyperlinkParent = (IContentAccessor)((Child)hyperlinkNode.getData()).getParent();
 		final DLList<Object> hyperlinkParentContent = (DLList<Object>)hyperlinkParent.getContent();
