@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,10 +49,7 @@
 
 package com.openexchange.office.filter.ooxml.docx.components;
 
-import javax.xml.bind.JAXBException;
 import org.docx4j.jaxb.Context;
-import org.docx4j.openpackaging.exceptions.InvalidFormatException;
-import org.docx4j.openpackaging.exceptions.PartUnrecognisedException;
 import org.docx4j.wml.CTSdtCell;
 import org.docx4j.wml.CTTrPrBase;
 import org.docx4j.wml.CTTrPrChange;
@@ -63,12 +60,11 @@ import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.core.DLNode;
-import com.openexchange.office.filter.core.component.Component;
 import com.openexchange.office.filter.core.component.ComponentContext;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.core.IContentAccessor;
 import com.openexchange.office.filter.core.DLList;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
-import com.openexchange.office.filter.ooxml.components.OfficeOpenXMLComponent;
 import com.openexchange.office.filter.ooxml.components.IRow;
 import com.openexchange.office.filter.ooxml.docx.tools.Table;
 import com.openexchange.office.filter.ooxml.docx.tools.Utils;
@@ -79,14 +75,14 @@ public class TrComponent extends DocxComponent implements IRow {
         super(parentContext, _node, _componentNumber);
     }
     @Override
-	public Component<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, Component<OfficeOpenXMLOperationDocument> previousChildComponent) {
+	public IComponent<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, IComponent<OfficeOpenXMLOperationDocument> previousChildComponent) {
         final DLNode<Object> trNode = getNode();
         final DLList<Object> nodeList = (DLList<Object>)((IContentAccessor)trNode.getData()).getContent();
         final int nextComponentNumber = previousChildComponent!=null?previousChildComponent.getNextComponentNumber():0;
         final int nextGridPosition = previousChildComponent instanceof TcComponent?((TcComponent)previousChildComponent).getNextGridPosition():0;
         DLNode<Object> childNode = previousChildContext!=null ? previousChildContext.getNode().getNext() : nodeList.getFirstNode();
 
-        Component<OfficeOpenXMLOperationDocument> nextComponent = null;
+        IComponent<OfficeOpenXMLOperationDocument> nextComponent = null;
         for(; nextComponent==null&&childNode!=null; childNode = childNode.getNext()) {
             final Object o = getContentModel(childNode, trNode.getData());
             if(o instanceof Tc) {
@@ -203,7 +199,7 @@ public class TrComponent extends DocxComponent implements IRow {
 	@Override
 	public void insertCells(int cellPosition, int count, JSONObject attrs) throws Exception {
 
-	    Component<OfficeOpenXMLOperationDocument> c = getChildComponent(cellPosition);
+	    IComponent<OfficeOpenXMLOperationDocument> c = getChildComponent(cellPosition);
     	final Tr tr = (Tr)getObject();
         final DLList<Object> trContent = tr.getContent();
         for (int i=0; i<count; i++) {
