@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -111,7 +111,8 @@ import com.google.common.collect.ImmutableMap;
 import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.core.DLNode;
 import com.openexchange.office.filter.core.SplitMode;
-import com.openexchange.office.filter.core.component.Component;
+import com.openexchange.office.filter.core.component.ComponentType;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.ooxml.components.OfficeOpenXMLComponent;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 import com.openexchange.office.filter.ooxml.components.IParagraph;
@@ -178,7 +179,7 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
 
     public void insertParagraph(JSONArray start, JSONObject attrs) throws Exception {
 
-        getOperationDocument().getRootComponent().getComponent(start, start.length()-1).insertChildComponent(start.getInt(start.length()-1), attrs, OfficeOpenXMLComponent.Type.PARAGRAPH);
+        getOperationDocument().getRootComponent().getComponent(start, start.length()-1).insertChildComponent(start.getInt(start.length()-1), attrs, ComponentType.PARAGRAPH);
     }
 
     public void splitParagraph(JSONArray start)
@@ -195,7 +196,7 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
     public void insertText(JSONArray start, String text, JSONObject attrs) throws Exception {
 
         if(text.length()>0) {
-            final Component<OfficeOpenXMLOperationDocument> component = getOperationDocument().getRootComponent().getComponent(start, start.length()-1);
+            final IComponent<OfficeOpenXMLOperationDocument> component = getOperationDocument().getRootComponent().getComponent(start, start.length()-1);
             ((IParagraph)component).insertText(start.getInt(start.length()-1), text, attrs);
         }
     }
@@ -203,17 +204,17 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
     public void insertTab(JSONArray start, JSONObject attrs) throws Exception {
 
         getOperationDocument().getRootComponent().getComponent(start, start.length()-1)
-            .insertChildComponent(start.getInt(start.length()-1), attrs, Component.Type.TAB);
+            .insertChildComponent(start.getInt(start.length()-1), attrs, ComponentType.TAB);
     }
 
     public void insertHardBreak(JSONArray start, String type, JSONObject attrs) throws Exception {
 
-        Component.Type textRunChild = Component.Type.HARDBREAK_DEFAULT;
+        ComponentType textRunChild = ComponentType.HARDBREAK_DEFAULT;
         if(type.equals("page")) {
-            textRunChild = Component.Type.HARDBREAK_PAGE;
+            textRunChild = ComponentType.HARDBREAK_PAGE;
         }
         else if(type.equals("column")) {
-            textRunChild = Component.Type.HARDBREAK_COLUMN;
+            textRunChild = ComponentType.HARDBREAK_COLUMN;
         }
         getOperationDocument().getRootComponent().getComponent(start, start.length()-1)
             .insertChildComponent(start.getInt(start.length()-1), attrs, textRunChild);
@@ -221,28 +222,28 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
 
     public void insertDrawing(JSONArray start, String type, JSONObject attrs) throws Exception {
 
-        Component.Type childComponentType = Component.Type.AC_IMAGE;
+        ComponentType childComponentType = ComponentType.AC_IMAGE;
         if(type.equals("shape")) {
             // we will create an AlternateContent for our shape (drawingML + VML)
-            childComponentType = Component.Type.AC_SHAPE;
+            childComponentType = ComponentType.AC_SHAPE;
         }
         else if(type.equals("connector")) {
-            childComponentType = Component.Type.AC_CONNECTOR;
+            childComponentType = ComponentType.AC_CONNECTOR;
         }
         else if(type.equals("group")) {
             // we will create an AlternateContent for our group (drawingML + VML)
-            childComponentType = Component.Type.AC_GROUP;
+            childComponentType = ComponentType.AC_GROUP;
         }
         else if(type.equals("image")) {
             // we will create an AlternateContent for our group (drawingML + VML)
-            childComponentType = Component.Type.AC_IMAGE;
+            childComponentType = ComponentType.AC_IMAGE;
         }
         getOperationDocument().getRootComponent().getComponent(start, start.length()-1).insertChildComponent(start.getInt(start.length()-1), attrs, childComponentType);
     }
 
     public void insertTable(JSONArray start, JSONObject attrs) throws Exception {
 
-        getOperationDocument().getRootComponent().getComponent(start, start.length()-1).insertChildComponent(start.getInt(start.length()-1), attrs, OfficeOpenXMLComponent.Type.TABLE);
+        getOperationDocument().getRootComponent().getComponent(start, start.length()-1).insertChildComponent(start.getInt(start.length()-1), attrs, ComponentType.TABLE);
     }
 
     public void splitTable(JSONArray start)
@@ -292,7 +293,7 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
                 return;
             endIndex = end.getInt(end.length()-1);
         }
-        Component<OfficeOpenXMLOperationDocument> component = getOperationDocument().getRootComponent().getComponent(start, start.length());
+        IComponent<OfficeOpenXMLOperationDocument> component = getOperationDocument().getRootComponent().getComponent(start, start.length());
         component.splitStart(startIndex, SplitMode.ATTRIBUTE);
         int nextComponentNumber = 0;
         while(component!=null&&component.getComponentNumber()<=endIndex) {
@@ -841,8 +842,8 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
 
     public void insertComment(JSONArray start, String id, String parentId, String uid, String author, String date, JSONObject attrs) throws Exception {
 
-        final Component<OfficeOpenXMLOperationDocument> component = getOperationDocument().getRootComponent().getComponent(start, start.length()-1)
-            .insertChildComponent(start.getInt(start.length()-1), attrs, Component.Type.COMMENT_REFERENCE);
+        final IComponent<OfficeOpenXMLOperationDocument> component = getOperationDocument().getRootComponent().getComponent(start, start.length()-1)
+            .insertChildComponent(start.getInt(start.length()-1), attrs, ComponentType.COMMENT_REFERENCE);
 
         final int index = DocxOperationDocument.operationIdToIndex(id);
         final int userId = DocxOperationDocument.operationIdToUserId(id);
@@ -867,8 +868,8 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
 
         if(type.equals("comment")) {
             final int cId = DocxOperationDocument.operationIdToIndex(id);
-            final Component.Type rangeType = position.equals("start") ? OfficeOpenXMLComponent.Type.COMMENT_RANGE_START : OfficeOpenXMLComponent.Type.COMMENT_RANGE_END;
-            final Component<OfficeOpenXMLOperationDocument> component = getOperationDocument().getRootComponent().getComponent(start, start.length()-1)
+            final ComponentType rangeType = position.equals("start") ? ComponentType.COMMENT_RANGE_START : ComponentType.COMMENT_RANGE_END;
+            final IComponent<OfficeOpenXMLOperationDocument> component = getOperationDocument().getRootComponent().getComponent(start, start.length()-1)
                 .insertChildComponent(start.getInt(start.length()-1), attrs, rangeType);
 
             final Object commentRangeObject = component.getObject();
@@ -881,15 +882,15 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
         }
         else if(type.equals("field")) {
             getOperationDocument().getRootComponent().getComponent(start, start.length()-1)
-                .insertChildComponent(start.getInt(start.length()-1), attrs, position.equals("start") ? OfficeOpenXMLComponent.Type.COMPLEX_FIELD_START : OfficeOpenXMLComponent.Type.COMPLEX_FIELD_END);
+                .insertChildComponent(start.getInt(start.length()-1), attrs, position.equals("start") ? ComponentType.COMPLEX_FIELD_START : ComponentType.COMPLEX_FIELD_END);
         }
     }
 
     public void insertBookmark(JSONArray start, String id, String position, String anchorName) throws Exception {
 
         final Integer cId = Integer.parseInt(id.substring(2));
-        final Component.Type rangeType = position.equals("start") ? OfficeOpenXMLComponent.Type.BOOKMARK_START : OfficeOpenXMLComponent.Type.BOOKMARK_END;
-        final Component<OfficeOpenXMLOperationDocument> component = getOperationDocument().getRootComponent().getComponent(start, start.length()-1)
+        final ComponentType rangeType = position.equals("start") ? ComponentType.BOOKMARK_START : ComponentType.BOOKMARK_END;
+        final IComponent<OfficeOpenXMLOperationDocument> component = getOperationDocument().getRootComponent().getComponent(start, start.length()-1)
             .insertChildComponent(start.getInt(start.length()-1), null, rangeType);
 
         if(component instanceof MultiComponent) {
@@ -902,7 +903,7 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
         }
     }
 
-    private static void applyBookmarkId(Component<OfficeOpenXMLOperationDocument> component, Integer cId, String anchorName) {
+    private static void applyBookmarkId(IComponent<OfficeOpenXMLOperationDocument> component, Integer cId, String anchorName) {
         final Object bookmarkObject = component.getObject();
         if(bookmarkObject.getClass()==CTBookmark.class) {
             ((CTBookmark)bookmarkObject).setId(cId);
@@ -915,8 +916,8 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
 
     public void insertComplexField(JSONArray start, String instruction, JSONObject attrs) throws Exception {
 
-        final Component<OfficeOpenXMLOperationDocument> component = getOperationDocument().getRootComponent().getComponent(start, start.length()-1)
-            .insertChildComponent(start.getInt(start.length()-1), attrs, Component.Type.COMPLEX_FIELD_SEPARATE);
+        final IComponent<OfficeOpenXMLOperationDocument> component = getOperationDocument().getRootComponent().getComponent(start, start.length()-1)
+            .insertChildComponent(start.getInt(start.length()-1), attrs, ComponentType.COMPLEX_FIELD_SEPARATE);
 
         if(component instanceof MultiComponent) {
             for(OfficeOpenXMLComponent fldCharComponent:((MultiComponent)component).getComponentList()) {
@@ -938,7 +939,7 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
 
     public void updateComplexField(JSONArray start, String instruction, JSONObject attrs) throws Exception {
 
-        final Component<OfficeOpenXMLOperationDocument> component = getOperationDocument().getRootComponent().getComponent(start, start.length());
+        final IComponent<OfficeOpenXMLOperationDocument> component = getOperationDocument().getRootComponent().getComponent(start, start.length());
         if(component instanceof MultiComponent) {
             for(OfficeOpenXMLComponent fldCharComponent:((MultiComponent)component).getComponentList()) {
                 if(instruction!=null) {
