@@ -27,7 +27,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -147,7 +147,7 @@ import com.openexchange.office.filter.api.FilterException;
 import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.api.OCValue;
 import com.openexchange.office.filter.core.IContentAccessor;
-import com.openexchange.office.filter.core.component.Component;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.ooxml.components.OfficeOpenXMLComponent;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 import com.openexchange.office.filter.ooxml.components.IShapeType;
@@ -499,13 +499,8 @@ public class DocxCreateOperationHelper extends CreateOperationHelper {
         }
         insertRangeObject.put(OCKey.POSITION.value(), startRange ? "start" : "end");
         final Comment comment = getOperationDocument().getComment(commentId, false);
-        if(comment!=null) {
-            final String operationId = DocxOperationDocument.getOperationId(comment.getId(), comment.getUserId());
-            if(operationId!=null) {
-                insertRangeObject.put(OCKey.ID.value(), operationId);
-                operationsArray.put(insertRangeObject);
-            }
-        }
+        insertRangeObject.put(OCKey.ID.value(), comment != null ? DocxOperationDocument.getOperationId(comment.getId(), comment.getUserId()) : "");
+        operationsArray.put(insertRangeObject);
     }
 
     public void AddInsertBookmarkOperation(final List<Integer> start, String target, Integer id, String anchorName, boolean bookmarkStart)
@@ -825,7 +820,7 @@ public class DocxCreateOperationHelper extends CreateOperationHelper {
     private void createOperations(IContentAccessor parent, List<Integer> parentPosition, String target) throws Exception {
 
         final RootComponent rootComponent = new RootComponent(getOperationDocument(), parent);
-        Component<OfficeOpenXMLOperationDocument> component = rootComponent.getNextChildComponent(null, null);
+        IComponent<OfficeOpenXMLOperationDocument> component = rootComponent.getNextChildComponent(null, null);
         while (component!=null) {
         	if(component instanceof ParagraphComponent) {
                 CreateParagraphOperations((ParagraphComponent)component, parentPosition, target);
@@ -845,7 +840,7 @@ public class DocxCreateOperationHelper extends CreateOperationHelper {
         AddInsertParagraphOperation(paragraphPosition, target, paragraphComponent.createJSONAttrs(new JSONObject(4)));
 
         // insert components (text and or other drawing objects)
-        Component<OfficeOpenXMLOperationDocument> component = paragraphComponent.getNextChildComponent(null, null);
+        IComponent<OfficeOpenXMLOperationDocument> component = paragraphComponent.getNextChildComponent(null, null);
         while(component!=null) {
             if (component instanceof TextComponent) {
                 AddInsertTextOperation(paragraphPosition, component.getComponentNumber(), target, (TextComponent)component);
@@ -930,16 +925,16 @@ public class DocxCreateOperationHelper extends CreateOperationHelper {
         }
     }
 
-    private void CreateDrawingOperations(Component<OfficeOpenXMLOperationDocument> component, String target, List<Integer> parentPosition) throws Exception {
+    private void CreateDrawingOperations(IComponent<OfficeOpenXMLOperationDocument> component, String target, List<Integer> parentPosition) throws Exception {
 
         final List<Integer> position = new ArrayList<Integer>(parentPosition);
         position.add(component.getComponentNumber());
         AddInsertDrawingOperation(position, target, ((IShapeType)component).getType(),
         	component instanceof ShapeComponent_Root ? null : ((OfficeOpenXMLComponent)component).createJSONAttrs(new JSONObject()));
 
-        Component<OfficeOpenXMLOperationDocument> childComponent = component.getNextChildComponent(null, null);
+        IComponent<OfficeOpenXMLOperationDocument> childComponent = component.getNextChildComponent(null, null);
         while(childComponent!=null) {
-            final Component<OfficeOpenXMLOperationDocument> c = childComponent instanceof MultiComponent ? ((MultiComponent)childComponent).getComponentList().get(0) : childComponent;
+            final IComponent<OfficeOpenXMLOperationDocument> c = childComponent instanceof MultiComponent ? ((MultiComponent)childComponent).getComponentList().get(0) : childComponent;
 	    	if(c instanceof ShapeComponent) {
 	    		CreateDrawingOperations(c, target, position);
 	    	}
@@ -959,12 +954,12 @@ public class DocxCreateOperationHelper extends CreateOperationHelper {
         tablePosition.add(tableComponent.getComponentNumber());
         final JSONObject attrs = tableComponent.createJSONAttrs(new JSONObject());
         if(AddInsertTableOperation(tablePosition, target, attrs)) {
-            Component<OfficeOpenXMLOperationDocument> rowComponent = tableComponent.getNextChildComponent(null, null);
+            IComponent<OfficeOpenXMLOperationDocument> rowComponent = tableComponent.getNextChildComponent(null, null);
             while(rowComponent!=null) {
                 final List<Integer> rowPosition = new ArrayList<Integer>(tablePosition);
                 rowPosition.add(rowComponent.getComponentNumber());
                 AddInsertRowsOperation(rowPosition, target, ((OfficeOpenXMLComponent)rowComponent).createJSONAttrs(new JSONObject()));
-                Component<OfficeOpenXMLOperationDocument> cellComponent = rowComponent.getNextChildComponent(null, null);
+                IComponent<OfficeOpenXMLOperationDocument> cellComponent = rowComponent.getNextChildComponent(null, null);
                 while(cellComponent!=null) {
                     final List<Integer> cellPosition = new ArrayList<Integer>(rowPosition);
                     cellPosition.add(cellComponent.getComponentNumber());
