@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -97,9 +97,9 @@ import com.openexchange.office.filter.api.FilterException;
 import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.core.DLNode;
 import com.openexchange.office.filter.core.IContentAccessor;
-import com.openexchange.office.filter.core.component.Component;
+import com.openexchange.office.filter.core.component.ComponentType;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.core.DLList;
-import com.openexchange.office.filter.ooxml.components.OfficeOpenXMLComponent;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 import com.openexchange.office.filter.ooxml.components.IShape;
 import com.openexchange.office.filter.ooxml.components.IShapeTxBxContentAccessor;
@@ -480,7 +480,7 @@ public abstract class DrawingML {
             return null;
         }
         @Override
-        public Object insertChild(int number, OfficeOpenXMLComponent.Type type) throws Exception {
+        public Object insertChild(int number, ComponentType type) throws Exception {
             return null;
         }
         protected void applyChildExtensionToParent(JSONObject attrs) {
@@ -563,10 +563,10 @@ public abstract class DrawingML {
 	    }
 
 		@Override
-    	public Object insertChild(int number, OfficeOpenXMLComponent.Type type) {
+    	public Object insertChild(int number, ComponentType type) {
 		    final CTTxbxContent txBoxContent = getTextboxContent(true);
 			final RootComponent rootComponent = new RootComponent(super.operationDocument, txBoxContent);
-			Component<OfficeOpenXMLOperationDocument> c = rootComponent.getNextChildComponent(null, null);
+			IComponent<OfficeOpenXMLOperationDocument> c = rootComponent.getNextChildComponent(null, null);
         	if(c!=null) {
         		c = c.getComponent(number);
         	}
@@ -663,26 +663,26 @@ public abstract class DrawingML {
             return null;
         }
         @Override
-        public Object insertChild(int number, Component.Type type)
+        public Object insertChild(int number, ComponentType type)
             throws JAXBException {
 
             final DLList<Object> groupContent = group.getContent();
-            if(type==Component.Type.AC_GROUP) {
+            if(type==ComponentType.AC_GROUP) {
                 final CTWordprocessingGroup child = createDrawingMLGroup();
                 groupContent.add(number, child);
                 return new DrawingML_group(super.operationDocument, child, group);
             }
-            else if(type==Component.Type.AC_SHAPE) {
+            else if(type==ComponentType.AC_SHAPE) {
                 final CTWordprocessingShape child = createDrawingMLShape(operationDocument.getPackage());
                 groupContent.add(number, child);
                 return new DrawingML_shape(super.operationDocument, child, group);
             }
-            else if(type==Component.Type.AC_CONNECTOR) {
+            else if(type==ComponentType.AC_CONNECTOR) {
                 final CTWordprocessingShape child = createDrawingMLConnectorShape(operationDocument.getPackage());
                 groupContent.add(number, child);
                 return new DrawingML_shape(super.operationDocument, child, group);
             }
-            else if(type==Component.Type.AC_IMAGE) {
+            else if(type==ComponentType.AC_IMAGE) {
                 final Pic child = createDrawingMLPic(operationDocument.getPackage());
                 groupContent.add(number, child);
                 return new DrawingML_pic(super.operationDocument, child, group);
@@ -738,26 +738,26 @@ public abstract class DrawingML {
             return null;
         }
         @Override
-        public Object insertChild(int number, Component.Type type)
+        public Object insertChild(int number, ComponentType type)
             throws JAXBException {
 
             final DLList<Object> groupContent = canvas.getContent();
-            if(type==Component.Type.AC_GROUP) {
+            if(type==ComponentType.AC_GROUP) {
                 final CTWordprocessingGroup child = createDrawingMLGroup();
                 groupContent.add(number, child);
                 return new DrawingML_group(super.operationDocument, child, canvas);
             }
-            else if(type==Component.Type.AC_SHAPE) {
+            else if(type==ComponentType.AC_SHAPE) {
                 final CTWordprocessingShape child = createDrawingMLShape(operationDocument.getPackage());
                 groupContent.add(number, child);
                 return new DrawingML_shape(super.operationDocument, child, canvas);
             }
-            else if(type==Component.Type.AC_CONNECTOR) {
+            else if(type==ComponentType.AC_CONNECTOR) {
                 final CTWordprocessingShape child = createDrawingMLConnectorShape(operationDocument.getPackage());
                 groupContent.add(number, child);
                 return new DrawingML_shape(super.operationDocument, child, canvas);
             }
-            else if(type==Component.Type.AC_IMAGE) {
+            else if(type==ComponentType.AC_IMAGE) {
                 final Pic child = createDrawingMLPic(operationDocument.getPackage());
                 groupContent.add(number, child);
                 return new DrawingML_pic(super.operationDocument, child, canvas);
@@ -1467,7 +1467,7 @@ public abstract class DrawingML {
 		    return drawing!=null?drawing.getChild():null;
 		}
 		@Override
-		public Object insertChild(int number, OfficeOpenXMLComponent.Type type) throws Exception {
+		public Object insertChild(int number, ComponentType type) throws Exception {
 		    return drawing==null?null:drawing.insertChild(number, type);
 		}
     }
