@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -89,7 +89,7 @@ import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.office.filter.api.FilterException;
 import com.openexchange.office.filter.api.OCKey;
-import com.openexchange.office.filter.core.component.Component;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 import com.openexchange.office.filter.ooxml.docx.DocxOperationDocument;
 import com.openexchange.office.filter.ooxml.docx.components.TableComponent;
@@ -228,9 +228,9 @@ public class Table {
                 if (value instanceof JSONArray) {
                     newTableGrid = (JSONArray)value;
                     if(tableComponent!=null) {
-                        Component<OfficeOpenXMLOperationDocument> tableRowComponent = tableComponent.getNextChildComponent(null,  null);
+                        IComponent<OfficeOpenXMLOperationDocument> tableRowComponent = tableComponent.getNextChildComponent(null,  null);
                         while(tableRowComponent!=null) {
-                            Component<OfficeOpenXMLOperationDocument> tableCellComponent = tableRowComponent.getNextChildComponent(null, null);
+                            IComponent<OfficeOpenXMLOperationDocument> tableCellComponent = tableRowComponent.getNextChildComponent(null, null);
                             while(tableCellComponent!=null) {
                                 final TcPr tcPr = ((Tc)tableCellComponent.getNode().getData()).getTcPr(false);
                                 if(tcPr!=null) {
@@ -270,9 +270,9 @@ public class Table {
                     Utils.initShdFromJSONColor(operationDocument, (JSONObject)value, tblPr.getShd(true));
 
                     if(tableComponent!=null) {
-                        Component<OfficeOpenXMLOperationDocument> tableRowComponent = tableComponent.getNextChildComponent(null, null);
+                        IComponent<OfficeOpenXMLOperationDocument> tableRowComponent = tableComponent.getNextChildComponent(null, null);
 	                    while(tableRowComponent!=null) {
-	                        Component<OfficeOpenXMLOperationDocument> tableCellComponent = tableRowComponent.getNextChildComponent(null, null);
+	                        IComponent<OfficeOpenXMLOperationDocument> tableCellComponent = tableRowComponent.getNextChildComponent(null, null);
 	                        while(tableCellComponent!=null) {
 	                            Tc tc = (Tc)tableCellComponent.getNode().getData();
 	                            Utils.initShdFromJSONColor(operationDocument, (JSONObject)value, tc.getTcPr(true).getShd(true));
