@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,13 +50,19 @@
 package com.openexchange.office.filter.ooxml.pptx;
 
 import java.io.InputStream;
+
 import org.pptx4j.jaxb.Context;
+import org.springframework.stereotype.Service;
+
 import com.openexchange.office.filter.api.DocumentProperties;
 import com.openexchange.office.filter.api.FilterException;
 import com.openexchange.office.filter.api.FilterException.ErrorCode;
 import com.openexchange.office.filter.api.IExporter;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 import com.openexchange.office.imagemgr.IResourceManager;
+import com.openexchange.office.tools.annotation.RegisteredService;
+import com.openexchange.office.tools.common.osgi.context.OsgiBundleContextAndActivator;
+import com.openexchange.office.tools.common.osgi.context.OsgiBundleContextAware;
 import com.openexchange.session.Session;
 
 /**
@@ -64,8 +70,12 @@ import com.openexchange.session.Session;
  *
  * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
  */
-public class Exporter implements IExporter {
+@Service
+@RegisteredService
+public class Exporter implements IExporter, OsgiBundleContextAware {
 
+	private OsgiBundleContextAndActivator bundleCtx;
+	
     /**
      * Initializes a new {@link Exporter}.
      */
@@ -101,6 +111,7 @@ public class Exporter implements IExporter {
     public InputStream _createDocument(Session session, InputStream documentStm, String applyOperations, IResourceManager resourceManager, DocumentProperties documentProperties, boolean createFinalDocument, boolean sortOperations) {
         InputStream document = null;
         try(PptxOperationDocument operationDocument = new PptxOperationDocument(session, resourceManager, documentProperties)) {
+        	bundleCtx.prepareObject(operationDocument);
             operationDocument.loadDocument(documentStm, false);
             operationDocument.setSortOperations(sortOperations);
             operationDocument.setCreateFinalDocument(createFinalDocument);
@@ -113,4 +124,9 @@ public class Exporter implements IExporter {
         }
         return document;
     }
+
+	@Override
+	public void setApplicationContext(OsgiBundleContextAndActivator bundleCtx) {
+		this.bundleCtx = bundleCtx;
+	}
 }
