@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -100,7 +100,7 @@ import com.openexchange.office.filter.core.DocumentComplexity;
 import com.openexchange.office.filter.core.DLNode;
 import com.openexchange.office.filter.core.DLList;
 import com.openexchange.office.filter.core.PresentationObjectTitles;
-import com.openexchange.office.filter.core.component.Component;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 import com.openexchange.office.filter.ooxml.components.OfficeOpenXMLComponent;
 import com.openexchange.office.filter.ooxml.pptx.components.ParagraphComponent;
@@ -336,7 +336,7 @@ public class PptxOperationDocument extends com.openexchange.office.filter.ooxml.
     }
 
     private void translatePresentationObjects(Part slidePart, String language) {
-        Component<OfficeOpenXMLOperationDocument> child = new SlideComponent(this, new DLNode<Object>(slidePart), 0).getNextChildComponent(null, null);
+        IComponent<OfficeOpenXMLOperationDocument> child = new SlideComponent(this, new DLNode<Object>(slidePart), 0).getNextChildComponent(null, null);
         while(child!=null) {
             if(child instanceof ShapeComponent) {
                 final Object o = child.getObject();
@@ -391,7 +391,7 @@ public class PptxOperationDocument extends com.openexchange.office.filter.ooxml.
     }
 
     private void translatePresentationObject(ShapeComponent presShape, STPlaceholderType placeholderType, String language) {
-        Component<OfficeOpenXMLOperationDocument> child = presShape.getNextChildComponent(null, null);
+        IComponent<OfficeOpenXMLOperationDocument> child = presShape.getNextChildComponent(null, null);
         while(child!=null) {
             if(child instanceof ParagraphComponent) {
                 translatePresentationParagraph((ParagraphComponent)child, placeholderType, language);
@@ -401,7 +401,7 @@ public class PptxOperationDocument extends com.openexchange.office.filter.ooxml.
     }
 
     private void translatePresentationParagraph(ParagraphComponent paragraphComponent, STPlaceholderType placeholderType, String language) {
-        Component<OfficeOpenXMLOperationDocument> child = paragraphComponent.getNextChildComponent(null, null);
+        IComponent<OfficeOpenXMLOperationDocument> child = paragraphComponent.getNextChildComponent(null, null);
         if(child==null) {
             return;
         }
