@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,7 +49,6 @@
 
 package com.openexchange.office.filter.ooxml.pptx.components;
 
-import javax.xml.bind.JAXBException;
 import org.docx4j.XmlUtils;
 import org.docx4j.dml.CTRegularTextRun;
 import org.docx4j.dml.CTTextCharacterProperties;
@@ -77,10 +76,10 @@ import com.openexchange.office.filter.core.DLNode;
 import com.openexchange.office.filter.core.IContentAccessor;
 import com.openexchange.office.filter.core.DLList;
 import com.openexchange.office.filter.core.SplitMode;
-import com.openexchange.office.filter.core.component.Component;
 import com.openexchange.office.filter.core.component.ComponentContext;
+import com.openexchange.office.filter.core.component.ComponentType;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
-import com.openexchange.office.filter.ooxml.components.OfficeOpenXMLComponent;
 import com.openexchange.office.filter.ooxml.components.IParagraph;
 import com.openexchange.office.filter.ooxml.drawingml.DMLHelper;
 import com.openexchange.office.filter.ooxml.pptx.tools.PMLShapeHelper;
@@ -99,13 +98,13 @@ public class ParagraphComponent extends PptxComponent implements IParagraph {
     }
 
     @Override
-    public Component<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, Component<OfficeOpenXMLOperationDocument> previousChildComponent) {
+    public IComponent<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, IComponent<OfficeOpenXMLOperationDocument> previousChildComponent) {
         final DLNode<Object> paragraphNode = getNode();
         final DLList<Object> nodeList = (DLList<Object>)((IContentAccessor)paragraphNode.getData()).getContent();
         final int nextComponentNumber = previousChildComponent!=null?previousChildComponent.getNextComponentNumber():0;
         DLNode<Object> childNode = previousChildContext!=null ? previousChildContext.getNode().getNext() : nodeList.getFirstNode();
 
-        Component<OfficeOpenXMLOperationDocument> nextComponent = null;
+        IComponent<OfficeOpenXMLOperationDocument> nextComponent = null;
         for(; nextComponent==null&&childNode!=null; childNode = childNode.getNext()) {
             final Object o = getContentModel(childNode, paragraphNode.getData());
             if(o instanceof CTRegularTextRun) {
@@ -127,8 +126,8 @@ public class ParagraphComponent extends PptxComponent implements IParagraph {
     public void insertText(int textPosition, String text, JSONObject attrs) throws Exception {
 
         if(text.length()>0) {
-            Component<OfficeOpenXMLOperationDocument> childComponent = getNextChildComponent(null, null);
-            Component<OfficeOpenXMLOperationDocument> cRet = null;
+            IComponent<OfficeOpenXMLOperationDocument> childComponent = getNextChildComponent(null, null);
+            IComponent<OfficeOpenXMLOperationDocument> cRet = null;
 
             if(childComponent!=null) {
                 if(textPosition>0) {
@@ -200,7 +199,7 @@ public class ParagraphComponent extends PptxComponent implements IParagraph {
         CTTextCharacterProperties lastRPr = null;
         if(textPosition>0) {
             // splitting the paragraph
-            Component<OfficeOpenXMLOperationDocument> childComponent = getChildComponent(textPosition-1);
+            IComponent<OfficeOpenXMLOperationDocument> childComponent = getChildComponent(textPosition-1);
             if(childComponent!=null) {
                 lastRPr = ((ITextCharacterProperties)childComponent.getObject()).getRPr(false);
                 childComponent.splitEnd(textPosition-1, SplitMode.DELETE);
@@ -228,7 +227,7 @@ public class ParagraphComponent extends PptxComponent implements IParagraph {
 
     @Override
     public void mergeParagraph() {
-        final Component<OfficeOpenXMLOperationDocument> nextParagraphComponent = getNextComponent();
+        final IComponent<OfficeOpenXMLOperationDocument> nextParagraphComponent = getNextComponent();
         if(nextParagraphComponent instanceof ParagraphComponent) {
             final DLList<Object> sourceContent = ((CTTextParagraph)nextParagraphComponent.getObject()).getContent();
             final DLList<Object> destContent = paragraph.getContent();
@@ -250,7 +249,7 @@ public class ParagraphComponent extends PptxComponent implements IParagraph {
         final boolean hasParagraphAttrs = attrs.hasAndNotNull(OCKey.PARAGRAPH.value());
         final boolean hasCharacterAttrs = attrs.hasAndNotNull(OCKey.CHARACTER.value());
         if(hasParagraphAttrs||hasCharacterAttrs) {
-            final Component<OfficeOpenXMLOperationDocument> parentComponent = getParentComponent();
+            final IComponent<OfficeOpenXMLOperationDocument> parentComponent = getParentComponent();
             if(parentComponent instanceof IShapeComponent&&((IShapeComponent)parentComponent).isPresentationObject()) {;
                 final ShapeComponent shapeComponent = (ShapeComponent)parentComponent;
                 final SlideComponent slideComponent = PMLShapeHelper.getSlideComponent(shapeComponent);
@@ -340,18 +339,18 @@ public class ParagraphComponent extends PptxComponent implements IParagraph {
     }
 
     @Override
-    public Component<OfficeOpenXMLOperationDocument> insertChildComponent(int textPosition, JSONObject attrs, Component.Type childType) throws Exception {
+    public IComponent<OfficeOpenXMLOperationDocument> insertChildComponent(int textPosition, JSONObject attrs, ComponentType childType) throws Exception {
 
         Object newChild = null;
 
         CTTextCharacterProperties textCharacterProperties = null;
-        if(childType == Type.HARDBREAK_DEFAULT) {
+        if(childType == ComponentType.HARDBREAK_DEFAULT) {
             newChild = Context.getDmlObjectFactory().createCTTextLineBreak();
         }
-        else if(childType == Type.SIMPLE_FIELD) {
+        else if(childType == ComponentType.SIMPLE_FIELD) {
             newChild = Context.getDmlObjectFactory().createCTTextField();
         }
-        Component<OfficeOpenXMLOperationDocument> childComponent = getNextChildComponent(null, null);
+        IComponent<OfficeOpenXMLOperationDocument> childComponent = getNextChildComponent(null, null);
         if(childComponent!=null) {
             if(textPosition>0) {
                 childComponent = childComponent.getComponent(textPosition-1);
