@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,8 +54,9 @@ import com.openexchange.office.filter.core.DLNode;
 import com.openexchange.office.filter.core.IContentAccessor;
 import com.openexchange.office.filter.core.DLList;
 import com.openexchange.office.filter.core.SplitMode;
-import com.openexchange.office.filter.core.component.Component;
 import com.openexchange.office.filter.core.component.ComponentContext;
+import com.openexchange.office.filter.core.component.ComponentType;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 import com.openexchange.office.filter.ooxml.components.OfficeOpenXMLComponent;
 import com.openexchange.office.filter.ooxml.pptx.PptxOperationDocument;
@@ -77,7 +78,7 @@ public abstract class PptxComponent extends OfficeOpenXMLComponent {
     }
 
     @Override
-    public Component<OfficeOpenXMLOperationDocument> insertChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> parentContext, DLNode<Object> contextNode, int number, Component<OfficeOpenXMLOperationDocument> child, Component.Type type, JSONObject attrs)
+    public IComponent<OfficeOpenXMLOperationDocument> insertChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> parentContext, DLNode<Object> contextNode, int number, IComponent<OfficeOpenXMLOperationDocument> child, ComponentType type, JSONObject attrs)
     	throws Exception {
 
     	return null;
@@ -88,7 +89,7 @@ public abstract class PptxComponent extends OfficeOpenXMLComponent {
     	final ComponentContext<OfficeOpenXMLOperationDocument> contextChild = getContextChild(null);
 
     	final int endComponent = (getComponentNumber()+count)-1;
-    	Component<OfficeOpenXMLOperationDocument> component = this;
+    	IComponent<OfficeOpenXMLOperationDocument> component = this;
         while(true) {
         	if(component instanceof IShapeComponent) {
         		final Integer id = ((IShapeComponent)component).getId();
