@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -81,8 +81,8 @@ import org.pptx4j.pml.CTOleObject;
 import org.pptx4j.pml.Pic;
 import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.core.DLNode;
-import com.openexchange.office.filter.core.component.Component;
 import com.openexchange.office.filter.core.component.ComponentContext;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.core.DLList;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 import com.openexchange.office.filter.ooxml.components.IShapeType;
@@ -116,13 +116,13 @@ public class ShapeGraphicComponent extends PptxComponent implements IShapeCompon
     }
 
     @Override
-	public Component<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, Component<OfficeOpenXMLOperationDocument> previousChildComponent) {
+	public IComponent<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, IComponent<OfficeOpenXMLOperationDocument> previousChildComponent) {
     	if(shapeType==ShapeType.TABLE) {
             final DLList<Object> nodeList = tbl.getContent();
             final int nextComponentNumber = previousChildComponent!=null?previousChildComponent.getNextComponentNumber():0;
             DLNode<Object> childNode = previousChildContext!=null ? previousChildContext.getNode().getNext() : nodeList.getFirstNode();
 
-            Component<OfficeOpenXMLOperationDocument> nextComponent = null;
+            IComponent<OfficeOpenXMLOperationDocument> nextComponent = null;
             for(; nextComponent==null&&childNode!=null; childNode = childNode.getNext()) {
                 final Object o = getContentModel(childNode, tbl);
                 if(o instanceof CTTableRow) {
@@ -301,7 +301,7 @@ public class ShapeGraphicComponent extends PptxComponent implements IShapeCompon
 
     	final TableRowComponent trReferenceRow = referenceRow!=-1 ? (TableRowComponent)getChildComponent(referenceRow) : null;
         final DLList<Object> tblContent = tbl.getContent();
-        final Component<OfficeOpenXMLOperationDocument> oldTr = getChildComponent(destinationRowComponent);
+        final IComponent<OfficeOpenXMLOperationDocument> oldTr = getChildComponent(destinationRowComponent);
         DLNode<Object> referenceNode = oldTr!=null?oldTr.getNode():null;
 
         for(int i = 0; i<count; i++) {
@@ -346,7 +346,7 @@ public class ShapeGraphicComponent extends PptxComponent implements IShapeCompon
             }
         }
         if(attrs!=null) {
-            Component<OfficeOpenXMLOperationDocument> c = getNextChildComponent(null, null).getComponent(destinationRowComponent);
+            IComponent<OfficeOpenXMLOperationDocument> c = getNextChildComponent(null, null).getComponent(destinationRowComponent);
 	        for(int i=0; i<count; i++) {
 	        	c.applyAttrsFromJSON(attrs);
 	        	c = c.getNextComponent();
@@ -363,7 +363,7 @@ public class ShapeGraphicComponent extends PptxComponent implements IShapeCompon
 	            if(referenceP.getPPr(false)!=null) {
 	                p.setPPr(XmlUtils.deepCopy(referenceP.getPPr(false), operationDocument.getPackage()));
 	            }
-	            Component<OfficeOpenXMLOperationDocument> c = referenceParagraphComponent.getNextChildComponent(null, null);
+	            IComponent<OfficeOpenXMLOperationDocument> c = referenceParagraphComponent.getNextChildComponent(null, null);
 	            if(c instanceof TextComponent) {
 	                final CTRegularTextRun textRun = ((CTRegularTextRun)c.getObject());
 	                if(textRun.getRPr(false)!=null) {
@@ -426,7 +426,7 @@ public class ShapeGraphicComponent extends PptxComponent implements IShapeCompon
 	}
 
     public void deleteColumns(int gridStart, int gridEnd) {
-        Component<OfficeOpenXMLOperationDocument> trComponent = getNextChildComponent(null, null);
+        IComponent<OfficeOpenXMLOperationDocument> trComponent = getNextChildComponent(null, null);
         while(trComponent!=null) {
             final DLNode<Object> trNode = trComponent.getNode();
         	final DLList<Object> rowContent = ((CTTableRow)trComponent.getObject()).getContent();
