@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -61,8 +61,9 @@ import com.openexchange.office.filter.core.DLNode;
 import com.openexchange.office.filter.core.IContentAccessor;
 import com.openexchange.office.filter.core.DLList;
 import com.openexchange.office.filter.core.component.Child;
-import com.openexchange.office.filter.core.component.Component;
 import com.openexchange.office.filter.core.component.ComponentContext;
+import com.openexchange.office.filter.core.component.ComponentType;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 import com.openexchange.office.filter.ooxml.components.IShapeType;
 import com.openexchange.office.filter.ooxml.components.ShapeType;
@@ -79,13 +80,13 @@ public class ShapeGroupComponent extends PptxComponent implements IShapeComponen
 	}
 
     @Override
-	public Component<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, Component<OfficeOpenXMLOperationDocument> previousChildComponent) {
+	public IComponent<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, IComponent<OfficeOpenXMLOperationDocument> previousChildComponent) {
         final DLNode<Object> groupShapeNode = getNode();
         final DLList<Object> nodeList = (DLList<Object>)((IContentAccessor)groupShapeNode.getData()).getContent();
         final int nextComponentNumber = previousChildComponent!=null?previousChildComponent.getNextComponentNumber():0;
         DLNode<Object> childNode = previousChildContext!=null ? previousChildContext.getNode().getNext() : nodeList.getFirstNode();
 
-        Component<OfficeOpenXMLOperationDocument> nextComponent = null;
+        IComponent<OfficeOpenXMLOperationDocument> nextComponent = null;
         for(; nextComponent==null&&childNode!=null; childNode = childNode.getNext()) {
             final Object o = getContentModel(childNode, groupShapeNode.getData());
             if(o instanceof GroupShape) {
@@ -113,7 +114,7 @@ public class ShapeGroupComponent extends PptxComponent implements IShapeComponen
     }
 
     @Override
-    public Component<OfficeOpenXMLOperationDocument> insertChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> parentContext, DLNode<Object> contextNode, int number, Component<OfficeOpenXMLOperationDocument> child, Component.Type type, JSONObject attrs) {
+    public IComponent<OfficeOpenXMLOperationDocument> insertChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> parentContext, DLNode<Object> contextNode, int number, IComponent<OfficeOpenXMLOperationDocument> child, ComponentType type, JSONObject attrs) {
 
     	DLList<Object> DLList = (DLList<Object>)((IContentAccessor)contextNode.getData()).getContent();
         DLNode<Object> referenceNode = child!=null ? child.getNode() : null;
