@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,7 +50,6 @@
 package com.openexchange.office.filter.ooxml.pptx.components;
 
 import java.util.List;
-import javax.xml.bind.JAXBException;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
 import org.docx4j.openpackaging.exceptions.PartUnrecognisedException;
 import org.docx4j.openpackaging.parts.Part;
@@ -86,11 +85,11 @@ import com.openexchange.office.filter.core.DLNode;
 import com.openexchange.office.filter.core.IContentAccessor;
 import com.openexchange.office.filter.core.DLList;
 import com.openexchange.office.filter.core.component.Child;
-import com.openexchange.office.filter.core.component.Component;
 import com.openexchange.office.filter.core.component.ComponentContext;
+import com.openexchange.office.filter.core.component.ComponentType;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
-import com.openexchange.office.filter.ooxml.components.OfficeOpenXMLComponent;
 import com.openexchange.office.filter.ooxml.drawingml.DMLHelper;
 import com.openexchange.office.filter.ooxml.pptx.PptxOperationDocument;
 import com.openexchange.office.filter.ooxml.pptx.tools.PMLShapeHelper;
@@ -106,13 +105,13 @@ public class SlideComponent extends PptxComponent {
     }
 
     @Override
-	public Component<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, Component<OfficeOpenXMLOperationDocument> previousChildComponent) {
+	public IComponent<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, IComponent<OfficeOpenXMLOperationDocument> previousChildComponent) {
         final DLNode<Object> paragraphNode = getNode();
         final DLList<Object> nodeList = (DLList<Object>)((IContentAccessor)paragraphNode.getData()).getContent();
         final int nextComponentNumber = previousChildComponent!=null?previousChildComponent.getNextComponentNumber():0;
         DLNode<Object> childNode = previousChildContext!=null ? previousChildContext.getNode().getNext() : nodeList.getFirstNode();
 
-        Component<OfficeOpenXMLOperationDocument> nextComponent = null;
+        IComponent<OfficeOpenXMLOperationDocument> nextComponent = null;
         for(; nextComponent==null&&childNode!=null; childNode = childNode.getNext()) {
             final Object o = getContentModel(childNode, paragraphNode.getData());
             if(o instanceof GroupShape) {
@@ -184,7 +183,7 @@ public class SlideComponent extends PptxComponent {
     }
 
     @Override
-    public Component<OfficeOpenXMLOperationDocument> insertChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> parentContext, DLNode<Object> contextNode, int number, Component<OfficeOpenXMLOperationDocument> child, Component.Type type, JSONObject attrs)
+    public IComponent<OfficeOpenXMLOperationDocument> insertChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> parentContext, DLNode<Object> contextNode, int number, IComponent<OfficeOpenXMLOperationDocument> child, ComponentType type, JSONObject attrs)
     	throws Exception {
 
     	DLList<Object> DLList = (DLList<Object>)((IContentAccessor)contextNode.getData()).getContent();
@@ -220,7 +219,7 @@ public class SlideComponent extends PptxComponent {
 	            return new ShapePicComponent(parentContext, newChildNode, number);
         	}
         	case TABLE: {
-        		final Child newChild = PMLShapeHelper.createGraphicalObjectFrame(Type.TABLE);
+        		final Child newChild = PMLShapeHelper.createGraphicalObjectFrame(ComponentType.TABLE);
 	            newChild.setParent(contextNode.getData());
 	            final DLNode<Object> newChildNode = new DLNode<Object>(newChild);
 	            DLList.addNode(referenceNode, newChildNode, true);
