@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,8 +54,8 @@ import org.docx4j.dml.CTTableRow;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.office.filter.core.DLNode;
-import com.openexchange.office.filter.core.component.Component;
 import com.openexchange.office.filter.core.component.ComponentContext;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.core.DLList;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 import com.openexchange.office.filter.ooxml.drawingml.DMLHelper;
@@ -71,13 +71,13 @@ public class TableRowComponent extends PptxComponent {
     }
 
     @Override
-	public Component<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, Component<OfficeOpenXMLOperationDocument> previousChildComponent) {
+	public IComponent<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, IComponent<OfficeOpenXMLOperationDocument> previousChildComponent) {
         final DLList<Object> nodeList = tableRow.getContent();
         final int nextComponentNumber = previousChildComponent!=null?previousChildComponent.getNextComponentNumber():0;
         final int nextGridPosition = previousChildComponent instanceof TableCellComponent ? ((TableCellComponent)previousChildComponent).getNextGridPosition() : 0;
         DLNode<Object> childNode = previousChildContext!=null ? previousChildContext.getNode().getNext() : nodeList.getFirstNode();
 
-        Component<OfficeOpenXMLOperationDocument> nextComponent = null;
+        IComponent<OfficeOpenXMLOperationDocument> nextComponent = null;
         for(; nextComponent==null&&childNode!=null; childNode = childNode.getNext()) {
             final Object o = getContentModel(childNode, tableRow);
             if(o instanceof CTTableCell&&!((CTTableCell)o).isHMerge()) {
@@ -105,7 +105,7 @@ public class TableRowComponent extends PptxComponent {
 
 	public void insertCells(int cellPosition, int count, JSONObject attrs) throws Exception {
 
-	    Component<OfficeOpenXMLOperationDocument> c = getChildComponent(cellPosition);
+	    IComponent<OfficeOpenXMLOperationDocument> c = getChildComponent(cellPosition);
         final DLList<Object> trContent = tableRow.getContent();
         for (int i=0; i<count; i++) {
             final CTTableCell tc = new CTTableCell();
