@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -68,8 +68,8 @@ import com.openexchange.office.filter.core.DLNode;
 import com.openexchange.office.filter.core.IContentAccessor;
 import com.openexchange.office.filter.core.DLList;
 import com.openexchange.office.filter.core.SplitMode;
-import com.openexchange.office.filter.core.component.Component;
 import com.openexchange.office.filter.core.component.ComponentContext;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 import com.openexchange.office.filter.ooxml.drawingml.DMLHelper;
 import com.openexchange.office.filter.ooxml.pptx.tools.PMLShapeHelper;
@@ -94,21 +94,21 @@ public class TextComponent extends PptxComponent {
             System.out.println("Error: empty text string is no component... this results in problems with the component iterator");
             textLength++;       // increasing.. preventing an endless loop
         }
-        return componentNumber + textLength;
+        return getComponentNumber() + textLength;
     }
 
     @Override
     public void splitStart(int componentPosition, SplitMode splitMode) {
-    	final int splitPosition = componentPosition-componentNumber;
+    	final int splitPosition = componentPosition-getComponentNumber();
     	if(splitPosition>0) {
     		splitText(splitPosition, true);
-    		componentNumber+=splitPosition;
+    		setComponentNumber(getComponentNumber() + splitPosition);
     	}
     }
 
     @Override
     public void delete(int count) {
-        if(componentNumber==0&&getNextComponent()==null) {
+        if(getComponentNumber()==0&&getNextComponent()==null) {
             getParagraphComponent().getParagraph().setEndParaRPr(textRun.getRPr(false));
         }
         super.delete(count);
@@ -117,7 +117,7 @@ public class TextComponent extends PptxComponent {
     @Override
     public void splitEnd(int componentPosition, SplitMode splitMode) {
     	if(getNextComponentNumber()>++componentPosition) {
-    		splitText(componentPosition-componentNumber, false);
+    		splitText(componentPosition-getComponentNumber(), false);
     	}
     }
 
@@ -141,7 +141,7 @@ public class TextComponent extends PptxComponent {
     }
 
 	@Override
-	public Component<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, Component<OfficeOpenXMLOperationDocument> previousChildComponent) {
+	public IComponent<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, IComponent<OfficeOpenXMLOperationDocument> previousChildComponent) {
 		return null;
 	}
 
@@ -156,7 +156,7 @@ public class TextComponent extends PptxComponent {
         throws JSONException {
 
         if(attrs!=null&& attrs.hasAndNotNull(OCKey.CHARACTER.value())) {
-            final Component<OfficeOpenXMLOperationDocument> parentComponent = ((ParagraphComponent)paragraphChildComponent.getParentComponent()).getParentComponent();
+            final IComponent<OfficeOpenXMLOperationDocument> parentComponent = ((ParagraphComponent)paragraphChildComponent.getParentComponent()).getParentComponent();
             if(parentComponent instanceof IShapeComponent&&((IShapeComponent)parentComponent).isPresentationObject()) {
                 final ShapeComponent shapeComponent = (ShapeComponent)parentComponent;
                 final SlideComponent slideComponent = PMLShapeHelper.getSlideComponent(shapeComponent);
