@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -121,8 +121,8 @@ import com.openexchange.office.filter.core.SplitMode;
 import com.openexchange.office.filter.core.Tools;
 import com.openexchange.office.filter.core.component.CUtil;
 import com.openexchange.office.filter.core.component.Child;
-import com.openexchange.office.filter.core.component.Component;
-import com.openexchange.office.filter.ooxml.components.OfficeOpenXMLComponent;
+import com.openexchange.office.filter.core.component.ComponentType;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 import com.openexchange.office.filter.ooxml.components.IParagraph;
 import com.openexchange.office.filter.ooxml.drawingml.DMLHelper;
@@ -383,7 +383,7 @@ public class PptxApplyOperationHelper extends ApplyOperationHelper {
                     }
                     final JSONArray start = new JSONArray(1);
                     start.put(i);
-                    final Component<OfficeOpenXMLOperationDocument> slideComponent = new RootComponent(getOperationDocument(), presentationMLPackage.getMainPresentationPart()).getComponent(start, 1);
+                    final IComponent<OfficeOpenXMLOperationDocument> slideComponent = new RootComponent(getOperationDocument(), presentationMLPackage.getMainPresentationPart()).getComponent(start, 1);
                     final SlidePart slidePart = (SlidePart)slideComponent.getObject();
                     presentationMLPackage.getSourcePartStore().marshalToSourcePart(slidePart);
                     slidePart.setJaxbElement(null);
@@ -510,11 +510,11 @@ public class PptxApplyOperationHelper extends ApplyOperationHelper {
                 break;
             }
             case INSERT_COMMENT : {
-                insertComment(op.getJSONArray(OCKey.START.value()),  op.getJSONArray(OCKey.POS.value()), op.getString(OCKey.TEXT.value()), op.getString(OCKey.DATE.value()), op.optInt(OCKey.COLOR_INDEX.value(), -1), op.optInt(OCKey.AUTHOR_ID.value(), -1), op.optString(OCKey.AUTHOR.value(), null), op.optString(OCKey.INITIALS.value(), ""), op.optString(OCKey.PROVIDER_ID.value(), null), op.optString(OCKey.USER_ID.value(), null), op.optInt(OCKey.PARENT.value(), -1));
+                insertComment(op.getJSONArray(OCKey.START.value()),  op.getJSONArray(OCKey.POS.value()), applyMentions(op.getString(OCKey.TEXT.value()), op.optJSONArray(OCKey.MENTIONS.value())), op.getString(OCKey.DATE.value()), op.optInt(OCKey.COLOR_INDEX.value(), -1), op.optInt(OCKey.AUTHOR_ID.value(), -1), op.optString(OCKey.AUTHOR.value(), null), op.optString(OCKey.INITIALS.value(), ""), op.optString(OCKey.PROVIDER_ID.value(), null), op.optString(OCKey.USER_ID.value(), null), op.optInt(OCKey.PARENT.value(), -1));
                 break;
             }
             case CHANGE_COMMENT : {
-                changeComment(op.getJSONArray(OCKey.START.value()),  op.optJSONArray(OCKey.POS.value()), op.optString(OCKey.TEXT.value(), null));
+                changeComment(op.getJSONArray(OCKey.START.value()),  op.optJSONArray(OCKey.POS.value()), applyMentions(op.optString(OCKey.TEXT.value(), null), op.optJSONArray(OCKey.MENTIONS.value())));
                 break;
             }
             case DELETE_COMMENT : {
@@ -536,7 +536,7 @@ public class PptxApplyOperationHelper extends ApplyOperationHelper {
 
     public void insertParagraph(JSONArray start, String target, JSONObject attrs) throws Exception {
 
-        new RootComponent(operationDocument, (SerializationPart<?>)getPartByTarget(target)).getComponent(start, start.length()-1).insertChildComponent(start.getInt(start.length()-1), attrs, Component.Type.PARAGRAPH);
+        new RootComponent(operationDocument, (SerializationPart<?>)getPartByTarget(target)).getComponent(start, start.length()-1).insertChildComponent(start.getInt(start.length()-1), attrs, ComponentType.PARAGRAPH);
     }
 
     public void splitParagraph(JSONArray start, String target)
@@ -553,7 +553,7 @@ public class PptxApplyOperationHelper extends ApplyOperationHelper {
     public void insertText(JSONArray start, String target, String text, JSONObject attrs) throws Exception {
 
     	if(text.length()>0) {
-    		final Component<OfficeOpenXMLOperationDocument> component = new RootComponent(operationDocument, (SerializationPart<?>)getPartByTarget(target)).getComponent(start, start.length()-1);
+    		final IComponent<OfficeOpenXMLOperationDocument> component = new RootComponent(operationDocument, (SerializationPart<?>)getPartByTarget(target)).getComponent(start, start.length()-1);
     		((IParagraph)component).insertText(start.getInt(start.length()-1), text, attrs);
     	}
     }
@@ -576,7 +576,7 @@ public class PptxApplyOperationHelper extends ApplyOperationHelper {
                 return;
             endIndex = end.getInt(end.length()-1);
         }
-        Component<OfficeOpenXMLOperationDocument> component = new RootComponent(operationDocument, (SerializationPart<?>)getPartByTarget(target)).getComponent(start, start.length());
+        IComponent<OfficeOpenXMLOperationDocument> component = new RootComponent(operationDocument, (SerializationPart<?>)getPartByTarget(target)).getComponent(start, start.length());
 		component.splitStart(startIndex, SplitMode.ATTRIBUTE);
         while(component!=null&&component.getComponentNumber()<=endIndex) {
         	if(component.getNextComponentNumber()>=endIndex+1) {
@@ -704,20 +704,20 @@ public class PptxApplyOperationHelper extends ApplyOperationHelper {
     	return spTree;
     }
 
-    public Component<OfficeOpenXMLOperationDocument> insertDrawing(JSONArray start, String target, String type, JSONObject attrs) throws Exception {
+    public IComponent<OfficeOpenXMLOperationDocument> insertDrawing(JSONArray start, String target, String type, JSONObject attrs) throws Exception {
 
-    	OfficeOpenXMLComponent.Type cType = OfficeOpenXMLComponent.Type.AC_SHAPE;
+    	ComponentType cType = ComponentType.AC_SHAPE;
     	if(type.equals("IMAGE")) {
-    		cType = OfficeOpenXMLComponent.Type.AC_IMAGE;
+    		cType = ComponentType.AC_IMAGE;
     	}
     	else if(type.equals("GROUP")) {
-    		cType = OfficeOpenXMLComponent.Type.AC_GROUP;
+    		cType = ComponentType.AC_GROUP;
     	}
     	else if(type.equals("CONNECTOR")) {
-    		cType = OfficeOpenXMLComponent.Type.AC_CONNECTOR;
+    		cType = ComponentType.AC_CONNECTOR;
     	}
     	else if(type.equals("TABLE")) {
-    		cType = OfficeOpenXMLComponent.Type.TABLE;
+    		cType = ComponentType.TABLE;
     	}
     	return new RootComponent(operationDocument, (SerializationPart<?>)getPartByTarget(target)).getComponent(start, start.length()-1).insertChildComponent(start.getInt(start.length()-1), attrs, cType);
     }
@@ -772,7 +772,7 @@ public class PptxApplyOperationHelper extends ApplyOperationHelper {
     public void insertHardBreak(JSONArray start, String target, JSONObject attrs) throws Exception {
 
         new RootComponent(operationDocument, (SerializationPart<?>)getPartByTarget(target)).getComponent(start, start.length()-1)
-			.insertChildComponent(start.getInt(start.length()-1), attrs, Component.Type.HARDBREAK_DEFAULT);
+			.insertChildComponent(start.getInt(start.length()-1), attrs, ComponentType.HARDBREAK_DEFAULT);
     }
 
     public void changeLayout(JSONArray start, String target)
@@ -838,7 +838,7 @@ public class PptxApplyOperationHelper extends ApplyOperationHelper {
     public void insertField(JSONArray start, String target, String type, String representation, JSONObject attrs) throws Exception {
 
     	final CTTextField textField = (CTTextField)new RootComponent(operationDocument, (SerializationPart<?>)getPartByTarget(target)).getComponent(start, start.length()-1)
-			.insertChildComponent(start.getInt(start.length()-1), attrs, Component.Type.SIMPLE_FIELD).getObject();
+			.insertChildComponent(start.getInt(start.length()-1), attrs, ComponentType.SIMPLE_FIELD).getObject();
 
     	textField.setId("{2640DB9D-575D-4FF8-9117-D1A6111C2CD0}");
     	textField.setType(type);
@@ -861,12 +861,12 @@ public class PptxApplyOperationHelper extends ApplyOperationHelper {
 
     	final List<Object> drawingChildObjects = new ArrayList<Object>();
     	for(int i = drawings.length()-1; i >= 0; i--) {
-    		final Component<OfficeOpenXMLOperationDocument> child = new RootComponent(operationDocument, (SerializationPart<?>)getPartByTarget(target)).getComponent(start, start.length()-1).getChildComponent(drawings.getInt(i));
+    		final IComponent<OfficeOpenXMLOperationDocument> child = new RootComponent(operationDocument, (SerializationPart<?>)getPartByTarget(target)).getComponent(start, start.length()-1).getChildComponent(drawings.getInt(i));
     		drawingChildObjects.add(0, child.getObject());
     		child.splitStart(child.getComponentNumber(), SplitMode.DELETE);
     		child.delete(1);
     	}
-    	final Component<OfficeOpenXMLOperationDocument> groupComponent = insertDrawing(start, target, "GROUP", attrs);
+    	final IComponent<OfficeOpenXMLOperationDocument> groupComponent = insertDrawing(start, target, "GROUP", attrs);
     	final GroupShape groupShape = (GroupShape)groupComponent.getObject();
     	groupShape.getContent().addAll(drawingChildObjects);
 
@@ -997,7 +997,7 @@ public class PptxApplyOperationHelper extends ApplyOperationHelper {
     	throws JSONException {
 
     	final int groupPosition = start.getInt(start.length()-1);
-    	final Component<OfficeOpenXMLOperationDocument> parentComponent = new RootComponent(operationDocument, (SerializationPart<?>)getPartByTarget(target)).getComponent(start, start.length()-1);
+    	final IComponent<OfficeOpenXMLOperationDocument> parentComponent = new RootComponent(operationDocument, (SerializationPart<?>)getPartByTarget(target)).getComponent(start, start.length()-1);
     	final DLList<Object> parentContent = (DLList<Object>)((IContentAccessor)parentComponent.getObject()).getContent();
 
     	final ShapeGroupComponent groupComponent = (ShapeGroupComponent)parentComponent.getChildComponent(groupPosition);
@@ -1017,7 +1017,7 @@ public class PptxApplyOperationHelper extends ApplyOperationHelper {
 		groupComponent.splitStart(groupComponent.getComponentNumber(), SplitMode.DELETE);;
 		groupComponent.delete(1);
 
-		Component<OfficeOpenXMLOperationDocument> referenceComponent = parentComponent.getChildComponent(groupPosition);
+		IComponent<OfficeOpenXMLOperationDocument> referenceComponent = parentComponent.getChildComponent(groupPosition);
 		DLNode<Object> referenceNode = referenceComponent!=null ? referenceComponent.getNode() : null;
 
 		for(int i = 0; i < groupContent.size(); i++) {
@@ -1113,15 +1113,15 @@ public class PptxApplyOperationHelper extends ApplyOperationHelper {
         if(i==startPosition.length()-1) {
             before = startPosition.getInt(i)>toPosition.getInt(i);
         }
-        final Component<OfficeOpenXMLOperationDocument> sourceBegComponent = operationDocument.getRootComponent().getComponent(startPosition, startPosition.length());
-        final Component<OfficeOpenXMLOperationDocument> sourceEndComponent = sourceBegComponent.getComponent(endPosition.getInt(startPosition.length()-1));
+        final IComponent<OfficeOpenXMLOperationDocument> sourceBegComponent = operationDocument.getRootComponent().getComponent(startPosition, startPosition.length());
+        final IComponent<OfficeOpenXMLOperationDocument> sourceEndComponent = sourceBegComponent.getComponent(endPosition.getInt(startPosition.length()-1));
         final DLList<Object> sourceContent = (DLList<Object>)((IContentAccessor)sourceBegComponent.getParentComponent().getNode().getData()).getContent();
         sourceBegComponent.splitStart(startPosition.getInt(startPosition.length()-1), SplitMode.DELETE);
         sourceEndComponent.splitEnd(endPosition.getInt(startPosition.length()-1), SplitMode.DELETE);
 
         // destComponent is empty if the content is to be appended
-        final Component<OfficeOpenXMLOperationDocument> destComponent = operationDocument.getRootComponent().getComponent(toPosition, toPosition.length());
-        Component<OfficeOpenXMLOperationDocument> destParentComponent;
+        final IComponent<OfficeOpenXMLOperationDocument> destComponent = operationDocument.getRootComponent().getComponent(toPosition, toPosition.length());
+        IComponent<OfficeOpenXMLOperationDocument> destParentComponent;
         if(destComponent!=null) {
             destComponent.splitStart(toPosition.getInt(toPosition.length()-1), SplitMode.DELETE);
             destParentComponent = destComponent.getParentComponent();
@@ -1221,6 +1221,7 @@ public class PptxApplyOperationHelper extends ApplyOperationHelper {
     private void insertComment(JSONArray start, JSONArray pos, String text, String date, int colorIndex, int authorId, String author, String initials, String providerId, String userId, int parentIndex)
         throws JSONException, InvalidFormatException, DatatypeConfigurationException {
 
+        // we are adding a suffix to the author to prevent same authors with different provider which make problems
         final CTCommentAuthorList commentAuthorList = presentationMLPackage.getMainPresentationPart().getCommentAuthorsList(true);
         final CTCommentAuthor commentAuthor = authorId==-1 ? commentAuthorList.getCommentAuthor(author, initials, providerId, userId, true) : commentAuthorList.getCommentAuthor(authorId);
         if(colorIndex>=0) {
@@ -1271,6 +1272,37 @@ public class PptxApplyOperationHelper extends ApplyOperationHelper {
         }
     }
 
+    private String applyMentions(String text, JSONArray mentions) throws JSONException, InvalidFormatException {
+        if(text == null || mentions == null || mentions.length() == 0) {
+            return text;
+        }
+        final CTCommentAuthorList commentAuthorList = presentationMLPackage.getMainPresentationPart().getCommentAuthorsList(true);
+        final StringBuilder builder = new StringBuilder(text);
+        for(int i = mentions.length() - 1; i >= 0; i--) {
+            final JSONObject mention = mentions.getJSONObject(i);
+            final int pos = mention.getInt(OCKey.POS.value());
+            final int length = mention.getInt(OCKey.LENGHT.value());
+            builder.insert(pos + length, ']');
+            builder.insert(pos, "[");
+
+            // adding mentioned person to the commentAuthors list
+            final String displayName = mention.optString(OCKey.DISPLAY_NAME.value(), "");
+            final String userId = mention.optString(OCKey.USER_ID.value(), "");
+            final String providerId = mention.optString(OCKey.PROVIDER_ID.value(), "");
+            if(!displayName.isEmpty() && !userId.isEmpty() && !providerId.isEmpty()) {
+                commentAuthorList.getCommentAuthor(applyProviderNameExtension(displayName, providerId), "", providerId, userId, true);
+            }
+        }
+        return builder.toString();
+    }
+
+    private String applyProviderNameExtension(String author, String providerId) {
+        if("ox".equals(providerId)) {
+            return author + " [~ox]";
+        }
+        return author;
+    }
+
     private void deleteComment(JSONArray start)
         throws InvalidFormatException, JSONException {
 
