@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -99,7 +99,7 @@ import com.openexchange.office.filter.api.FilterException;
 import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.api.OCValue;
 import com.openexchange.office.filter.core.DLNode;
-import com.openexchange.office.filter.core.component.Component;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.ooxml.components.OfficeOpenXMLComponent;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 import com.openexchange.office.filter.ooxml.components.IShapeType;
@@ -194,15 +194,22 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
             while(commentAuthorNode!=null) {
                 final JSONObject author = new JSONObject();
                 final CTCommentAuthor commentAuthor = commentAuthorNode.getData();
+                String authorName = commentAuthor.getName();
                 author.put(OCKey.AUTHOR_ID.value(), commentAuthor.getId());
-                author.put(OCKey.AUTHOR_NAME.value(), commentAuthor.getName());
                 author.put(OCKey.INITIALS.value(), commentAuthor.getInitials());
                 author.put(OCKey.COLOR_INDEX.value(), commentAuthor.getClrIdx());
                 final CTPresenceInfo presenceInfo = commentAuthor.getPresenceInfo(false);
                 if(presenceInfo!=null) {
-                    author.put(OCKey.PROVIDER_ID.value(), presenceInfo.getProviderId());
+                    final String providerId = presenceInfo.getProviderId();
+                    author.put(OCKey.PROVIDER_ID.value(), providerId);
                     author.put(OCKey.USER_ID.value(), presenceInfo.getUserId());
+                    // removing [ox] if provider id is ox
+                    final String suffix = " [~ox]";
+                    if("ox".equals(providerId) && authorName.length() > suffix.length() && authorName.endsWith(suffix)) {
+                        authorName = authorName.substring(0, authorName.length() - suffix.length());
+                    }
                 }
+                author.put(OCKey.AUTHOR_NAME.value(), authorName);
                 authors.put(author);
                 commentAuthorNode = commentAuthorNode.getNext();
             }
@@ -248,7 +255,7 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
     public void createSlides() throws Exception {
 
         final RootComponent rootComponent = new RootComponent(getOperationDocument(), presentationMLPackage.getMainPresentationPart());
-        Component<OfficeOpenXMLOperationDocument> slideComponent = rootComponent.getNextChildComponent(null, null);
+        IComponent<OfficeOpenXMLOperationDocument> slideComponent = rootComponent.getNextChildComponent(null, null);
         while (slideComponent!=null) {
 
             getOperationDocument().setContextPart((Part)slideComponent.getObject());
@@ -283,7 +290,7 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
                     pos.put(Double.valueOf(((comment.getPos().getX() * 2540.0) / 576.0) + 0.5).longValue());
                     pos.put(Double.valueOf(((comment.getPos().getY() * 2540.0) / 576.0) + 0.5).longValue());
                     commentOperation.put(OCKey.POS.value(), pos);
-                    commentOperation.put(OCKey.TEXT.value(), comment.getText());
+                    commentOperation.put(OCKey.TEXT.value(), createMentions(comment.getText(), commentOperation));
                     if (comment.getDt() != null) {
                         String date = comment.getDt().toXMLFormat();
                         if (!date.toLowerCase().endsWith("z")) {
@@ -317,10 +324,50 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
         }
     }
 
+    /*
+     * removing each [@...] of a mention
+     *
+     * returned: the text without '[@]'... a corresponding mentions array is put into the commentOperation
+     */
+    private String createMentions(String text, JSONObject commentOperation) throws JSONException {
+        if(text==null || text.isEmpty()) {
+            return text;
+        }
+        JSONArray jsonArray = null;
+        final StringBuilder builder = new StringBuilder(text);
+        for(int j, i = 0; (i + 1) < builder.length(); i++) {
+            if(builder.charAt(i) == '[' && builder.charAt(i + 1) == '@') {
+                for(j = i + 2; j < builder.length(); j++) {
+                    if(builder.charAt(j)==']') {
+                        final JSONObject mention = new JSONObject(2);
+                        mention.put(OCKey.POS.value(), i);
+                        // mention.put(OCKey.LENGHT.value(), j - (i + 2));
+                        mention.put(OCKey.LENGHT.value(), j - (i + 1));
+                        if(jsonArray==null) {
+                            jsonArray = new JSONArray();
+                            commentOperation.put(OCKey.MENTIONS.value(), jsonArray);
+                        }
+                        jsonArray.put(mention);
+                        builder.deleteCharAt(j);
+                        builder.deleteCharAt(i);
+                        // builder.deleteCharAt(i);
+                        // i = j - 2;
+                        i = j - 1;
+                        break;
+                    }
+                }
+                if(j == builder.length()) { // there is no ']' -> there are no more mentions
+                    break;
+                }
+            }
+        }
+        return builder.toString();
+    }
+
     public void createMasterSlideOperations(SlideMasterPart slideMasterPart, String target) throws Exception {
 
         final RootComponent rootComponent = new RootComponent(getOperationDocument(), slideMasterPart);
-        final Component<OfficeOpenXMLOperationDocument> slideComponent = rootComponent.getNextChildComponent(null, null);
+        final IComponent<OfficeOpenXMLOperationDocument> slideComponent = rootComponent.getNextChildComponent(null, null);
         if(slideComponent!=null) {
             final JSONObject jsonInsertMasterSlideOperation = new JSONObject(3);
             jsonInsertMasterSlideOperation.put(OCKey.NAME.value(), OCValue.INSERT_MASTER_SLIDE.value());
@@ -353,7 +400,7 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
     public void createLayoutSlideOperations(SlideLayoutPart slideLayoutPart, String target, String referencedMaster) throws Exception {
 
         final RootComponent rootComponent = new RootComponent(getOperationDocument(), slideLayoutPart);
-        final Component<OfficeOpenXMLOperationDocument> slideComponent = rootComponent.getNextChildComponent(null, null);
+        final IComponent<OfficeOpenXMLOperationDocument> slideComponent = rootComponent.getNextChildComponent(null, null);
         if(slideComponent!=null) {
             final JSONObject jsonInsertLayoutSlideOperation = new JSONObject(4);
             jsonInsertLayoutSlideOperation.put(OCKey.NAME.value(), OCValue.INSERT_LAYOUT_SLIDE.value());
@@ -366,7 +413,7 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
         part.setJaxbElement(null);
     }
 
-    public void createCommonSlideDataOperations(Component<OfficeOpenXMLOperationDocument> slideComponent, int slide, String target, JSONObject slideInsertOperation, JSONObject attrs) throws Exception {
+    public void createCommonSlideDataOperations(IComponent<OfficeOpenXMLOperationDocument> slideComponent, int slide, String target, JSONObject slideInsertOperation, JSONObject attrs) throws Exception {
 
         ((OfficeOpenXMLComponent)slideComponent).createJSONAttrs(attrs);
 
@@ -392,7 +439,7 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
 
         final ArrayList<Integer> position = new ArrayList<Integer>();
         position.add(slide);
-        Component<OfficeOpenXMLOperationDocument> shapeComponent = slideComponent.getNextChildComponent(null, null);
+        IComponent<OfficeOpenXMLOperationDocument> shapeComponent = slideComponent.getNextChildComponent(null, null);
         while(shapeComponent!=null) {
             createShapeOperations(shapeComponent, position, target);
             shapeComponent = shapeComponent.getNextComponent();
@@ -428,7 +475,7 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
         }
     }
 
-    public void createShapeOperations(Component<OfficeOpenXMLOperationDocument> shapeComponent, List<Integer> parentPosition, String target) throws Exception {
+    public void createShapeOperations(IComponent<OfficeOpenXMLOperationDocument> shapeComponent, List<Integer> parentPosition, String target) throws Exception {
 
         final List<Integer> position = new ArrayList<Integer>(parentPosition);
         position.add(shapeComponent.getComponentNumber());
@@ -445,7 +492,7 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
             jsonInsertOperation.put(OCKey.ATTRS.value(), attrs);
         }
         operationsArray.put(jsonInsertOperation);
-        Component<OfficeOpenXMLOperationDocument> shapeChildComponent = shapeComponent.getNextChildComponent(null, null);
+        IComponent<OfficeOpenXMLOperationDocument> shapeChildComponent = shapeComponent.getNextChildComponent(null, null);
         while(shapeChildComponent!=null) {
             if(shapeChildComponent instanceof ParagraphComponent) {
                 createParagraphOperations((ParagraphComponent)shapeChildComponent, position, target);
@@ -476,7 +523,7 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
             jsonInsertParagraphOperation.put(OCKey.ATTRS.value(), attrs);
         }
         operationsArray.put(jsonInsertParagraphOperation);
-        Component<OfficeOpenXMLOperationDocument> paragraphChild = paragraphComponent.getNextChildComponent(null, null);
+        IComponent<OfficeOpenXMLOperationDocument> paragraphChild = paragraphComponent.getNextChildComponent(null, null);
         while(paragraphChild!=null) {
             if(paragraphChild instanceof TextComponent) {
                 int n = paragraphChild.getComponentNumber();
@@ -534,7 +581,7 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
         }
         operationsArray.put(jsonInsertRowOperation);
 
-        Component<OfficeOpenXMLOperationDocument> tableRowChild = tableRowComponent.getNextChildComponent(null, null);
+        IComponent<OfficeOpenXMLOperationDocument> tableRowChild = tableRowComponent.getNextChildComponent(null, null);
         while(tableRowChild!=null) {
             if(tableRowChild instanceof TableCellComponent) {
                 createTableCellOperation((TableCellComponent)tableRowChild, position, target);
@@ -560,7 +607,7 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
         }
         operationsArray.put(jsonInsertRowOperation);
 
-        Component<OfficeOpenXMLOperationDocument> tableCellChild = tableCellComponent.getNextChildComponent(null, null);
+        IComponent<OfficeOpenXMLOperationDocument> tableCellChild = tableCellComponent.getNextChildComponent(null, null);
         while(tableCellChild!=null) {
             if(tableCellChild instanceof ParagraphComponent) {
                 createParagraphOperations((ParagraphComponent)tableCellChild, position, target);
