@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -97,9 +97,9 @@ import org.pptx4j.pml.Shape;
 import org.pptx4j.pml.Shape.NvSpPr;
 import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.core.IContentAccessor;
-import com.openexchange.office.filter.core.component.Component;
+import com.openexchange.office.filter.core.component.ComponentType;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
-import com.openexchange.office.filter.ooxml.components.OfficeOpenXMLComponent;
 import com.openexchange.office.filter.ooxml.pptx.PptxOperationDocument;
 import com.openexchange.office.filter.ooxml.pptx.components.SlideComponent;
 
@@ -206,7 +206,7 @@ final public class PMLShapeHelper {
         return attrs;
 	}
 
-	public static SlideComponent getSlideComponent(Component<OfficeOpenXMLOperationDocument> component) {
+	public static SlideComponent getSlideComponent(IComponent<OfficeOpenXMLOperationDocument> component) {
 		while(!(component instanceof SlideComponent)) {
 			component = component.getParentComponent();
 		}
@@ -299,7 +299,7 @@ final public class PMLShapeHelper {
 		"	</a:graphic>" +
 		"</p:graphicFrame>";
 
-	public static CTGraphicalObjectFrame createGraphicalObjectFrame(OfficeOpenXMLComponent.Type type)
+	public static CTGraphicalObjectFrame createGraphicalObjectFrame(ComponentType type)
 		throws JAXBException {
 
 		final java.util.HashMap<String, String> mappings = new java.util.HashMap<String, String>();
