@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -107,8 +107,8 @@ import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.api.OCValue;
 import com.openexchange.office.filter.core.DocumentComplexity;
 import com.openexchange.office.filter.core.component.CUtil;
-import com.openexchange.office.filter.core.spreadsheet.ColumnRef;
-import com.openexchange.office.filter.core.spreadsheet.RowRef;
+import com.openexchange.office.filter.core.spreadsheet.CellRef;
+import com.openexchange.office.filter.core.spreadsheet.IntervalArray;
 import com.openexchange.office.filter.core.spreadsheet.SUtil;
 import com.openexchange.office.filter.core.spreadsheet.SmlUtils;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
@@ -532,31 +532,31 @@ public class XlsxOperationDocument extends com.openexchange.office.filter.ooxml.
                     		break;
                     	}
 	                    case CHANGE_CELLS : {
-	                        applyOperationHelper.changeCells(op.getInt(OCKey.SHEET.value()), SmlUtils.createCellRef(op.getString(OCKey.START.value())), op.getJSONArray(OCKey.CONTENTS.value()));
+	                        applyOperationHelper.changeCells(op.getInt(OCKey.SHEET.value()), op.getJSONObject(OCKey.CONTENTS.value()));
 	                        break;
 	                    }
 	                    case CHANGE_ROWS : {
-	                        applyOperationHelper.changeRows(op.getInt(OCKey.SHEET.value()), RowRef.createIntervals(op.getString(OCKey.INTERVALS.value())), op.optJSONObject(OCKey.ATTRS.value()), op.optString(OCKey.S.value(), null));
+	                        applyOperationHelper.changeRows(op.getInt(OCKey.SHEET.value()), IntervalArray.createIntervals(false, op.getString(OCKey.INTERVALS.value())), op.optJSONObject(OCKey.ATTRS.value()), op.optString(OCKey.S.value(), null));
 	                        break;
 	                    }
 	                    case CHANGE_COLUMNS : {
-	                        applyOperationHelper.changeColumns(op.getInt(OCKey.SHEET.value()),  ColumnRef.createIntervals(op.getString(OCKey.INTERVALS.value())), op.optJSONObject(OCKey.ATTRS.value()), op.optString(OCKey.S.value(), null));
+	                        applyOperationHelper.changeColumns(op.getInt(OCKey.SHEET.value()),  IntervalArray.createIntervals(true, op.getString(OCKey.INTERVALS.value())), op.optJSONObject(OCKey.ATTRS.value()), op.optString(OCKey.S.value(), null));
 	                        break;
 	                    }
 	                    case INSERT_ROWS : {
-	                        applyOperationHelper.insertRows(op.getInt(OCKey.SHEET.value()), RowRef.createIntervals(op.getString(OCKey.INTERVALS.value())), op.optJSONObject(OCKey.ATTRS.value()), op.optString(OCKey.S.value(), null));
+	                        applyOperationHelper.insertRows(op.getInt(OCKey.SHEET.value()), IntervalArray.createIntervals(false, op.getString(OCKey.INTERVALS.value())), op.optJSONObject(OCKey.ATTRS.value()), op.optString(OCKey.S.value(), null));
 	                        break;
 	                    }
 	                    case DELETE_ROWS : {
-	                        applyOperationHelper.deleteRows(op.getInt(OCKey.SHEET.value()), RowRef.createIntervals(op.getString(OCKey.INTERVALS.value())));
+	                        applyOperationHelper.deleteRows(op.getInt(OCKey.SHEET.value()), IntervalArray.createIntervals(false, op.getString(OCKey.INTERVALS.value())));
 	                        break;
 	                    }
 	                    case INSERT_COLUMNS : {
-	                        applyOperationHelper.insertColumns(op.getInt(OCKey.SHEET.value()), ColumnRef.createIntervals(op.getString(OCKey.INTERVALS.value())), op.optJSONObject(OCKey.ATTRS.value()), op.optString(OCKey.S.value(), null));
+	                        applyOperationHelper.insertColumns(op.getInt(OCKey.SHEET.value()), IntervalArray.createIntervals(true, op.getString(OCKey.INTERVALS.value())), op.optJSONObject(OCKey.ATTRS.value()), op.optString(OCKey.S.value(), null));
 	                        break;
 	                    }
 	                    case DELETE_COLUMNS : {
-	                        applyOperationHelper.deleteColumns(op.getInt(OCKey.SHEET.value()), ColumnRef.createIntervals(op.getString(OCKey.INTERVALS.value())));
+	                        applyOperationHelper.deleteColumns(op.getInt(OCKey.SHEET.value()), IntervalArray.createIntervals(true, op.getString(OCKey.INTERVALS.value())));
 	                        break;
 	                    }
 	                    case INSERT_SHEET : {
@@ -595,8 +595,8 @@ public class XlsxOperationDocument extends com.openexchange.office.filter.ooxml.
 	                        applyOperationHelper.deleteDrawing(op.getJSONArray(OCKey.START.value()));
 	                        break;
 	                    }
-	                    case SET_DRAWING_ATTRIBUTES : {
-	                        applyOperationHelper.applyDrawingAttributes(op.getJSONArray(OCKey.START.value()), op.getJSONObject(OCKey.ATTRS.value()));
+	                    case CHANGE_DRAWING : {
+	                        applyOperationHelper.changeDrawing(op.getJSONArray(OCKey.START.value()), op.getJSONObject(OCKey.ATTRS.value()));
 	                        break;
 	                    }
                         case MOVE_DRAWING : {
@@ -619,16 +619,16 @@ public class XlsxOperationDocument extends com.openexchange.office.filter.ooxml.
 	                        applyOperationHelper.deleteAutoStyle(op.optString(OCKey.TYPE.value(), "cell"), op.getString(OCKey.STYLE_ID.value()));
 	                        break;
 	                    }
-	                    case INSERT_CHART_DATA_SERIES : {
-	                        applyOperationHelper.insertChartDataSeries(op.getJSONArray(OCKey.START.value()), op.getInt(OCKey.SERIES.value()), op.optJSONObject(OCKey.ATTRS.value()));
+	                    case INSERT_CHART_SERIES : {
+	                        applyOperationHelper.insertChartSeries(op.getJSONArray(OCKey.START.value()), op.getInt(OCKey.SERIES.value()), op.optJSONObject(OCKey.ATTRS.value()));
 	                        break;
 	                    }
-	                    case SET_CHART_DATA_SERIES_ATTRIBUTES : {
-	                        applyOperationHelper.setChartDataSeriesAttributes(op.getJSONArray(OCKey.START.value()), op.getInt(OCKey.SERIES.value()), op.optJSONObject(OCKey.ATTRS.value()));
+	                    case CHANGE_CHART_SERIES : {
+	                        applyOperationHelper.changeChartSeries(op.getJSONArray(OCKey.START.value()), op.getInt(OCKey.SERIES.value()), op.optJSONObject(OCKey.ATTRS.value()));
 	                        break;
 	                    }
-	                    case DELETE_CHART_DATA_SERIES : {
-	                        applyOperationHelper.deleteChartDataSeries(op.getJSONArray(OCKey.START.value()), op.getInt(OCKey.SERIES.value()));
+	                    case DELETE_CHART_SERIES : {
+	                        applyOperationHelper.deleteChartSeries(op.getJSONArray(OCKey.START.value()), op.getInt(OCKey.SERIES.value()));
 	                        break;
 	                    }
 	                    case INSERT_NAME : {
@@ -643,31 +643,31 @@ public class XlsxOperationDocument extends com.openexchange.office.filter.ooxml.
 	                        applyOperationHelper.deleteName(op.optLong(OCKey.SHEET.value(), -1), op.getString(OCKey.LABEL.value()));
 	                        break;
 	                    }
-	                    case SET_CHART_AXIS_ATTRIBUTES : {
-	                        applyOperationHelper.setChartAxisAttributes(op.getJSONArray(OCKey.START.value()), op.getLong(OCKey.AXIS.value()), op.getLong(OCKey.CROSS_AX.value()), op.getString(OCKey.AX_POS.value()), op.optBoolean(OCKey.Z_AXIS.value()), op.optJSONObject(OCKey.ATTRS.value()));
+	                    case CHANGE_CHART_AXIS : {
+	                        applyOperationHelper.changeChartAxis(op.getJSONArray(OCKey.START.value()), op.getLong(OCKey.AXIS.value()), op.getLong(OCKey.CROSS_AX.value()), op.getString(OCKey.AX_POS.value()), op.optBoolean(OCKey.Z_AXIS.value()), op.optJSONObject(OCKey.ATTRS.value()));
 	                        break;
 	                    }
-	                    case SET_CHART_GRIDLINE_ATTRIBUTES : {
-	                        applyOperationHelper.setChartGridlineAttributes(op.getJSONArray(OCKey.START.value()), op.getLong(OCKey.AXIS.value()), op.optJSONObject(OCKey.ATTRS.value()));
+	                    case CHANGE_CHART_GRID : {
+	                        applyOperationHelper.changeChartGrid(op.getJSONArray(OCKey.START.value()), op.getLong(OCKey.AXIS.value()), op.optJSONObject(OCKey.ATTRS.value()));
 	                        break;
 	                    }
-	                    case SET_CHART_TITLE_ATTRIBUTES : {
-	                        applyOperationHelper.setChartTitleAttributes(op.getJSONArray(OCKey.START.value()), op.has(OCKey.AXIS.value()) ? op.getLong(OCKey.AXIS.value()) : null, op.optJSONObject(OCKey.ATTRS.value()));
+	                    case CHANGE_CHART_TITLE : {
+	                        applyOperationHelper.changeChartTitle(op.getJSONArray(OCKey.START.value()), op.has(OCKey.AXIS.value()) ? op.getLong(OCKey.AXIS.value()) : null, op.optJSONObject(OCKey.ATTRS.value()));
 	                        break;
 	                    }
-	                    case SET_CHART_LEGEND_ATTRIBUTES : {
-	                        applyOperationHelper.setChartLegendAttributes(op.getJSONArray(OCKey.START.value()), op.optJSONObject(OCKey.ATTRS.value()));
+	                    case CHANGE_CHART_LEGEND : {
+	                        applyOperationHelper.changeChartLegend(op.getJSONArray(OCKey.START.value()), op.optJSONObject(OCKey.ATTRS.value()));
 	                        break;
 	                    }
-	                    case INSERT_VALIDATION : {
+	                    case INSERT_DV_RULE : {
 	                    	ValidationUtils.insertValidation(this, op);
 	                    	break;
 	                    }
-	                    case CHANGE_VALIDATION : {
+	                    case CHANGE_DV_RULE : {
 	                    	ValidationUtils.changeValidation(this, op);
 	                    	break;
 	                    }
-	                    case DELETE_VALIDATION : {
+	                    case DELETE_DV_RULE : {
 	                    	ValidationUtils.deleteValidation(this, op.getInt(OCKey.SHEET.value()), op.getInt(OCKey.INDEX.value()));
 	                    	break;
 	                    }
@@ -731,29 +731,29 @@ public class XlsxOperationDocument extends com.openexchange.office.filter.ooxml.
 	                    	applyOperationHelper.deleteHyperlink(op.getInt(OCKey.SHEET.value()), SmlUtils.createCellRefRanges(op.getString(OCKey.RANGES.value())));
 	                    	break;
 	                    }
-	                    case INSERT_COMMENT :
-	                        applyOperationHelper.insertComment(op.getInt(OCKey.SHEET.value()), SmlUtils.createCellRef(op.getString(OCKey.ANCHOR.value())), op.optString(OCKey.TEXT.value(), ""), op.optString(OCKey.AUTHOR.value(), null), op.optString(OCKey.UID.value(), null), op.optString(OCKey.DATE.value(), null), op.optJSONObject(OCKey.ATTRS.value()));
+	                    case INSERT_NOTE :
+	                        applyOperationHelper.insertNote(op.getInt(OCKey.SHEET.value()), CellRef.createCellRef(op.getString(OCKey.ANCHOR.value())), op.optString(OCKey.TEXT.value(), ""), op.optString(OCKey.AUTHOR.value(), null), op.optString(OCKey.UID.value(), null), op.optString(OCKey.DATE.value(), null), op.optJSONObject(OCKey.ATTRS.value()));
 	                        break;
-	                    case CHANGE_COMMENT :
-	                        applyOperationHelper.changeComment(op.getInt(OCKey.SHEET.value()), SmlUtils.createCellRef(op.getString(OCKey.ANCHOR.value())), op.optString(OCKey.TEXT.value(), null), op.optJSONObject(OCKey.ATTRS.value()));
+	                    case CHANGE_NOTE :
+	                        applyOperationHelper.changeNote(op.getInt(OCKey.SHEET.value()), CellRef.createCellRef(op.getString(OCKey.ANCHOR.value())), op.optString(OCKey.TEXT.value(), null), op.optJSONObject(OCKey.ATTRS.value()));
 	                        break;
-	                    case DELETE_COMMENT :
-	                        applyOperationHelper.deleteComment(op.getInt(OCKey.SHEET.value()), SmlUtils.createCellRef(op.getString(OCKey.ANCHOR.value())));
+	                    case DELETE_NOTE :
+	                        applyOperationHelper.deleteNote(op.getInt(OCKey.SHEET.value()), CellRef.createCellRef(op.getString(OCKey.ANCHOR.value())));
 	                        break;
-	                    case MOVE_COMMENTS :
-	                        applyOperationHelper.moveComments(op.getInt(OCKey.SHEET.value()), op.getString(OCKey.FROM.value()).split(" ", -1), op.getString(OCKey.TO.value()).split(" ", -1));
+	                    case MOVE_NOTES :
+	                        applyOperationHelper.moveNotes(op.getInt(OCKey.SHEET.value()), op.getString(OCKey.FROM.value()).split(" ", -1), op.getString(OCKey.TO.value()).split(" ", -1));
 	                        break;
-	                    case INSERT_THREADED_COMMENT:
-	                        applyOperationHelper.insertThreadedComment(op.getInt(OCKey.SHEET.value()), SmlUtils.createCellRef(op.getString(OCKey.ANCHOR.value())), op.getString(OCKey.TEXT.value()), op.optString(OCKey.DATE.value(), null), op.getString(OCKey.AUTHOR.value()), op.optString(OCKey.AUTHOR_ID.value()), op.optString(OCKey.AUTHOR_PROVIDER.value()), op.has(OCKey.DONE.value()) ? op.getBoolean(OCKey.DONE.value()) : null, op.optJSONObject(OCKey.DRAWING.value()));
+	                    case INSERT_COMMENT:
+	                        applyOperationHelper.insertComment(op.getInt(OCKey.SHEET.value()), CellRef.createCellRef(op.getString(OCKey.ANCHOR.value())), op.optString(OCKey.TEXT.value(), ""), op.optJSONArray(OCKey.MENTIONS.value()), op.optString(OCKey.DATE.value(), null), op.optString(OCKey.AUTHOR.value()), op.optString(OCKey.AUTHOR_ID.value()), op.optString(OCKey.AUTHOR_PROVIDER.value()), op.has(OCKey.DONE.value()) ? op.getBoolean(OCKey.DONE.value()) : null, op.optJSONObject(OCKey.ATTRS.value()));
 	                        break;
-	                    case DELETE_THREADED_COMMENT:
-	                        applyOperationHelper.deleteThreadedComment(op.getInt(OCKey.SHEET.value()), SmlUtils.createCellRef(op.getString(OCKey.ANCHOR.value())), op.has(OCKey.INDEX.value()) ? op.getInt(OCKey.INDEX.value()) : null);
+	                    case DELETE_COMMENT:
+	                        applyOperationHelper.deleteComment(op.getInt(OCKey.SHEET.value()), CellRef.createCellRef(op.getString(OCKey.ANCHOR.value())), op.getInt(OCKey.INDEX.value()));
 	                        break;
-                        case CHANGE_THREADED_COMMENT:
-                            applyOperationHelper.changeThreadedComment(op.getInt(OCKey.SHEET.value()), SmlUtils.createCellRef(op.getString(OCKey.ANCHOR.value())), op.has(OCKey.INDEX.value()) ? op.getInt(OCKey.INDEX.value()) : null, op.optString(OCKey.TEXT.value(), null), op.has(OCKey.DONE.value()) ? op.getBoolean(OCKey.DONE.value()) : null, op.optJSONObject(OCKey.DRAWING.value()));
+                        case CHANGE_COMMENT:
+                            applyOperationHelper.changeComment(op.getInt(OCKey.SHEET.value()), CellRef.createCellRef(op.getString(OCKey.ANCHOR.value())), op.has(OCKey.INDEX.value()) ? op.getInt(OCKey.INDEX.value()) : null, op.optString(OCKey.TEXT.value(), null), op.optJSONArray(OCKey.MENTIONS.value()), op.has(OCKey.DONE.value()) ? op.getBoolean(OCKey.DONE.value()) : null, op.optJSONObject(OCKey.ATTRS.value()));
                             break;
-                        case MOVE_THREADED_COMMENTS:
-                            applyOperationHelper.moveThreadedComments(op.getInt(OCKey.SHEET.value()), op.getString(OCKey.FROM.value()).split(" ", -1), op.getString(OCKey.TO.value()).split(" ", -1));
+                        case MOVE_COMMENTS:
+                            applyOperationHelper.moveComments(op.getInt(OCKey.SHEET.value()), op.getString(OCKey.FROM.value()).split(" ", -1), op.getString(OCKey.TO.value()).split(" ", -1));
                             break;
 	                    case NO_OP : {
 	                        break;
