@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,8 +54,8 @@ import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.office.filter.api.FilterException;
 import com.openexchange.office.filter.core.DLNode;
-import com.openexchange.office.filter.core.component.Component;
 import com.openexchange.office.filter.core.component.ComponentContext;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 import com.openexchange.office.filter.ooxml.drawingml.DMLHelper;
 
@@ -67,14 +67,14 @@ public class HardBreakComponent extends XlsxComponent {
 
     @Override
     public void delete(int count) {
-        if(componentNumber==0&&getNextComponent()==null) {
+        if(getComponentNumber()==0&&getNextComponent()==null) {
             getParagraphComponent().getParagraph().setEndParaRPr(((CTTextLineBreak)getObject()).getRPr(false));
         }
         super.delete(count);
     }
 
     @Override
-	public Component<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, Component<OfficeOpenXMLOperationDocument> previousChildComponent) {
+	public IComponent<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, IComponent<OfficeOpenXMLOperationDocument> previousChildComponent) {
 		return null;
 	}
 
