@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,8 +53,8 @@ import org.json.JSONObject;
 import org.xlsx4j.sml.Sheet;
 import org.xlsx4j.sml.Sheets;
 import com.openexchange.office.filter.core.DLNode;
-import com.openexchange.office.filter.core.component.Component;
 import com.openexchange.office.filter.core.component.ComponentContext;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.core.IContentAccessor;
 import com.openexchange.office.filter.core.DLList;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
@@ -73,7 +73,7 @@ public class RootComponent extends XlsxComponent {
     }
 
     @Override
-    public Component<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, Component<OfficeOpenXMLOperationDocument> previousChildComponent) {
+    public IComponent<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, IComponent<OfficeOpenXMLOperationDocument> previousChildComponent) {
         final DLNode<Object> rootNode = getNode();
         final DLList<Object> nodeList = (DLList<Object>)((IContentAccessor)rootNode.getData()).getContent();
         final int nextComponentNumber = previousChildComponent!=null?previousChildComponent.getNextComponentNumber():0;
