@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,18 +54,16 @@ import org.docx4j.dml.CTTextParagraph;
 import org.docx4j.dml.spreadsheetdrawing.AnchorBase;
 import org.docx4j.dml.spreadsheetdrawing.CTShape;
 import org.docx4j.jaxb.Context;
-import org.docx4j.openpackaging.exceptions.InvalidFormatException;
-import org.docx4j.openpackaging.exceptions.PartUnrecognisedException;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.core.DLNode;
 import com.openexchange.office.filter.core.DLList;
 import com.openexchange.office.filter.core.component.Child;
-import com.openexchange.office.filter.core.component.Component;
 import com.openexchange.office.filter.core.component.ComponentContext;
+import com.openexchange.office.filter.core.component.ComponentType;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
-import com.openexchange.office.filter.ooxml.components.OfficeOpenXMLComponent;
 import com.openexchange.office.filter.ooxml.components.IShapeType;
 import com.openexchange.office.filter.ooxml.components.ShapeType;
 import com.openexchange.office.filter.ooxml.xlsx.tools.Drawings;
@@ -87,12 +85,12 @@ public class ShapeComponent extends XlsxComponent implements IShapeType {
 	}
 
     @Override
-	public Component<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, Component<OfficeOpenXMLOperationDocument> previousChildComponent) {
+	public IComponent<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, IComponent<OfficeOpenXMLOperationDocument> previousChildComponent) {
         final DLList<Object> nodeList = shape.getContent();
         final int nextComponentNumber = previousChildComponent!=null?previousChildComponent.getNextComponentNumber():0;
         DLNode<Object> childNode = previousChildContext!=null ? previousChildContext.getNode().getNext() : nodeList.getFirstNode();
 
-        Component<OfficeOpenXMLOperationDocument> nextComponent = null;
+        IComponent<OfficeOpenXMLOperationDocument> nextComponent = null;
         for(; nextComponent==null&&childNode!=null; childNode = childNode.getNext()) {
             final Object o = getContentModel(childNode, shape.getTxBody(false));
             if(o instanceof CTTextParagraph) {
@@ -103,7 +101,7 @@ public class ShapeComponent extends XlsxComponent implements IShapeType {
     }
 
     @Override
-    public Component<OfficeOpenXMLOperationDocument> insertChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> parentContext, DLNode<Object> contextNode, int number, Component<OfficeOpenXMLOperationDocument> child, Component.Type type, JSONObject attrs) {
+    public IComponent<OfficeOpenXMLOperationDocument> insertChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> parentContext, DLNode<Object> contextNode, int number, IComponent<OfficeOpenXMLOperationDocument> child, ComponentType type, JSONObject attrs) {
 
     	DLList<Object> DLList = shape.getContent();
         DLNode<Object> referenceNode = child!=null ? child.getNode() : null;
