@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,12 +57,12 @@ import org.docx4j.dml.spreadsheetdrawing.CTPicture;
 import org.docx4j.dml.spreadsheetdrawing.CTShape;
 import org.docx4j.dml.spreadsheetdrawing.CTTwoCellAnchor;
 import org.docx4j.mce.AlternateContent.Choice;
-import org.json.JSONException;
 import org.json.JSONObject;
 import org.xlsx4j.sml.Sheet;
 import com.openexchange.office.filter.core.DLNode;
-import com.openexchange.office.filter.core.component.Component;
 import com.openexchange.office.filter.core.component.ComponentContext;
+import com.openexchange.office.filter.core.component.ComponentType;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.core.IContentAccessor;
 import com.openexchange.office.filter.core.DLList;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
@@ -89,7 +89,7 @@ public class SheetComponent extends XlsxComponent {
     }
 
     @Override
-	public Component<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, Component<OfficeOpenXMLOperationDocument> previousChildComponent) {
+	public IComponent<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, IComponent<OfficeOpenXMLOperationDocument> previousChildComponent) {
         final DLNode<Object> sheetNode = getNode();
         final DLList<Object> nodeList = (DLList<Object>)((IContentAccessor)sheetNode.getData()).getContent();
         final int nextComponentNumber = previousChildComponent!=null?previousChildComponent.getNextComponentNumber():0;
@@ -142,7 +142,7 @@ public class SheetComponent extends XlsxComponent {
     }
 
     @Override
-    public Component<OfficeOpenXMLOperationDocument> insertChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> parentContext, DLNode<Object> contextNode, int number, Component<OfficeOpenXMLOperationDocument> child, Component.Type type, JSONObject attrs) {
+    public IComponent<OfficeOpenXMLOperationDocument> insertChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> parentContext, DLNode<Object> contextNode, int number, IComponent<OfficeOpenXMLOperationDocument> child, ComponentType type, JSONObject attrs) {
 
         DLList<Object> DLList = ((Sheet)contextNode.getData()).getContent();
         DLNode<Object> referenceNode = child!=null ? child.getNode() : null;
