@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,8 +58,8 @@ import com.openexchange.office.filter.core.DLNode;
 import com.openexchange.office.filter.core.IContentAccessor;
 import com.openexchange.office.filter.core.DLList;
 import com.openexchange.office.filter.core.SplitMode;
-import com.openexchange.office.filter.core.component.Component;
 import com.openexchange.office.filter.core.component.ComponentContext;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 import com.openexchange.office.filter.ooxml.drawingml.DMLHelper;
 
@@ -74,7 +74,7 @@ public class TextComponent extends XlsxComponent {
 
     @Override
     public void delete(int count) {
-        if(componentNumber==0&&getNextComponent()==null) {
+        if(getComponentNumber()==0&&getNextComponent()==null) {
             getParagraphComponent().getParagraph().setEndParaRPr(textRun.getRPr(false));
         }
         super.delete(count);
@@ -87,22 +87,22 @@ public class TextComponent extends XlsxComponent {
             System.out.println("Error: empty text string is no component... this results in problems with the component iterator");
             textLength++;       // increasing.. preventing an endless loop
         }
-        return componentNumber + textLength;
+        return getComponentNumber() + textLength;
     }
 
     @Override
     public void splitStart(int componentPosition, SplitMode splitMode) {
-    	final int splitPosition = componentPosition-componentNumber;
+    	final int splitPosition = componentPosition-getComponentNumber();
     	if(splitPosition>0) {
     		splitText(splitPosition, true);
-    		componentNumber+=splitPosition;
+    		setComponentNumber(getComponentNumber() +splitPosition);
     	}
     }
 
     @Override
     public void splitEnd(int componentPosition, SplitMode splitMode) {
     	if(getNextComponentNumber()>++componentPosition) {
-    		splitText(componentPosition-componentNumber, false);
+    		splitText(componentPosition-getComponentNumber(), false);
     	}
     }
 
@@ -126,7 +126,7 @@ public class TextComponent extends XlsxComponent {
     }
 
 	@Override
-	public Component<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, Component<OfficeOpenXMLOperationDocument> previousChildComponent) {
+	public IComponent<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, IComponent<OfficeOpenXMLOperationDocument> previousChildComponent) {
 		return null;
 	}
 
