@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,6 +51,8 @@ package com.openexchange.office.filter.ooxml.xlsx.operations;
 
 import java.text.ParseException;
 import java.util.ArrayList;
+import java.util.Collections;
+import java.util.Comparator;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
@@ -116,12 +118,12 @@ import com.openexchange.office.filter.api.DocumentProperties;
 import com.openexchange.office.filter.api.FilterException;
 import com.openexchange.office.filter.api.FilterException.ErrorCode;
 import com.openexchange.office.filter.core.DLList;
-import com.openexchange.office.filter.core.component.Component;
+import com.openexchange.office.filter.core.component.IComponent;
+import com.openexchange.office.filter.core.spreadsheet.CellRef;
+import com.openexchange.office.filter.core.spreadsheet.CellRefRange;
 import com.openexchange.office.filter.core.spreadsheet.ColumnRef;
 import com.openexchange.office.filter.core.spreadsheet.Interval;
 import com.openexchange.office.filter.core.spreadsheet.RowRef;
-import com.openexchange.office.filter.core.spreadsheet.SmlUtils;
-import com.openexchange.office.filter.core.spreadsheet.SmlUtils.CellRef;
 import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.api.OCValue;
 import com.openexchange.office.filter.ooxml.components.OfficeOpenXMLComponent;
@@ -574,14 +576,17 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
         }
     }
 
-    private JSONObject getCellObject(Cell cell)
+    private Object getCellObject(Cell cell)
         throws Exception {
 
         STCellType cellType = cell.getT();
         if(cellType==null) {
             cellType = STCellType.N;
         }
+
         final JSONObject cellObject = new JSONObject();
+        Object v = null;
+
         final CTCellFormula cellFormula = cell.getF();
         if(cellFormula!=null) {
             STCellFormulaType cellFormulaType = cellFormula.getT();
@@ -609,44 +614,47 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
             final CTRst is = cell.getIs();
             if(is!=null) {
                 if(is.getT()!=null) {
-                    cellObject.put(OCKey.V.value(), new String(is.getT().getValue()));;
+                    v = new String(is.getT().getValue());
                 }
             }
         }
         else if(cell.getV()!=null) {
             if(cellType==STCellType.N) {
                 try {
-                    cellObject.put(OCKey.V.value(), new Double(Double.parseDouble(cell.getV())));
+                    v = new Double(Double.parseDouble(cell.getV()));
                 }
                 catch(NumberFormatException e) {
                     // TODO: ups
                 }
             }
             else if(cellType==STCellType.S) {
-                String sharedString = getOperationDocument().getSharedString(cell.getV());
-                if(sharedString!=null) {
-                    cellObject.put(OCKey.V.value(), sharedString);
-                }
+                v = getOperationDocument().getSharedString(cell.getV());
             }
             else if(cellType==STCellType.B) {
                 if(cell.getV().equals("0")||cell.getV().toLowerCase().equals("false")) {
-                    cellObject.put(OCKey.V.value(), new Boolean(false));
+                    v = new Boolean(false);
                 }
                 else if(cell.getV().equals("1")||cell.getV().toLowerCase().equals("true")) {
-                    cellObject.put(OCKey.V.value(), new Boolean(true));
+                    v = new Boolean(true);
                 }
             }
             else if(cellType==STCellType.E) {
                 cellObject.put(OCKey.E.value(), cell.getV());
             }
             else {  // STCellType.STR, STCellType.F (ARRAY or DATA_TABLE format)
-                cellObject.put(OCKey.V.value(), cell.getV());
+                v = cell.getV();
             }
         }
         final long s = cell.getStyle();
         if ((s > 0) || cellObject.isEmpty()) {
             cellObject.put(OCKey.S.value(), "a" + Long.toString(s));
         }
+        if(cellObject.isEmpty() && v!=null) {
+            return v;
+        }
+        if(v!=null) {
+            cellObject.put(OCKey.V.value(), v);
+        }
         return cellObject;
     }
 
@@ -689,95 +697,106 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
         final CTThreadedComments threadedComments = worksheetPart.getThreadedComments(false);
 
         if (threadedComments != null) {
-            CTPersonList personList = getOperationDocument().getPersons(false);
-            int i = 0;
-            Map<String, Integer> idToIdx = new HashMap<>();
-            List<CellRef> cellRefs = new ArrayList<CellRef>();
+            final CTPersonList personList = getOperationDocument().getPersons(false);
+            final Map<String, Integer> idToIdx = new HashMap<>();
+            final List<CellRef> cellRefs = new ArrayList<CellRef>();
             for (CTThreadedComment comment : threadedComments.getThreadedComments()) {
 
-                final JSONObject jsonOperations = new JSONObject();
+                final JSONObject jsonOperation = new JSONObject();
 
-                jsonOperations.put(OCKey.NAME.value(), OCValue.INSERT_THREADED_COMMENT.value());
-                jsonOperations.put(OCKey.SHEET.value(), sheetIndex);
+                jsonOperation.put(OCKey.NAME.value(), OCValue.INSERT_COMMENT.value());
+                jsonOperation.put(OCKey.SHEET.value(), sheetIndex);
 
                 CellRef cellRef = comment.getCellRef(true);
-                jsonOperations.put(OCKey.ANCHOR.value(), SmlUtils.getCellRef(cellRef));
-                jsonOperations.put(OCKey.TEXT.value(), comment.getText());
+                jsonOperation.put(OCKey.ANCHOR.value(), CellRef.getCellRef(cellRef));
+                jsonOperation.put(OCKey.TEXT.value(), createMentions(comment, personList, jsonOperation));
 
                 if (comment.getDateTime() != null) {
                     String date = comment.getDateTime().toXMLFormat();
                     if (!date.toLowerCase().endsWith("z")) {
                         date += "Z";
                     }
-                    jsonOperations.put(OCKey.DATE.value(), date);
+                    jsonOperation.put(OCKey.DATE.value(), date);
                 }
 
                 if (personList != null) {
                     CTPerson person = personList.getPersonById(comment.getPersonId());
                     if (person != null) {
-                        jsonOperations.put(OCKey.AUTHOR.value(), person.getDisplayName());
-                        jsonOperations.put(OCKey.AUTHOR_ID.value(), person.getUserId());
-                        jsonOperations.put(OCKey.AUTHOR_PROVIDER.value(), person.getProviderId());
+                        jsonOperation.put(OCKey.AUTHOR.value(), person.getDisplayName());
+                        jsonOperation.put(OCKey.AUTHOR_ID.value(), person.getUserId());
+                        jsonOperation.put(OCKey.AUTHOR_PROVIDER.value(), person.getProviderId());
                     }
-
-
                 }
-
-                jsonOperations.put(OCKey.INDEX.value(), i);
-
                 if (comment.getParentId() == null) {
 
                     if (cellRefs.contains(cellRef)) {
                         throw new FilterException("an threaded comment on this address exists. " + cellRef.toString(), ErrorCode.CRITICAL_ERROR);
                     }
-                    idToIdx.put(comment.getId(), i);
-                    threadedCommentOperations.put(cellRef.toString(), jsonOperations);
-                } else {
-                    jsonOperations.put(OCKey.PARENT.value(), idToIdx.get(comment.getParentId()));
-                }
+                    idToIdx.put(comment.getId(), 0);
+                    jsonOperation.put(OCKey.INDEX.value(), 0);
 
+                    threadedCommentOperations.put(cellRef.toString(), jsonOperation);
+                }
+                else {
+                    int index = idToIdx.get(comment.getParentId()) + 1;
+                    idToIdx.put(comment.getParentId(), index);
+
+                    jsonOperation.put(OCKey.INDEX.value(), index);
+                }
                 cellRefs.add(cellRef);
-
                 if (comment.getDone() != null) {
-                    jsonOperations.put(OCKey.DONE.value(), comment.getDone());
+                    jsonOperation.put(OCKey.DONE.value(), comment.getDone());
                 }
-
-                // Mentions
-//                CTThreadedCommentMentions mentions = comment.getMentions();
-//                if (personList != null && mentions != null && !mentions.getMentions().isEmpty()) {
-//                    JSONArray jsonMentions = new JSONArray();
-//                    int mentionIndex = 0;
-//                    for (CTMention mention : mentions.getMentions()) {
-//                        CTPerson person = personList.getPersonById(mention.getPersonId());
-//
-//                        JSONObject jsonMention = new JSONObject();
-//                        jsonMention.put(OCKey.INDEX.value(), mentionIndex);
-//                        jsonMention.put(OCKey.AUTHOR.value(), person.getDisplayName());
-//                        jsonMention.put(OCKey.AUTHOR_ID.value(), person.getUserId());
-//                        jsonMention.put(OCKey.AUTHOR_PROVIDER.value(), person.getProviderId());
-//                        jsonMention.put(OCKey.START_INDEX.value(), mention.getStartIndex());
-//                        jsonMention.put(OCKey.LENGHT.value(), mention.getLength());
-//
-//                        jsonMentions.put(jsonMention);
-//                        mentionIndex++;
-//                    }
-//                    if (!jsonMentions.isEmpty()) {
-//                        jsonOperations.put(OCKey.MENTIONS.value(), jsonMentions);
-//                    }
-//                }
-
                 threadedCommentIds.add("tc=" + comment.getId().toLowerCase());
-                operationsArray.put(jsonOperations);
-                i++;
+                operationsArray.put(jsonOperation);
             }
         }
+    }
 
+    private String createMentions(CTThreadedComment comment, CTPersonList personList, JSONObject operation) throws JSONException {
+        // Mentions
+        final CTThreadedCommentMentions _mentions = comment.getMentions();
+        if (personList==null || _mentions==null || _mentions.getMentions().isEmpty()) {
+            return comment.getText();
+        }
+        final List<CTMention> mentions = _mentions.getMentions();
+        Collections.sort(mentions, new Comparator<CTMention>() {
+            @Override
+            public int compare(CTMention d0, CTMention d1) {
+                return (int)d0.getStartIndex() - (int)d1.getStartIndex();
+            }
+        });
+        // This was only needed when removing @-signs
+        // int offset = 0;
+        final StringBuilder builder = new StringBuilder(comment.getText());
+        final JSONArray jsonMentions = new JSONArray(mentions.size());
+        for (CTMention mention : mentions) {
+            final CTPerson person = personList.getPersonById(mention.getPersonId());
+            final int index = (int)mention.getStartIndex() /* - offset */;
+            if(person!=null && mention.getLength() > 0 && builder.charAt(index) == '@') {
+                // removing '@'
+                // builder.deleteCharAt(index);
+
+                final JSONObject jsonMention = new JSONObject();
+                jsonMention.put(OCKey.DISPLAY_NAME.value(), person.getDisplayName());
+                jsonMention.put(OCKey.USER_ID.value(), person.getUserId());
+                jsonMention.put(OCKey.PROVIDER_ID.value(), person.getProviderId());
+                jsonMention.put(OCKey.POS.value(), index);
+                // jsonMention.put(OCKey.LENGHT.value(), mention.getLength() - 1);
+                jsonMention.put(OCKey.LENGHT.value(), mention.getLength());
+                jsonMentions.put(jsonMention);
+                // offset++;
+            }
+        }
+        if(!jsonMentions.isEmpty()) {
+            operation.put(OCKey.MENTIONS.value(), jsonMentions);
+        }
+        return builder.toString();
     }
 
     private void createCommentOperations(WorksheetPart worksheetPart, int sheetIndex) throws Exception {
         final CTComments comments = worksheetPart.getComments(false);
         if(comments!=null) {
-            final Worksheet worksheet = worksheetPart.getJaxbElement();
             final CTCommentList commentList = comments.getCommentList();
             final CTAuthors authors = comments.getAuthors();
             final List<String> authorList = authors!=null ? authors.getAuthor() : null;
@@ -796,34 +815,36 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
                         if (threadedCommpentOperation != null) {
                             JSONObject vmlAttributes = getVMLCommentAttributes(worksheetPart, cellRef);
                             if (vmlAttributes != null && vmlAttributes.has(OCKey.DRAWING.value())) {
-                                threadedCommpentOperation.put(OCKey.DRAWING.value(), vmlAttributes.get(OCKey.DRAWING.value()));
+                                JSONObject drawing = new JSONObject();
+                                drawing.put(OCKey.DRAWING.value(), vmlAttributes.get(OCKey.DRAWING.value()));
+                                threadedCommpentOperation.put(OCKey.ATTRS.value(), drawing);
                             }
                         }
                         continue;
                     }
                 }
 
-                final JSONObject jsonInsertCommentOperation = new JSONObject(6);
-                jsonInsertCommentOperation.put(OCKey.NAME.value(), OCValue.INSERT_COMMENT.value());
-                jsonInsertCommentOperation.put(OCKey.SHEET.value(), sheetIndex);
+                final JSONObject jsonInsertNoteOperation = new JSONObject(6);
+                jsonInsertNoteOperation.put(OCKey.NAME.value(), OCValue.INSERT_NOTE.value());
+                jsonInsertNoteOperation.put(OCKey.SHEET.value(), sheetIndex);
 
-                jsonInsertCommentOperation.put(OCKey.ANCHOR.value(), SmlUtils.getCellRef(cellRef));
+                jsonInsertNoteOperation.put(OCKey.ANCHOR.value(), CellRef.getCellRef(cellRef));
 
                 if (author!=null && author.length()>0) {
-                    jsonInsertCommentOperation.put(OCKey.AUTHOR.value(), author);
+                    jsonInsertNoteOperation.put(OCKey.AUTHOR.value(), author);
                 }
 
                 final String text = comment.toString();
                 if (text!=null && text.length()>0) {
-                	jsonInsertCommentOperation.put(OCKey.TEXT.value(), comment.toString());
+                	jsonInsertNoteOperation.put(OCKey.TEXT.value(), comment.toString());
                 }
                 JSONObject vmlAttributes = getVMLCommentAttributes(worksheetPart, cellRef);
 
                 if (vmlAttributes != null) {
-                    jsonInsertCommentOperation.put(OCKey.ATTRS.value(), vmlAttributes);
+                    jsonInsertNoteOperation.put(OCKey.ATTRS.value(), vmlAttributes);
                 }
 
-                operationsArray.put(jsonInsertCommentOperation);
+                operationsArray.put(jsonInsertNoteOperation);
             }
         }
     }
@@ -834,7 +855,7 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
 
         if(vmlPart!=null) {
 
-            Component<OfficeOpenXMLOperationDocument> component = new VMLRootComponent("spreadsheet", operationDocument, vmlPart.getJaxbElement()).getNextChildComponent(null, null);
+            IComponent<OfficeOpenXMLOperationDocument> component = new VMLRootComponent("spreadsheet", operationDocument, vmlPart.getJaxbElement()).getNextChildComponent(null, null);
 
             while(component!=null) {
                 if(component instanceof VMLBase) {
@@ -905,14 +926,14 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
             final List<CTHyperlink> hyperlinkList = hyperlinks.getHyperlink();
             for(int i=0; i<hyperlinkList.size();i++) {
                 final CTHyperlink hyperlink = hyperlinkList.get(i);
-                final SmlUtils.CellRefRange cellRefRange = hyperlink.getCellRefRange(false);
+                final CellRefRange cellRefRange = hyperlink.getCellRefRange(false);
                 if(cellRefRange!=null) {
                     final String hyperlinkUrl = Commons.getUrl(worksheetPart, hyperlink.getId());
                     if(hyperlinkUrl!=null&&!hyperlinkUrl.isEmpty()) {
                         final JSONObject insertHyperlinkOperation = new JSONObject(5);
                         insertHyperlinkOperation.put(OCKey.NAME.value(), OCValue.INSERT_HYPERLINK.value());
                         insertHyperlinkOperation.put(OCKey.SHEET.value(), sheetIndex);
-                        insertHyperlinkOperation.put(OCKey.RANGES.value(), SmlUtils.getCellRefRange(cellRefRange));
+                        insertHyperlinkOperation.put(OCKey.RANGES.value(), CellRefRange.getCellRefRange(cellRefRange));
                         insertHyperlinkOperation.put(OCKey.URL.value(), hyperlinkUrl);
                         operationsArray.put(insertHyperlinkOperation);
                     }
@@ -922,7 +943,7 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
         final SheetComponent sheetComponent = new SheetComponent(sheet, getOperationDocument(), sheetIndex);
         final List<Integer> sheetPosition = new ArrayList<Integer>(1);
         sheetPosition.add(sheetIndex);
-        Component<OfficeOpenXMLOperationDocument> childComponent = sheetComponent.getNextChildComponent(null, null);
+        IComponent<OfficeOpenXMLOperationDocument> childComponent = sheetComponent.getNextChildComponent(null, null);
         while(childComponent!=null) {
             createDrawingOperations(childComponent, sheetPosition, null);
             childComponent = childComponent.getNextComponent();
@@ -964,14 +985,14 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
         final ChartsheetComponent sheetComponent = new ChartsheetComponent(sheet, getOperationDocument(), sheetIndex);
         final List<Integer> sheetPosition = new ArrayList<Integer>(1);
         sheetPosition.add(sheetIndex);
-        Component<OfficeOpenXMLOperationDocument> childComponent = sheetComponent.getNextChildComponent(null, null);
+        IComponent<OfficeOpenXMLOperationDocument> childComponent = sheetComponent.getNextChildComponent(null, null);
         while(childComponent!=null) {
             createDrawingOperations(childComponent, sheetPosition, null);
             childComponent = childComponent.getNextComponent();
         }
     }
 
-    private void createDrawingOperations(Component<OfficeOpenXMLOperationDocument> drawingComponent, List<Integer> parentPosition, String target)
+    private void createDrawingOperations(IComponent<OfficeOpenXMLOperationDocument> drawingComponent, List<Integer> parentPosition, String target)
         throws Exception {
 
         final List<Integer> position = new ArrayList<Integer>(parentPosition);
@@ -991,7 +1012,7 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
         if(((IShapeType)drawingComponent).getType()==ShapeType.CHART) {
             Drawings.getChart(((ShapeGraphicComponent) drawingComponent).getDrawingProperties()).createChartSpaceOperations(operationsArray, position);
         }
-        Component<OfficeOpenXMLOperationDocument> shapeChildComponent = drawingComponent.getNextChildComponent(null, null);
+        IComponent<OfficeOpenXMLOperationDocument> shapeChildComponent = drawingComponent.getNextChildComponent(null, null);
 
         while(shapeChildComponent!=null) {
             if(shapeChildComponent instanceof ParagraphComponent) {
@@ -1020,7 +1041,7 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
             jsonInsertParagraphOperation.put(OCKey.ATTRS.value(), attrs);
         }
         operationsArray.put(jsonInsertParagraphOperation);
-        Component<OfficeOpenXMLOperationDocument> paragraphChild = paragraphComponent.getNextChildComponent(null, null);
+        IComponent<OfficeOpenXMLOperationDocument> paragraphChild = paragraphComponent.getNextChildComponent(null, null);
         while(paragraphChild!=null) {
             if(paragraphChild instanceof TextComponent) {
                 int n = paragraphChild.getComponentNumber();
@@ -1204,7 +1225,7 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
     private void createDataValidation(int sheetIndex, int validationIndex, IDataValidation dataValidation)
         throws JSONException {
 
-        final List<SmlUtils.CellRefRange> cellRefRangeList = Utils.createCellRefRangeListFromSqrefList(dataValidation.getsqref());
+        final List<CellRefRange> cellRefRangeList = Utils.createCellRefRangeListFromSqrefList(dataValidation.getsqref());
         ValidationUtils.addInsertValidationOperation(operationsArray, sheetIndex, validationIndex, cellRefRangeList, dataValidation.getType(), dataValidation.getOperator(), dataValidation.getFormula1(), dataValidation.getFormula2(), dataValidation.isShowInputMessage(),
             dataValidation.getPromptTitle(), dataValidation.getPrompt(), dataValidation.isShowErrorMessage(), dataValidation.getErrorTitle(), dataValidation.getError(), dataValidation.getErrorStyle(),
                 dataValidation.isShowDropDown()==false, dataValidation.isAllowBlank());
@@ -1273,63 +1294,48 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
             }
         }
 
-        // create cell content for each row
+        JSONObject contents = new JSONObject();
+
         rowIterator = sheetData.createRowIterator();
         while(rowIterator.hasNext()) {
             final Row row = rowIterator.next();
 
-            JSONArray cellArray = new JSONArray();
-            SmlUtils.CellRef topLeftCellRef = null;
-
-            Cell        lastCell = null;
-            JSONObject  lastCellObject = null;
-            int         lastCellX = -1;
+            CellRefRange lastCellRefRange = null;
+            Cell lastCell = null;
 
             Iterator<Cell> cellIterator = row.createCellIterator();
             while(cellIterator.hasNext()) {
-                boolean repeat = false;
-                Cell cell = cellIterator.next();
-                final SmlUtils.CellRef cellRef = new SmlUtils.CellRef(cell.getColumn(), row.getRow());
-                if(topLeftCellRef==null) {
-                    topLeftCellRef = cellRef;
+                final Cell cell = cellIterator.next();
+                if(lastCellRefRange==null) {
+                    lastCellRefRange = new CellRefRange(cell.getColumn(), row.getRow(), cell.getColumn(), row.getRow());
+                    lastCell = cell;
                 }
-                if(lastCell!=null) {
-                    // checking empty cells
-                    final int cellDifference = cellRef.getColumn() - lastCellX;
-                    if(cellDifference > 1) {
-                        // we have empty cells ... at least one
-                        cellArray.put(lastCellObject);
-                        final JSONObject emptyCell = new JSONObject(1);
-                        emptyCell.put(OCKey.R.value(), cellDifference-1);
-                        cellArray.put(emptyCell);
+                else {
+                    if(cell.getColumn() == lastCellRefRange.getEnd().getColumn() + 1 && compareCell(cell, lastCell)) {
+                        lastCellRefRange.getEnd().setColumn(cell.getColumn());
                     }
                     else {
-                        if(compareCell(lastCell, cell)) {
-                            lastCellObject.put(OCKey.R.value(), lastCellObject.optInt(OCKey.R.value(), 1) + 1);
-                            repeat = true;
-                        }
-                        else {
-                            cellArray.put(lastCellObject);
-                        }
+                        contents = addCellContent(contents, sheetIndex, lastCellRefRange, lastCell);
+                        lastCellRefRange = new CellRefRange(cell.getColumn(), row.getRow(), cell.getColumn(), row.getRow());
+                        lastCell = cell;
                     }
                 }
-                lastCell = cell;
-                lastCellX = cellRef.getColumn();
-                if(repeat==false) {
-                    lastCellObject = getCellObject(cell);
-                }
             }
-            if(lastCellObject!=null) {
-                cellArray.put(lastCellObject);
-            }
-            if(!cellArray.isEmpty()) {
-                final JSONObject rowObject = new JSONObject(1);
-                rowObject.put(OCKey.C.value(), cellArray);
-                final JSONArray rowArray = new JSONArray(1);
-                rowArray.put(rowObject);
-                addChangeCellsOperation(sheetIndex, topLeftCellRef, rowArray);
+            if(lastCellRefRange!=null) {
+                contents = addCellContent(contents, sheetIndex, lastCellRefRange, lastCell);
             }
         }
+        addChangeCellsOperation(sheetIndex, contents);
+    }
+
+     private JSONObject addCellContent(JSONObject contents, int sheetIndex, CellRefRange cellRefRange, Cell cell) throws JSONException, Exception {
+         if(contents.length() == getOperationDocument().getMaxJsonSize()) {
+             addChangeCellsOperation(sheetIndex, contents);
+             contents = new JSONObject();
+         }
+        final String key = cellRefRange.getStart().equals(cellRefRange.getEnd()) ? CellRef.getCellRef(cellRefRange.getStart()) : CellRefRange.getCellRefRange(cellRefRange);
+        contents.put(key, getCellObject(cell));
+        return contents;
     }
 
     private void createColumnOperations(List<Cols> colsIter, int sheetIndex)
@@ -1343,8 +1349,8 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
             if(colIter!=null) {
                 for(Col col:colIter) {
                     final JSONObject attrs = ColumnUtils.createColumnProperties(getOperationDocument(), col);
-                    final Long style = col.getStyle();
-                    if(attrs!=null || style!=null) {
+                    final long style = col.getStyle();
+                    if(attrs!=null) {
                         addChangeColumns(sheetIndex, (int)col.getMin()-1, (int)col.getMax()-1, attrs, style);
                     }
                 }
@@ -1391,16 +1397,16 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
 
     final static List<Object> objectList = new ArrayList<Object>();
 
-    public void addChangeCellsOperation(int sheetIndex, SmlUtils.CellRef cellRef, JSONArray cellContent)
+    public void addChangeCellsOperation(int sheetIndex, JSONObject contents)
         throws JSONException {
 
-        final JSONObject insertCellsObject = new JSONObject(4);
-        insertCellsObject.put(OCKey.NAME.value(), OCValue.CHANGE_CELLS.value());
-        insertCellsObject.put(OCKey.SHEET.value(), sheetIndex);
-        insertCellsObject.put(OCKey.START.value(), SmlUtils.getCellRef(cellRef));
-        insertCellsObject.put(OCKey.CONTENTS.value(), cellContent);
-
-        operationsArray.put(insertCellsObject);
+        if(!contents.isEmpty()) {
+            final JSONObject insertCellsObject = new JSONObject(4);
+            insertCellsObject.put(OCKey.NAME.value(), OCValue.CHANGE_CELLS.value());
+            insertCellsObject.put(OCKey.SHEET.value(), sheetIndex);
+            insertCellsObject.put(OCKey.CONTENTS.value(), contents);
+            operationsArray.put(insertCellsObject);
+        }
     }
 
     public void addChangeRows(int sheetIndex, int start, int end, JSONObject attrs, Long style)
@@ -1417,7 +1423,7 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
         if (operation.length()>0) {
             operation.put(OCKey.NAME.value(), OCValue.CHANGE_ROWS.value());
             operation.put(OCKey.SHEET.value(), sheetIndex);
-            operation.put(OCKey.INTERVALS.value(), new Interval<RowRef>(new RowRef(start), new RowRef(end)).toString());
+            operation.put(OCKey.INTERVALS.value(), new Interval(new RowRef(start), new RowRef(end)).toString());
             operationsArray.put(operation);
         }
     }
@@ -1436,7 +1442,7 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
         if (operation.length()>0) {
             operation.put(OCKey.NAME.value(), OCValue.CHANGE_COLUMNS.value());
             operation.put(OCKey.SHEET.value(), sheetIndex);
-            operation.put(OCKey.INTERVALS.value(), new Interval<ColumnRef>(new ColumnRef(start), new ColumnRef(end)).toString());
+            operation.put(OCKey.INTERVALS.value(), new Interval(new ColumnRef(start), new ColumnRef(end)).toString());
             operationsArray.put(operation);
         }
     }
