@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -84,8 +84,7 @@ import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.office.filter.core.DLList;
-import com.openexchange.office.filter.core.spreadsheet.SmlUtils;
-import com.openexchange.office.filter.core.spreadsheet.SmlUtils.CellRef;
+import com.openexchange.office.filter.core.spreadsheet.CellRef;
 import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.api.OCValue;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
@@ -136,13 +135,13 @@ public class Drawings {
                 }
                 builder.append(aType)
                        .append(' ')
-                       .append(SmlUtils.getCellRef(startRef))
+                       .append(CellRef.getCellRef(startRef))
                        .append(' ')
                        .append(startColumnOffset)
                        .append(' ')
                        .append(startRowOffset)
                        .append(' ')
-                       .append(SmlUtils.getCellRef(endRef))
+                       .append(CellRef.getCellRef(endRef))
                        .append(' ')
                        .append(endColumnOffset)
                        .append(' ')
@@ -155,7 +154,7 @@ public class Drawings {
                 final long startRowOffset = Commons.coordinateTo100TH_MM(from.getRowOff());
                 builder.append('1')
                         .append(' ')
-                        .append(SmlUtils.getCellRef(startRef))
+                        .append(CellRef.getCellRef(startRef))
                         .append(' ')
                         .append(startColumnOffset)
                         .append(' ')
@@ -334,10 +333,10 @@ public class Drawings {
             final String[] anchorAttrs = anchor.substring(2).split(" ", -1);
 
             if(anchorType == '2' || anchorType == 'O' || anchorType == 'A') {
-                final CellRef startRef = SmlUtils.createCellRef(anchorAttrs[0]);
+                final CellRef startRef = CellRef.createCellRef(anchorAttrs[0]);
                 final long startColumnOffset = Commons.coordinateFrom100TH_MM(Integer.parseInt(anchorAttrs[1]));
                 final long startRowOffset = Commons.coordinateFrom100TH_MM(Integer.parseInt(anchorAttrs[2]));
-                final CellRef endRef = SmlUtils.createCellRef(anchorAttrs[3]);
+                final CellRef endRef = CellRef.createCellRef(anchorAttrs[3]);
                 final long endColumnOffset = Commons.coordinateFrom100TH_MM(Integer.parseInt(anchorAttrs[4]));
                 final long endRowOffset = Commons.coordinateFrom100TH_MM(Integer.parseInt(anchorAttrs[5]));
 
@@ -355,7 +354,7 @@ public class Drawings {
                 }
             }
             else if(anchorType == '1') {
-                final CellRef startRef = SmlUtils.createCellRef(anchorAttrs[0]);
+                final CellRef startRef = CellRef.createCellRef(anchorAttrs[0]);
                 final long startColumnOffset = Commons.coordinateFrom100TH_MM(Integer.parseInt(anchorAttrs[1]));
                 final long startRowOffset = Commons.coordinateFrom100TH_MM(Integer.parseInt(anchorAttrs[2]));
                 final long width = Commons.coordinateFrom100TH_MM(drawingProperties.optInt(OCKey.WIDTH.value(), 0));
