@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -75,7 +75,8 @@ import org.xlsx4j.sml.SheetViews;
 import org.xlsx4j.sml.Workbook;
 import org.xlsx4j.sml.Worksheet;
 import com.openexchange.office.filter.api.OCKey;
-import com.openexchange.office.filter.core.spreadsheet.SmlUtils;
+import com.openexchange.office.filter.core.spreadsheet.CellRef;
+import com.openexchange.office.filter.core.spreadsheet.CellRefRange;
 import com.openexchange.office.filter.ooxml.tools.Commons;
 import com.openexchange.office.filter.ooxml.xlsx.XlsxOperationDocument;
 
@@ -153,9 +154,9 @@ public class SheetUtils {
             final Object scrollLeft = sheetProperties.opt(OCKey.SCROLL_LEFT.value());
             final Object scrollTop  = sheetProperties.opt(OCKey.SCROLL_TOP.value());
             if(scrollLeft!=null||scrollTop!=null) {
-                SmlUtils.CellRef topLeft = SmlUtils.createCellRef(sheetView.getTopLeftCell());
+                CellRef topLeft = CellRef.createCellRef(sheetView.getTopLeftCell());
                 if(topLeft==null) {
-                    topLeft = new SmlUtils.CellRef(0, 0);
+                    topLeft = new CellRef(0, 0);
                 }
                 if(scrollLeft!=null) {
                     topLeft.setColumn(scrollLeft instanceof Number
@@ -171,7 +172,7 @@ public class SheetUtils {
                     sheetView.setTopLeftCell(null);
                 }
                 else {
-                    sheetView.setTopLeftCell(SmlUtils.getCellRef(topLeft));
+                    sheetView.setTopLeftCell(CellRef.getCellRef(topLeft));
                 }
             }
 
@@ -237,9 +238,9 @@ public class SheetUtils {
                 final Object scrollRight = sheetProperties.opt(OCKey.SCROLL_RIGHT.value());
                 final Object scrollBottom  = sheetProperties.opt(OCKey.SCROLL_BOTTOM.value());
                 if(scrollRight!=null||scrollBottom!=null) {
-                    SmlUtils.CellRef topLeft = SmlUtils.createCellRef(pane.getTopLeftCell());
+                    CellRef topLeft = CellRef.createCellRef(pane.getTopLeftCell());
                     if(topLeft==null) {
-                        topLeft = new SmlUtils.CellRef(0, 0);
+                        topLeft = new CellRef(0, 0);
                     }
                     if(scrollRight!=null) {
                         topLeft.setColumn(scrollRight instanceof Number
@@ -255,7 +256,7 @@ public class SheetUtils {
                         pane.setTopLeftCell(null);
                     }
                     else {
-                        pane.setTopLeftCell(SmlUtils.getCellRef(topLeft));
+                        pane.setTopLeftCell(CellRef.getCellRef(topLeft));
                     }
                 }
             }
@@ -269,8 +270,8 @@ public class SheetUtils {
                 final CTSelection selection=getSelection(sheetView, true);
                 if(activeCell!=null) {
                     if(activeCell instanceof String) {
-                        final SmlUtils.CellRef cellRef = SmlUtils.createCellRef((String)activeCell);
-                        selection.setActiveCell(SmlUtils.getCellRef(cellRef));
+                        final CellRef cellRef = CellRef.createCellRef((String)activeCell);
+                        selection.setActiveCell(CellRef.getCellRef(cellRef));
                     }
                     else {
                         selection.setActiveCell(null);
@@ -301,10 +302,10 @@ public class SheetUtils {
                 if(selection.getActiveCell()==null) {
                     selection.setActiveCell("A1");
                 }
-                final SmlUtils.CellRef activeCellRef = SmlUtils.createCellRef(selection.getActiveCell());
+                final CellRef activeCellRef = CellRef.createCellRef(selection.getActiveCell());
                 final List<String> sel = selection.getSqref();
                 if(sel.isEmpty()) {
-                    sel.add(SmlUtils.getCellRef(activeCellRef));
+                    sel.add(CellRef.getCellRef(activeCellRef));
                     selection.setActiveCellId(null);
                 }
                 else {
@@ -312,13 +313,13 @@ public class SheetUtils {
                     boolean activeCellIsPartOfSelection = false;
                     // now check if the active cell is part of the sqref
                     if(cellId>=0&&cellId<sel.size()) {
-                        final SmlUtils.CellRefRange cellRefRange = SmlUtils.createCellRefRange(sel.get((int)cellId));
+                        final CellRefRange cellRefRange = CellRefRange.createCellRefRange(sel.get((int)cellId));
                         activeCellIsPartOfSelection = cellRefRange.isInside(activeCellRef.getColumn(), activeCellRef.getRow());
                     }
                     if(activeCellIsPartOfSelection==false) {
                         selection.setActiveCellId(null);
                         sel.clear();
-                        sel.add(SmlUtils.getCellRef(activeCellRef));
+                        sel.add(CellRef.getCellRef(activeCellRef));
                     }
                 }
             }
@@ -473,7 +474,7 @@ public class SheetUtils {
                         Commons.jsonPut(attrs, OCKey.GRID_COLOR.value(), Utils.createColor(null, color));
                     }
                 }
-                final SmlUtils.CellRef topLeft = SmlUtils.createCellRef(sheetView.getTopLeftCell());
+                final CellRef topLeft = CellRef.createCellRef(sheetView.getTopLeftCell());
                 if(topLeft!=null) {
                     final int column = topLeft.getColumn();
                     final int row = topLeft.getRow();
@@ -496,7 +497,7 @@ public class SheetUtils {
                 attrs.put(OCKey.ACTIVE_PANE.value(), p);
 
                 if(pane!=null) {
-                    final SmlUtils.CellRef topLeftP = SmlUtils.createCellRef(pane.getTopLeftCell());
+                    final CellRef topLeftP = CellRef.createCellRef(pane.getTopLeftCell());
                     if(topLeftP!=null) {
                         if(topLeftP.getColumn()>0) {
                             attrs.put(OCKey.SCROLL_RIGHT.value(), topLeftP.getColumn());
@@ -553,9 +554,9 @@ public class SheetUtils {
                                 attrs.put(OCKey.SELECTED_RANGES.value(), ranges);
                                 attrs.put(OCKey.ACTIVE_INDEX.value(), selection.getActiveCellId());
                                 if(selection.getActiveCell()!=null) {
-                                    final SmlUtils.CellRef activeCell = SmlUtils.createCellRef(selection.getActiveCell());
+                                    final CellRef activeCell = CellRef.createCellRef(selection.getActiveCell());
                                     if(activeCell!=null) {
-                                        attrs.put(OCKey.ACTIVE_CELL.value(), SmlUtils.getCellRef(activeCell));
+                                        attrs.put(OCKey.ACTIVE_CELL.value(), CellRef.getCellRef(activeCell));
                                     }
                                 }
                             }
