@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -93,8 +93,8 @@ import org.xlsx4j.sml.SheetData;
 import org.xlsx4j.sml.Worksheet;
 import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.api.OCValue;
-import com.openexchange.office.filter.core.spreadsheet.SmlUtils;
-import com.openexchange.office.filter.core.spreadsheet.SmlUtils.CellRefRange;
+import com.openexchange.office.filter.core.spreadsheet.CellRef;
+import com.openexchange.office.filter.core.spreadsheet.CellRefRange;
 import com.openexchange.office.filter.ooxml.xlsx.XlsxOperationDocument;
 import com.openexchange.office.filter.ooxml.xlsx.operations.XlsxApplyOperationHelper;
 import com.openexchange.office.filter.ooxml.xlsx.tools.AutoFilterHelper.FilterType;
@@ -111,7 +111,7 @@ public class TableHelper {
     	for(CTTablePart tablePartId:tablePartList) {
     		final CTTable table = getTable(worksheetPart, tablePartId);
     		if(table!=null) {
-    	        final SmlUtils.CellRefRange cellRefRange = table.getCellRefRange(false);
+    	        final CellRefRange cellRefRange = table.getCellRefRange(false);
     			final String tableName = table.getDisplayName();
     	        if (cellRefRange!=null && tableName!=null && !tableName.isEmpty()) {
     	            final JSONObject attrs = new JSONObject(1);
@@ -163,7 +163,7 @@ public class TableHelper {
                 final String ref = sortCondition.getRef();
                 if(ref!=null) {
                     final JSONObject sortAttrs = new JSONObject();
-                    final Integer column = Integer.valueOf(SmlUtils.createCellRef(ref).getColumn()-tableStartColumn);
+                    final Integer column = Integer.valueOf(CellRef.createCellRef(ref).getColumn()-tableStartColumn);
                     if(column.intValue()>=0) {
                         final STSortBy sortBy = sortCondition.getSortBy();
                         String type = "value";
@@ -207,7 +207,7 @@ public class TableHelper {
 
         // collecting filter columns ...
         if(autoFilter!=null) {
-            final List<CTFilterColumn> filterColumns = autoFilter.getFilterColumn();
+            final List<CTFilterColumn> filterColumns = autoFilter.getFilterColumn(true);
             for(CTFilterColumn filterColumn:filterColumns) {
                 final JSONObject filterAttrs = new JSONObject(3);
                 final CTFilters filters = filterColumn.getFilters();
@@ -269,13 +269,13 @@ public class TableHelper {
         }
     }
 
-    public static void addInsertTableOperation(JSONArray operationsArray, int sheetIndex, SmlUtils.CellRefRange range, String tableName, JSONObject attrs)
+    public static void addInsertTableOperation(JSONArray operationsArray, int sheetIndex, CellRefRange range, String tableName, JSONObject attrs)
             throws JSONException {
 
         final JSONObject addInsertTableObject = new JSONObject(6);
         addInsertTableObject.put(OCKey.NAME.value(), OCValue.INSERT_TABLE.value());
         addInsertTableObject.put(OCKey.SHEET.value(), sheetIndex);
-        addInsertTableObject.put(OCKey.RANGE.value(), SmlUtils.getCellRefRange(range));
+        addInsertTableObject.put(OCKey.RANGE.value(), CellRefRange.getCellRefRange(range));
         if(!attrs.isEmpty()) {
             addInsertTableObject.put(OCKey.ATTRS.value(), attrs);
         }
@@ -289,7 +289,7 @@ public class TableHelper {
     	final WorksheetPart worksheetPart = (WorksheetPart)applyOperationHelper.getSheetPart(sheetIndex);
         CTTable table;
     	if(insert) {
-    		final CellRefRange cellRefRange = SmlUtils.createCellRefRange(range);
+    		final CellRefRange cellRefRange = CellRefRange.createCellRefRange(range);
             final CTTableParts tableParts = worksheetPart.getJaxbElement().getTableParts(true);
             final TablePart tablePart = new TablePart();
             table = new CTTable();
@@ -311,7 +311,7 @@ public class TableHelper {
     	else {
     		table = getTable(worksheetPart, tableName);
     		if(range!=null) {
-    		    table.setCellRefRange(SmlUtils.createCellRefRange(range));
+    		    table.setCellRefRange(CellRefRange.createCellRefRange(range));
     		}
         	final CTAutoFilter autoFilter = table.getAutoFilter(false);
         	if(autoFilter!=null) {
@@ -350,7 +350,7 @@ public class TableHelper {
 	                if(sortState.getRef()==null) {
 	                    final CellRefRange tableRef = table.getCellRefRange(true);
 	                    final CellRefRange sortRef = new CellRefRange(tableRef.getStart().getColumn(), tableRef.getStart().getRow()+1, tableRef.getEnd().getColumn(), tableRef.getEnd().getRow()+1);
-	                    sortState.setRef(SmlUtils.getCellRefRange(sortRef));
+	                    sortState.setRef(CellRefRange.getCellRefRange(sortRef));
 	                }
 	            }
 	            else {
@@ -434,7 +434,7 @@ public class TableHelper {
                     final CTSortState sortState = sortStateAccessor.getSortState(true);
                     if(sortState.getRef()==null) {
                         final CellRefRange sortRef = new CellRefRange(refRange.getStart().getColumn(), refRange.getStart().getRow()+1, refRange.getEnd().getColumn(), refRange.getEnd().getRow()+1);
-                        sortState.setRef(SmlUtils.getCellRefRange(sortRef));
+                        sortState.setRef(CellRefRange.getCellRefRange(sortRef));
                     }
                     applySortState(refRange, sortState, col, (JSONObject)o, sort);
                 }
@@ -456,7 +456,7 @@ public class TableHelper {
                 filterType = FilterType.DISCRETE;
             }
         }
-        final List<CTFilterColumn> filterColumns = autoFilter.getFilterColumn();
+        final List<CTFilterColumn> filterColumns = autoFilter.getFilterColumn(true);
         int filterColumnIndex = 0;
         CTFilterColumn filterColumn = null;
         for(;filterColumnIndex<filterColumns.size();filterColumnIndex++) {
@@ -510,7 +510,7 @@ public class TableHelper {
         int sortIndex = 0;
         for(; sortIndex<sortConditionList.size(); sortIndex++) {
             final CTSortCondition ci = sortConditionList.get(sortIndex);
-            if(SmlUtils.createCellRef(ci.getRef()).getColumn()-refRange.getStart().getColumn()==col) {
+            if(CellRef.createCellRef(ci.getRef()).getColumn()-refRange.getStart().getColumn()==col) {
                 currentCondition = sortConditionList.remove(sortIndex);
                 break;
             }
@@ -523,7 +523,7 @@ public class TableHelper {
             currentCondition = new CTSortCondition();
             final int c = refRange.getStart().getColumn() + col;
             final CellRefRange newCellRefRange =  new CellRefRange(c, refRange.getStart().getRow()+1, c, refRange.getEnd().getRow());
-            currentCondition.setRef(SmlUtils.getCellRefRange(newCellRefRange));
+            currentCondition.setRef(CellRefRange.getCellRefRange(newCellRefRange));
         }
         sortConditionList.add(sort ? sortConditionList.size() : sortIndex, currentCondition);
         if(type.equals("value")) {
@@ -568,7 +568,7 @@ public class TableHelper {
 	    	for(CTTablePart tablePartId:tablePartList) {
 	    		final CTTable table = getTable(worksheetPart, tablePartId);
 	    		if(table!=null) {
-	    	        final SmlUtils.CellRefRange cellRefRange = table.getCellRefRange(false);
+	    	        final CellRefRange cellRefRange = table.getCellRefRange(false);
 	    	        if(tableName.equals(table.getDisplayName())&&cellRefRange!=null) {
 	    	        	return table;
 	    	        }
@@ -594,92 +594,75 @@ public class TableHelper {
 
     public static void insertRows(WorksheetPart worksheetPart, CTTablePart tablePart, int start, int count) {
     	final CTTable table = getTable(worksheetPart, tablePart);
-    	final CellRefRange tableRef = SmlUtils.CellRefRange.insertRowRange(table.getCellRefRange(true), start, count, false);
-    	final CellRefRange autofilterRef = table.getAutoFilter(false)!=null ? SmlUtils.CellRefRange.insertRowRange(table.getAutoFilter(false).getCellRefRange(true), start, count, false) : null;
+    	final CellRefRange tableRef = CellRefRange.insertRowRange(table.getCellRefRange(true), start, count, false);
+    	final CellRefRange newAutoFilterRef = table.getAutoFilter(false) != null ? AutoFilterHelper.handleAutoFilter(table.getAutoFilter(true), start, count, false, 1) : null;
     	final CTSortState sortState = table.getSortState(false);
     	if(sortState!=null) {
-    	    final CellRefRange sortRef = SmlUtils.CellRefRange.insertRowRange(table.getSortState(false).getCellRefRange(true), start, count, false);
+    	    final CellRefRange sortRef = CellRefRange.insertRowRange(table.getSortState(false).getCellRefRange(true), start, count, false);
     	    if(sortRef!=null) {
     	        sortState.setCellRefRange(sortRef);
-    	        SmlUtils.CellRefRange.insertRows(sortState.getSortCondition(), start, count, false, null);
+    	        CellRefRange.insertRows(sortState.getSortCondition(), start, count, false, null);
     	    }
     	    else {
     	        table.setSortState(null);
     	    }
     	}
-    	applyTableRefChange(worksheetPart, table, tableRef, autofilterRef);
+    	applyTableRefChange(worksheetPart, table, tableRef, newAutoFilterRef);
     }
 
     public static void deleteRows(WorksheetPart worksheetPart, CTTablePart tablePart, int start, int count) {
     	final CTTable table = getTable(worksheetPart, tablePart);
-    	final CellRefRange tableRef = SmlUtils.CellRefRange.deleteRowRange(table.getCellRefRange(true), start, count);
-    	final CellRefRange autofilterRef = table.getAutoFilter(false)!=null ? SmlUtils.CellRefRange.deleteRowRange(table.getAutoFilter(false).getCellRefRange(true), start, count) : null;
+    	final CellRefRange tableRef = CellRefRange.deleteRowRange(table.getCellRefRange(true), start, count);
+        final CellRefRange newAutoFilterRef = table.getAutoFilter(false) != null ? AutoFilterHelper.handleAutoFilter(table.getAutoFilter(true), start, count, false, -1) : null;
     	final CTSortState sortState = table.getSortState(false);
     	if(sortState!=null) {
-    	    final CellRefRange sortRef = SmlUtils.CellRefRange.deleteRowRange(table.getSortState(false).getCellRefRange(true), start, count);
+    	    final CellRefRange sortRef = CellRefRange.deleteRowRange(table.getSortState(false).getCellRefRange(true), start, count);
     	    if(sortRef!=null) {
     	        sortState.setCellRefRange(sortRef);
-    	        SmlUtils.CellRefRange.deleteRows(sortState.getSortCondition(), start, count, false, null);
+    	        CellRefRange.deleteRows(sortState.getSortCondition(), start, count, false, null);
     	    }
     	    else {
     	        table.setSortState(null);
     	    }
     	}
-    	applyTableRefChange(worksheetPart, table, tableRef, autofilterRef);
+    	applyTableRefChange(worksheetPart, table, tableRef, newAutoFilterRef);
     }
 
     public static void insertColumns(WorksheetPart worksheetPart, CTTablePart tablePart, int start, int count) {
     	final CTTable table = getTable(worksheetPart, tablePart);
-    	final CellRefRange tableRef = SmlUtils.CellRefRange.insertColumnRange(table.getCellRefRange(true), start, count, false);
-    	final CellRefRange autofilterRef = table.getAutoFilter(false)!=null ? SmlUtils.CellRefRange.insertColumnRange(table.getAutoFilter(false).getCellRefRange(true), start, count, false) : null;
+    	final CellRefRange tableRef = CellRefRange.insertColumnRange(table.getCellRefRange(true), start, count, false);
+    	final CellRefRange newAutofilterRef = table.getAutoFilter(false) != null ? AutoFilterHelper.handleAutoFilter(table.getAutoFilter(true), start, count, true, 1) : null;
     	final CTSortState sortState = table.getSortState(false);
     	if(sortState!=null) {
-    	    final CellRefRange sortRef = SmlUtils.CellRefRange.insertColumnRange(table.getSortState(false).getCellRefRange(true), start, count, false);
+    	    final CellRefRange sortRef = CellRefRange.insertColumnRange(table.getSortState(false).getCellRefRange(true), start, count, false);
     	    if(sortRef!=null) {
     	        sortState.setCellRefRange(sortRef);
-    	        SmlUtils.CellRefRange.insertColumns(sortState.getSortCondition(), start, count, false, null);
+    	        CellRefRange.insertColumns(sortState.getSortCondition(), start, count, false, null);
     	    }
     	    else {
     	        table.setSortState(null);
     	    }
     	}
-    	applyTableRefChange(worksheetPart, table, tableRef, autofilterRef);
+    	applyTableRefChange(worksheetPart, table, tableRef, newAutofilterRef);
     }
 
     public static void deleteColumns(WorksheetPart worksheetPart, CTTablePart tablePart, int start, int count) {
     	final CTTable table = getTable(worksheetPart, tablePart);
-    	final CellRefRange tableRef = SmlUtils.CellRefRange.deleteColumnRange(table.getCellRefRange(true), start, count);
-    	CellRefRange autofilterRef = null;
-    	final CTAutoFilter autoFilter = table.getAutoFilter(false);
-    	if(autoFilter!=null) {
-    	    autofilterRef = SmlUtils.CellRefRange.deleteColumnRange(autoFilter.getCellRefRange(true), start, count);
-
-    	    // removing invalid filterColumns ...
-    	    int maxColId = -1;
-    	    if(autofilterRef!=null) {
-    	        maxColId = Math.abs(autofilterRef.getEnd().getColumn() - autofilterRef.getStart().getColumn());
-    	    }
-    	    final List<CTFilterColumn> filterColumnList = autoFilter.getFilterColumn();
-    	    for(int i = filterColumnList.size() - 1; i >= 0; i--) {
-    	        final CTFilterColumn filterColumn = filterColumnList.get(i);
-    	        if(filterColumn.getColId()>maxColId) {
-    	            filterColumnList.remove(i);
-    	        }
-    	    }
-    	}
+    	final CellRefRange tableRef = CellRefRange.deleteColumnRange(table.getCellRefRange(true), start, count);
+    	final CellRefRange newAutofilterRef = table.getAutoFilter(false) != null ? AutoFilterHelper.handleAutoFilter(table.getAutoFilter(true), start, count, true, -1) : null;
     	final CTSortState sortState = table.getSortState(false);
     	if(sortState!=null) {
-            final CellRefRange sortRef = SmlUtils.CellRefRange.deleteColumnRange(table.getSortState(false).getCellRefRange(true), start, count);
+            final CellRefRange sortRef = CellRefRange.deleteColumnRange(table.getSortState(false).getCellRefRange(true), start, count);
             if(sortRef!=null) {
                 sortState.setCellRefRange(sortRef);
-                SmlUtils.CellRefRange.deleteColumns(sortState.getSortCondition(), start, count, false, null);
+                CellRefRange.deleteColumns(sortState.getSortCondition(), start, count, false, null);
 
             }
             else {
                 table.setSortState(null);
             }
     	}
-    	applyTableRefChange(worksheetPart, table, tableRef, autofilterRef);
+    	applyTableRefChange(worksheetPart, table, tableRef, newAutofilterRef);
     }
 
     private static void applyTableRefChange(WorksheetPart worksheetPart, CTTable table, CellRefRange tableRef, CellRefRange autofilterRef) {
