@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -99,7 +99,7 @@ import org.xlsx4j.sml.STPatternType;
 import org.xlsx4j.sml.STVerticalAlignment;
 import com.openexchange.office.filter.api.FilterException;
 import com.openexchange.office.filter.api.OCKey;
-import com.openexchange.office.filter.core.spreadsheet.SmlUtils;
+import com.openexchange.office.filter.core.spreadsheet.CellRefRange;
 import com.openexchange.office.filter.ooxml.tools.Commons;
 import com.openexchange.office.filter.ooxml.tools.json.JSONHelper;
 import com.openexchange.office.filter.ooxml.xlsx.XlsxOperationDocument;
@@ -1104,10 +1104,10 @@ public class Utils {
         }
     }
 
-    public static List<SmlUtils.CellRefRange> createCellRefRangeListFromSqrefList(List<String> sqrefList) {
-		final List<SmlUtils.CellRefRange> cellRefRangeList = new ArrayList<SmlUtils.CellRefRange>();
+    public static List<CellRefRange> createCellRefRangeListFromSqrefList(List<String> sqrefList) {
+		final List<CellRefRange> cellRefRangeList = new ArrayList<CellRefRange>();
 	    for(String sqRef:sqrefList) {
-	        final SmlUtils.CellRefRange cellRefRange = SmlUtils.createCellRefRange(sqRef);
+	        final CellRefRange cellRefRange = CellRefRange.createCellRefRange(sqRef);
 	        if(cellRefRange!=null) {
 	            cellRefRangeList.add(cellRefRange);
 	        }
