@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -66,8 +66,7 @@ import org.xlsx4j.sml.STDataValidationType;
 import org.xlsx4j.sml.Worksheet;
 import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.api.OCValue;
-import com.openexchange.office.filter.core.spreadsheet.SmlUtils;
-import com.openexchange.office.filter.core.spreadsheet.SmlUtils.CellRefRange;
+import com.openexchange.office.filter.core.spreadsheet.CellRefRange;
 import com.openexchange.office.filter.ooxml.xlsx.XlsxOperationDocument;
 
 public class ValidationUtils {
@@ -106,12 +105,12 @@ public class ValidationUtils {
     	return value;
     }
 
-    public static void addInsertValidationOperation(JSONArray operationsArray, int sheetIndex, int validationIndex, List<SmlUtils.CellRefRange> rangeList, STDataValidationType type, STDataValidationOperator operator, String value1, String value2,
+    public static void addInsertValidationOperation(JSONArray operationsArray, int sheetIndex, int validationIndex, List<CellRefRange> rangeList, STDataValidationType type, STDataValidationOperator operator, String value1, String value2,
                                             boolean showInfo, String infoTitle, String infoText, boolean showError, String errorTitle, String errorText, STDataValidationErrorStyle errorStyle, boolean showDropDown, boolean ignoreBlank)
         throws JSONException {
 
         final JSONObject insertValidationObject = new JSONObject();
-        insertValidationObject.put(OCKey.NAME.value(), OCValue.INSERT_VALIDATION.value());
+        insertValidationObject.put(OCKey.NAME.value(), OCValue.INSERT_DV_RULE.value());
         insertValidationObject.put(OCKey.SHEET.value(), sheetIndex);
         insertValidationObject.put(OCKey.INDEX.value(), validationIndex);
         final StringBuffer rangesBuffer = new StringBuffer();
@@ -119,7 +118,7 @@ public class ValidationUtils {
             if(rangesBuffer.length()!=0) {
                 rangesBuffer.append(" ");
             }
-            rangesBuffer.append(SmlUtils.getCellRefRange(cellRefRange));
+            rangesBuffer.append(CellRefRange.getCellRefRange(cellRefRange));
         }
         insertValidationObject.put(OCKey.RANGES.value(), rangesBuffer.toString());
         int val = type.ordinal();
