@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -67,10 +67,12 @@ import java.util.zip.ZipEntry;
 import java.util.zip.ZipException;
 import java.util.zip.ZipInputStream;
 import java.util.zip.ZipOutputStream;
+
 import javax.xml.bind.JAXBElement;
 import javax.xml.bind.JAXBException;
 import javax.xml.datatype.DatatypeConstants;
 import javax.xml.datatype.XMLGregorianCalendar;
+
 import org.apache.commons.io.IOUtils;
 import org.docx4j.XmlUtils;
 import org.docx4j.dml.Theme;
@@ -97,6 +99,8 @@ import org.docx4j.wml.CTSettings;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
+import org.springframework.beans.factory.InitializingBean;
+
 import com.openexchange.exception.ExceptionUtils;
 import com.openexchange.office.filter.api.DocumentProperties;
 import com.openexchange.office.filter.api.FilterException;
@@ -105,10 +109,9 @@ import com.openexchange.office.filter.core.OperationDocument;
 import com.openexchange.office.filter.ooxml.components.OfficeOpenXMLComponent;
 import com.openexchange.office.filter.ooxml.tools.ThemeFonts;
 import com.openexchange.office.imagemgr.IResourceManager;
-import com.openexchange.office.tools.config.ConfigurationHelper;
 import com.openexchange.session.Session;
 
-abstract public class OfficeOpenXMLOperationDocument extends OperationDocument {
+abstract public class OfficeOpenXMLOperationDocument extends OperationDocument implements InitializingBean {
 
 	private class ChangeTrackAuthor {
 
@@ -156,26 +159,27 @@ abstract public class OfficeOpenXMLOperationDocument extends OperationDocument {
 	private static final String MODULE = "//module/";
 
     private 	  ByteArrayInputStream  debugDocument;
-    protected final boolean             saveDebugOperations;
+    protected boolean             saveDebugOperations;
     private Set<ChangeTrackAuthor> 		changeTrackAuthors = null;
     protected Part 						contextPart = null;
     protected ThemeFonts 				themeFonts = null;
     private Map<String, CTShapetype>    vmlShapeTypes = null;
-    private boolean                     useConfiguration = true;
 
     static final int DEFAULT_BUFFER_SIZE = 8192;
 
     protected OfficeOpenXMLOperationDocument(Session session, IResourceManager resourceManager, DocumentProperties documentProperties) {
         super(session, resourceManager, documentProperties);
+    };
 
+    @Override
+	public void afterPropertiesSet() throws Exception {
         saveDebugOperations = Boolean.parseBoolean(getOfficeConfigurationValue(MODULE + "debugoperations", "false"));
         if(documentProperties!=null) {
             documentProperties.optBoolean("useConfiguration", true);
         }
-    };
+	}
 
-
-    final public void loadDocument(InputStream inputStream, boolean XMLReadOnly) throws Exception {
+	final public void loadDocument(InputStream inputStream, boolean XMLReadOnly) throws Exception {
         try {
             debugDocument = _loadDocument(inputStream, XMLReadOnly);
         }
@@ -1055,14 +1059,6 @@ abstract public class OfficeOpenXMLOperationDocument extends OperationDocument {
         this.vmlShapeTypes = shapeTypes;
     }
 
-    public String getOfficeConfigurationValue(String settingPath, String defaultValue) {
-        return useConfiguration ? ConfigurationHelper.getOfficeConfigurationValue(null, session, settingPath, defaultValue) : defaultValue;
-    }
-
-    public Integer getIntegerOfficeConfigurationValue(String settingPath, Integer defaultValue) {
-        return useConfiguration ? ConfigurationHelper.getIntegerOfficeConfigurationValue(null, session, settingPath, defaultValue) : defaultValue;
-    }
-
     private HashSet<String> usedLanguages = new HashSet<String>();
 
     public Set<String> getUsedLanguages() {
