@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,7 +50,7 @@
 package com.openexchange.office.filter.ooxml.components;
 
 import org.json.JSONObject;
-import com.openexchange.office.filter.core.component.Component;
+import com.openexchange.office.filter.core.component.ComponentType;
 
 public interface IShape extends IShapeType {
 
@@ -66,5 +66,5 @@ public interface IShape extends IShapeType {
 
 	// inserts a new shape (image, shape and or group into the parent group)
 	// returns either IShape or Component
-    public Object insertChild(int number, Component.Type type) throws Exception;
+    public Object insertChild(int number, ComponentType type) throws Exception;
 }
