@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,8 +57,9 @@ import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.office.filter.core.DLNode;
 import com.openexchange.office.filter.core.SplitMode;
-import com.openexchange.office.filter.core.component.Component;
 import com.openexchange.office.filter.core.component.ComponentContext;
+import com.openexchange.office.filter.core.component.ComponentType;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 
 public class MultiComponent extends OfficeOpenXMLComponent implements IParagraph, ITable, IRow {
@@ -104,7 +105,7 @@ public class MultiComponent extends OfficeOpenXMLComponent implements IParagraph
 		return createComponent(operationDocument, nextComponents);
 	}
 	@Override
-	public Component<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, Component<OfficeOpenXMLOperationDocument> previousChildComponent) {
+	public IComponent<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, IComponent<OfficeOpenXMLOperationDocument> previousChildComponent) {
 		final List<OfficeOpenXMLComponent> childComponents = new ArrayList<OfficeOpenXMLComponent>(componentList.size());
 		for(OfficeOpenXMLComponent component:componentList) {
 			final OfficeOpenXMLComponent childComponent = (OfficeOpenXMLComponent)component.getNextChildComponent(previousChildContext, previousChildComponent);
@@ -115,11 +116,11 @@ public class MultiComponent extends OfficeOpenXMLComponent implements IParagraph
 		return createComponent(operationDocument, childComponents);
 	}
 	@Override
-	public Component<OfficeOpenXMLOperationDocument> insertChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> parentContext, DLNode<Object> contextNode, int number, Component<OfficeOpenXMLOperationDocument> child, Component.Type type, JSONObject attrs) {
+	public IComponent<OfficeOpenXMLOperationDocument> insertChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> parentContext, DLNode<Object> contextNode, int number, IComponent<OfficeOpenXMLOperationDocument> child, ComponentType type, JSONObject attrs) {
 		return null;
 	}
 	@Override
-    public Component<OfficeOpenXMLOperationDocument> insertChildComponent(int number, JSONObject attrs, Component.Type type) throws Exception {
+    public IComponent<OfficeOpenXMLOperationDocument> insertChildComponent(int number, JSONObject attrs, ComponentType type) throws Exception {
 	    final List<OfficeOpenXMLComponent> childComponents = new ArrayList<OfficeOpenXMLComponent>(componentList.size());
 		for(OfficeOpenXMLComponent component:componentList) {
 			childComponents.add((OfficeOpenXMLComponent)component.insertChildComponent(number, attrs, type));
