@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -84,10 +84,10 @@ import com.openexchange.office.filter.core.DLNode;
 import com.openexchange.office.filter.core.IContentAccessor;
 import com.openexchange.office.filter.core.DLList;
 import com.openexchange.office.filter.core.SplitMode;
-import com.openexchange.office.filter.core.component.Component;
 import com.openexchange.office.filter.core.component.ComponentContext;
-import com.openexchange.office.filter.core.spreadsheet.SmlUtils;
-import com.openexchange.office.filter.core.spreadsheet.SmlUtils.CellRef;
+import com.openexchange.office.filter.core.component.ComponentType;
+import com.openexchange.office.filter.core.component.IComponent;
+import com.openexchange.office.filter.core.spreadsheet.CellRef;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 import com.openexchange.office.filter.ooxml.tools.Commons;
 
@@ -159,7 +159,7 @@ public abstract class VMLBase extends OfficeOpenXMLComponent implements IShape,
         final ComponentContext<OfficeOpenXMLOperationDocument> contextChild = getContextChild(null);
 
         final int endComponent = (getComponentNumber()+count)-1;
-        Component<OfficeOpenXMLOperationDocument> component = this;
+        IComponent<OfficeOpenXMLOperationDocument> component = this;
         while(true) {
             if(component.getNextComponentNumber()>endComponent) {
                 break;
@@ -206,12 +206,12 @@ public abstract class VMLBase extends OfficeOpenXMLComponent implements IShape,
     }
 
     @Override
-    public Object insertChild(int number, Component.Type type) throws Exception {
+    public Object insertChild(int number, ComponentType type) throws Exception {
         if(documentType.equals("text")) {
             final CTTxbxContent textboxContent = getTextboxContent(true);
             final OfficeOpenXMLComponent rootComponent = operationDocument.getRootComponent();
             rootComponent.setNode(new DLNode<Object>(textboxContent));
-            Component<OfficeOpenXMLOperationDocument> c = rootComponent.getNextChildComponent(null, null);
+            IComponent<OfficeOpenXMLOperationDocument> c = rootComponent.getNextChildComponent(null, null);
             if(c!=null) {
                 c = c.getComponent(number);
             }
@@ -387,7 +387,7 @@ public abstract class VMLBase extends OfficeOpenXMLComponent implements IShape,
                             final String[] anchorAttrs = anchor.substring(2).split(" ", -1);
                             final int pC = anchorAttrs.length;
                             if(pC>0) {
-                                final CellRef startRef = SmlUtils.createCellRef(anchorAttrs[0]);
+                                final CellRef startRef = CellRef.createCellRef(anchorAttrs[0]);
                                 vmlCoreObject.getClientData(true).getAnchorArray(true)[0] = startRef.getColumn();
                                 vmlCoreObject.getClientData(true).getAnchorArray(true)[2] = startRef.getRow();
                             }
@@ -400,7 +400,7 @@ public abstract class VMLBase extends OfficeOpenXMLComponent implements IShape,
                                 vmlCoreObject.getClientData(true).getAnchorArray(true)[3] = (int)((((Long)startRowOffset).doubleValue()*0.037795)+0.5);
                             }
                             if(pC>3) {
-                                final CellRef endRef = SmlUtils.createCellRef(anchorAttrs[3]);
+                                final CellRef endRef = CellRef.createCellRef(anchorAttrs[3]);
                                 vmlCoreObject.getClientData(true).getAnchorArray(true)[4] = endRef.getColumn();
                                 vmlCoreObject.getClientData(true).getAnchorArray(true)[6] = endRef.getRow();
                             }
@@ -872,13 +872,13 @@ public abstract class VMLBase extends OfficeOpenXMLComponent implements IShape,
                         final CellRef startRef = new CellRef(anchorArray[0], anchorArray[2]);
                         final CellRef endRef = new CellRef(anchorArray[4], anchorArray[6]);
                         builder.append(' ')
-                               .append(SmlUtils.getCellRef(startRef))
+                               .append(CellRef.getCellRef(startRef))
                                .append(' ')
                                .append(Integer.valueOf((int)getLength(anchorArray[1], UnitType.PX)).toString())
                                .append(' ')
                                .append(Integer.valueOf((int)getLength(anchorArray[3], UnitType.PX)).toString())
                                .append(' ')
-                               .append(SmlUtils.getCellRef(endRef))
+                               .append(CellRef.getCellRef(endRef))
                                .append(' ')
                                .append(Integer.valueOf((int)getLength(anchorArray[5], UnitType.PX)).toString())
                                .append(' ')
