@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -72,8 +72,9 @@ import org.docx4j.vml.spreadsheetDrawing.CTClientData;
 import org.docx4j.vml.spreadsheetDrawing.STObjectType;
 import org.json.JSONObject;
 import com.openexchange.office.filter.core.DLNode;
-import com.openexchange.office.filter.core.component.Component;
 import com.openexchange.office.filter.core.component.ComponentContext;
+import com.openexchange.office.filter.core.component.ComponentType;
+import com.openexchange.office.filter.core.component.IComponent;
 import com.openexchange.office.filter.core.IContentAccessor;
 import com.openexchange.office.filter.core.DLList;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
@@ -86,7 +87,7 @@ public class VMLRootComponent extends VMLBase {
      }
 
      @Override
-     public Component<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, Component<OfficeOpenXMLOperationDocument> previousChildComponent) {
+     public IComponent<OfficeOpenXMLOperationDocument> getNextChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> previousChildContext, IComponent<OfficeOpenXMLOperationDocument> previousChildComponent) {
          final DLNode<Object> paragraphNode = getNode();
          final DLList<Object> nodeList = (DLList<Object>)((IContentAccessor)paragraphNode.getData()).getContent();
          final int nextComponentNumber = previousChildComponent!=null?previousChildComponent.getNextComponentNumber():0;
@@ -141,7 +142,7 @@ public class VMLRootComponent extends VMLBase {
      }
 
      @Override
-     public Object insertChild(int number, Type type) {
+     public Object insertChild(int number, ComponentType type) {
          try {
              return insertChildComponent(number, null, type);
          }
@@ -151,7 +152,7 @@ public class VMLRootComponent extends VMLBase {
      }
 
      @Override
-     public Component<OfficeOpenXMLOperationDocument> insertChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> parentContext, DLNode<Object> contextNode, int number, Component<OfficeOpenXMLOperationDocument> child, Component.Type type, JSONObject attrs) {
+     public IComponent<OfficeOpenXMLOperationDocument> insertChildComponent(ComponentContext<OfficeOpenXMLOperationDocument> parentContext, DLNode<Object> contextNode, int number, IComponent<OfficeOpenXMLOperationDocument> child, ComponentType type, JSONObject attrs) {
 
          final DLList<Object> DLList = (DLList<Object>)((IContentAccessor)contextNode.getData()).getContent();
          final DLNode<Object> referenceNode = child!=null ? child.getNode() : null;
