@@ -66,7 +66,7 @@ public class DMLChartSpace2014 {
             attrs.put(OCKey.LINE.value(), shape);
 
             JSONObject op = new JSONObject(4);
-            op.put(OCKey.NAME.value(), OCValue.INSERT_CHART_DATA_SERIES.value());
+            op.put(OCKey.NAME.value(), OCValue.INSERT_CHART_SERIES.value());
             op.put(OCKey.START.value(), position);
             op.put(OCKey.SERIES.value(), i);
             op.put(OCKey.ATTRS.value(), attrs);
