@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -85,7 +85,7 @@ import org.slf4j.LoggerFactory;
 import com.openexchange.office.filter.ooxml.OfficeOpenXMLOperationDocument;
 import com.openexchange.office.imagemgr.IResourceManager;
 import com.openexchange.office.imagemgr.Resource;
-import com.openexchange.office.tools.files.FileHelper;
+import com.openexchange.office.tools.common.files.FileHelper;
 
 final public class Commons {
 
@@ -195,7 +195,7 @@ final public class Commons {
 
     private static Map<String, String> createHighlightColorsMap() {
         // highlight color map according to ooxml specification
-        Map<String, String> result = new HashMap<>();
+        Map<String, String> result = new HashMap<String, String>();
         result.put( "black", "000000");
         result.put( "blue", "0000FF");
         result.put( "cyan", "00FFFF");
@@ -242,7 +242,7 @@ final public class Commons {
 
     public static String mapRgbToPredefined(String rgbColor, Map<String, String> mappings) {
         String predefinedColor = null;
-        int diff = Integer.MAX_VALUE;
+        int diff = Integer.MAX_VALUE;;
         int rgbColorValue = Integer.parseInt(rgbColor);
 
         if (mappings != null) {
@@ -396,8 +396,10 @@ final public class Commons {
         final String filename = FilenameUtils.getBaseName(imageUrl);
         if(filename.startsWith(Resource.RESOURCE_UID_PREFIX)) {
             try {
-                buf = resourceManager.getResourceBuffer(filename.substring(Resource.RESOURCE_UID_PREFIX.length()));
-            } catch(NumberFormatException e) {
+                String uid = filename.substring(Resource.RESOURCE_UID_PREFIX.length());
+                buf = resourceManager.getResourceBuffer(uid);
+            }
+            catch(NumberFormatException e) {
                 //
             }
             if(buf==null) {
