@@ -28,7 +28,7 @@
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
-*     Copyright (C) 2016-2020 OX Software GmbH
+*     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
@@ -49,9 +49,12 @@
 
 package com.openexchange.office.hazelcast.serialization.document;
 
+import org.springframework.stereotype.Service;
+
 import com.hazelcast.nio.serialization.ClassDefinition;
 import com.hazelcast.nio.serialization.Portable;
 import com.openexchange.hazelcast.serialization.AbstractCustomPortableFactory;
+import com.openexchange.office.tools.annotation.RegisteredService;
 
 /**
 * {@link PortableCleanupStatusFactory}
@@ -59,6 +62,8 @@ import com.openexchange.hazelcast.serialization.AbstractCustomPortableFactory;
 * @author <a href="mailto:carsten.driesner@open-xchange.com">Carsten Driesner</a>
 * @since 7.8.1
 */
+@Service
+@RegisteredService
 public class PortableCleanupStatusFactory extends AbstractCustomPortableFactory {
 
    @Override
