@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,12 +57,13 @@ import java.util.HashSet;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Set;
+
 import org.apache.commons.lang3.StringUtils;
 import org.json.JSONArray;
 import org.json.JSONObject;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import com.openexchange.file.storage.File;
+
 import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.api.OCValue;
 
@@ -88,15 +89,15 @@ public class PresentationHtmlDocumentBuilder
         return LOG;
     }
 
-    static
+    static public
             String
             buildHtmlDocument(
                 JSONObject documentOperations,
-                File file,
+                DocMetaData docMetaData,
                 TextTableLimits tableLimits)
     {
 
-        return buildHtmlDocument(documentOperations, file.getId(), file.getFolderId(), file.getVersion(), file.getFileName(), tableLimits);
+        return buildHtmlDocument(documentOperations, docMetaData.getId(), docMetaData.getFolderId(), docMetaData.getVersionOrAttachment(), docMetaData.getFileName(), docMetaData.getSource(), tableLimits);
     }
 
     static private
@@ -107,6 +108,7 @@ public class PresentationHtmlDocumentBuilder
                 String folderId,
                 String fileVersion,
                 String fileName,
+                String source,
                 TextTableLimits textTableLimits)
     {
         String result = null;
@@ -185,7 +187,7 @@ public class PresentationHtmlDocumentBuilder
                     }
                     else if (OCValue.INSERT_DRAWING.value().equals(opName))
                     {
-                        insert = new Drawing(operation.optString(OCKey.TYPE.value(), null), fileId, folderId, fileVersion).setPresentation(true).setTarget(target);
+                        insert = new Drawing(operation.optString(OCKey.TYPE.value(), null), fileId, folderId, fileVersion, source).setPresentation(true).setTarget(target);
 
                         if (attrs != null)
                         {
