@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,12 +55,13 @@ import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Set;
 import java.util.Stack;
+
 import org.apache.commons.lang3.StringUtils;
 import org.json.JSONArray;
 import org.json.JSONObject;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import com.openexchange.file.storage.File;
+
 import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.api.OCValue;
 
@@ -83,12 +84,12 @@ public class TextHtmlDocumentBuilder
         return LOG;
     }
 
-    static String buildHtmlDocument(
+    public static String buildHtmlDocument(
         JSONObject documentOperations,
-        File file,
+        DocMetaData docMetaData,
         TextTableLimits tableLimits) {
 
-        return buildHtmlDocument(documentOperations, file.getId(), file.getFolderId(), file.getVersion(), file.getFileName(), tableLimits);
+        return buildHtmlDocument(documentOperations, docMetaData.getId(), docMetaData.getFolderId(), docMetaData.getVersionOrAttachment(), docMetaData.getFileName(), docMetaData.getSource(), tableLimits);
     }
 
     static private String buildHtmlDocument(
@@ -97,6 +98,7 @@ public class TextHtmlDocumentBuilder
         String folderId,
         String fileVersion,
         String fileName,
+        String source,
         TextTableLimits textTableLimits)
     {
 
@@ -223,7 +225,7 @@ public class TextHtmlDocumentBuilder
                         }
                         else if (opName.equals(OCValue.INSERT_DRAWING.value()))
                         {
-                            insert = new Drawing(operation.optString(OCKey.TYPE.value(), null), fileId, folderId, fileVersion);
+                            insert = new Drawing(operation.optString(OCKey.TYPE.value(), null), fileId, folderId, fileVersion, source);
 
                             if (attrs != null)
                             {
