@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,146 +49,52 @@
 
 package com.openexchange.office.imagemgr;
 
-import java.io.ByteArrayInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.security.MessageDigest;
 import java.security.NoSuchAlgorithmException;
+import java.time.Instant;
+import java.time.LocalDateTime;
+import java.time.ZoneOffset;
+import org.apache.commons.codec.binary.Hex;
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang3.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+
 import com.openexchange.exception.OXException;
 import com.openexchange.filemanagement.ManagedFile;
-import com.openexchange.filemanagement.ManagedFileManagement;
-import com.openexchange.office.tools.osgi.ServiceLookupRegistry;
-import com.openexchange.server.ServiceLookup;
-import com.openexchange.tools.encoding.Hex;
+import com.openexchange.office.tools.common.IOHelper;
 
 /**
  * {@link Resource}
  *
  * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
+ * @author <a href="mailto:carsten.driesner@open-xchange.com">Carsten Driesner</a>
  */
 public class Resource {
 
     public static final String RESOURCE_UID_PREFIX = "xid";
-
     private static final Logger LOG = LoggerFactory.getLogger(Resource.class);
     private static final String idPrefix = "office.resource0x";
 
-    private static class ResourceInfo {
+    private ManagedFile m_managedFile = null;
+    private String m_uid = null;
 
-        public ManagedFile managedFile;
-        public String uid;
-
-        public ResourceInfo(final ManagedFile managedFile, String uid) {
-            this.managedFile = managedFile;
-            this.uid = uid;
+    public Resource(ManagedFile managedFile, String uid) {
+    	this.m_managedFile = managedFile;
+    	this.m_uid = uid;
+    }
+    
+    @Override
+    public String toString() {
+        final StringBuilder tmp = new StringBuilder("Resource: ");
+        tmp.append("ManagedId: ").append(getManagedId());
+        if (m_managedFile != null) {
+            tmp.append(", managed file: ").append(m_managedFile.getFile());
+            tmp.append(", last access: ").append(convertToLocalDateTime(m_managedFile.getLastAccess()));
         }
-    }
-
-    /**
-     * Initializes a new {@link Resource}.
-     *
-     * @param services
-     * @param buffer
-     */
-    public Resource(ServiceLookup servicesDEPRECATED, byte[] buffer) {
-        this(null, getSHA256(buffer), buffer);
-    }
-
-    /**
-     * Initializes a new {@link Resource}.
-     *
-     * @param services If set, a <link>ManagedFile</Link> will be created to hold the content
-     * @param _buffer The content of this resource as a byte Array
-     */
-    public Resource(ServiceLookup servicesDEPRECATED, String sha256, byte[] buffer) {
-        if (null != buffer) {
-            m_uid = Resource.getUIDFromData(sha256, buffer);
-
-            final ManagedFileManagement fileMgr = ServiceLookupRegistry.get().getService(ManagedFileManagement.class);
-
-            if (null != fileMgr) {
-                // first try to find out, if we already have the managed file
-                try {
-                    final String managedId = getManagedIdFromUID(m_uid);
-                    if (fileMgr.contains(managedId))
-                        m_managedFile = fileMgr.getByID(managedId);
-                } catch (OXException e) {
-                    // nothing to do - exception means managed file is not known
-                }
-
-                if (null == m_managedFile) {
-                    // create a new managed file
-                    try {
-                        final InputStream inputStream = new ByteArrayInputStream(buffer);
-                        m_managedFile = fileMgr.createManagedFile(getManagedIdFromUID(m_uid), inputStream, true);
-                        IOUtils.closeQuietly(inputStream);
-                    } catch (OXException e) {
-                        LOG.error(e.getMessage(), e);
-                    }
-                }
-            }
-        }
-    }
-
-    /**
-     * Initializes a new {@link Resource}.
-     *
-     * @param services
-     * @param id The id of the distributed managed file
-     */
-    public Resource(ServiceLookup servicesDEPRECATED, String id) {
-        try {
-            final ResourceInfo aResInfo = Resource.createResourceInfoIfExists(id);
-            if (null != aResInfo) {
-                m_managedFile = aResInfo.managedFile;
-                m_uid = aResInfo.uid;
-            }
-        } catch (OXException e) {
-            LOG.error(e.getMessage(), e);
-        }
-    }
-
-    /**
-     * Initializes a new {@link Resource using an
-     * initialized ResourceInfo object.
-     *
-     * @param aResourceInfo a valid ResourceInfo object to initialize this Resource instance
-     */
-    private Resource(ResourceInfo aResourceInfo) {
-        m_managedFile = aResourceInfo.managedFile;
-        m_uid = aResourceInfo.uid;
-    }
-
-    /**
-     * Creates a ResourceInfo object which contains the mandatory
-     * data to describe a unique managed file to be used by the
-     * ResourceManager.
-     *
-     * @param id The unique resource identifier used by the ManagedFileManagement.
-     * @return A ResourceInfo object or null if no object could be created
-     * @throws OXException A ManagedFileExceptionErrorMessage.NOT_FOUND is thrown if
-     *             the object couldn't found in the ManagedFileManagement.
-     */
-    static private ResourceInfo createResourceInfoIfExists(String id) throws OXException {
-        ResourceInfo result = null;
-        String uid = null;
-
-        final ManagedFileManagement fileMgr = ServiceLookupRegistry.get().getService(ManagedFileManagement.class);
-        uid = Resource.getUIDFromManagedId(id);
-
-        if ((null != fileMgr) && (null != uid) && (fileMgr.contains(id))) {
-            ManagedFile aManagedFile = null;
-
-            if (null != (aManagedFile = fileMgr.getByID(id))) {
-                result = new ResourceInfo(aManagedFile, uid);
-            }
-        }
-
-        return result;
+        return tmp.toString();
     }
 
     /**
@@ -197,9 +103,7 @@ public class Resource {
     public byte[] getBuffer() {
         byte[] ret = null;
 
-        if (null == m_managedFile) {
-            ret = m_buffer;
-        } else {
+        if (null != m_managedFile) {
             try {
                 final InputStream inputStream = m_managedFile.getInputStream();
 
@@ -209,7 +113,7 @@ public class Resource {
                     } catch (IOException e) {
                         LOG.error(e.getMessage(), e);
                     } finally {
-                        IOUtils.closeQuietly(inputStream);
+                        IOHelper.closeQuietly(inputStream);
                     }
                 }
             } catch (OXException e) {
@@ -220,21 +124,6 @@ public class Resource {
         return ret;
     }
 
-    /**
-     * @param data
-     * @return
-     */
-    public static String getSHA256(byte[] data) {
-        String result = null;
-        try {
-            result = Hex.toHexString(MessageDigest.getInstance("SHA-256").digest(data));
-        } catch (NoSuchAlgorithmException e) {
-            LOG.error("Not possible to determine SHA-256 hash from data", e);
-        }
-
-        return result;
-    }
-
     /**
      * @return The UID of the contained data
      */
@@ -250,7 +139,8 @@ public class Resource {
     }
 
     /**
-     * @return The resource identifier of this resource as a string according to the following schema: "xid" + HexValueString
+     * @return The resource identifier of this resource as a string according to the following schema:
+     * Resource.RESOURCE_UID_PREFIX + HexValueString
      */
     public String getResourceName() {
         return getResourceNameFromUID(m_uid);
@@ -275,18 +165,32 @@ public class Resource {
     }
 
     /**
-     * @param crc32Key
+     * @param data the data where the SHA-256 hash should be calculated from
+     * @return the SHA-256 hash of the provided data or null if not possible
+     */
+    public static String getSHA256(byte[] data) {
+        String result = null;
+        try {
+            result = Hex.encodeHexString(MessageDigest.getInstance("SHA-256").digest(data), true);
+        } catch (NoSuchAlgorithmException e) {
+            LOG.error("Not possible to determine SHA-256 hash from data", e);
+        }
+        return result;
+    }
+
+    /**
+     * @param hash of the managed file (is the SHA256 hash of the resource data)
      * @return
      */
-    static public String getManagedIdFromUID(String hash) {
+    public static String getManagedIdFromUID(String hash) {
         return (idPrefix + hash);
     }
 
     /**
-     * @param id
+     * @param managedFileId the managed file id
      * @return
      */
-    static public String getUIDFromManagedId(String managedFileId) {
+    public static String getUIDFromManagedId(String managedFileId) {
         String uid = null;
 
         if (StringUtils.isNotEmpty(managedFileId) && managedFileId.startsWith(idPrefix)) {
@@ -297,57 +201,39 @@ public class Resource {
     }
 
     /**
-     * @param services
-     * @param id
-     * @return The distributed managed file resource or null if no resource with this id exists
-     */
-    static public Resource createFrom(ServiceLookup servicesDEPRECATED, String id) {
-        Resource result = null;
-
-        try {
-            final ResourceInfo aResInfo = Resource.createResourceInfoIfExists(id);
-
-            if (null != aResInfo) {
-                result = new Resource(aResInfo);
-            }
-        } catch (final OXException e) {
-            // nothing to do - resource could not be created
-        }
-
-        return result;
-    }
-
-    /**
-     * @param uid The uid of a resource
+     * @param uid The hash of a resource
      * @return The resource identifier for the given uid as a string according to the
-     *         following schema: "xid" + HexValueString, or null in case of an invalid uid
+     * following schema: RESOURCE_UID_PREFIX + HexValueString, or null in case of an invalid uid
      */
-    static public String getResourceNameFromUID(String hash) {
+    public static String getResourceNameFromUID(String hash) {
         return ((null != hash) ? (RESOURCE_UID_PREFIX + hash) : null);
     }
 
     /**
-     * @param resourceName A resource name with the folllowing schema: "xid" + HexValueString
-     * @return The uid of a resource name, or 0 in case of an invalid resource name
+     * @param resourceName A resource name with the following schema: Resource.RESOURCE_UID_PREFIX + HexValueString
+     * @return The hash of a resource name, or 0 in case of an invalid resource name
      */
-    static public String getUIDFromResourceName(String resourceName) {
-        return ((null != resourceName) ? resourceName.substring(RESOURCE_UID_PREFIX.length()) : null);
+    public static String getUIDFromResourceName(String resourceName) {
+        return ((null != resourceName) ? resourceName.substring(3) : null);
     }
 
     /**
      * @param sha256
      * @param resdata
      * @return
+     * @throws NoSuchAlgorithmException 
      */
     public static String getUIDFromData(String sha256, byte[] resdata) {
         return sha256;
     }
 
-    // - Members ---------------------------------------------------------------
+    /**
+     * 
+     * @param millisInEpoch
+     * @return
+     */
+    private String convertToLocalDateTime(long millisInEpoch) {
+        return LocalDateTime.ofInstant(Instant.ofEpochMilli(millisInEpoch), ZoneOffset.UTC).toString();
+    }
 
-    private ManagedFile m_managedFile = null;
-
-    private byte[] m_buffer = null;
-
-    private String m_uid = null;
 }
