@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -48,18 +48,12 @@
  */
 package com.openexchange.office.message;
 
-import org.apache.commons.lang3.Validate;
-import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
-import com.openexchange.exception.OXException;
-import com.openexchange.office.tools.error.ErrorCode;
-import com.openexchange.office.tools.user.UserData;
-import com.openexchange.server.services.ServerServiceRegistry;
-import com.openexchange.session.Session;
-import com.openexchange.sessiond.SessiondService;
-import com.openexchange.tools.session.ServerSession;
-import com.openexchange.tools.session.ServerSessionAdapter;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
+import com.openexchange.office.tools.common.error.ErrorCode;
 
 
 public class MessageHelper {
@@ -69,7 +63,7 @@ public class MessageHelper {
 
 
     // - Members ---------------------------------------------------------------
-    static protected final org.apache.commons.logging.Log LOG = com.openexchange.log.LogFactory.getLog(MessageHelper.class);
+    private static final Logger log = LoggerFactory.getLogger(MessageHelper.class);
 
     /**
      * Creates the final JSON result object to be sent to the client-side.
@@ -94,7 +88,7 @@ public class MessageHelper {
                     tmpResult.put(MessagePropertyKey.KEY_UNIQUE_ID, jsonRequest.get(MessagePropertyKey.KEY_UNIQUE_ID));
                 }
             } catch (JSONException e) {
-                LOG.error("RT2: getJSfinalizeJSONResult catches exception trying to to put unique id to the JSON object. ", e);
+                log.error("RT2: getJSfinalizeJSONResult catches exception trying to to put unique id to the JSON object. ", e);
             }
 
             // add extra data, if set
@@ -160,7 +154,7 @@ public class MessageHelper {
                 }
                 tmpResult.put(MessagePropertyKey.KEY_ERROR_DATA, errorCode.getAsJSON());
             } catch (JSONException e) {
-                LOG.error("RT2: getJSfinalizeJSONResult catches exception trying to to put unique id to the JSON object. ", e);
+                log.error("RT2: getJSfinalizeJSONResult catches exception trying to to put unique id to the JSON object. ", e);
             }
 
             // add extra data, if set
@@ -189,7 +183,7 @@ public class MessageHelper {
             try {
                 jsonResult.put(MessagePropertyKey.KEY_HAS_ERRORS, true);
             } catch (JSONException e) {
-                LOG.error("RT2: checkJSONResult catches exception trying to to put hasErrors to the JSON object. ", e);
+                log.error("RT2: checkJSONResult catches exception trying to to put hasErrors to the JSON object. ", e);
             }
         }
 
