@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -60,21 +60,27 @@ import java.util.Iterator;
 import java.util.Map;
 import java.util.TimeZone;
 import java.util.UUID;
+
 import org.apache.commons.io.IOUtils;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.api.OCValue;
 import com.openexchange.office.tools.common.TimeZoneHelper;
-import com.openexchange.office.tools.json.JSONDebugWriter;
-import com.openexchange.office.tools.json.JSONHelper;
+import com.openexchange.office.tools.common.json.JSONDebugWriter;
+import com.openexchange.office.tools.common.json.JSONHelper;
 
 public class OperationHelper {
 
+	static protected final Logger log = LoggerFactory.getLogger(OperationHelper.class);
+	
     // - Constants -------------------------------------------------------------
 
-    private final static String OP_NAME_NOOP = "noOp";
+    public final static String OP_NAME_INVALID    = "_invalid_operation_";
 
     public final static String KEY_OSN            = "osn";
     public final static String KEY_OPL            = "opl";
@@ -97,6 +103,7 @@ public class OperationHelper {
     public static final String KEY_SENDER         = "sender";
     public static final String KEY_PREVIEW        = "preview";
     public static final String KEY_ACTIVESHEET    = "activeSheet";
+    public static final String KEY_NAME           = "name";
 
     /**
      * Comparing, if two positions in the form of JSONArrays have the same
@@ -307,7 +314,7 @@ public class OperationHelper {
                     insertNextOp = false;
 
                 } catch (IndexOutOfBoundsException e) {
-                    LOG.error("RT2: Wrong index used within mergeInsertAndDeleteOperations", e);
+                    log.error("RT2: Wrong index used within mergeInsertAndDeleteOperations", e);
                 }
             }
         }
@@ -387,7 +394,7 @@ public class OperationHelper {
 
                             }
                         } catch (JSONException e) {
-                            LOG.error("RT2: Exception caught while setting up JSON result within optimizeOperationsArray", e);
+                            log.error("RT2: Exception caught while setting up JSON result within optimizeOperationsArray", e);
                         }
 
                         if (insertNextOp) {
@@ -398,7 +405,7 @@ public class OperationHelper {
                     jsonResult.put(KEY_OPERATIONS, operationArr);
                 }
             } catch (JSONException e) {
-                LOG.error("RT2: Exception caught while setting up JSON result within optimizeOperationsArray", e);
+                log.error("RT2: Exception caught while setting up JSON result within optimizeOperationsArray", e);
             }
         }
     }
@@ -468,7 +475,7 @@ public class OperationHelper {
                     }
                 }
             } catch (JSONException e) {
-                LOG.error("RT2: Exception caught while setting up JSON result within appendJSON", e);
+                log.error("RT2: Exception caught while setting up JSON result within appendJSON", e);
             }
         }
 
@@ -500,7 +507,7 @@ public class OperationHelper {
                 jsonResult.put(key, element);
             }
         } catch (JSONException e) {
-            LOG.error("RT2: Exception caught while setting up JSON result within appendJSONElement", e);
+            log.error("RT2: Exception caught while setting up JSON result within appendJSONElement", e);
         }
     }
 
@@ -523,7 +530,7 @@ public class OperationHelper {
                 operation.write(myWriter);
                 result = myWriter.getData();
             } catch (final Exception e) {
-                LOG.warn("RT2: operationshortName catches exception writing operation to string. ", e);
+                log.warn("RT2: operationshortName catches exception writing operation to string. ", e);
             } finally {
                 IOUtils.closeQuietly(myWriter);
             }
@@ -636,9 +643,9 @@ public class OperationHelper {
         	writer.append(SEP).close();
 
 		} catch (Exception e) {
-            LOG.debug("LogEditorPerformanceData writing to log file failed due to exception", e);
+            log.debug("LogEditorPerformanceData writing to log file failed due to exception", e);
 			// Do nothing, simply not logging performance data
-			LOG.debug("RT2: IOException caught trying to write performance data to log file!", e);
+			log.debug("RT2: IOException caught trying to write performance data to log file!", e);
 	    }
 
     }
@@ -735,7 +742,7 @@ public class OperationHelper {
             writer.append(SEP).close();
 
         } catch (Exception e) {
-            LOG.debug("LogViewerPerformanceData writing to log file failed due to exception", e);
+            log.debug("LogViewerPerformanceData writing to log file failed due to exception", e);
             // Do nothing, simply not logging performance data
         }
 
@@ -932,7 +939,7 @@ public class OperationHelper {
                     }
                 }
             } catch (JSONException e) {
-            	LOG.info("Exception caught trying to find index for operations with larger osn than " + largerThanOSN, e);
+            	log.info("Exception caught trying to find index for operations with larger osn than " + largerThanOSN, e);
             }
         }
 
@@ -985,7 +992,7 @@ public class OperationHelper {
                     }
                 }
             } catch (JSONException e) {
-            	LOG.info("Exception caught trying to find an operation with a larger osn than " + largerThanOSN, e);
+            	log.info("Exception caught trying to find an operation with a larger osn than " + largerThanOSN, e);
             }
         }
 
@@ -1018,13 +1025,10 @@ public class OperationHelper {
                     }
             	}
             } catch (JSONException e) {
-                LOG.info("Exception caught trying to count operations with a larger osn than " + largerThanOSN, e);
+                log.info("Exception caught trying to count operations with a larger osn than " + largerThanOSN, e);
             }
         }
 
         return count;
-    }
-
-    // - Members ---------------------------------------------------------------
-    static protected final org.apache.commons.logging.Log LOG = com.openexchange.log.LogFactory.getLog(OperationHelper.class);
+    }    
 }
