@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2016-2020 OX Software GmbH All rights reserved.
+ *  Copyright (C) 2016 OX Software GmbH All rights reserved.
  *
  *  This program is proprietary software and licensed to you under
  *  OX Software GmbH's Software License Agreement.
@@ -12,9 +12,9 @@
 
 package com.openexchange.office.monitoring;
 
-import javax.management.NotCompliantMBeanException;
-import javax.management.StandardMBean;
-import com.openexchange.annotation.NonNull;
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.jmx.export.annotation.ManagedResource;
+import org.springframework.stereotype.Service;
 import com.openexchange.office.monitoring.api.IMonitoring;
 import com.openexchange.office.tools.doc.DocumentType;
 import com.openexchange.office.tools.monitoring.CloseType;
@@ -22,32 +22,36 @@ import com.openexchange.office.tools.monitoring.OpenType;
 import com.openexchange.office.tools.monitoring.OperationsType;
 import com.openexchange.office.tools.monitoring.SaveType;
 import com.openexchange.office.tools.monitoring.Statistics;
+import com.udojava.jmx.wrapper.JMXBean;
+import com.udojava.jmx.wrapper.JMXBeanAttribute;
 
 /**
  * {@link OfficeMonitoring}
  *
  * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
  */
-public class OfficeMonitoring extends StandardMBean implements IMonitoring {
+@JMXBean
+@ManagedResource(objectName="com.openexchange.office:name=OfficeMonitoring")
+@Service
+public class OfficeMonitoring implements IMonitoring {
 
-    /**
-     * Domain
-     */
     public static final String DOMAIN = "com.openexchange.office";
 
-    /**
-     * Initializes a new {@link OfficeMonitoring}.
-     * @param statistics
-     * @throws NotCompliantMBeanException
-     */
-    public OfficeMonitoring(@NonNull Statistics statistics) throws NotCompliantMBeanException {
-        super(IMonitoring.class);
+    @Autowired
+    private Statistics m_statistics;
 
-        m_statistics = statistics;
-    }
+//    /**
+//     * Initializes a new {@link OfficeMonitoring}.
+//     * @param statistics
+//     * @throws NotCompliantMBeanException
+//     */
+//    public OfficeMonitoring() throws NotCompliantMBeanException {
+//        super(IMonitoring.class);
+//    }
 
     // - IMonitoringCommon
 
+    @JMXBeanAttribute(name="AdvisoryLockInfo_Mode")
     @Override
     public String getAdvisoryLockInfo_Mode() {
         return m_statistics.getAdvisoryLockInfoMode();
@@ -56,6 +60,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.IInformation#getDocumentsCreated_Total()
      */
+    @JMXBeanAttribute(name="DocumentsCreated_Total")
     @Override
     public long getDocumentsCreated_Total() {
         return m_statistics.getDocumentsCreated(null);
@@ -64,6 +69,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Text_Outgoing_Distributeted#getDocumentsCreated_Text()
      */
+    @JMXBeanAttribute(name="DocumentsCreated_Text")
     @Override
     public long getDocumentsCreated_Text() {
         return m_statistics.getDocumentsCreated(DocumentType.TEXT);
@@ -72,6 +78,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.IInformation#getDocumentsCreated_Spreadsheet()
      */
+    @JMXBeanAttribute(name="DocumentsCreated_Spreadsheet")
     @Override
     public long getDocumentsCreated_Spreadsheet() {
         return m_statistics.getDocumentsCreated(DocumentType.SPREADSHEET);
@@ -80,6 +87,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.IInformation#getDocumentsCreated_Presentation()
      */
+    @JMXBeanAttribute(name="DocumentsCreated_Presentation")
     @Override
     public long getDocumentsCreated_Presentation() {
         return m_statistics.getDocumentsCreated(DocumentType.PRESENTATION);
@@ -88,6 +96,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.IMonitoring#getMedianDocumentsSize_Total()
      */
+    @JMXBeanAttribute(name="DocumentsSizeMedian_Total")
     @Override
     public long getDocumentsSizeMedian_Total() {
         return m_statistics.getDocumentsSizeMedian(null);
@@ -96,6 +105,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Text_Outgoing_Distributeted#getMedianDocumentsSize_Text_KB()
      */
+    @JMXBeanAttribute(name="DocumentsSizeMedian_Text")
     @Override
     public long getDocumentsSizeMedian_Text() {
         return m_statistics.getDocumentsSizeMedian(DocumentType.TEXT);
@@ -104,6 +114,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.IInformation#getMedianDocumentsSize_Spreadsheet()
      */
+    @JMXBeanAttribute(name="DocumentsSizeMedian_Spreadsheet")
     @Override
     public long getDocumentsSizeMedian_Spreadsheet() {
         return m_statistics.getDocumentsSizeMedian(DocumentType.SPREADSHEET);
@@ -112,31 +123,37 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.IInformation#getMedianDocumentsSize_Presentation()
      */
+    @JMXBeanAttribute(name="DocumentsSizeMedian_Presentation")
     @Override
     public long getDocumentsSizeMedian_Presentation() {
         return m_statistics.getDocumentsSizeMedian(DocumentType.PRESENTATION);
     }
 
+    @JMXBeanAttribute(name="RestoreDocsCreated_Total")
     @Override
     public long getRestoreDocsCreated_Total() {
         return m_statistics.getRestoreDocCreated();
     }
 
+    @JMXBeanAttribute(name="RestoreDocsRemoved_Total")
     @Override
     public long getRestoreDocsRemoved_Total() {
         return m_statistics.getRestoreDocRemoved();
     }
 
+    @JMXBeanAttribute(name="RestoreDocs_Current")
     @Override
     public long getRestoreDocs_Current() {
         return m_statistics.getRestoreDocCurrent();
     }
 
+    @JMXBeanAttribute(name="RestoreDocsRestored_Success")
     @Override
     public long getRestoreDocsRestored_Success() {
         return m_statistics.getRestoreDocRestoredSuccess();
     }
 
+    @JMXBeanAttribute(name="RestoreDocsRestored_Failure")
     @Override
     public long getRestoreDocsRestored_Failure() {
         return m_statistics.getRestoreDocRestoredFailure();
@@ -147,6 +164,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Text_Outgoing_Distributeted#getDocumentsOpened_Text_Total()
      */
+    @JMXBeanAttribute(name="DocumentsOpened_Text_Total")
     @Override
     public long getDocumentsOpened_Text_Total() {
         return m_statistics.getDocumentsOpened(DocumentType.TEXT, null);
@@ -155,6 +173,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Text_Outgoing_Distributeted#getDocumentsOpened_Text_Msx()
      */
+    @JMXBeanAttribute(name="DocumentsOpened_Text_OOXML")
     @Override
     public long getDocumentsOpened_Text_OOXML() {
         return m_statistics.getDocumentsOpened(DocumentType.TEXT, OpenType.MSX);
@@ -163,6 +182,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Text_Outgoing_Distributeted#getDocumentsOpened_Text_Binary()
      */
+    @JMXBeanAttribute(name="DocumentsOpened_Text_Binary")
     @Override
     public long getDocumentsOpened_Text_Binary() {
         return m_statistics.getDocumentsOpened(DocumentType.TEXT, OpenType.BINARY);
@@ -171,6 +191,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Text_Outgoing_Distributeted#getDocumentsOpened_Text_Odf()
      */
+    @JMXBeanAttribute(name="DocumentsOpened_Text_ODF")
     @Override
     public long getDocumentsOpened_Text_ODF() {
         return m_statistics.getDocumentsOpened(DocumentType.TEXT, OpenType.ODF);
@@ -179,6 +200,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Text_Outgoing_Distributeted#getDocumentsClosed_Text_Total()
      */
+    @JMXBeanAttribute(name="DocumentsClosed_Text_Total")
     @Override
     public long getDocumentsClosed_Text_Total() {
         return m_statistics.getDocumentsClosed(DocumentType.TEXT, CloseType.CLOSE);
@@ -187,6 +209,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Text_Outgoing_Distributeted#getDocumentsClosed_Text_Timeout()
      */
+    @JMXBeanAttribute(name="DocumentsClosed_Text_Timeout")
     @Override
     public long getDocumentsClosed_Text_Timeout() {
         return m_statistics.getDocumentsClosed(DocumentType.TEXT, CloseType.TIMEOUT);
@@ -195,6 +218,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.IInformation#getDocumentsSaved_Text_Total()
      */
+    @JMXBeanAttribute(name="DocumentsSaved_Text_Total")
     @Override
     public long getDocumentsSaved_Text_Total() {
         return m_statistics.getDocumentsSaved(DocumentType.TEXT, null);
@@ -203,6 +227,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Text_Outgoing_Distributeted#getDocumentsSaved_Text_Close()
      */
+    @JMXBeanAttribute(name="DocumentsSaved_Text_Close")
     @Override
     public long getDocumentsSaved_Text_Close() {
         return m_statistics.getDocumentsSaved(DocumentType.TEXT, SaveType.CLOSE);
@@ -211,6 +236,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Text_Outgoing_Distributeted#getDocumentsSaved_Text_100ops()
      */
+    @JMXBeanAttribute(name="DocumentsSaved_Text_100ops")
     @Override
     public long getDocumentsSaved_Text_100ops() {
         return m_statistics.getDocumentsSaved(DocumentType.TEXT, SaveType.OPS_100);
@@ -219,6 +245,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Text_Outgoing_Distributeted#getDocumentsSaved_Text_15min()
      */
+    @JMXBeanAttribute(name="DocumentsSaved_Text_15mins")
     @Override
     public long getDocumentsSaved_Text_15mins() {
         return m_statistics.getDocumentsSaved(DocumentType.TEXT, SaveType.OPS_15MINS);
@@ -227,6 +254,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Text_Outgoing_Distributeted#getDocumentOperations_Text_Incoming()
      */
+    @JMXBeanAttribute(name="DocumentsOperations_Text_Incoming")
     @Override
     public long getDocumentsOperations_Text_Incoming() {
         return m_statistics.getDocumentsOperations(DocumentType.TEXT, OperationsType.INCOMING);
@@ -235,6 +263,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Text_Outgoing_Distributeted#getDocumentOperations_Text_Outgoing_Distributeted()
      */
+    @JMXBeanAttribute(name="DocumentsOperations_Text_Distributed")
     @Override
     public long getDocumentsOperations_Text_Distributed() {
         return m_statistics.getDocumentsOperations(DocumentType.TEXT, OperationsType.DISTRIBUTED);
@@ -245,6 +274,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Spreadsheet_Outgoing_Distributeted#getDocumentsOpened_Spreadsheet_Total()
      */
+    @JMXBeanAttribute(name="DocumentsOpened_Spreadsheet_Total")
     @Override
     public long getDocumentsOpened_Spreadsheet_Total() {
         return m_statistics.getDocumentsOpened(DocumentType.SPREADSHEET, null);
@@ -253,6 +283,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Spreadsheet_Outgoing_Distributeted#getDocumentsOpened_Spreadsheet_Msx()
      */
+    @JMXBeanAttribute(name="DocumentsOpened_Spreadsheet_OOXML")
     @Override
     public long getDocumentsOpened_Spreadsheet_OOXML() {
         return m_statistics.getDocumentsOpened(DocumentType.SPREADSHEET, OpenType.MSX);
@@ -261,6 +292,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Spreadsheet_Outgoing_Distributeted#getDocumentsOpened_Spreadsheet_Binary()
      */
+    @JMXBeanAttribute(name="DocumentsOpened_Spreadsheet_Binary")
     @Override
     public long getDocumentsOpened_Spreadsheet_Binary() {
         return m_statistics.getDocumentsOpened(DocumentType.SPREADSHEET, OpenType.BINARY);
@@ -269,6 +301,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Spreadsheet_Outgoing_Distributeted#getDocumentsOpened_Spreadsheet_Odf()
      */
+    @JMXBeanAttribute(name="DocumentsOpened_Spreadsheet_ODF")
     @Override
     public long getDocumentsOpened_Spreadsheet_ODF() {
         return m_statistics.getDocumentsOpened(DocumentType.SPREADSHEET, OpenType.ODF);
@@ -277,6 +310,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Spreadsheet_Outgoing_Distributeted#getDocumentsClosed_Spreadsheet_Total()
      */
+    @JMXBeanAttribute(name="DocumentsClosed_Spreadsheet_Total")
     @Override
     public long getDocumentsClosed_Spreadsheet_Total() {
         return m_statistics.getDocumentsClosed(DocumentType.SPREADSHEET, CloseType.CLOSE);
@@ -285,6 +319,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Spreadsheet_Outgoing_Distributeted#getDocumentsClosed_Spreadsheet_Timeout()
      */
+    @JMXBeanAttribute(name="DocumentsClosed_Spreadsheet_Timeout")
     @Override
     public long getDocumentsClosed_Spreadsheet_Timeout() {
         return m_statistics.getDocumentsClosed(DocumentType.SPREADSHEET, CloseType.TIMEOUT);
@@ -293,6 +328,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.IInformation#getDocumentsSaved_Spreadsheet_Total()
      */
+    @JMXBeanAttribute(name="DocumentsSaved_Spreadsheet_Total")
     @Override
     public long getDocumentsSaved_Spreadsheet_Total() {
         return m_statistics.getDocumentsSaved(DocumentType.SPREADSHEET, null);
@@ -301,6 +337,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Spreadsheet_Outgoing_Distributeted#getDocumentsSaved_Spreadsheet_Close()
      */
+    @JMXBeanAttribute(name="DocumentsSaved_Spreadsheet_Close")
     @Override
     public long getDocumentsSaved_Spreadsheet_Close() {
         return m_statistics.getDocumentsSaved(DocumentType.SPREADSHEET, SaveType.CLOSE);
@@ -309,6 +346,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Spreadsheet_Outgoing_Distributeted#getDocumentsSaved_Spreadsheet_100ops()
      */
+    @JMXBeanAttribute(name="DocumentsSaved_Spreadsheet_100ops")
     @Override
     public long getDocumentsSaved_Spreadsheet_100ops() {
         return m_statistics.getDocumentsSaved(DocumentType.SPREADSHEET, SaveType.OPS_100);
@@ -317,6 +355,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Spreadsheet_Outgoing_Distributeted#getDocumentsSaved_Spreadsheet_15min()
      */
+    @JMXBeanAttribute(name="DocumentsSaved_Spreadsheet_15mins")
     @Override
     public long getDocumentsSaved_Spreadsheet_15mins() {
         return m_statistics.getDocumentsSaved(DocumentType.SPREADSHEET, SaveType.OPS_15MINS);
@@ -325,6 +364,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Spreadsheet_Outgoing_Distributeted#getDocumentOperations_Spreadsheet_Incoming()
      */
+    @JMXBeanAttribute(name="DocumentsOperations_Spreadsheet_Incoming")
     @Override
     public long getDocumentsOperations_Spreadsheet_Incoming() {
         return m_statistics.getDocumentsOperations(DocumentType.SPREADSHEET, OperationsType.INCOMING);
@@ -333,6 +373,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Spreadsheet_Outgoing_Distributeted#getDocumentOperations_Spreadsheet_Outgoing_Distributeted()
      */
+    @JMXBeanAttribute(name="DocumentsOperations_Spreadsheet_Distributed")
     @Override
     public long getDocumentsOperations_Spreadsheet_Distributed() {
         return m_statistics.getDocumentsOperations(DocumentType.SPREADSHEET, OperationsType.DISTRIBUTED);
@@ -343,6 +384,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Presentation_Outgoing_Distributeted#getDocumentsOpened_Presentation_Total()
      */
+    @JMXBeanAttribute(name="DocumentsOpened_Presentation_Total")
     @Override
     public long getDocumentsOpened_Presentation_Total() {
         return m_statistics.getDocumentsOpened(DocumentType.PRESENTATION, null);
@@ -351,6 +393,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Presentation_Outgoing_Distributeted#getDocumentsOpened_Presentation_Msx()
      */
+    @JMXBeanAttribute(name="DocumentsOpened_Presentation_OOXML")
     @Override
     public long getDocumentsOpened_Presentation_OOXML() {
         return m_statistics.getDocumentsOpened(DocumentType.PRESENTATION, OpenType.MSX);
@@ -359,6 +402,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Presentation_Outgoing_Distributeted#getDocumentsOpened_Presentation_Binary()
      */
+    @JMXBeanAttribute(name="DocumentsOpened_Presentation_Binary")
     @Override
     public long getDocumentsOpened_Presentation_Binary() {
         return m_statistics.getDocumentsOpened(DocumentType.PRESENTATION, OpenType.BINARY);
@@ -367,6 +411,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Presentation_Outgoing_Distributeted#getDocumentsOpened_Presentation_Odf()
      */
+    @JMXBeanAttribute(name="DocumentsOpened_Presentation_ODF")
     @Override
     public long getDocumentsOpened_Presentation_ODF() {
         return m_statistics.getDocumentsOpened(DocumentType.PRESENTATION, OpenType.ODF);
@@ -375,6 +420,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Presentation_Outgoing_Distributeted#getDocumentsClosed_Presentation_Total()
      */
+    @JMXBeanAttribute(name="DocumentsClosed_Presentation_Total")
     @Override
     public long getDocumentsClosed_Presentation_Total() {
         return m_statistics.getDocumentsClosed(DocumentType.PRESENTATION, CloseType.CLOSE);
@@ -383,6 +429,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Presentation_Outgoing_Distributeted#getDocumentsClosed_Presentation_Timeout()
      */
+    @JMXBeanAttribute(name="DocumentsClosed_Presentation_Timeout")
     @Override
     public long getDocumentsClosed_Presentation_Timeout() {
         return m_statistics.getDocumentsClosed(DocumentType.PRESENTATION, CloseType.TIMEOUT);
@@ -391,6 +438,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.IInformation#getDocumentsSaved_Presentation_Total()
      */
+    @JMXBeanAttribute(name="DocumentsSaved_Presentation_Total")
     @Override
     public long getDocumentsSaved_Presentation_Total() {
         return m_statistics.getDocumentsSaved(DocumentType.PRESENTATION, null);
@@ -399,6 +447,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Presentation_Outgoing_Distributeted#getDocumentsSaved_Presentation_Close()
      */
+    @JMXBeanAttribute(name="DocumentsSaved_Presentation_Close")
     @Override
     public long getDocumentsSaved_Presentation_Close() {
         return m_statistics.getDocumentsSaved(DocumentType.PRESENTATION, SaveType.CLOSE);
@@ -407,6 +456,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Presentation_Outgoing_Distributeted#getDocumentsSaved_Presentation_100ops()
      */
+    @JMXBeanAttribute(name="DocumentsSaved_Presentation_100ops")
     @Override
     public long getDocumentsSaved_Presentation_100ops() {
         return m_statistics.getDocumentsSaved(DocumentType.PRESENTATION, SaveType.OPS_100);
@@ -415,6 +465,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Presentation_Outgoing_Distributeted#getDocumentsSaved_Presentation_15min()
      */
+    @JMXBeanAttribute(name="DocumentsSaved_Presentation_15mins")
     @Override
     public long getDocumentsSaved_Presentation_15mins() {
         return m_statistics.getDocumentsSaved(DocumentType.PRESENTATION, SaveType.OPS_15MINS);
@@ -423,6 +474,7 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Presentation_Outgoing_Distributeted#getDocumentOperations_Presentation_Incoming()
      */
+    @JMXBeanAttribute(name="DocumentsOperations_Presentation_Incoming")
     @Override
     public long getDocumentsOperations_Presentation_Incoming() {
         return m_statistics.getDocumentsOperations(DocumentType.PRESENTATION, OperationsType.INCOMING);
@@ -431,106 +483,127 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
     /* (non-Javadoc)
      * @see com.openexchange.office.getDocumentsOperations_Presentation_Outgoing_Distributeted#getDocumentOperations_Presentation_Outgoing_Distributeted()
      */
+    @JMXBeanAttribute(name="DocumentsOperations_Presentation_Distributed")
     @Override
     public long getDocumentsOperations_Presentation_Distributed() {
         return m_statistics.getDocumentsOperations(DocumentType.PRESENTATION, OperationsType.DISTRIBUTED);
     }
 
+    @JMXBeanAttribute(name="DocumentsStarted_RemotePresenter_Total")
 	@Override
 	public long getDocumentsStarted_RemotePresenter_Total() {
 		return m_statistics.getDocumentsStarted_RemotePresenterTotal();
 	}
 
+    @JMXBeanAttribute(name="DocumentsOpened_Presenter_Total")
 	@Override
 	public long getDocumentsOpened_Presenter_Total() {
 		return m_statistics.getDocumentsOpenedPresenterTotal();
 	}
 
+    @JMXBeanAttribute(name="DocumentsClosed_Presenter_Total")
 	@Override
 	public long getDocumentsClosed_Presenter_Total() {
 		return m_statistics.getDocumentsClosedPresenterTotal();
 	}
 
+    @JMXBeanAttribute(name="DocumentsClosed_Presenter_Timeout")
 	@Override
 	public long getDocumentsClosed_Presenter_Timeout() {
 		return m_statistics.getDocumentsClosedPresenterTimeout();
 	}
 
+    @JMXBeanAttribute(name="DocumentsOperations_Presenter_Incoming")
 	@Override
 	public long getDocumentsOperations_Presenter_Incoming() {
 		return m_statistics.getDocumentsOperationsPresenterIncoming();
 	}
 
+    @JMXBeanAttribute(name="DocumentsOperations_Presenter_Distributed")
 	@Override
 	public long getDocumentsOperations_Presenter_Distributed() {
 		return m_statistics.getDocumentsOperationsPresenterDistributed();
 	}
 
+    @JMXBeanAttribute(name="RestoreDocsOpsMsgs_StoredLastCycle")
 	@Override
 	public long getRestoreDocsOpsMsgs_StoredLastCycle() {
 		return m_statistics.getRestoreDocOpsMsgStored();
 	}
 
+    @JMXBeanAttribute(name="RestoreDocsOpsMsgs_StoreTimeNeededLastCycle")
 	@Override
 	public long getRestoreDocsOpsMsgs_StoreTimeNeededLastCycle() {
 		return m_statistics.getRestoreDocOpsMsgStoredTime();
 	}
 
+    @JMXBeanAttribute(name="BackgroundSave_SavedLastCycle")
 	@Override
 	public long getBackgroundSave_SavedLastCycle() {
 		return m_statistics.getBackgroundSaveLastCycleDocCount();
 	}
 
+    @JMXBeanAttribute(name="BackgroundSave_TimeNeededLastCycle")
 	@Override
 	public long getBackgroundSave_TimeNeededLastCycle() {
 		return m_statistics.getBackgroundSaveLastCycleTime();
 	}
 
+    @JMXBeanAttribute(name="BackgroundSave_AverageTimePerDoc")
 	@Override
 	public long getBackgroundSave_AverageTimePerDoc() {
 		return m_statistics.getBackgroundSaveAverageTimePerDoc();
 	}
 
+    @JMXBeanAttribute(name="BackgroundSave_Setting_MaxTimeForSave")
 	@Override
 	public long getBackgroundSave_Setting_MaxTimeForSave() {
 		return m_statistics.getBackgroundSaveMaxTimeForSave();
 	}
 
+    @JMXBeanAttribute(name="BackgroundSave_Setting_MinTimeForFasterSave")
 	@Override
 	public long getBackgroundSave_Setting_MinTimeForFasterSave() {
 		return m_statistics.getBackgroundSaveMinTimeFasterSave();
 	}
 
+    @JMXBeanAttribute(name="BackgroundSave_Setting_MinNumOfMessagesForSave_Text")
 	@Override
 	public long getBackgroundSave_Setting_MinNumOfMessagesForSave_Text() {
 		return m_statistics.getBackgroundSaveMinNumOfMsgForFasterSaveText();
 	}
 
+    @JMXBeanAttribute(name="BackgroundSave_Setting_MinNumOfMessagesForSave_Spreadsheet")
 	@Override
 	public long getBackgroundSave_Setting_MinNumOfMessagesForSave_Spreadsheet() {
 		return m_statistics.getBackgroundSaveMinNumOfMsgForFasterSaveSpreadsheet();
 	}
 
+    @JMXBeanAttribute(name="BackgroundSave_Setting_MinNumOfMessagesForSave_Presentation")
 	@Override
 	public long getBackgroundSave_Setting_MinNumOfMessagesForSave_Presentation() {
 		return m_statistics.getBackgroundSaveMinNumOfMsgForFasterSavePresentation();
 	}
 
+    @JMXBeanAttribute(name="RestoreDocsManagedFiles_RemovedLastCycle")
 	@Override
 	public long getRestoreDocsManagedFiles_RemovedLastCycle() {
 		return m_statistics.getRestoreDocManagedFilesRemovedLastCycle();
 	}
 
+    @JMXBeanAttribute(name="RestoreDocsManagedFiles_InRemoveQueue")
 	@Override
 	public long getRestoreDocsManagedFiles_InRemoveQueue() {
 		return m_statistics.getRestoreDocManagedFilesInRemoveQueue();
 	}
 
+    @JMXBeanAttribute(name="RestoreDocsManagedFiles_RuntimeLastCycle")
 	@Override
 	public long getRestoreDocsManagedFiles_RuntimeLastCycle() {
 		return m_statistics.getRestoreDocManagedFilesRuntimeLastCycle();
 	}
 
+    @JMXBeanAttribute(name="RestoreDocsManagedFiles_Current")
 	@Override
 	public long getRestoreDocsManagedFiles_Current() {
 		return m_statistics.getRestoreDocManagedFilesCurrent();
@@ -538,46 +611,77 @@ public class OfficeMonitoring extends StandardMBean implements IMonitoring {
 
 	// - IMonitoringOT ---------------------------------------------------------
 
+    @JMXBeanAttribute(name="DocumentsOperations_Total_ServerTransformed")
     @Override
     public long getDocumentsOperations_Total_ServerTransformed() {
         return m_statistics.getTransformationCount(null);
     }
 
+    @JMXBeanAttribute(name="DocumentsOperations_Text_ServerTransformed")
     @Override
     public long getDocumentsOperations_Text_ServerTransformed() {
         return m_statistics.getTransformationCount(DocumentType.TEXT);
     }
 
+    @JMXBeanAttribute(name="DocumentsOperations_Spreadsheet_ServerTransformed")
     @Override
     public long getDocumentsOperations_Spreadsheet_ServerTransformed() {
         return m_statistics.getTransformationCount(DocumentType.SPREADSHEET);
     }
 
+    @JMXBeanAttribute(name="DocumentsOperations_Presentation_ServerTransformed")
     @Override
     public long getDocumentsOperations_Presentation_ServerTransformed() {
         return m_statistics.getTransformationCount(DocumentType.PRESENTATION);
     }
 
-    // - Implementation
+    @JMXBeanAttribute(name="DocumentsOperations_Total_UnresolvableTransformations")
+	@Override
+	public long getDocumentsOperations_Total_UnresolvableTransformations() {
+		return m_statistics.getUnresolvableTransformations(null);
+	}
 
-    /**
-     * @return The statistics object, all office runtime information is collected at
-     */
-    public @NonNull Statistics getStatistics() {
-        return m_statistics;
+    @JMXBeanAttribute(name="DocumentsOperations_Text_UnresolvableTransformations")
+	@Override
+	public long getDocumentsOperations_Text_UnresolvableTransformations() {
+		return m_statistics.getUnresolvableTransformations(DocumentType.TEXT);
+	}
+
+    @JMXBeanAttribute(name="DocumentsOperations_Spreadsheet_UnresolvableTransformations")
+	@Override
+	public long getDocumentsOperations_Spreadsheet_UnresolvableTransformations() {
+		return m_statistics.getUnresolvableTransformations(DocumentType.SPREADSHEET);
+	}
+
+    @JMXBeanAttribute(name="DocumentsOperations_Presentation_UnresolvableTransformations")
+	@Override
+	public long getDocumentsOperations_Presentation_UnresolvableTransformations() {
+		return m_statistics.getUnresolvableTransformations(DocumentType.PRESENTATION);
+	}
+
+    @JMXBeanAttribute(name="DocumentsOperations_Total_UnresolvableTransformationReloads")
+    @Override
+    public long getDocumentsOperations_Total_UnresolvableTransformationReloads() {
+        return m_statistics.getUnresolvableTransformationReloads(null);
     }
 
-    /**
-     * Terminating all internally used threads and freeing resources
-     */
-    public void shutdown() {
-        if (null != m_statistics) {
-            m_statistics.shutdown();
-        }
+    @JMXBeanAttribute(name="DocumentsOperations_Text_UnresolvableTransformationReloads")
+    @Override
+    public long getDocumentsOperations_Text_UnresolvableTransformationReloads() {
+        return m_statistics.getUnresolvableTransformationReloads(DocumentType.TEXT);
     }
 
-    // - Members ---------------------------------------------------------------
+    @JMXBeanAttribute(name="DocumentsOperations_Spreadsheet_UnresolvableTransformationReloads")
+    @Override
+    public long getDocumentsOperations_Spreadsheet_UnresolvableTransformationReloads() {
+        return m_statistics.getUnresolvableTransformationReloads(DocumentType.SPREADSHEET);
+    }
+
+    @JMXBeanAttribute(name="DocumentsOperations_Presentation_UnresolvableTransformationReloads")
+    @Override
+    public long getDocumentsOperations_Presentation_UnresolvableTransformationReloads() {
+        return m_statistics.getUnresolvableTransformationReloads(DocumentType.PRESENTATION);
+    }
 
-    final private Statistics m_statistics;
 }
 
