@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -66,6 +66,9 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.validator.routines.UrlValidator;
 import org.json.JSONException;
 import org.json.JSONObject;
+import org.springframework.beans.factory.InitializingBean;
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.web.bind.annotation.RestController;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.config.ConfigurationService;
@@ -75,18 +78,19 @@ import com.openexchange.imagetransformation.ImageMetadata;
 import com.openexchange.imagetransformation.ImageMetadataOptions;
 import com.openexchange.imagetransformation.ImageMetadataService;
 import com.openexchange.net.HostList;
-import com.openexchange.office.document.DocFileHelper;
+import com.openexchange.office.document.api.DocFileServiceFactory;
+import com.openexchange.office.document.tools.DocFileHelper;
 import com.openexchange.office.imagemgr.IResourceManager;
+import com.openexchange.office.imagemgr.IResourceManagerFactory;
 import com.openexchange.office.imagemgr.Resource;
 import com.openexchange.office.rest.tools.RESTException;
+import com.openexchange.office.rest.tools.RequestDataHelper;
 import com.openexchange.office.tools.common.DigestHelper;
+import com.openexchange.office.tools.common.IOHelper;
+import com.openexchange.office.tools.common.error.ErrorCode;
 import com.openexchange.office.tools.common.memory.MemoryObserver;
 import com.openexchange.office.tools.doc.DocumentFormat;
 import com.openexchange.office.tools.doc.StreamInfo;
-import com.openexchange.office.tools.error.ErrorCode;
-import com.openexchange.office.tools.files.StorageHelper;
-import com.openexchange.office.tools.osgi.ServiceLookupRegistry;
-import com.openexchange.office.tools.rest.RequestDataHelper;
 import com.openexchange.tools.encoding.Base64;
 import com.openexchange.tools.net.URITools;
 import com.openexchange.tools.session.ServerSession;
@@ -96,8 +100,9 @@ import com.openexchange.tools.session.ServerSession;
  *
  * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
  */
-
-public class AddFileAction extends DocumentRESTAction {
+@SuppressWarnings("rawtypes")
+@RestController
+public class AddFileAction extends DocumentRESTAction implements InitializingBean {
 
 	public static final String HOST_BLACKLIST_DEFAULT = "127.0.0.1-127.255.255.255,localhost";
 
@@ -126,34 +131,38 @@ public class AddFileAction extends DocumentRESTAction {
 
     // - Members ---------------------------------------------------------------
 
-    private IResourceManager resourceManager = null;
+    @Autowired
+    private IResourceManagerFactory resourceManagerFactory = null;
+
+    @Autowired
+    private ConfigurationService configurationService;
+
+    @Autowired
+    private ImageMetadataService imageMetadataService;
+
+    @Autowired
+    private DocFileServiceFactory docFileServiceFactory;
+
+    private IResourceManager resourceManager;
+
     private HostList blackImageUrlHostlist;
     private String blackImageUrlHostlistAsStr;
     private HostList whiteImageUrlHostlist;
     private String whiteImageUrlHostlistAsStr;
     private int maxUrlLength;
 
-    /**
-     * Initializes a new {@link AddFileAction}.
-     *
-     * @param services
-     * @param oqm
-     */
-    public AddFileAction(final IResourceManager resMgr) {
-        resourceManager = resMgr;
+    @Override
+	public void afterPropertiesSet() throws Exception {
+          maxImageSizeSupported = configurationService.getIntProperty("com.openexchange.office.maxImageSize", MAX_IMAGE_SIZE_IN_MB) * 1024L * 1024L;
+          maxUrlLength = configurationService.getIntProperty("com.openexchange.office.maxUrlLength", MAX_URL_LENGTH);
+	      blackImageUrlHostlistAsStr = configurationService.getProperty("com.openexchange.office.upload.blacklist", HOST_BLACKLIST_DEFAULT);
+	      blackImageUrlHostlist = HostList.valueOf(blackImageUrlHostlistAsStr);
+	      whiteImageUrlHostlistAsStr = configurationService.getProperty("com.openexchange.office.upload.whitelist", "");
+	      whiteImageUrlHostlist = HostList.valueOf(whiteImageUrlHostlistAsStr);
+	      resourceManager = resourceManagerFactory.createInstance(AddFileAction.class.getCanonicalName());
+	}
 
-        final ConfigurationService configService = ServiceLookupRegistry.get().getService(ConfigurationService.class);
-        if (null != configService) {
-            maxImageSizeSupported = configService.getIntProperty("com.openexchange.office.maxImageSize", MAX_IMAGE_SIZE_IN_MB) * 1024L * 1024L;
-        }
-        blackImageUrlHostlistAsStr = configService.getProperty("com.openexchange.office.upload.blacklist", HOST_BLACKLIST_DEFAULT);
-        blackImageUrlHostlist = HostList.valueOf(blackImageUrlHostlistAsStr);
-        whiteImageUrlHostlistAsStr = configService.getProperty("com.openexchange.office.upload.whitelist", "");
-        whiteImageUrlHostlist = HostList.valueOf(whiteImageUrlHostlistAsStr);
-        maxUrlLength = configService.getIntProperty("com.openexchange.office.maxUrlLength", MAX_URL_LENGTH);
-    }
-
-    /*
+	/*
      * (non-Javadoc)
      * @see com.openexchange.ajax.requesthandler.AJAXActionService#perform(com.openexchange.ajax.requesthandler.AJAXRequestData,
      * com.openexchange.tools.session.ServerSession)
@@ -189,9 +198,7 @@ public class AddFileAction extends DocumentRESTAction {
         LOG.debug("AddFileAction called with ext=" + extension + ", fileId=" + fileId + ", folderId=" + folderId + ", sha256=" + sha256 + ", data-length=" + ((data != null) ? data.length : "0"));
 
         if ((null != fileId) && (null != folderId)) {
-            final DocFileHelper fileHelper = new DocFileHelper();
-            final StorageHelper storageHelper = new StorageHelper(session, folderId);
-            final StreamInfo streamInfo = fileHelper.getDocumentStream(session, storageHelper, folderId, fileId, "");
+            final StreamInfo streamInfo = docFileServiceFactory.createInstance().getDocumentStream(session, folderId, fileId, "");
             final InputStream inputStream = streamInfo.getDocumentStream();
             if (null != inputStream) {
                 try {
@@ -199,7 +206,7 @@ public class AddFileAction extends DocumentRESTAction {
                 } catch (IOException e) {
                     LOG.error("Could not read file stream", e);
                 } finally {
-                    IOUtils.closeQuietly(inputStream);
+                    IOHelper.closeQuietly(inputStream);
                     try {
                         streamInfo.close();
                     } catch (IOException e) {
@@ -248,7 +255,7 @@ public class AddFileAction extends DocumentRESTAction {
                     } catch (IOException e) {
                         LOG.error("Could not read file stream", e);
                     } finally {
-                        IOUtils.closeQuietly(uploadStm);
+                    	IOHelper.closeQuietly(uploadStm);
                     }
                 }
             }
@@ -256,6 +263,7 @@ public class AddFileAction extends DocumentRESTAction {
 
         if ((data != null) && (data.length > 0)) {
 
+
             try {
                 if (StringUtils.isEmpty(sha256)) {
                     sha256 = Resource.getSHA256(data);
@@ -281,7 +289,6 @@ public class AddFileAction extends DocumentRESTAction {
 
                 if (resname != null) {
                     resname = resname + Resource.RESOURCE_UID_PREFIX + uid + "." + extension;
-
                     final Resource resource = resourceManager.getResource(uid);
                     String managedResourceId = null;
 
@@ -325,13 +332,13 @@ public class AddFileAction extends DocumentRESTAction {
      */
     private Function<URL, Optional<OXException>> validator = (url) -> {
 
-       	String urlasStr = url.toString();
+    	String urlasStr = url.toString();
     	if (urlasStr.length() > maxUrlLength) {
     		return Optional.of(new OXException(new RESTException("The length " + blackImageUrlHostlistAsStr.length() + " is to long!", ErrorCode.GENERAL_ARGUMENTS_ERROR)));
     	}
 
         final UrlValidator defaultValidator = new UrlValidator();
-        if (!defaultValidator.isValid(url.toString())) {
+        if (!defaultValidator.isValid(urlasStr)) {
             return Optional.of(new OXException(new RESTException(ErrorCode.GENERAL_ARGUMENTS_ERROR)));
         }
 		String host = url.getHost();
@@ -356,7 +363,7 @@ public class AddFileAction extends DocumentRESTAction {
         	try {
         		httpConn = (HttpURLConnection) URITools.getTerminalConnection(fileURL, Optional.of(validator), Optional.empty());
             } catch (Exception e) {
-                throw new RESTException(e.getMessage(), ErrorCode.GENERAL_ARGUMENTS_ERROR);
+                throw new RESTException(ErrorCode.GENERAL_MISSING_SERVICE_ERROR, e);
             }
     		try {
 		        int responseCode = httpConn.getResponseCode();
@@ -370,7 +377,7 @@ public class AddFileAction extends DocumentRESTAction {
 		                errorCode.setValue(new Long(maxImageSizeSupported / (1024L * 1024L)).toString());
 		                throw new RESTException("Image size exceeds limit " + maxImageSizeSupported, errorCode);
 		            }
-		            final boolean notEnoughMemory = MemoryObserver.getMemoryObserver().willMemoryThresholdExceeded(contentLength);
+		            final boolean notEnoughMemory = MemoryObserver.get().willHeapLimitBeReached(contentLength);
 		            if (notEnoughMemory) {
 		                throw new RESTException("Memory threshold will be exceeded due to reading image data in memory", ErrorCode.GENERAL_MEMORY_TOO_LOW_ERROR);
 		            }
@@ -383,11 +390,17 @@ public class AddFileAction extends DocumentRESTAction {
 		                if (StringUtils.isEmpty(imageType) || !SUPPORTED_IMAGE_TYPES.contains(imageType)) {
 		                    throw new RESTException(ErrorCode.GENERAL_IMAGE_TYPE_NOT_SUPPORTED_ERROR);
 		                }
-	                } else {
-	                    throw new RESTException("Error: " + responseCode + ", " + httpConn.getResponseMessage(), ErrorCode.GENERAL_ARGUMENTS_ERROR);
+		            } else {
+		                throw new RESTException(ErrorCode.GENERAL_UNKNOWN_ERROR);
+		            }
+		            if (StringUtils.isEmpty(imageType) || !SUPPORTED_IMAGE_TYPES.contains(imageType)) {
+	                    throw new RESTException(ErrorCode.GENERAL_IMAGE_TYPE_NOT_SUPPORTED_ERROR);
 	                }
-		        }
-	        } finally {
+                } else {
+                    throw new RESTException("Error: " + responseCode + ", " + httpConn.getResponseMessage(), ErrorCode.GENERAL_ARGUMENTS_ERROR);
+                }
+	        }
+    		finally {
 	        	httpConn.disconnect();
 			}
 	    } catch (RESTException e) {
@@ -400,14 +413,12 @@ public class AddFileAction extends DocumentRESTAction {
     	return result;
     }
 
-    private static String imageTypeDetection(InputStream imageInputStm) throws OXException {
-
-        final ImageMetadataService metadataService = ServiceLookupRegistry.get().getService(ImageMetadataService.class);
+    private String imageTypeDetection(InputStream imageInputStm) throws OXException {
 
         String imageFormatName = null;
-        if ((null != imageInputStm) && (null != metadataService)) {
+        if (null != imageInputStm) {
             try {
-                final ImageMetadata imageMetadata = metadataService.getMetadataFor(imageInputStm, null, null, ImageMetadataOptions.builder().withDimension().withFormatName().build());
+                final ImageMetadata imageMetadata = imageMetadataService.getMetadataFor(imageInputStm, null, null, ImageMetadataOptions.builder().withDimension().withFormatName().build());
                 imageFormatName = imageMetadata.getFormatName();
             } catch (IOException e) {
                 LOG.trace(e.getMessage());
