@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,36 +50,39 @@ package com.openexchange.office.rest;
 
 import java.util.Collections;
 import java.util.List;
-import org.apache.commons.logging.Log;
+
 import org.json.JSONObject;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.web.bind.annotation.RestController;
 
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.exception.OXException;
-import com.openexchange.office.rest.tools.ParamValidator;
+import com.openexchange.office.recentfilelist.RecentFileListManager;
+import com.openexchange.office.recentfilelist.RecentFileListManagerFactory;
+import com.openexchange.office.rest.tools.ParamValidatorService;
 import com.openexchange.office.rest.tools.SessionIdCheck;
+import com.openexchange.office.tools.common.error.HttpStatusCode;
 import com.openexchange.office.tools.doc.ApplicationType;
-import com.openexchange.office.tools.doc.RecentFileListManager;
-import com.openexchange.office.tools.error.HttpStatusCode;
 import com.openexchange.tools.session.ServerSession;
 
+@RestController
 public class ClearRecentListAction extends DocumentRESTAction {
-    @SuppressWarnings("deprecation")
-    private static final Log LOG = com.openexchange.log.Log.loggerFor(ClearRecentListAction.class);
+    private static final Logger LOG = LoggerFactory.getLogger(ClearRecentListAction.class);
     private final static String[] MANDATORY_PARAMS = { ParameterDefinitions.PARAM_TYPE };
 
-    public ClearRecentListAction() {
-        // nothing to do
-    }
-
-	@SuppressWarnings("unused")
+    @Autowired
+    private RecentFileListManagerFactory recentFileListManagerFactory;
+    
     @Override
 	public AJAXRequestResult perform(AJAXRequestData requestData, ServerSession session) throws OXException {
         if (null == session)
-            return ParamValidator.getResultFor(HttpStatusCode.UNAUTHORIZED.getStatusCode());
+            return ParamValidatorService.getResultFor(HttpStatusCode.UNAUTHORIZED.getStatusCode());
 
-        if (!ParamValidator.areAllParamsNonEmpty(requestData, MANDATORY_PARAMS))
-            return ParamValidator.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
+        if (!paramValidatorService.areAllParamsNonEmpty(requestData, MANDATORY_PARAMS))
+            return ParamValidatorService.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
 
         final String type = requestData.getParameter("type").toLowerCase();
     	final ApplicationType appType = ApplicationType.stringToEnum(type);
@@ -89,11 +92,11 @@ public class ClearRecentListAction extends DocumentRESTAction {
         // correct sessionId; set errorcode to 400 in case of an invalid request
         if (SessionIdCheck.isNotValid(requestData.getParameter("session"), session)) {
             LOG.warn("ClearRecentListAction detected invalid session id - request rejected!");
-            return ParamValidator.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
+            return ParamValidatorService.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
         }
 
         if (appType != ApplicationType.APP_NONE) {
-            final RecentFileListManager recentFileListManager = new RecentFileListManager(null, session);
+            final RecentFileListManager recentFileListManager = recentFileListManagerFactory.create(session);
 
             final List<JSONObject> appRecentFiles = recentFileListManager.readRecentFileList(appType);
             if ((null != appRecentFiles) && (!appRecentFiles.isEmpty())) {
@@ -103,7 +106,7 @@ public class ClearRecentListAction extends DocumentRESTAction {
 
             requestResult = new AJAXRequestResult();
         } else {
-            return ParamValidator.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
+            return ParamValidatorService.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
         }
 
         return requestResult;
