@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,11 +52,15 @@ import java.io.ByteArrayInputStream;
 import java.io.InputStream;
 import java.util.HashMap;
 import java.util.Map;
-import org.apache.commons.io.IOUtils;
+
 import org.apache.commons.lang3.StringUtils;
-import org.apache.commons.logging.Log;
 import org.json.JSONException;
 import org.json.JSONObject;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.web.bind.annotation.RestController;
+
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.documentconverter.IDocumentConverter;
@@ -66,44 +70,46 @@ import com.openexchange.file.storage.File;
 import com.openexchange.file.storage.FileStorageFileAccess;
 import com.openexchange.file.storage.composition.IDBasedFileAccess;
 import com.openexchange.file.storage.composition.IDBasedFileAccessFactory;
-import com.openexchange.file.storage.composition.IDBasedFolderAccess;
-import com.openexchange.file.storage.composition.IDBasedFolderAccessFactory;
-import com.openexchange.office.document.DocFileHelper;
-import com.openexchange.office.document.EmptyDocData;
-import com.openexchange.office.document.EmptyDocumentCache;
-import com.openexchange.office.document.ImExportHelper;
-import com.openexchange.office.document.OXDocument;
-import com.openexchange.office.document.OfficeDocumentTypeProperties;
-import com.openexchange.office.fields.DynamicFields;
+import com.openexchange.office.document.api.ImExporterAccessFactory;
+import com.openexchange.office.document.api.OXDocument;
+import com.openexchange.office.document.api.OXDocumentFactory;
+import com.openexchange.office.document.tools.EmptyDocData;
+import com.openexchange.office.document.tools.EmptyDocumentCache;
+import com.openexchange.office.fields.DynamicFieldsService;
 import com.openexchange.office.filter.api.DocumentProperties;
 import com.openexchange.office.filter.api.FilterException;
 import com.openexchange.office.filter.api.IImporter;
 import com.openexchange.office.filter.core.FilterExceptionToErrorCode;
+import com.openexchange.office.htmldoc.DocMetaData;
 import com.openexchange.office.htmldoc.GenericHtmlDocumentBuilder;
 import com.openexchange.office.message.MessagePropertyKey;
 import com.openexchange.office.rest.operations.OperationTools;
-import com.openexchange.office.rest.tools.ParamValidator;
+import com.openexchange.office.rest.tools.ParamValidatorService;
 import com.openexchange.office.rest.tools.SessionIdCheck;
 import com.openexchange.office.templatemgr.api.IResourceProvider;
 import com.openexchange.office.tools.common.IOHelper;
 import com.openexchange.office.tools.common.MissingParameter;
+import com.openexchange.office.tools.common.error.ErrorCode;
+import com.openexchange.office.tools.common.error.ExceptionToErrorCode;
+import com.openexchange.office.tools.common.error.HttpStatusCode;
+import com.openexchange.office.tools.common.files.FileHelper;
+import com.openexchange.office.tools.common.user.UserHelper;
 import com.openexchange.office.tools.doc.ApplicationType;
 import com.openexchange.office.tools.doc.DocumentFormatHelper;
 import com.openexchange.office.tools.doc.DocumentType;
 import com.openexchange.office.tools.doc.FileDescriptor;
+import com.openexchange.office.tools.doc.OfficeDocumentTypeProperties;
 import com.openexchange.office.tools.doc.PaperSize;
-import com.openexchange.office.tools.error.ErrorCode;
-import com.openexchange.office.tools.error.ExceptionToErrorCode;
-import com.openexchange.office.tools.error.HttpStatusCode;
-import com.openexchange.office.tools.files.FileHelper;
-import com.openexchange.office.tools.files.FolderHelper;
-import com.openexchange.office.tools.files.StorageHelper;
 import com.openexchange.office.tools.monitoring.CreateEvent;
 import com.openexchange.office.tools.monitoring.DocumentEvent;
 import com.openexchange.office.tools.monitoring.ErrorType;
 import com.openexchange.office.tools.monitoring.Statistics;
-import com.openexchange.office.tools.osgi.ServiceLookupRegistry;
-import com.openexchange.office.tools.user.UserHelper;
+import com.openexchange.office.tools.service.files.FileHelperService;
+import com.openexchange.office.tools.service.files.FileHelperServiceFactory;
+import com.openexchange.office.tools.service.files.FolderHelperService;
+import com.openexchange.office.tools.service.files.FolderHelperServiceFactory;
+import com.openexchange.office.tools.service.storage.StorageHelperService;
+import com.openexchange.office.tools.service.storage.StorageHelperServiceFactory;
 import com.openexchange.tools.session.ServerSession;
 import com.openexchange.user.User;
 
@@ -129,10 +135,47 @@ import com.openexchange.user.User;
  * )
  */
 
+@RestController
 public class CreateDefaultDocumentAction extends DocumentRESTAction {
 
-    @SuppressWarnings("deprecation")
-	private static final Log LOG = com.openexchange.log.Log.loggerFor(CreateDefaultDocumentAction.class);
+	private static final Logger LOG = LoggerFactory.getLogger(CreateDefaultDocumentAction.class);
+	private static final String ENCRYPT_ACTION = "encrypt";
+
+	@Autowired
+    private IResourceProvider resourceProvider;
+
+	@Autowired
+    private EmptyDocumentCache defaultDocCache;
+
+	@Autowired
+    private ImExporterAccessFactory imExporterFactory;
+
+	@Autowired
+	private FileHelperServiceFactory fileHelperServiceFactory;
+
+	@Autowired
+	private FolderHelperServiceFactory folderHelperServiceFactory;
+
+	@Autowired
+	private StorageHelperServiceFactory storageHelperServiceFactory;
+
+	@Autowired
+	private OXDocumentFactory oxDocumentFactory;
+
+	@Autowired
+	private DynamicFieldsService dynamicFieldsService;
+
+	@Autowired
+	private IDBasedFileAccessFactory idBasedFileAccessFactory;
+
+	@Autowired(required=false)
+	private IDocumentConverter documentConverter;
+
+	@Autowired
+	private GenericHtmlDocumentBuilder genericHtmlDocumentBuilder;
+
+    @Autowired
+    private Statistics statistics;
 
     private class TemplateResult {
         public final JSONObject jsonResult;
@@ -144,15 +187,6 @@ public class CreateDefaultDocumentAction extends DocumentRESTAction {
         }
     }
 
-    /**
-     * Initializes a new {@link CreateDefaultDocumentAction}.
-     *
-     * @param services
-     * @param oqm
-     */
-    public CreateDefaultDocumentAction() {
-    }
-
     @Override
     public AJAXRequestResult perform(AJAXRequestData request, ServerSession session) {
         AJAXRequestResult requestResult = null;
@@ -164,7 +198,7 @@ public class CreateDefaultDocumentAction extends DocumentRESTAction {
             // correct sessionId; set errorcode to 400 in case of an invalid request
             if (SessionIdCheck.isNotValid(request.getParameter("session"), session)) {
                 LOG.warn("CreateDefaultDocumentAction detected invalid session id - request rejected!");
-                return ParamValidator.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
+                return ParamValidatorService.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
             }
 
             JSONObject jsonResult = null;
@@ -204,7 +238,7 @@ public class CreateDefaultDocumentAction extends DocumentRESTAction {
         }
 
         // update statistics with a possibly created event
-        Statistics.handleDocumentEvent(documentEvent);
+        statistics.handleDocumentEvent(documentEvent);
 
         return requestResult;
     }
@@ -271,12 +305,11 @@ public class CreateDefaultDocumentAction extends DocumentRESTAction {
 
         InputStream inputStream = null;
         InputStream resourceInputStream = null;
-        final IResourceProvider resourceProvider = ServiceLookupRegistry.get().getService(IResourceProvider.class);
 
         final String docTypeName = request.getParameter(RESTParameters.PARAMETER_DOCUMENT_TYPE).toLowerCase();
         final String initialSheetname = request.getParameter(RESTParameters.PARAMETER_INITIAL_SHEETNAME);
         final String initialFormats = request.getParameter(RESTParameters.PARAMETER_INITIAL_FORMATS);
-        final EmptyDocumentCache aDefaultDocCache = ServiceLookupRegistry.get().getService(EmptyDocumentCache.class);
+        final String initialLanguage = request.getParameter(RESTParameters.PARAMETER_INITIAL_LANGUAGE);
 
         // will be needed for speed-up access if creating a new empty document
         String htmlDoc = null;
@@ -284,16 +317,16 @@ public class CreateDefaultDocumentAction extends DocumentRESTAction {
 
         // determine requested document type and corresponding extensionType
         final OfficeDocumentTypeProperties aDocTypeProps = OfficeDocumentTypeProperties.determineDefaultOfficeProperties(docTypeName);
-        final String module              = aDocTypeProps.getModule();
-        final String extensionType       = aDocTypeProps.getExtension();
-        final String mimeType            = aDocTypeProps.getMimeType();
+        final String module = aDocTypeProps.getModule();
+        final String extensionType = aDocTypeProps.getExtension();
+        final String mimeType = aDocTypeProps.getMimeType();
 
         try {
             // look into the soft cache for stored empty default document data
-            final User         user          = session.getUser();
-            final String       aUserLangCode = UserHelper.mapUserLanguageToLangCode(user.getPreferredLanguage());
-            final IImporter    importer      = ImExportHelper.getImporterService(null, aDocTypeProps.getDocumentFormat());
-            final EmptyDocData cacheData     = aDefaultDocCache.getDocData(module, aUserLangCode);
+            final User user = session.getUser();
+            final String aUserLangCode = ((initialLanguage != null) && (initialLanguage.length() > 0)) ? initialLanguage : UserHelper.mapUserLanguageToLangCode(user.getPreferredLanguage());
+            final IImporter importer = imExporterFactory.getImporterAccess(aDocTypeProps.getDocumentFormat());
+            final EmptyDocData cacheData = defaultDocCache.getDocData(module, aUserLangCode);
 
             if (null != cacheData) {
                 // cache hit - provide the fastLoad empty document data
@@ -304,9 +337,9 @@ public class CreateDefaultDocumentAction extends DocumentRESTAction {
 
                 // create a input stream buffered by the byte array stored in the cache
                 inputStream = new ByteArrayInputStream(cacheData.getDocumentData());
-                LOG.debug("RT connection: cache hit for document type: " + module + " data send from cache.");
+                LOG.debug("RT connection: cache hit for document type: {} data send from cache.", module);
             } else {
-                LOG.debug("RT connection: cache miss for document type: " + module + " data must be retrieved from file.");
+                LOG.debug("RT connection: cache miss for document type: {} data must be retrieved from file.", module);
                 // no cache hit - load the default document
                 // try to get default document from resource first
                 if (null != resourceProvider) {
@@ -343,7 +376,7 @@ public class CreateDefaultDocumentAction extends DocumentRESTAction {
                     // Close resource input stream if default document stream
                     // was created by the import getDefaultDocument function. Don't
                     // do that if inputStm refers to resourceInputStream
-                    IOUtils.closeQuietly(resourceInputStream);
+                    IOHelper.closeQuietly(resourceInputStream);
                 }
             }
 
@@ -356,26 +389,28 @@ public class CreateDefaultDocumentAction extends DocumentRESTAction {
 
             inputStream = impl_handleDynamicFields(inputStream, extensionType, request, jsonResult, session);
 
+            final FileHelperService fileHelperService = fileHelperServiceFactory.create(session);
+            final IDBasedFileAccess writeFileAccess = getFileAccess(session, request);
+
             ErrorCode errorCode = ErrorCode.NO_ERROR;
-            IDBasedFileAccess fileAccess = getFileAccess(session, request);
             if ((module.equalsIgnoreCase(ApplicationType.APP_TEXT_STRING) || module.equalsIgnoreCase(ApplicationType.APP_PRESENTATION_STRING)) &&
                 (null == cacheData) && (null != inputStream)) {
                 // just continue with the slower way - no cache hit
-                final StorageHelper aStorageHelper = new StorageHelper(session, file.getFolderId());
-                final OXDocument    oxDoc = new OXDocument(session, null, inputStream, file.getFileName(), mimeType, null, aStorageHelper);
+                final StorageHelperService aStorageHelper = storageHelperServiceFactory.create(session, file.getFolderId());
+                final OXDocument oxDoc = oxDocumentFactory.createDocumentAccess(session, inputStream, file.getFileName(), mimeType, null, aStorageHelper);
                 documentOperations = oxDoc.getOperations(importer, null);
 
                 // create new buffered input stream to write it to the storage
                 inputStream = new ByteArrayInputStream(oxDoc.getDocumentBuffer());
 
                 // now we have to create the new document file using the input stream
-                errorCode = FileHelper.createFileAndWriteStream(null, session, fileAccess, file, inputStream);
+                errorCode = fileHelperService.createFileAndWriteStream(writeFileAccess, file, inputStream);
                 if (!errorCode.isError()) {
-                    if (GenericHtmlDocumentBuilder.isFastLoadActive(module, session)) {
+                    if (genericHtmlDocumentBuilder.isFastLoadActive(module, session)) {
                         // OperationReducer.reduceOperationCount(documentOperations);
-                        htmlDoc = GenericHtmlDocumentBuilder.buildHtmlDocument(module, documentOperations, file, session);
+                        htmlDoc = genericHtmlDocumentBuilder.buildHtmlDocument(module, documentOperations, new DocMetaData(file), session);
                         OperationTools.setOperationStateNumberToOperations(OXDocument.DEFAULT_DOCUMENT_ID, documentOperations);
-                        aDefaultDocCache.setDocData(module,
+                        defaultDocCache.setDocData(module,
                                                     aUserLangCode,
                                                     new EmptyDocData(htmlDoc, documentOperations.getJSONArray(MessagePropertyKey.KEY_OPERATIONS), oxDoc.getDocumentBuffer()));
                         jsonResult.put(MessagePropertyKey.KEY_HTMLDOCUMENT, htmlDoc);
@@ -386,7 +421,7 @@ public class CreateDefaultDocumentAction extends DocumentRESTAction {
                 }
             } else {
                 // now we have to create the new document file using the input stream
-                errorCode = FileHelper.createFileAndWriteStream(null, session, fileAccess, file, inputStream);
+                errorCode = fileHelperService.createFileAndWriteStream(writeFileAccess, file, inputStream);
                 if (!errorCode.isError() && (null != cacheData)) {
                     // set result data in case of a cache hit and the new file could be created
                     if (null != cacheData.getHtmlDocString()) {
@@ -413,23 +448,29 @@ public class CreateDefaultDocumentAction extends DocumentRESTAction {
         return jsonResult;
     }
 
+    /**
+     * Handles optional dynamic fields which should be inserted.
+     *
+     * @param inputStream the document content stream
+     * @param extensionType the extension type of the document
+     * @param request the original request by the client
+     * @param jsonResult the JSONObject instance that contains the current
+     *                   result for the client
+     * @param session the session of the requesting client
+     * @return an updated document content stream or the original one if
+     *         dynamic fields could not be applied
+     */
     private InputStream impl_handleDynamicFields(final InputStream inputStream, String extensionType, final AJAXRequestData request, final JSONObject jsonResult, final ServerSession session) {
         InputStream result = inputStream;
 
-        try
-        {
-            result = DynamicFields.insertOptionalFields(inputStream, extensionType, request, jsonResult, session, null);
-        }
-        catch (Exception e)
-        {
+        try {
+            result = dynamicFieldsService.insertOptionalFields(inputStream, extensionType, request, jsonResult, session);
+        } catch (Exception e) {
             LOG.debug("Handling optional fields is broken " + ErrorCode.GENERAL_ARGUMENTS_ERROR.getDescription(), e);
 
-            try
-            {
+            try {
                 jsonResult.put(MessagePropertyKey.KEY_ERROR_DATA,  ErrorCode.GENERAL_ARGUMENTS_ERROR.getAsJSONResultObject().get(MessagePropertyKey.KEY_ERROR_DATA));
-            }
-            catch (final Exception je)
-            {
+            } catch (final Exception je) {
                 LOG.debug("Couldn't create JSON object while creating new document from template", je);
             }
         }
@@ -489,14 +530,16 @@ public class CreateDefaultDocumentAction extends DocumentRESTAction {
             version = FileStorageFileAccess.CURRENT_VERSION;
         }
 
-        final IDBasedFileAccessFactory fileFactory = ServiceLookupRegistry.get().getService(IDBasedFileAccessFactory.class);
-        final IDBasedFolderAccessFactory folderFactory = ServiceLookupRegistry.get().getService(IDBasedFolderAccessFactory.class);
+        final String reqCryptoAction = getCryptoAction(request);
+        final boolean encryptTargetFile = determineEncryptTargetValue(reqCryptoAction);
+
         IDBasedFileAccess templateFileAccess;
         if (Boolean.parseBoolean(request.getParameter(RESTParameters.PARAMETER_ENCRYPTED_FILE))) {
             templateFileAccess = getFileAccess(session, request, "Decrypt");
         } else {
-            templateFileAccess = fileFactory.createAccess(session);
+            templateFileAccess = idBasedFileAccessFactory.createAccess(session);
         }
+
         File templateFile = templateFileAccess.getFileMetadata(templateAccessId, version);
         final String templateFileName = templateFile.getFileName();
 
@@ -505,10 +548,8 @@ public class CreateDefaultDocumentAction extends DocumentRESTAction {
         conversionFormat = DocumentFormatHelper.getConversionFormatInfo(mimeType, extensionType);
         boolean binaryConverted = false;
         if (conversionFormat != null) {
-            final IDocumentConverter documentConverter = ServiceLookupRegistry.get().getService(IDocumentConverter.class);
-
             if (null != documentConverter) {
-                AJAXRequestData loadRequest = new AJAXRequestData();
+                final AJAXRequestData loadRequest = new AJAXRequestData();
                 loadRequest.putParameter(RESTParameters.PARAMETER_ID, fileId);
                 loadRequest.putParameter(RESTParameters.PARAMETER_FOLDER_ID, templateFile.getFolderId());
                 loadRequest.putParameter(RESTParameters.PARAMETER_VERSION, version);
@@ -559,10 +600,10 @@ public class CreateDefaultDocumentAction extends DocumentRESTAction {
             inputStm = templateFileAccess.getDocument(templateAccessId, version);
         }
 
-        final IDBasedFolderAccess folderAccess = folderFactory.createAccess(session);
+        final FolderHelperService folderHelperService = folderHelperServiceFactory.create(session);
+        boolean canWriteToFolder = folderHelperService.folderHasWriteAccess(targetFolderId);
+        boolean canCreateFilesInFolder = folderHelperService.folderHasCreateAccess(targetFolderId);
 
-        boolean canWriteToFolder = FolderHelper.folderHasWriteAccess(folderAccess, targetFolderId);
-        boolean canCreateFilesInFolder = FolderHelper.folderHasCreateAccess(folderAccess, targetFolderId);
         if (!canWriteToFolder || !canCreateFilesInFolder) {
             // #43749: Checking the write/create permissions is not dependent on the argument
             // preserveFileName! Therefore remove the check for preserveFileName.
@@ -570,7 +611,7 @@ public class CreateDefaultDocumentAction extends DocumentRESTAction {
             // We cannot create files/write to the folder which contains our source template document (Edit as New).
             // Use a fall-back and create the document in the user's documents folder instead.
             // If this doesn't work we give up and provide an error.
-            targetFolderId = DocFileHelper.getUserDocumentsFolderId(session, null);
+            targetFolderId = folderHelperService.getUserDocumentsFolderId(session);
         }
 
         // ATTENTION: This method MUST be called after every detail where and how the new file must
@@ -584,8 +625,16 @@ public class CreateDefaultDocumentAction extends DocumentRESTAction {
 
         try {
             if (null != inputStm) {
-                IDBasedFileAccess fileAcces = getFileAccess(session, request);
-                errorCode = FileHelper.createFileAndWriteStream(null, session, fileAcces, file, inputStm);
+            	final FileHelperService fileHelperService = fileHelperServiceFactory.create(session);
+
+            	IDBasedFileAccess writeFileAccess = null;
+                if (encryptTargetFile) {
+                    writeFileAccess = getFileAccess(session, request, "Encrypt");
+                } else {
+                    writeFileAccess = idBasedFileAccessFactory.createAccess(session);
+                }
+
+                errorCode = fileHelperService.createFileAndWriteStream(writeFileAccess, file, inputStm);
 
                 if (!errorCode.isError()) {
                     // set the file descriptor
@@ -609,10 +658,14 @@ public class CreateDefaultDocumentAction extends DocumentRESTAction {
             // error to the client by just return a null result
             jsonResult = null;
         } finally {
-            IOUtils.closeQuietly(inputStm);
+        	IOHelper.closeQuietly(inputStm);
         }
 
         return result;
     }
 
+    private boolean determineEncryptTargetValue(String reqCryptoAction) {
+        return ENCRYPT_ACTION.equalsIgnoreCase(reqCryptoAction);
+    }
+
 }
