@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,10 +52,15 @@ import java.io.InputStream;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.Map;
+
 import org.apache.commons.lang3.StringUtils;
-import org.apache.commons.logging.Log;
 import org.json.JSONException;
 import org.json.JSONObject;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.web.bind.annotation.RestController;
+
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.documentconverter.IDocumentConverter;
@@ -65,52 +70,66 @@ import com.openexchange.file.storage.File;
 import com.openexchange.file.storage.File.Field;
 import com.openexchange.file.storage.FileStorageFileAccess;
 import com.openexchange.file.storage.composition.IDBasedFileAccess;
-import com.openexchange.file.storage.composition.IDBasedFolderAccess;
-import com.openexchange.file.storage.composition.IDBasedFolderAccessFactory;
 import com.openexchange.groupware.infostore.InfostoreExceptionCodes;
-import com.openexchange.office.document.DocFileHelper;
-import com.openexchange.office.document.ImExportHelper;
-import com.openexchange.office.document.LocalFileMappingManager;
-import com.openexchange.office.fields.DynamicFields;
+import com.openexchange.office.document.api.DocFileService;
+import com.openexchange.office.document.api.DocFileServiceFactory;
+import com.openexchange.office.document.api.ImExporterAccessFactory;
+import com.openexchange.office.document.tools.DocFileHelper;
+import com.openexchange.office.document.tools.LocalFileMappingManager;
+import com.openexchange.office.fields.DynamicFieldsService;
 import com.openexchange.office.filter.api.DocumentProperties;
 import com.openexchange.office.filter.api.FilterException;
 import com.openexchange.office.filter.api.IImporter;
 import com.openexchange.office.message.MessagePropertyKey;
-import com.openexchange.office.rest.tools.ParamValidator;
+import com.openexchange.office.rest.tools.ParamValidatorService;
 import com.openexchange.office.rest.tools.SessionIdCheck;
 import com.openexchange.office.tools.common.IOHelper;
+import com.openexchange.office.tools.common.error.ErrorCode;
+import com.openexchange.office.tools.common.error.ExceptionToErrorCode;
+import com.openexchange.office.tools.common.error.HttpStatusCode;
+import com.openexchange.office.tools.common.files.FileHelper;
+import com.openexchange.office.tools.common.user.UserHelper;
 import com.openexchange.office.tools.doc.DocumentFormatHelper;
 import com.openexchange.office.tools.doc.DocumentType;
 import com.openexchange.office.tools.doc.ExtensionHelper;
 import com.openexchange.office.tools.doc.FileDescriptor;
 import com.openexchange.office.tools.doc.StreamInfo;
-import com.openexchange.office.tools.error.ErrorCode;
-import com.openexchange.office.tools.error.ExceptionToErrorCode;
-import com.openexchange.office.tools.error.HttpStatusCode;
-import com.openexchange.office.tools.files.FileHelper;
-import com.openexchange.office.tools.files.FolderHelper;
-import com.openexchange.office.tools.files.StorageHelper;
 import com.openexchange.office.tools.monitoring.CreateEvent;
 import com.openexchange.office.tools.monitoring.DocumentEvent;
 import com.openexchange.office.tools.monitoring.ErrorType;
 import com.openexchange.office.tools.monitoring.Statistics;
-import com.openexchange.office.tools.osgi.ServiceLookupRegistry;
-import com.openexchange.office.tools.user.UserHelper;
+import com.openexchange.office.tools.service.files.FolderHelperService;
+import com.openexchange.office.tools.service.files.FolderHelperServiceFactory;
 import com.openexchange.tools.session.ServerSession;
 import com.openexchange.tx.TransactionAwares;
 import com.openexchange.user.User;
 
+@RestController
 public class CreateFromTemplateAction extends DocumentRESTAction {
 
-    @SuppressWarnings("deprecation")
-    private static final Log LOG = com.openexchange.log.Log.loggerFor(CreateFromTemplateAction.class);
+    private static final Logger LOG = LoggerFactory.getLogger(CreateFromTemplateAction.class);
     private static final String UNNAMED = "unnamed";
 
-    private LocalFileMappingManager m_localFileMapper = null;
+    @Autowired
+    private LocalFileMappingManager m_localFileMapper;
 
-    public CreateFromTemplateAction(final LocalFileMappingManager localFileMapper) {
-        m_localFileMapper = localFileMapper;
-    }
+    @Autowired
+    private FolderHelperServiceFactory folderHelperServiceFactory;
+
+    @Autowired(required=false)
+    private IDocumentConverter documentConverter;
+
+    @Autowired
+    private DocFileServiceFactory docFileServiceFactory;
+
+    @Autowired
+    private ImExporterAccessFactory imExporterAccessFactory;
+
+    @Autowired
+    private Statistics statistics;
+
+    @Autowired
+    private DynamicFieldsService dynamicFieldsService;
 
     @Override
     public AJAXRequestResult perform(AJAXRequestData request, ServerSession session) throws OXException {
@@ -122,7 +141,7 @@ public class CreateFromTemplateAction extends DocumentRESTAction {
             // correct sessionId; set errorcode to 400 in case of an invalid request
             if (SessionIdCheck.isNotValid(request.getParameter("session"), session)) {
                 LOG.warn("CreateFromTemplateAction detected invalid session id - request rejected!");
-                return ParamValidator.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
+                return ParamValidatorService.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
             }
 
             final IDBasedFileAccess fileAccess = getFileAccess(session, request);
@@ -133,23 +152,22 @@ public class CreateFromTemplateAction extends DocumentRESTAction {
 
             try {
                 final String fileId = request.getParameter("file_id");
+            	final FolderHelperService folderHelperService = folderHelperServiceFactory.create(session);
+
 
                 String targetFolderId = request.getParameter("target_folder_id");
                 if (StringUtils.isNotBlank(targetFolderId)) {
-                    final IDBasedFolderAccessFactory folderFactory = ServiceLookupRegistry.get().getService(IDBasedFolderAccessFactory.class);
-                    final IDBasedFolderAccess folderAccess = (null != folderFactory) ? folderFactory.createAccess(session) : null;
-
                     // Fix for 64188: We have to check for write & create access which are
                     // two different access rights
-                    boolean canWriteToFolder = FolderHelper.folderHasWriteAccess(folderAccess, targetFolderId);
-                    boolean canCreateFilesInFolder = FolderHelper.folderHasCreateAccess(folderAccess, targetFolderId);
+                    boolean canWriteToFolder = folderHelperService.folderHasWriteAccess(targetFolderId);
+                    boolean canCreateFilesInFolder = folderHelperService.folderHasCreateAccess(targetFolderId);
                     if (!canWriteToFolder || !canCreateFilesInFolder) {
-                        targetFolderId = DocFileHelper.getUserDocumentsFolderId(session, null);
+                        targetFolderId = folderHelperService.getUserDocumentsFolderId(session);
                     }
                 }
 
                 if (StringUtils.isBlank(targetFolderId)) {
-                    targetFolderId = DocFileHelper.getUserDocumentsFolderId(session, null);
+                    targetFolderId = folderHelperService.getUserDocumentsFolderId(session);
                 }
 
                 if ((null != fileId) && (null != fileAccess) && (null != targetFolderId)) {
@@ -186,7 +204,6 @@ public class CreateFromTemplateAction extends DocumentRESTAction {
 
                         if (conversionFormat != null) {
                             // conversion already sets the correct target document format
-                            final IDocumentConverter documentConverter = ServiceLookupRegistry.get().getService(IDocumentConverter.class);
                             ErrorCode errorCode = ErrorCode.NO_ERROR;
 
                             if (null != documentConverter) {
@@ -203,8 +220,8 @@ public class CreateFromTemplateAction extends DocumentRESTAction {
                                     loadRequest.putParameter("folder_id", targetFolderId);
                                     loadRequest.putParameter("version", version);
                                     loadRequest.putParameter("fileName", templateFileName);
-                                    final StorageHelper storageHelper = new StorageHelper(session, targetFolderId);
-                                    streamInfo = DocFileHelper.getDocumentStream(null, session, loadRequest, storageHelper, "");
+
+                                    streamInfo = docFileServiceFactory.createInstance().getDocumentStream(session, loadRequest, DocFileService.NO_ENCRYPTION);
                                     documentInputStm = streamInfo.getDocumentStream();
                                     errorCode = streamInfo.getErrorCode();
                                 }
@@ -243,7 +260,7 @@ public class CreateFromTemplateAction extends DocumentRESTAction {
                                 } else {
                                     // no document stream -> provide error information
                                     documentEvent = new DocumentEvent(eventDocumentType, ErrorType.CREATE);
-                                    Statistics.handleDocumentEvent(documentEvent);
+                                    statistics.handleDocumentEvent(documentEvent);
 
                                     if (null != streamInfo) {
                                         streamInfo.close();
@@ -273,12 +290,13 @@ public class CreateFromTemplateAction extends DocumentRESTAction {
                         final File file = getNewFile(request, targetFolderId, null, mimeType, extensionType, templateFile, false);
 
                         if (null != inputStm) {
-                            final IImporter importer = ImExportHelper.getImporterService(null, DocFileHelper.getDocumentFormat("." + extensionType));
+                            final IImporter importer = imExporterAccessFactory.getImporterAccess(DocFileHelper.getDocumentFormat("." + extensionType));
                             if(importer!=null) {
                                 try {
                                     final User user = session.getUser();
-                                    final String aUserLangCode = UserHelper.mapUserLanguageToLangCode(user.getPreferredLanguage());
 
+                                    final String initialLanguage = request.getParameter(RESTParameters.PARAMETER_INITIAL_LANGUAGE);
+                                    final String aUserLangCode = ((initialLanguage != null) && (initialLanguage.length() > 0)) ? initialLanguage : UserHelper.mapUserLanguageToLangCode(user.getPreferredLanguage());
                                     final DocumentProperties documentProperties = new DocumentProperties();
                                     documentProperties.put(DocumentProperties.PROP_SAVE_TEMPLATE_DOCUMENT, false);
                                     documentProperties.put(DocumentProperties.PROP_USER_LANGUAGE, aUserLangCode);
@@ -301,34 +319,25 @@ public class CreateFromTemplateAction extends DocumentRESTAction {
                         if (null != inputStm) {
                             final JSONObject result = new JSONObject(2);
 
-                            try
-                            {
-                                inputStm = DynamicFields.insertOptionalFields(inputStm, extensionType, request, result, session, null);
-                            }
-                            catch (Exception e)
-                            {
+                            try {
+                                inputStm = dynamicFieldsService.insertOptionalFields(inputStm, extensionType, request, result, session);
+                            } catch (Exception e) {
                                 ErrorCode errorCode = ErrorCode.GENERAL_ARGUMENTS_ERROR;
                                 LOG.debug("Handling optional fields is broken " + errorCode.getDescription(), e);
-                                try
-                                {
+                                try {
                                     requestResult = new AJAXRequestResult(createErrorObject(errorCode));
                                     documentEvent = new DocumentEvent(eventDocumentType, ErrorType.CREATE);
-                                }
-                                catch (final JSONException je)
-                                {
-                                    LOG.debug("Couldn't create JSON object while creating new document from template");
+                                } catch (final JSONException je) {
+                                    LOG.debug("Couldn't create JSON object while creating new document from template", e);
                                 }
                             }
 
                             fileAccess.startTransaction();
                             rollback = true;
-                            try
-                            {
+                            try {
                                 LOG.trace("RT connection: [CreateFromTemplate] saveDocument using meta data: " + ((null != file) ? file.toString() : "null"));
                                 fileAccess.saveDocument(file, inputStm, FileStorageFileAccess.DISTANT_FUTURE, new ArrayList<Field>());
-                            }
-                            catch (OXException e)
-                            {
+                            } catch (OXException e) {
                                 //if 'only' validation of the name fails, we try it again with 'unnamend'
                                 if ((e.getCode() == InfostoreExceptionCodes.VALIDATION_FAILED_CHARACTERS.getNumber()) || (e.getCode() == InfostoreExceptionCodes.VALIDATION_FAILED_SLASH.getNumber())){
                                     setFileName(file, UNNAMED, mimeType, extensionType, request);
@@ -408,7 +417,7 @@ public class CreateFromTemplateAction extends DocumentRESTAction {
         }
 
         // update statistics with a possibly created event
-        Statistics.handleDocumentEvent(documentEvent);
+        statistics.handleDocumentEvent(documentEvent);
 
         return requestResult;
     }
