@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,35 +49,44 @@
 package com.openexchange.office.rest;
 
 import java.util.List;
-import org.apache.commons.logging.Log;
+
 import org.json.JSONException;
 import org.json.JSONObject;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.web.bind.annotation.RestController;
+
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.exception.OXException;
-import com.openexchange.office.rest.tools.ParamValidator;
+import com.openexchange.office.recentfilelist.RecentFileListManager;
+import com.openexchange.office.recentfilelist.RecentFileListManagerFactory;
+import com.openexchange.office.rest.tools.ParamValidatorService;
 import com.openexchange.office.rest.tools.SessionIdCheck;
+import com.openexchange.office.tools.common.error.HttpStatusCode;
 import com.openexchange.office.tools.doc.ApplicationType;
-import com.openexchange.office.tools.doc.RecentFileListManager;
-import com.openexchange.office.tools.error.HttpStatusCode;
-import com.openexchange.office.tools.rest.RequestDataHelper;
+import com.openexchange.office.tools.service.files.FolderHelperService;
+import com.openexchange.office.tools.service.files.FolderHelperServiceFactory;
 import com.openexchange.tools.session.ServerSession;
 
+@RestController
 public class DeleteFileFromRecentListAction extends DocumentRESTAction {
-    @SuppressWarnings("deprecation")
-	private static final Log      LOG = com.openexchange.log.Log.loggerFor(DeleteFileFromRecentListAction.class);
-
+	private static final Logger LOG = LoggerFactory.getLogger(DeleteFileFromRecentListAction.class);
     private static final String[] MANDATORY_PARAMS = { ParameterDefinitions.PARAM_TYPE, ParameterDefinitions.PARAM_REMOVE_FILE_ID };
 
-    public DeleteFileFromRecentListAction() {
-        // nothing to do
-    }
-
-	@SuppressWarnings("unused")
+    @Autowired
+    private FolderHelperServiceFactory folderHelperServiceFactory;
+    
+    @Autowired
+    private RecentFileListManagerFactory recentFileListManagerFactory;
+    
+    
+    
     @Override
 	public AJAXRequestResult perform(AJAXRequestData requestData, ServerSession session) throws OXException {
-        if (!ParamValidator.areAllParamsNonEmpty(requestData, MANDATORY_PARAMS))
-            return ParamValidator.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
+        if (!paramValidatorService.areAllParamsNonEmpty(requestData, MANDATORY_PARAMS))
+            return ParamValidatorService.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
 
         final String type = requestData.getParameter(ParameterDefinitions.PARAM_TYPE).toLowerCase();
     	final ApplicationType appType = ApplicationType.stringToEnum(type);
@@ -88,16 +97,17 @@ public class DeleteFileFromRecentListAction extends DocumentRESTAction {
             // correct sessionId; set errorcode to 400 in case of an invalid request
             if (SessionIdCheck.isNotValid(requestData.getParameter("session"), session)) {
                 LOG.warn("DeleteFileFromRecentListAction detected invalid session id - request rejected!");
-                return ParamValidator.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
+                return ParamValidatorService.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
             }
 
             try {
+            	final FolderHelperService folderHelperService = folderHelperServiceFactory.create(session);
                 final String removeFileId = requestData.getParameter(ParameterDefinitions.PARAM_REMOVE_FILE_ID);
             	final JSONObject remove = new JSONObject();
-            	remove.put("folder_id", RequestDataHelper.getFolderId(null, session, removeFileId));
+            	remove.put("folder_id", folderHelperService.getFolderId(removeFileId));
             	remove.put("id", removeFileId);
 
-            	final RecentFileListManager recentFileListManager = new RecentFileListManager(null, session);
+                final RecentFileListManager recentFileListManager = recentFileListManagerFactory.create(session);
                 final List<JSONObject> appRecentFiles = recentFileListManager.readRecentFileList(appType);
                 if ((null != appRecentFiles) && (!appRecentFiles.isEmpty())) {
                     boolean changed = recentFileListManager.removeFileFromList(appRecentFiles, remove);
@@ -107,7 +117,7 @@ public class DeleteFileFromRecentListAction extends DocumentRESTAction {
                     }
                 }
             } catch (JSONException e) {
-                LOG.error("Exception while creating JSONObject answering AJAXRequest 'gettemplateandrecentlist'", e);
+                LOG.error("Exception while creating JSONObject answering AJAXRequest in 'DeleteFileFromRecentListAction'", e);
             }
             requestResult = new AJAXRequestResult();
         }
