@@ -27,7 +27,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,13 +51,16 @@ package com.openexchange.office.rest;
 import java.util.EnumSet;
 import java.util.HashMap;
 import java.util.Map;
+
 import org.apache.commons.codec.binary.Base64;
 import org.apache.commons.lang3.StringUtils;
-import org.apache.commons.logging.Log;
 import org.json.JSONException;
 import org.json.JSONObject;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import org.springframework.beans.factory.annotation.Autowired;
+
 import com.openexchange.ajax.container.ByteArrayFileHolder;
-import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.ajax.requesthandler.crypto.CryptographicServiceAuthenticationFactory;
@@ -70,12 +73,11 @@ import com.openexchange.file.storage.composition.IDBasedFileAccess;
 import com.openexchange.file.storage.composition.IDBasedFileAccessFactory;
 import com.openexchange.file.storage.composition.crypto.CryptographicAwareIDBasedFileAccessFactory;
 import com.openexchange.file.storage.composition.crypto.CryptographyMode;
-import com.openexchange.log.LogFactory;
-import com.openexchange.office.document.DocumentMetaData;
-import com.openexchange.office.session.SessionService;
-import com.openexchange.office.tools.files.FileHelper;
-import com.openexchange.office.tools.osgi.ServiceLookupRegistry;
-import com.openexchange.office.tools.osgi.ServiceLookupRegistryService;
+import com.openexchange.office.rest.tools.ParamValidatorService;
+import com.openexchange.office.tools.common.files.FileHelper;
+import com.openexchange.office.tools.doc.DocumentMetaData;
+import com.openexchange.office.tools.service.http.AjaxActionServiceWithConcreteModel;
+import com.openexchange.office.tools.service.session.SessionService;
 import com.openexchange.server.ServiceExceptionCode;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
 import com.openexchange.tools.session.ServerSession;
@@ -91,27 +93,32 @@ import com.openexchange.tools.session.ServerSession;
  * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
  * @author <a href="mailto:malte.timmermann@open-xchange.com">Malte Timmermann</a>
  */
-@SuppressWarnings("deprecation")
-public abstract class DocumentRESTAction implements AJAXActionService {
+public abstract class DocumentRESTAction<T> extends AjaxActionServiceWithConcreteModel<T> {
+
+	private static final Logger LOG = LoggerFactory.getLogger(DocumentRESTAction.class);
 
 	public static final String USE_DEFAULT_TARGET_FOLDER_ID = null;
 
-	private static final Log LOG = LogFactory.getLog(DocumentRESTAction.class);
+	public static final String HTTP_CLIENT_USER_AGENT = "Open-Xchange Documents";
+	public static final String HTTP_CLIENT_ID_DOCUMENTS = "documents";
 
-    static final String m_operationsSyntheticUser = "operations";
+	private static final String m_errorKey = "hasErrors";
+    private static final String m_eTagBase = "http://www.open-xchange.com/filestore/";
 
-    static final String m_errorKey = "hasErrors";
+    @Autowired(required=false)
+    protected CryptographicServiceAuthenticationFactory cryptographicServiceAuthenticationFactory;
 
-    static final String m_eTagBase = "http://www.open-xchange.com/filestore/";
+    @Autowired(required=false)
+    protected CryptographicAwareIDBasedFileAccessFactory cryptographicAwareIDBasedFileAccessFactory;
 
-    /**
-     * Initializes a new {@link DocumentRESTAction}.
-     *
-     * @param services
-     * @param oqm
-     */
-    public DocumentRESTAction() {
-    }
+    @Autowired
+    protected IDBasedFileAccessFactory idBasedFileAccessFactory;
+
+    @Autowired
+    protected SessionService sessionService;
+
+    @Autowired
+    protected ParamValidatorService paramValidatorService;
 
     /**
      * @param request
@@ -215,17 +222,17 @@ public abstract class DocumentRESTAction implements AJAXActionService {
 
             //Parsing authentication from the request. Might be null since not all crypto-actions require authentication.
             String authentication = null;
-            CryptographicServiceAuthenticationFactory encryptionAuthenticationFactory = ServiceLookupRegistry.get().getService(CryptographicServiceAuthenticationFactory.class);
+            CryptographicServiceAuthenticationFactory encryptionAuthenticationFactory = cryptographicServiceAuthenticationFactory;
             if(encryptionAuthenticationFactory != null && request != null && request.optHttpServletRequest() != null) {
                 authentication = encryptionAuthenticationFactory.createAuthenticationFrom(request.optHttpServletRequest());
             }
 
             //Creating file access with crypto functionalities
-            CryptographicAwareIDBasedFileAccessFactory encryptionAwareFileAccessFactory = ServiceLookupRegistry.get().getService(CryptographicAwareIDBasedFileAccessFactory.class);
+            CryptographicAwareIDBasedFileAccessFactory encryptionAwareFileAccessFactory = cryptographicAwareIDBasedFileAccessFactory;
             if (encryptionAwareFileAccessFactory != null) {
                 EnumSet<CryptographyMode> cryptMode = CryptographyMode.createSet(cryptoAction);
                 if (cryptMode.size() > 0) {
-                    return encryptionAwareFileAccessFactory.createAccess(ServiceLookupRegistry.get().getService(IDBasedFileAccessFactory.class).createAccess(session), cryptMode, session, authentication);
+                    return encryptionAwareFileAccessFactory.createAccess(idBasedFileAccessFactory.createAccess(session), cryptMode, session, authentication);
                 }
 
                 throw AjaxExceptionCodes.INVALID_PARAMETER_VALUE.create("cryptoAction",cryptoAction);
@@ -233,7 +240,7 @@ public abstract class DocumentRESTAction implements AJAXActionService {
             throw ServiceExceptionCode.SERVICE_UNAVAILABLE.create(CryptographicAwareIDBasedFileAccessFactory.class.getSimpleName());
         }
 
-        return ServiceLookupRegistry.get().getService(IDBasedFileAccessFactory.class).createAccess(session);
+        return idBasedFileAccessFactory.createAccess(session);
     }
 
     protected IDBasedFileAccess getFileAccess(ServerSession session, AJAXRequestData request) throws OXException {
@@ -269,7 +276,6 @@ public abstract class DocumentRESTAction implements AJAXActionService {
      */
     protected JSONObject getJSONObjectFromServerSession(final ServerSession session)
     {
-    	SessionService sessionService = ServiceLookupRegistryService.getInstance().getService(SessionService.class);
         JSONObject jsonSession = new JSONObject();
 
         try
