@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,26 +51,25 @@ package com.openexchange.office.rest;
 
 import org.json.JSONArray;
 import org.json.JSONObject;
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.web.bind.annotation.RestController;
 
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.exception.OXException;
-import com.openexchange.office.tools.config.UserConfigurationHelper;
-import com.openexchange.office.tools.config.UserConfigurationHelper.Mode;
-import com.openexchange.office.tools.session.FakeSession;
+import com.openexchange.office.tools.common.session.FakeSession;
+import com.openexchange.office.tools.service.config.UserConfigurationFactory;
+import com.openexchange.office.tools.service.config.UserConfigurationHelper;
+import com.openexchange.office.tools.service.config.UserConfigurationHelper.Mode;
 import com.openexchange.session.Session;
 import com.openexchange.tools.session.ServerSession;
 
+@RestController
 public class GetContextTemplateFoldersAction extends DocumentRESTAction {
 
-    /**
-     * Initializes a new {@link GetTemplateListAction}.
-     * @param services
-     */
-    public GetContextTemplateFoldersAction() {
-        super();
-    }
-
+	@Autowired
+	private UserConfigurationFactory userConfigFactory;
+	
     /* (non-Javadoc)
      * @see com.openexchange.ajax.requesthandler.AJAXActionService#perform(com.openexchange.ajax.requesthandler.AJAXRequestData, com.openexchange.tools.session.ServerSession)
      */
@@ -81,7 +80,7 @@ public class GetContextTemplateFoldersAction extends DocumentRESTAction {
 
         if ((null != request) && (null != session)) {
             Session fakeSession = new FakeSession(session.getContext().getMailadmin(), session);
-            UserConfigurationHelper userConfHelper = new UserConfigurationHelper(fakeSession, "io.ox/office", Mode.WRITE_BACK);
+            UserConfigurationHelper userConfHelper = userConfigFactory.create(fakeSession, "io.ox/office", Mode.WRITE_BACK);
             final JSONArray array = userConfHelper.getJSONArray("ContextTemplateFolders");
             if (null != array){
                 jsonObj = array;
