@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,16 +49,17 @@
 
 package com.openexchange.office.rest;
 
-import org.apache.commons.logging.Log;
 import org.json.JSONException;
 import org.json.JSONObject;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.web.bind.annotation.RestController;
 
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.documentconverter.IDocumentConverter;
 import com.openexchange.exception.OXException;
-import com.openexchange.log.LogFactory;
-import com.openexchange.office.tools.osgi.ServiceLookupRegistry;
 import com.openexchange.tools.session.ServerSession;
 
 
@@ -67,19 +68,14 @@ import com.openexchange.tools.session.ServerSession;
  *
  * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
  */
-@SuppressWarnings("deprecation")
+@RestController
 public class GetFeaturesAction extends DocumentRESTAction {
 
-	private static final Log LOG = LogFactory.getLog(GetFeaturesAction.class);
-
-    /**
-     * Initializes a new {@link GetFeaturesAction}.
-     * @param services
-     */
-    public GetFeaturesAction() {
-        super();
-    }
+	private static final Logger LOG = LoggerFactory.getLogger(GetFeaturesAction.class);
 
+	@Autowired(required=false)
+    private IDocumentConverter documentConverter;
+	
     /* (non-Javadoc)
      * @see com.openexchange.ajax.requesthandler.AJAXActionService#perform(com.openexchange.ajax.requesthandler.AJAXRequestData, com.openexchange.tools.session.ServerSession)
      */
@@ -89,9 +85,6 @@ public class GetFeaturesAction extends DocumentRESTAction {
         final StringBuilder featureBuilder = new StringBuilder();
         final JSONObject resultObj = new JSONObject(1);
 
-        // check for existence of documentconverter
-        final IDocumentConverter documentConverter = ServiceLookupRegistry.get().getService(IDocumentConverter.class);
-
         if (null != documentConverter) {
             featureBuilder.append("documentconverter");
         }
