@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -64,6 +64,7 @@ import java.util.Iterator;
 import java.util.LinkedHashMap;
 import java.util.LinkedHashSet;
 import java.util.Map;
+import java.util.Optional;
 import java.util.Set;
 import java.util.Timer;
 import java.util.TimerTask;
@@ -83,28 +84,34 @@ import org.apache.commons.lang3.ArrayUtils;
 import org.apache.commons.lang3.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+import org.springframework.beans.factory.InitializingBean;
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.web.bind.annotation.RestController;
 import com.google.common.base.Throwables;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.ajax.requesthandler.DispatcherNotes;
 import com.openexchange.annotation.NonNull;
 import com.openexchange.config.ConfigurationService;
+import com.openexchange.configuration.ServerConfig;
 import com.openexchange.documentconverter.IDocumentConverter;
 import com.openexchange.documentconverter.Properties;
 import com.openexchange.exception.ExceptionUtils;
 import com.openexchange.exception.OXException;
 import com.openexchange.imageconverter.api.ElementLock.LockMode;
 import com.openexchange.imageconverter.api.ElementLocker;
-import com.openexchange.office.document.DocFileHelper;
+import com.openexchange.office.datasource.access.DataSourceAccess;
+import com.openexchange.office.datasource.access.DataSourceAccessFactory;
+import com.openexchange.office.datasource.access.DataSourceException;
+import com.openexchange.office.datasource.access.MetaData;
+import com.openexchange.office.document.tools.DocFileHelper;
 import com.openexchange.office.imagemgr.IResourceManager;
+import com.openexchange.office.imagemgr.IResourceManagerFactory;
 import com.openexchange.office.imagemgr.Resource;
-import com.openexchange.office.rest.tools.EncryptionInfo;
-import com.openexchange.office.session.SessionService;
-import com.openexchange.office.tools.doc.StreamInfo;
-import com.openexchange.office.tools.files.FileHelper;
-import com.openexchange.office.tools.files.StorageHelper;
-import com.openexchange.office.tools.osgi.ServiceLookupRegistry;
-import com.openexchange.office.tools.user.AuthorizationCache;
+import com.openexchange.office.imagemgr.ResourceFactory;
+import com.openexchange.office.tools.common.files.FileHelper;
+import com.openexchange.office.tools.common.string.StringHelper;
+import com.openexchange.office.tools.common.user.AuthorizationCache;
 import com.openexchange.tools.session.ServerSession;
 
 /**
@@ -112,6 +119,7 @@ import com.openexchange.tools.session.ServerSession;
  *
  * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
  */
+@SuppressWarnings("rawtypes")
 /*
  * MH/KA compile fix for buildsystem
  *
@@ -143,7 +151,8 @@ import com.openexchange.tools.session.ServerSession;
  * the case of EMF, WMF and SVM graphic file formats)
  */
 @DispatcherNotes(defaultFormat = "file", allowPublicSession = true)
-public class GetFileAction extends DocumentRESTAction {
+@RestController
+public class GetFileAction extends DocumentRESTAction implements InitializingBean {
     /**
      * {@link Cache}
      *
@@ -163,7 +172,7 @@ public class GetFileAction extends DocumentRESTAction {
         final private static long CLEAR_ALL_ENTRIES = 0L;
 
         /**
-         * use AES encyption
+         * LOG
          */
         final private static String ENCRYPTION_ALGORITHM = "AES";
 
@@ -251,7 +260,6 @@ public class GetFileAction extends DocumentRESTAction {
 
                         if ((null != uidResourceName) && uidResourceName.startsWith(Resource.RESOURCE_UID_PREFIX) &&
                             (uidResourceName.length() > Resource.RESOURCE_UID_PREFIX.length())) {
-
                             for (final String curEntryName : m_entryNames) {
                                 if (curEntryName.contains(uidResourceName)) {
                                     // use first entry whose uid fragment is contained in entry name
@@ -299,6 +307,9 @@ public class GetFileAction extends DocumentRESTAction {
              */
             void implExtractResources(@NonNull InputStream documentStm) throws Exception {
                 try (final ZipInputStream zipInputStm = new ZipInputStream(documentStm)) {
+                    final String canonicalEntryDirPath = m_entryDir.getCanonicalPath();
+                    boolean suspiciousPathFound = false;
+
                     for (ZipEntry zipEntry = null; null != (zipEntry = zipInputStm.getNextEntry());) {
                         try {
                             final String curEntryName = zipEntry.getName();
@@ -318,18 +329,25 @@ public class GetFileAction extends DocumentRESTAction {
 
                                     // extract image to cache entry dir as encrypted file
                                     if (IMAGE_EXTENSION_TO_MIMETYPE_MAP.containsKey(fileExtension)) {
-                                        // write to encrypted file with defined encryption cipher
-                                        try (OutputStream outputStm = new CipherOutputStream(
-                                            FileUtils.openOutputStream(
-                                                new File(m_entryDir, curEntryName)), m_encryptCipher)) {
+                                        final File outputFile = new File(m_entryDir, curEntryName);
+                                        final String canonicalOutputPath = outputFile.getCanonicalPath();
 
-                                            // !!! use IOUtils.copy in order to leave the zip input stream open !!!
-                                            IOUtils.copy(zipInputStm, outputStm);
+                                        if (canonicalOutputPath.startsWith(canonicalEntryDirPath)) {
+                                            // write to encrypted file with defined encryption cipher
+                                            try (OutputStream outputStm = new CipherOutputStream(
+                                                    FileUtils.openOutputStream(outputFile), m_encryptCipher)) {
+
+                                                // !!! use IOUtils.copy in order to leave the zip input stream open !!!
+                                                IOUtils.copy(zipInputStm, outputStm);
+                                            }
+
+                                            // store entry names to be able to search for resources,
+                                            // specified by uid fragment only when retrieving files
+                                            m_entryNames.add(curEntryName);
+                                        } else if (!suspiciousPathFound) {
+                                            suspiciousPathFound = true;
+                                            log.warn("GetFile cache detected suspicious document with entries having a relative path pointing outside of archive root, ignored");
                                         }
-
-                                        // store entry names to be able to search for resources,
-                                        // specified by uid fragment only when retrieving files
-                                        m_entryNames.add(curEntryName);
                                     }
                                 } catch (IOException e) {
                                     log.error("GetFile cache exception caught while extracting image entry from document stream: " + curEntryName, e);
@@ -610,25 +628,20 @@ public class GetFileAction extends DocumentRESTAction {
     }
 
     /**
-     * Initializes a new {@link GetFileAction}.
-     * @param resMgr
-     * @param sessionService
+     *
      */
-    public GetFileAction(final IResourceManager resMgr, final SessionService sessionService) {
-        super();
-
-        this.resourceManager = resMgr;
-        this.documentConverter = ServiceLookupRegistry.get().getService(IDocumentConverter.class);
-        this.configurationService = ServiceLookupRegistry.get().getService(ConfigurationService.class);
+    @Override
+	public void afterPropertiesSet() throws Exception {
+		resourceManager = resourceManagerFactory.createInstance(GetFileAction.class.getCanonicalName());
 
 		try {
 		    // create Cache instance to speedup GetFile requests for a document
-		    final long cacheTimeoutMillis = (null != this.configurationService) ?
-		        this.configurationService.getIntProperty("com.openexchange.office.cache.getFile.timeout", 120000) :
+		    final long cacheTimeoutMillis = (null != configService) ?
+		        configService.getIntProperty("com.openexchange.office.cache.getFile.timeout", 120000) :
 		            120000;
 
 		    if (cacheTimeoutMillis > 0) {
-		        this.cache = new Cache(new File(this.configurationService.getProperty("UPLOAD_DIRECTORY", "/tmp/")), cacheTimeoutMillis);
+		        cache = new Cache(ServerConfig.getTmpDir(), cacheTimeoutMillis);
 		        log.info("AjaxRequest GetFileAction cache is enabled with a timeout of {}ms", cacheTimeoutMillis);
 		    } else {
                 log.info("AjaxRequest GetFileAction cache is disabled");
@@ -636,8 +649,7 @@ public class GetFileAction extends DocumentRESTAction {
 		} catch (Exception e) {
             log.error("AjaxRequest GetFileAction exception caught while creating cache => disabling cache)", e);
 		}
-    }
-
+	}
 
     /*
      * (non-Javadoc)
@@ -650,24 +662,36 @@ public class GetFileAction extends DocumentRESTAction {
         AJAXRequestResult requestResult = null;
         String resourceName = request.getParameter("get_filename");
         String getFormat = request.getParameter("get_format");
-        final String fileId = request.getParameter("id");
+        final String id = request.getParameter("id");
         final String folderId = request.getParameter("folder_id");
         final String versionOrAttachment = request.getParameter("version");
         final String source = request.getParameter("source");
 
         // check fileId/folderId
-        if (isEmpty(fileId) || isEmpty(folderId)) {
+        if (isEmpty(id) || isEmpty(folderId)) {
             requestResult = new AJAXRequestResult();
             requestResult.setHttpStatusCode(400);
 
-            log.error("AjaxRequest GetFileAction: for source {} and id {} / folderId {} / version {} not valid: ", source, fileId, folderId, versionOrAttachment);
+            log.error("AjaxRequest GetFileAction: for source {} and id {} / folderId {} / version {} not valid: ", source, id, folderId, versionOrAttachment);
             return requestResult;
         }
 
+        DataSourceAccess dataSourceAccess = null;
+
         int userId = Integer.MIN_VALUE;
         // retrieve user id and create data source access
         try {
-            userId = session.getUserId();
+            userId = sessionService.getUserId(session);
+
+            dataSourceAccess = dataSourceAccessFactory.createDataSourceAccess(session, source);
+        } catch (DataSourceException e) {
+            final String errMsg = StringHelper.replacePlaceholdersWithArgs("AjaxRequest GetFileAction DataSourceException caught trying to create data source access for data source {}, folder {}, id {}, versionOrAttachment {}",
+                source, folderId, id, versionOrAttachment);
+            log.error(errMsg, e);
+
+            final AJAXRequestResult result = new AJAXRequestResult();
+            result.setHttpStatusCode(400);
+            return result;
         } catch (Exception e) {
             log.error("AjaxRequest GetFileAction exception caught while trying to get user id", e);
 
@@ -677,11 +701,19 @@ public class GetFileAction extends DocumentRESTAction {
         }
 
         // check read access rights
-        if (Integer.MIN_VALUE == userId) {
+        try {
+            if ((Integer.MIN_VALUE == userId) || !dataSourceAccess.canRead(folderId, id, versionOrAttachment)) {
+                final AJAXRequestResult result = new AJAXRequestResult();
+                result.setHttpStatusCode(403);
+
+                log.error("AjaxRequest GetFileAction error while checking file access rights");
+                return result;
+            }
+        } catch (DataSourceException e) {
             final AJAXRequestResult result = new AJAXRequestResult();
             result.setHttpStatusCode(403);
 
-            log.error("AjaxRequest GetFileAction error while checking file access rights");
+            log.error("AjaxRequest GetFileAction error while checking file access rights", e);
             return result;
         }
 
@@ -697,24 +729,24 @@ public class GetFileAction extends DocumentRESTAction {
             resourceName = resourceName.substring(2);
         }
 
-        String fileName = FileHelper.getBaseName(resourceName);
+        String filename = FileHelper.getBaseName(resourceName);
 
-        log.debug("AjaxRequest GetFileAction request for " + fileName);
+        log.debug("AjaxRequest GetFileAction request for " + filename);
 
         if (!"json".equals(getFormat)) {
             getFormat = "file";
         }
 
-        boolean fileNameStartWithXID = fileName.startsWith(Resource.RESOURCE_UID_PREFIX);
+        boolean fileNameStartWithXID = filename.startsWith(Resource.RESOURCE_UID_PREFIX);
 
         // try to get the graphic from the resource manager(s) first
         if (fileNameStartWithXID) {
             // 1. try: resource is already contained within this nodes resource manager
-            final String uid = Resource.getUIDFromResourceName(fileName);
+            final String uid = Resource.getUIDFromResourceName(filename);
             final Resource nodeResource = resourceManager.getResource(uid);
             byte[] resdata = ((nodeResource != null) ? nodeResource.getBuffer() : null);
 
-            log.trace("AjaxRequest GetFileAction " + fileName + " not found in resourceManager");
+            log.trace("AjaxRequest GetFileAction " + filename + " not found in resourceManager");
 
             // 2. try: create a managed resource with the given uid
             if (null == resdata) {
@@ -722,7 +754,7 @@ public class GetFileAction extends DocumentRESTAction {
                     final String managedId = Resource.getManagedIdFromUID(uid);
 
                     if ((null != managedId) && (managedId.length() > 0)) {
-                        final Resource managedResource = Resource.createFrom(null, managedId);
+                        final Resource managedResource = resourceFactory.create(managedId);
 
                         // add a new managed resource to this nodes resource manager for later speedup
                         // if we have data with content, otherwise we fall-back to read the doc stream
@@ -749,39 +781,28 @@ public class GetFileAction extends DocumentRESTAction {
 
         // 3. try getting the graphic from the Cache (preferred) or the document's zip archive itself
         if (null == requestResult) {
-            final String authCode = AuthorizationCache.getKey("" + session.getContextId(), "" + session.getUserId(), fileId);
-            final String encryptionInfo = (null != authCode) ? EncryptionInfo.createEncryptionInfo(session, authCode) : "";
+            final String authCode = AuthorizationCache.getKey(""+session.getContextId(), ""+session.getUserId(), id);
+            final Optional<String> authCodeData = (null != authCode) ? Optional.of(authCode) : Optional.empty();
             final String widthParam = request.getParameter("width");
             final String heightParam = request.getParameter("height");
             final Dimension imageExtents = getImageExtents(widthParam, heightParam);
-            final StorageHelper storageHelper = new StorageHelper(session, folderId);
             final String[] mimeType = { "" };
-            final String documentId = new StringBuilder(256).
-                append("MetaData [folderId=").
-                append(folderId).
-                append(", id=").
-                append(fileId).
-                append(", versionOrAttachment=").
-                append(versionOrAttachment).
-                append(", fileName=").
-                append(fileName).
-                append(", source=").
-                append(source).
-                append("]").toString();
+            String documentId = null;
 
-            // always use the current version of the document
-            request.putParameter("version", "0");
+            // get documentId from metadata
+            try {
+                final MetaData metaData = dataSourceAccess.getMetaData(folderId, id, versionOrAttachment, authCodeData);
+                documentId = (null != metaData) ? metaData.toString() : null;
+            } catch (Exception e) {
+                log.trace("AjaxRequest GetFileAction could not get metadata " + filename, e);
+            }
 
-            // 3.1 try to get result from cache or add to/retrieve from cache afterwards
+            // 3.1 trying to retrieve the result from the Cache first
             if ((null != cache) && (null != documentId) && cache.lock(documentId)) {
                 try {
                     if (!cache.hasEntry(documentId)) {
-                        try (final StreamInfo streamInfo = DocFileHelper.getDocumentStream(null, session, request, storageHelper, encryptionInfo);
-                            final InputStream documentStm = streamInfo.getDocumentStream()) {
-
-                            if (null != documentStm) {
-                                cache.addEntry(documentId, documentStm);
-                            }
+                        try (final InputStream documentStm = dataSourceAccess.getContentStream(folderId, id, versionOrAttachment, authCodeData)) {
+                            cache.addEntry(documentId, documentStm);
                         }
                     }
 
@@ -793,14 +814,14 @@ public class GetFileAction extends DocumentRESTAction {
                             resourceManager.addResource(resourceBuffer);
                         }
 
-                        requestResult = createFileRequestResult(request, resourceBuffer, getFormat, mimeType[0], fileName);
+                        requestResult = createFileRequestResult(request, resourceBuffer, getFormat, mimeType[0], filename);
 
-                        log.trace("AjaxRequest GetFileAction " + fileName + " successfully retrieved from cache");
+                        log.trace("AjaxRequest GetFileAction {} successfully retrieved from cache", filename);
                     } else {
-                        log.warn("AjaxRequest GetFileAction " + fileName + " not able to be retrieved from cache");
+                        log.warn("AjaxRequest GetFileAction {} not able to be retrieved from cache", filename);
                     }
-                } catch (IOException e) {
-                    log.trace("AjaxRequest GetFileAction could not access file via GetFile cache " + fileName, e);
+                } catch (Exception e) {
+                    log.trace("AjaxRequest GetFileAction could not access file via GetFile cache " + filename, e);
                 } finally {
                     cache.unlock(documentId);
                 }
@@ -810,11 +831,10 @@ public class GetFileAction extends DocumentRESTAction {
             if (null == requestResult) {
                 log.trace("AjaxRequest GetFileAction image must be retrieved from document stream");
 
-                try (final StreamInfo streamInfo = DocFileHelper.getDocumentStream(null, session, request, storageHelper, encryptionInfo);
-                    final InputStream documentStm = streamInfo.getDocumentStream()) {
+                try (final InputStream documentStm = dataSourceAccess.getContentStream(folderId, id, versionOrAttachment, authCodeData)) {
 
                     if (null != documentStm) {
-                        log.trace("AjaxRequest GetFileAction document stream successfully retrieved - try to get substream for " + fileName);
+                        log.trace("AjaxRequest GetFileAction document stream successfully retrieved - try to get substream for " + filename);
 
                         try (final InputStream resultStm = getZipEntryStream(documentStm, session, resourceName, imageExtents, mimeType)) {
                             if (null != resultStm) {
@@ -826,15 +846,17 @@ public class GetFileAction extends DocumentRESTAction {
                                         resourceManager.addResource(buffer);
                                     }
 
-                                    requestResult = createFileRequestResult(request, buffer, getFormat, mimeType[0], fileName);
+                                    requestResult = createFileRequestResult(request, buffer, getFormat, mimeType[0], filename);
 
-                                    log.trace("AjaxRequest GetFileAction " + fileName + " successfully retrieved");
+                                    log.trace("AjaxRequest GetFileAction " + filename + " successfully retrieved");
                                 } else {
-                                    log.warn("AjaxRequest GetFileAction " + fileName + " not found");
+                                    log.warn("AjaxRequest GetFileAction " + filename + " not found");
                                 }
                             }
                         }
                     }
+                } catch (DataSourceException e) {
+                    log.error("AjaxRequest GetFileAction exception caught trying to retrieving image data from document stream", e);
                 } catch (IOException e) {
                     log.error("AjaxRequest GetFileAction I/O exception caught while reading data from document stream", e);
                 }
@@ -842,10 +864,11 @@ public class GetFileAction extends DocumentRESTAction {
         }
 
         if (null == requestResult) {
-            log.warn("AjaxRequest: GetFileAction request not successfully processed for resource: " + ((null == resourceName) ? "unknown resource name" : resourceName) + " in: " + fileName);
+            log.warn("AjaxRequest: GetFileAction request not successfully processed for resource: " + ((null == resourceName) ? "unknown resource name" : resourceName) + " in: " + filename);
 
             request.setFormat("json");
             requestResult = new AJAXRequestResult();
+            requestResult.setHttpStatusCode(404);
         }
 
         return requestResult;
@@ -1040,17 +1063,31 @@ public class GetFileAction extends DocumentRESTAction {
 
     // - Members ---------------------------------------------------------------
 
-    final private IResourceManager resourceManager;
+    @Autowired
+    private ConfigurationService configService = null;
 
-    final private ConfigurationService configurationService;
+    @Autowired
+    private IResourceManagerFactory resourceManagerFactory = null;
 
-    final private IDocumentConverter documentConverter;
+    @Autowired
+    private DataSourceAccessFactory dataSourceAccessFactory;
+
+    @Autowired(required=false)
+    private IDocumentConverter documentConverter;
+
+    @Autowired
+    private ResourceFactory resourceFactory;
+
+    private IResourceManager resourceManager = null;
 
     private Cache cache = null;
 
-    // - Static members --------------------------------------------------------
+    // - Static members -------------------------------------------------------.
 
-    protected final static Logger log = LoggerFactory.getLogger(GetFileAction.class);
+    /**
+     * log
+     */
+    final private static Logger log = LoggerFactory.getLogger(GetFileAction.class);
 
     /**
      * IMAGE_EXTENSION_TO_MIMETYPE_MAP
