@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,6 +53,7 @@ import java.util.Date;
 import java.util.HashMap;
 import java.util.List;
 import java.util.ListIterator;
+import java.util.Map;
 
 import org.apache.commons.lang3.StringUtils;
 import org.json.JSONArray;
@@ -60,6 +61,9 @@ import org.json.JSONException;
 import org.json.JSONObject;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+import org.springframework.beans.factory.InitializingBean;
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.web.bind.annotation.RestController;
 
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
@@ -67,43 +71,52 @@ import com.openexchange.exception.OXException;
 import com.openexchange.file.storage.File;
 import com.openexchange.file.storage.File.Field;
 import com.openexchange.file.storage.FileStorageFileAccess;
-import com.openexchange.file.storage.FileStorageFolder;
 import com.openexchange.file.storage.composition.IDBasedFileAccess;
 import com.openexchange.file.storage.composition.IDBasedFileAccessFactory;
 import com.openexchange.file.storage.composition.IDBasedFolderAccess;
 import com.openexchange.file.storage.composition.IDBasedFolderAccessFactory;
 import com.openexchange.groupware.results.TimedResult;
-import com.openexchange.office.document.TemplateFilesScanner;
+import com.openexchange.office.document.api.TemplateFilesScanner;
+import com.openexchange.office.document.api.TemplateFilesScannerFactory;
+import com.openexchange.office.document.api.TemplateFilesScannerFactory.TemplateFilterType;
+import com.openexchange.office.recentfilelist.RecentFileListManager;
+import com.openexchange.office.recentfilelist.RecentFileListManagerFactory;
+import com.openexchange.office.tools.common.error.ErrorCode;
+import com.openexchange.office.tools.common.files.FileDescriptorHelper;
 import com.openexchange.office.tools.doc.ApplicationType;
-import com.openexchange.office.tools.doc.RecentFileListManager;
-import com.openexchange.office.tools.error.ErrorCode;
-import com.openexchange.office.tools.files.FileDescriptorHelper;
-import com.openexchange.office.tools.files.FolderHelper;
-import com.openexchange.office.tools.osgi.ServiceLookupRegistry;
+import com.openexchange.office.tools.service.files.FolderHelperService;
+import com.openexchange.office.tools.service.files.FolderHelperServiceFactory;
+import com.openexchange.session.Session;
 import com.openexchange.tools.filename.FileNameTools;
 import com.openexchange.tools.iterator.SearchIterator;
 import com.openexchange.tools.session.ServerSession;
 
-public class GetTemplateAndRecentListAction extends DocumentRESTAction {
+@RestController
+public class GetTemplateAndRecentListAction extends DocumentRESTAction implements InitializingBean {
     private static final Logger LOG = LoggerFactory.getLogger(GetTemplateAndRecentListAction.class);
     private static final String UNKNOWN = "unknown";
 
-    private final TemplateFilesScanner m_templateFilesScanner;
-    private final IDBasedFileAccessFactory m_fileFactory;
-    private final IDBasedFolderAccessFactory m_folderFactory;
-    private final List<Field> m_fields;
+    @Autowired
+    private TemplateFilesScannerFactory m_TemplateFilesScannerFactory;
+    
+    @Autowired
+    private IDBasedFileAccessFactory m_fileFactory;
+    
+    @Autowired
+    private IDBasedFolderAccessFactory m_folderFactory;
+    
+    @Autowired
+    private RecentFileListManagerFactory recentFileListManagerFactory;
+    
+    @Autowired
+    private FolderHelperServiceFactory folderHelperServiceFactory;
+    
+    private TemplateFilesScanner templateFilesScanner;
+    private List<Field> m_fields;
     private final String[] m_props = { "filename", "last_modified", "title" };
 
-    /**
-     * Initializes a new {@link GetTemplateAndRecentListAction}.
-     * @param services
-     */
-    public GetTemplateAndRecentListAction(final TemplateFilesScanner templateFilesScanner) {
-        super();
-
-        m_templateFilesScanner = templateFilesScanner;
-        m_fileFactory = ServiceLookupRegistry.get().getService(IDBasedFileAccessFactory.class);
-        m_folderFactory = ServiceLookupRegistry.get().getService(IDBasedFolderAccessFactory.class);
+	@Override
+	public void afterPropertiesSet() throws Exception {
         m_fields = new ArrayList<>(5);
         // initialize fields array with good to know fields
         m_fields.add(Field.ID);
@@ -111,7 +124,8 @@ public class GetTemplateAndRecentListAction extends DocumentRESTAction {
         m_fields.add(Field.FILENAME);
         m_fields.add(Field.LAST_MODIFIED);
         m_fields.add(Field.TITLE);
-    }
+        templateFilesScanner = m_TemplateFilesScannerFactory.create(TemplateFilterType.ALL_DOCUMENTS);
+	}
 
 	@Override
 	public AJAXRequestResult perform(AJAXRequestData requestData, ServerSession session) {
@@ -123,11 +137,11 @@ public class GetTemplateAndRecentListAction extends DocumentRESTAction {
 
         if ((null != session) && (appType != ApplicationType.APP_NONE)) {
         	try {
-        	    ErrorCode errorCode = m_templateFilesScanner.searchForTemplates(session, type, templates);
+        	    ErrorCode errorCode = templateFilesScanner.searchForTemplates(session, type, templates);
                 jsonObj.put("error", errorCode.getAsJSON());
                 jsonObj.put("templates", templates);
 
-                final RecentFileListManager recentFileListManager = new RecentFileListManager(null, session);
+                final RecentFileListManager recentFileListManager = recentFileListManagerFactory.create(session);
                 final List<JSONObject> appRecentFiles = recentFileListManager.readRecentFileList(appType);
                 if ((null != appRecentFiles) && (!appRecentFiles.isEmpty())) {
                     // now we have to check the recents list to be up to date
@@ -146,7 +160,7 @@ public class GetTemplateAndRecentListAction extends DocumentRESTAction {
                             }
                         }
 
-                        HashMap<String, JSONObject> newMetaDataMap = null;
+                        Map<String, JSONObject> newMetaDataMap = null;
                         try {
                             newMetaDataMap = getMetaDataForFiles(fileAccess, ids);
                         } catch (Exception e) {
@@ -156,9 +170,9 @@ public class GetTemplateAndRecentListAction extends DocumentRESTAction {
                             newMetaDataMap = getMetaDataForFileList(fileAccess, ids);
                         }
                         if (null != newMetaDataMap) {
-                            final HashMap<String, Boolean> removedIds = new HashMap<String, Boolean>();
+                            final Map<String, Boolean> removedIds = new HashMap<String, Boolean>();
 
-                            boolean recentListChanged = checkRecentListWithMetaData(folderAccess, appRecentFiles, newMetaDataMap, removedIds);
+                            boolean recentListChanged = checkRecentListWithMetaData(session, appRecentFiles, newMetaDataMap, removedIds);
                             if (recentListChanged && (removedIds.size() > 0)) {
                                 // remove recent entries which were moved to trash or deleted
                                 ListIterator<JSONObject> recentsIter = appRecentFiles.listIterator();
@@ -215,7 +229,9 @@ public class GetTemplateAndRecentListAction extends DocumentRESTAction {
      *
      * @throws JSONException
      */
-	private boolean checkRecentListWithMetaData(IDBasedFolderAccess folderAccess, List<JSONObject> appRecentFiles, HashMap<String, JSONObject> newMetaDataMap, HashMap<String, Boolean> removedIds) throws OXException, JSONException {
+	private boolean checkRecentListWithMetaData(Session session, List<JSONObject> appRecentFiles, Map<String, JSONObject> newMetaDataMap, Map<String, Boolean> removedIds) throws OXException, JSONException {
+		final FolderHelperService folderHelperService = folderHelperServiceFactory.create(session);
+
         // Use new meta data to update recent files - there are some situations
 	    // where we have to dig deeper to find out what happened. We want to
 	    // support to still open files that have been moved to other folders -
@@ -239,10 +255,9 @@ public class GetTemplateAndRecentListAction extends DocumentRESTAction {
                     JSONObject newFileMetaData = newMetaDataMap.get(id);
                     if (null != newFileMetaData) {
                         String newFolderId = newFileMetaData.optString("folder_id");
-                        FileStorageFolder folder = folderAccess.getFolder(newFolderId);
                         if (folderId.equals(newFolderId)) {
                             // check if the parent folder was moved to the trash
-                            if (FolderHelper.isFolderTrashOrInTrash(folder)) {
+                            if (folderHelperService.isFolderTrashOrInTrash(newFolderId)) {
                                 removedIds.put(id, true);
                                 recentListChanged = true;
                             } else if (FileDescriptorHelper.containsChanges(fileObj, newFileMetaData, m_props)) {
@@ -257,7 +272,7 @@ public class GetTemplateAndRecentListAction extends DocumentRESTAction {
                             }
                         } else {
                             // We have a move - check if the new folder is the trash folder
-                            if (FolderHelper.isFolderTrashOrInTrash(folder)) {
+                            if (folderHelperService.isFolderTrashOrInTrash(newFolderId)) {
                                 // file has been moved to the trash => remove from recent files
                                 removedIds.put(id, true);
                                 recentListChanged = true;
@@ -319,7 +334,7 @@ public class GetTemplateAndRecentListAction extends DocumentRESTAction {
 	 * @throws OXException
 	 * @throws JSONException
 	 */
-	private HashMap<String, JSONObject> getMetaDataForFiles(IDBasedFileAccess fileAccess, List<String> ids) throws OXException, JSONException {
+	private Map<String, JSONObject> getMetaDataForFiles(IDBasedFileAccess fileAccess, List<String> ids) throws OXException, JSONException {
 	    HashMap<String, JSONObject> newMetaDataMap = null;
         // now check the meta data of the files using file access
         TimedResult<File> fileResult = fileAccess.getDocuments(ids, m_fields);
@@ -356,7 +371,7 @@ public class GetTemplateAndRecentListAction extends DocumentRESTAction {
 	 *  A mapping of id to File which provides access to the file meta data,
 	 *  can be null if no meta data can be retrieved.
 	 */
-	private HashMap<String, JSONObject> getMetaDataForFileList(IDBasedFileAccess fileAccess, List<String> ids) {
+	private Map<String, JSONObject> getMetaDataForFileList(IDBasedFileAccess fileAccess, List<String> ids) {
         HashMap<String, JSONObject> newMetaDataMap = null;
         // now check the meta data of the files using file access
         // use the slower single access to filter out problematic files
