@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,18 +49,24 @@
 
 package com.openexchange.office.rest;
 
-import org.apache.commons.logging.Log;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import org.springframework.beans.factory.InitializingBean;
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.web.bind.annotation.RestController;
 
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.exception.OXException;
-import com.openexchange.office.document.TemplateFilesScanner;
-import com.openexchange.office.rest.tools.ParamValidator;
-import com.openexchange.office.tools.error.ErrorCode;
-import com.openexchange.office.tools.error.HttpStatusCode;
+import com.openexchange.office.document.api.TemplateFilesScanner;
+import com.openexchange.office.document.api.TemplateFilesScannerFactory;
+import com.openexchange.office.document.api.TemplateFilesScannerFactory.TemplateFilterType;
+import com.openexchange.office.rest.tools.ParamValidatorService;
+import com.openexchange.office.tools.common.error.ErrorCode;
+import com.openexchange.office.tools.common.error.HttpStatusCode;
 import com.openexchange.tools.session.ServerSession;
 
 /**
@@ -68,31 +74,29 @@ import com.openexchange.tools.session.ServerSession;
  *
  * @author <a href="mailto:carsten.driesner@open-xchange.com">Carsten Driesner</a>
  */
-public class GetTemplateListAction extends DocumentRESTAction {
-    @SuppressWarnings("deprecation")
-	private static final Log LOG = com.openexchange.log.Log.loggerFor(GetTemplateListAction.class);
+@RestController
+public class GetTemplateListAction extends DocumentRESTAction implements InitializingBean {
+	private static final Logger LOG = LoggerFactory.getLogger(GetTemplateListAction.class);
 
     private final static String[] MANDATORY_PARAMS = { ParameterDefinitions.PARAM_TYPE };
+    
+    private TemplateFilesScanner templateFilesScanner;
+    
+    @Autowired
+    private TemplateFilesScannerFactory templateFilesScannerFactory;
 
-    private final TemplateFilesScanner m_templateFilesScanner;
+    @Override
+	public void afterPropertiesSet() throws Exception {
+    	templateFilesScanner = templateFilesScannerFactory.create(TemplateFilterType.ALL_DOCUMENTS);
+	}
 
-    /**
-     * Initializes a new {@link GetTemplateListAction}.
-     * @param services
-     */
-    public GetTemplateListAction(final TemplateFilesScanner templateFilesScanner) {
-        super();
-
-        m_templateFilesScanner = templateFilesScanner;
-    }
-
-    /* (non-Javadoc)
+	/* (non-Javadoc)
      * @see com.openexchange.ajax.requesthandler.AJAXActionService#perform(com.openexchange.ajax.requesthandler.AJAXRequestData, com.openexchange.tools.session.ServerSession)
      */
     @Override
     public AJAXRequestResult perform(AJAXRequestData requestData, ServerSession session) throws OXException {
-        if (!ParamValidator.areAllParamsNonEmpty(requestData, MANDATORY_PARAMS))
-            return ParamValidator.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
+        if (!paramValidatorService.areAllParamsNonEmpty(requestData, MANDATORY_PARAMS))
+            return ParamValidatorService.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
 
         final JSONObject jsonObj = new JSONObject();
         final String type = requestData.getParameter(ParameterDefinitions.PARAM_TYPE).toLowerCase();
@@ -100,7 +104,7 @@ public class GetTemplateListAction extends DocumentRESTAction {
         AJAXRequestResult requestResult = null;
 
         if (null != session) {
-        	ErrorCode errorCode = m_templateFilesScanner.searchForTemplates(session, type, templates);
+        	ErrorCode errorCode = templateFilesScanner.searchForTemplates(session, type, templates);
         	try {
                 jsonObj.put("error", errorCode.getAsJSON());
                 jsonObj.put("templates", templates);
