@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,34 +51,37 @@ package com.openexchange.office.rest;
 
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicReference;
+
 import org.apache.commons.lang3.BooleanUtils;
 import org.apache.commons.lang3.StringUtils;
-import org.apache.commons.logging.Log;
 import org.json.JSONException;
 import org.json.JSONObject;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.web.bind.annotation.RestController;
+
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.exception.OXException;
-import com.openexchange.office.tools.config.ConfigurationHelper;
+import com.openexchange.office.tools.service.config.ConfigurationHelper;
 import com.openexchange.tools.session.ServerSession;
 
-
+@RestController
 public class LogPerformanceDataAction extends DocumentRESTAction {
-    @SuppressWarnings("deprecation")
-    private static final Log LOG = com.openexchange.log.Log.loggerFor(LogPerformanceDataAction.class);
+    private static final Logger LOG = LoggerFactory.getLogger(LogPerformanceDataAction.class);
 
     private static AtomicReference<Boolean> logPerformanceDataEnabled = new AtomicReference<>(null);
     private static AtomicReference<String> logPerformanceDataPath = new AtomicReference<>(null);
 
+    @Autowired
     private LogPerformanceDataWriter aPerformanceDataWriter;
+    
+    @Autowired
+    private ConfigurationHelper configurationHelper;
+
     private AtomicBoolean aPerformanceDataWriterInit = new AtomicBoolean(false);
 
-    public LogPerformanceDataAction(final LogPerformanceDataWriter aDataWriter) {
-        super();
-
-        aPerformanceDataWriter = aDataWriter;
-    }
-
     @Override
     public AJAXRequestResult perform(AJAXRequestData requestData, ServerSession session) throws OXException {
         if ((null == session) || (session.isAnonymous())) {
@@ -95,10 +98,9 @@ public class LogPerformanceDataAction extends DocumentRESTAction {
 
         if (null == enabled) {
             try {
-                enabled = ConfigurationHelper.getBooleanOfficeConfigurationValue(null, session, "module/logPerformanceData", false);
+                enabled = configurationHelper.getBooleanOfficeConfigurationValue(session, "//module/logPerformanceData", false);
                 if (enabled) {
-                    loggingFilePath = ConfigurationHelper.getStringOfficeConfigurationValue(
-                                          null, session, "//module/performanceDataLogPath", null);
+                    loggingFilePath = configurationHelper.getStringOfficeConfigurationValue(session, "//module/performanceDataLogPath", null);
 
                     if (StringUtils.isNotEmpty(loggingFilePath)) {
                         logPerformanceDataPath.compareAndSet(null, loggingFilePath);
