@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,18 +53,17 @@ import java.io.BufferedWriter;
 import java.io.File;
 import java.io.FileOutputStream;
 import java.io.FileWriter;
-import java.text.DateFormat;
-import java.text.SimpleDateFormat;
-import java.util.Date;
-import java.util.TimeZone;
-import java.util.UUID;
-import com.openexchange.office.message.OperationHelper;
-import com.openexchange.office.tools.common.TimeZoneHelper;
+
 import org.apache.commons.lang3.StringUtils;
 import org.apache.commons.logging.Log;
 import org.json.JSONObject;
+import org.springframework.beans.factory.DisposableBean;
+import org.springframework.stereotype.Service;
 
-public class LogPerformanceDataWriter extends AsyncFileWriter<JSONObject> {
+import com.openexchange.office.message.OperationHelper;
+
+@Service
+public class LogPerformanceDataWriter extends AsyncFileWriter<JSONObject> implements DisposableBean {
     public static final long MAX_PERFORMANCE_LOG_FILESIZE  = 32 * 1024 * 1024; // 32 MB
 
     @SuppressWarnings("deprecation")
@@ -82,6 +81,11 @@ public class LogPerformanceDataWriter extends AsyncFileWriter<JSONObject> {
     }
 
     @Override
+	public void destroy() throws Exception {
+    	this.shutdown();
+	}
+
+	@Override
     public void init(String filePath) throws Exception {
         super.init(filePath);
 
@@ -100,8 +104,6 @@ public class LogPerformanceDataWriter extends AsyncFileWriter<JSONObject> {
      */
     @Override
     protected void writeData(JSONObject performanceData) {
-        String uid = UUID.randomUUID().toString().substring(0, 8); // only using 8 digits
-
         String app = performanceData.optString("application", "");
 
         // Saving performance data in log file
@@ -162,26 +164,4 @@ public class LogPerformanceDataWriter extends AsyncFileWriter<JSONObject> {
         }
     }
 
-    /**
-     * The current date in ISO 8601 format.
-     *
-     * @param useSeconds
-     *  Whether seconds shall be included into the result string or not.
-     *
-     * @return
-     *  The date as string in ISO 8601 format.
-     */
-    private static String getISODateFormat(Boolean useSeconds) {
-
-        TimeZone tz = TimeZoneHelper.getTimeZone("UTC");
-        DateFormat df = null;
-
-        if (useSeconds) {
-            df = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss'Z'");
-        } else {
-            df = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm':00Z'");
-        }
-        df.setTimeZone(tz);
-        return df.format(new Date());
-    }
 }
