@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,19 +51,22 @@ package com.openexchange.office.rest;
 public class ParameterDefinitions {
     private ParameterDefinitions() { /* nothing to do */ }
 
-    public final static String PARAM_AUTH_CODE          = "cryptoAuth";
-    public final static String PARAM_FILE_ID            = "id";
-    public final static String PARAM_FOLDER_ID          = "folder_id";
-    public final static String PARAM_REMOVE_FILE_ID     = "remove_file_id";
-    public final static String PARAM_SUB_ACTION         = "subaction";
-    public final static String PARAM_SUBACTION_CLOSE    = "close";
-    public final static String PARAM_SUBACTION_OPEN     = "open";
+    public final static String PARAM_ATTACHMENT = "attachment";
+    public final static String PARAM_AUTH_CODE = "cryptoAuth";
+    public final static String PARAM_FILE_ID = "id";
+    public final static String PARAM_FOLDER_ID = "folder_id";
+    public final static String PARAM_REMOVE_FILE_ID = "remove_file_id";
+    public final static String PARAM_SUB_ACTION = "subaction";
+    public final static String PARAM_SUBACTION_CLOSE = "close";
+    public final static String PARAM_SUBACTION_OPEN = "open";
     public final static String PARAM_SUBACTION_PREFETCH = "prefetch";
-    public final static String PARAM_TYPE               = "type";
-    public final static String PARAM_VERSION            = "version";
-    public final static String PARAM_FILENAME           = "filename";
-    public final static String PARAM_MIMETYPE           = "mimetype";
-    public final static String PARAM_CLIENTUID          = "client_uid";
-    public final static String PARAM_DOCUID             = "doc_uid";
+    public final static String PARAM_TYPE = "type";
+    public final static String PARAM_VERSION = "version";
+    public final static String PARAM_FILENAME = "filename";
+    public final static String PARAM_MIMETYPE = "mimetype";
+    public final static String PARAM_CLIENTUID = "client_uid";
+    public final static String PARAM_DOCUID = "doc_uid";
+    public final static String PARAM_SOURCE = "source";
+    public final static String PARAM_MODULE = "module";
 
 }
