@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,21 +50,23 @@
 package com.openexchange.office.rest;
 
 import org.apache.commons.lang3.StringUtils;
-import org.apache.commons.logging.Log;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.web.bind.annotation.RestController;
 
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.exception.OXException;
+import com.openexchange.office.backup.restore.IRestoreDocument;
 import com.openexchange.office.backup.restore.RestoreData;
-import com.openexchange.office.backup.restore.RestoreDocument;
-import com.openexchange.office.tools.error.HttpStatusCode;
-import com.openexchange.office.rest.tools.ParamValidator;
+import com.openexchange.office.rest.tools.ParamValidatorService;
 import com.openexchange.office.rest.tools.SessionIdCheck;
-import com.openexchange.office.tools.common.MissingParameter;
-import com.openexchange.office.tools.error.ErrorCode;
+import com.openexchange.office.tools.common.error.ErrorCode;
+import com.openexchange.office.tools.common.error.HttpStatusCode;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
 import com.openexchange.tools.session.ServerSession;
 
@@ -73,17 +75,13 @@ import com.openexchange.tools.session.ServerSession;
  *
  * @author <a href="mailto:carsten.driesner@open-xchange.com">Carsten Driesner</a>
  */
+@RestController
 public class SaveAsWithBackupAction extends DocumentRESTAction {
 
-    @SuppressWarnings("deprecation")
-	private static final Log LOG = com.openexchange.log.Log.loggerFor(SaveAsWithBackupAction.class);
+	private static final Logger LOG = LoggerFactory.getLogger(SaveAsWithBackupAction.class);
 
-    /**
-     * Initializes a new {@link CopyDocumentAction}.
-     * @param services
-     */
-    public SaveAsWithBackupAction() {
-    }
+	@Autowired
+	private IRestoreDocument restoreDocument;
 
     /* (non-Javadoc)
      * @see com.openexchange.ajax.requesthandler.AJAXActionService#perform(com.openexchange.ajax.requesthandler.AJAXRequestData, com.openexchange.tools.session.ServerSession)
@@ -112,7 +110,7 @@ public class SaveAsWithBackupAction extends DocumentRESTAction {
         // correct sessionId; set errorcode to 400 in case of an invalid request
         if (SessionIdCheck.isNotValid(request.getParameter("session"), session)) {
             LOG.warn("SaveAsWithBackupAction detected invalid session id - request rejected!");
-            return ParamValidator.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
+            return ParamValidatorService.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
         }
 
         final String clientOperations = request.getParameter("operations");
@@ -131,7 +129,6 @@ public class SaveAsWithBackupAction extends DocumentRESTAction {
             }
 
             // try to initiate the save as with backup document
-            RestoreDocument restoreDocument = new RestoreDocument(null);
             RestoreData result = restoreDocument.saveAsWithBackupDocumentAndOperations(session, origFileId, restoreID, targetFolderId, targetFileName, operations);
 
             // create json result object from the result of saveAsWithBackupDocumentAndOperations
