@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,10 +49,15 @@
 package com.openexchange.office.rest;
 
 import static com.openexchange.java.Strings.isEmpty;
+
 import java.io.IOException;
 import java.io.InputStream;
-import org.apache.commons.io.IOUtils;
-import org.apache.commons.logging.Log;
+
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.web.bind.annotation.RestController;
+
 import com.openexchange.ajax.container.FileHolder;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
@@ -61,10 +66,10 @@ import com.openexchange.conversion.DataProperties;
 import com.openexchange.conversion.SimpleData;
 import com.openexchange.exception.OXException;
 import com.openexchange.java.Streams;
-import com.openexchange.office.document.LocalFileMappingManager;
+import com.openexchange.office.document.tools.LocalFileMappingManager;
+import com.openexchange.office.tools.common.IOHelper;
+import com.openexchange.office.tools.common.files.FileHelper;
 import com.openexchange.office.tools.doc.ExtensionHelper;
-import com.openexchange.office.tools.files.FileHelper;
-import com.openexchange.office.tools.osgi.ServiceLookupRegistry;
 import com.openexchange.preview.PreviewDocument;
 import com.openexchange.preview.PreviewExceptionCodes;
 import com.openexchange.preview.PreviewOutput;
@@ -80,27 +85,17 @@ import com.openexchange.tools.session.ServerSession;
  */
 
 @DispatcherNotes(defaultFormat = "file", allowPublicSession = true)
+@RestController
 public class TemplatePreviewAction extends DocumentRESTAction {
 
-    @SuppressWarnings("deprecation")
-	private static final Log LOG = com.openexchange.log.Log.loggerFor(TemplatePreviewAction.class);
+	private static final Logger LOG = LoggerFactory.getLogger(TemplatePreviewAction.class);
     private static final long TEMPLATEPREVIEW_CACHE_EXPIRES = 10 * 60 * 60 * 1000; // 10 hours
 
-    private final LocalFileMappingManager m_localFileMapper;
-
-    /**
-     * Initializes a new {@link TemplatePreviewAction}.
-     *
-     * @param services
-     *  The service lookup instance to be used by the TemplatePreviewAction.
-     *
-     * @param localFileMapper
-     *  The local file mapping manager to be used by the TemplatePreviewAction
-     *  instance to support previews for local files.
-     */
-    public TemplatePreviewAction(final LocalFileMappingManager localFileMapper) {
-        m_localFileMapper = localFileMapper;
-    }
+    @Autowired
+    private LocalFileMappingManager m_localFileMapper;
+    
+    @Autowired(required=false)
+    private PreviewService previewService; 
 
     /* (non-Javadoc)
      * @see com.openexchange.ajax.requesthandler.AJAXActionService#perform(com.openexchange.ajax.requesthandler.AJAXRequestData, com.openexchange.tools.session.ServerSession)
@@ -123,8 +118,6 @@ public class TemplatePreviewAction extends DocumentRESTAction {
                     final InputStream stream = m_localFileMapper.getInputStreamFromID(id);
 
                     if (null != stream) {
-                        final PreviewService previewService = ServiceLookupRegistry.get().getService(PreviewService.class);
-
                         if (null != previewService) {
                             final String mimeType = requestData.getParameter("mimeType");
                             final String fileName = FileHelper.getFileName(fullFilePath);
@@ -170,7 +163,7 @@ public class TemplatePreviewAction extends DocumentRESTAction {
                             } catch (final RuntimeException e) {
                                 throw AjaxExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
                             } finally {
-                                IOUtils.closeQuietly(thumbnail);
+                                IOHelper.closeQuietly(thumbnail);
                             }
                         } else {
                             throw AjaxExceptionCodes.UNEXPECTED_ERROR.create("PreviewService is not available.");
@@ -188,11 +181,6 @@ public class TemplatePreviewAction extends DocumentRESTAction {
             throw AjaxExceptionCodes.MISSING_PARAMETER.create("Session, id or folder parameters are missing or have invalid values.");
         }
 
-        if (null == requestResult) {
-            requestData.setFormat("json");
-            requestResult = new AJAXRequestResult();
-        }
-
         return requestResult;
     }
 
