@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,50 +49,39 @@
 
 package com.openexchange.office.rest.operations;
 
-import com.openexchange.file.storage.composition.IDBasedFileAccess;
-import com.openexchange.file.storage.composition.IDBasedFileAccessFactory;
-import com.openexchange.office.rest.GetOperationsAction;
+import com.openexchange.office.datasource.access.DataSourceResourceAccess;
+import com.openexchange.office.datasource.access.MetaData;
 import com.openexchange.office.rest.job.Job;
-import com.openexchange.office.tools.osgi.ServiceLookupRegistry;
 import com.openexchange.tools.session.ServerSession;
 
 public class GetOperationsJob extends Job {
 
-    // ---------------------------------------------------------------
     private final ServerSession session;
+    private final DataSourceResourceAccess docAccess;
+    private final DocumentOperationService documentOperationService;
+    private final OperationDataCache operationDataCache;
 
     // ---------------------------------------------------------------
-    private String folderId;
-
-    // ---------------------------------------------------------------
-    private String fileId;
-
-    // ---------------------------------------------------------------
-    private String version;
-
-    // ---------------------------------------------------------------
-    public GetOperationsJob(final ServerSession session, String folderId, String fileId, String version) {
+    public GetOperationsJob(ServerSession session, DataSourceResourceAccess docAccess, DocumentOperationService documentOperationService, OperationDataCache operationDataCache) {
         this.session = session;
-        this.folderId = folderId;
-        this.fileId = fileId;
-        this.version = version;
+        this.docAccess = docAccess;
+        this.documentOperationService = documentOperationService;
+        this.operationDataCache = operationDataCache;
     }
 
     // ---------------------------------------------------------------
     @Override
     public boolean execute() throws Exception {
-        final IDBasedFileAccess fileAccess = ServiceLookupRegistry.get().getService(IDBasedFileAccessFactory.class).createAccess(session);
-        final String            hash       = fileAccess.getFileMetadata(fileId, version).getFileMD5Sum();
-        final OperationsResult  aResult    = GetOperationsAction.getOperationsFromDocument(fileAccess, session, folderId, fileId, version, "");
+    	final MetaData metaData = docAccess.getMetaData();
+        final String hash = metaData.getHash();
+        final OperationsResult aResult = documentOperationService.getOperationsFromDataSourceAccess(docAccess, session);
 
         if (aResult.getErrorCode().isNoError()) {
-            final String        aEntryKey = OperationDataCache.getKeyFromProps(fileId, version, session.getContextId());
-            final OperationData aData     = new OperationData(aEntryKey, hash, aResult.getHtmlDoc(), aResult.getPreviewData(), aResult.getOperations());
+            final String aEntryKey = OperationDataCache.createKey(docAccess.getFolder(), docAccess.getId(), docAccess.getVersionOrAttachmentId(), docAccess.getContextId());
+            final OperationData aData = new OperationData(aEntryKey, hash, aResult.getHtmlDoc(), aResult.getPreviewData(), aResult.getOperations());
 
-            OperationDataCache.getInstance().put(aEntryKey, aData);
+            operationDataCache.put(aEntryKey, aData);
         }
-
         return aResult.getErrorCode().isNoError();
     }
-
 }
