@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -56,36 +56,31 @@ import java.util.HashMap;
 import java.util.Map;
 import java.util.Set;
 import java.util.stream.Collectors;
+
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang3.StringUtils;
 import org.json.JSONArray;
 import org.json.JSONObject;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+import org.springframework.beans.factory.InitializingBean;
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.stereotype.Service;
 
 import com.openexchange.filemanagement.ManagedFile;
 import com.openexchange.filemanagement.ManagedFileManagement;
-import com.openexchange.office.tools.osgi.ServiceLookupRegistry;
 import com.openexchange.timer.TimerService;
 
-public class OperationDataCache implements Runnable {
+@Service
+public class OperationDataCache implements Runnable, InitializingBean {
 
     // ---------------------------------------------------------------
 	private static final Logger log = LoggerFactory.getLogger(OperationDataCache.class);
+    private static final int  MAX_OPERATIONSCACHE_ENTRIES = 32;
+    private static final long GC_FREQUENCY = 60000;
 
     //-------------------------------------------------------------------------
-    private final static int  MAX_OPERATIONSCACHE_ENTRIES = 32;
-
-    //-------------------------------------------------------------------------
-    private final static long GC_FREQUENCY                = 60000;
-
-    //-------------------------------------------------------------------------
-    private final static long MAX_IDLE_TIMESPAN           = 300000;
-
-    //-------------------------------------------------------------------------
-    private static class Holder {
-        static final OperationDataCache INSTANCE = new OperationDataCache(MAX_OPERATIONSCACHE_ENTRIES);
-    }
+    private final static long MAX_IDLE_TIMESPAN = 300000;
 
     //-------------------------------------------------------------------------
     private static class OperationDataHolder {
@@ -132,34 +127,24 @@ public class OperationDataCache implements Runnable {
     // ---------------------------------------------------------------
     private final Map<String, OperationDataHolder> cacheOpsData = new HashMap<>();
 
-    // ---------------------------------------------------------------
-    private final ManagedFileManagement managedFileService;
+    @Autowired
+    private ManagedFileManagement managedFileService;
 
-    // ---------------------------------------------------------------
+    @Autowired
+    private TimerService timerService; 
+    
     private int maxEntries;
 
     // ---------------------------------------------------------------
-    private OperationDataCache(int maxEntries) {
-        this.maxEntries = maxEntries;
-
-        final TimerService timerService = ServiceLookupRegistry.get().getService(TimerService.class);
-        if (null != timerService) {
-            timerService.scheduleAtFixedRate(this, GC_FREQUENCY, GC_FREQUENCY);
-        } else {
-            log.error("OperationDataCache timer service not available - gc function won't work");
-        }
-
-        managedFileService = ServiceLookupRegistry.get().getService(ManagedFileManagement.class);
-        if (null == managedFileService) {
-            log.error("OperationDataCache cannot access mandatory ManagedFileManagement service - cache won't work!");
-        }
+    public OperationDataCache() {
+        this.maxEntries = MAX_OPERATIONSCACHE_ENTRIES;
     }
 
-    //-------------------------------------------------------------------------
-    public static OperationDataCache getInstance()
-    {
-        return Holder.INSTANCE;
-    }
+    // ---------------------------------------------------------------    
+    @Override
+	public void afterPropertiesSet() throws Exception {
+    	timerService.scheduleAtFixedRate(this, GC_FREQUENCY, GC_FREQUENCY);		
+	}
 
     // ---------------------------------------------------------------
     public boolean isEmpty() {
@@ -169,9 +154,12 @@ public class OperationDataCache implements Runnable {
     }
 
     // ---------------------------------------------------------------
-    public boolean hasEntryAndTouch(String fileId, String version, int context) {
-        final String key = getKeyFromProps(fileId, version, context);
+    public static String createKey(String folderId, String fileId, String versionOrAttachmentId, int context) {
+    	return getKeyFromProps(folderId, fileId, versionOrAttachmentId, context);
+    }
 
+    // ---------------------------------------------------------------
+    public boolean hasEntryAndTouch(String key) {
         OperationDataHolder cacheEntry = null;
         synchronized (cacheOpsData) {
             cacheEntry = cacheOpsData.get(key);
@@ -184,9 +172,7 @@ public class OperationDataCache implements Runnable {
     }
 
     // ---------------------------------------------------------------
-    public OperationData get(String fileId, String version, int context) {
-        final String key = getKeyFromProps(fileId, version, context);
-
+    public OperationData get(String key) {
         OperationDataHolder aHolder = null;
         synchronized (cacheOpsData) {
             final OperationDataHolder cacheEntry = cacheOpsData.get(key);
@@ -236,9 +222,9 @@ public class OperationDataCache implements Runnable {
     }
 
     // ---------------------------------------------------------------
-    public static String getKeyFromProps(String fileId, String version, int context) {
-        final StringBuilder tmp = new StringBuilder(fileId);
-        tmp.append("-").append(version).append("-").append(context);
+    public static String getKeyFromProps(String folderId, String fileId, String version, int context) {
+        final StringBuilder tmp = new StringBuilder(folderId);
+        tmp.append(fileId).append("-").append(version).append("-").append(context);
         return tmp.toString();
     }
 
