@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,7 +52,8 @@ package com.openexchange.office.rest.operations;
 import org.apache.commons.lang3.Validate;
 import org.json.JSONArray;
 import org.json.JSONObject;
-import com.openexchange.office.tools.error.ErrorCode;
+
+import com.openexchange.office.tools.common.error.ErrorCode;
 
 public class OperationsResult implements OperationDataAccess {
 
