@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,7 +49,7 @@
 
 package com.openexchange.office.rest.tools;
 
-import com.openexchange.office.tools.error.ErrorCode;
+import com.openexchange.office.tools.common.error.ErrorCode;
 
 public class RESTException extends RuntimeException {
 
@@ -62,6 +62,11 @@ public class RESTException extends RuntimeException {
         this.errorCode = errorCode;
     }
 
+    public RESTException(ErrorCode errorCode, Exception e) {
+        super(e);
+        this.errorCode = errorCode;
+    }
+
     public RESTException(String message, ErrorCode errorCode) {
         super(message);
         this.errorCode = errorCode;
