@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,19 +50,22 @@ package com.openexchange.office.rest.tools;
 
 import java.util.Arrays;
 import java.util.stream.Collectors;
+
 import org.apache.commons.lang3.StringUtils;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
-import com.openexchange.office.session.SessionService;
-import com.openexchange.office.tools.files.FileHelper;
-import com.openexchange.office.tools.osgi.ServiceLookupRegistryService;
-import com.openexchange.office.tools.rest.RequestDataHelper;
+import com.openexchange.office.tools.service.files.FileHelperService;
+import com.openexchange.office.tools.service.files.FileHelperServiceFactory;
+import com.openexchange.office.tools.service.session.SessionService;
+import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.session.ServerSession;
 
 public class RTRequestParamValidator {
 
     // ---------------------------------------------------------------
-    @SuppressWarnings("deprecation")
-    static protected final org.apache.commons.logging.Log LOG = com.openexchange.log.LogFactory.getLog(RTRequestParamValidator.class);
+    private static final Logger LOG = LoggerFactory.getLogger(RTRequestParamValidator.class);
 
     // ---------------------------------------------------------------
     public static boolean areAllParamsNonEmpty(final RequestDataHelper aRequestDataHelper, String[] paramNames) {
@@ -77,13 +80,15 @@ public class RTRequestParamValidator {
     }
 
     // ---------------------------------------------------------------
-    public static boolean canReadFile(final ServerSession aSession, String folderId, String fileId) {
+    public static boolean canReadFile(final ServiceLookup services, final ServerSession aSession, String folderId, String fileId) {
         boolean canRead = false;
         try {
-            final int userId = ServiceLookupRegistryService.getInstance().getService(SessionService.class).getUserId(aSession);
+            final int userId = services.getService(SessionService.class).getUserId(aSession);
 
             // check document access rights to ensure that the current user has access rights to retrieve document content
-            canRead = FileHelper.canReadFile(aSession, folderId, fileId, userId);
+            final FileHelperServiceFactory fileHelperServiceRegistry = services.getService(FileHelperServiceFactory.class);
+            final FileHelperService fileHelperService = fileHelperServiceRegistry.create(aSession);
+            canRead = fileHelperService.canReadFile(folderId, fileId, userId);
         } catch (Exception e) {
             LOG.error("AjaxRequest GetFileAction exception caught while trying to check access rights", e);
         }
