@@ -57,6 +57,8 @@ import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 import java.util.Set;
+import java.util.UUID;
+import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.Executors;
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.ThreadFactory;
@@ -71,98 +73,120 @@ import org.apache.commons.lang3.Validate;
 import org.apache.commons.lang3.time.DurationFormatUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+import org.springframework.beans.factory.DisposableBean;
+import org.springframework.beans.factory.InitializingBean;
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.stereotype.Service;
 
 import com.codahale.metrics.Counter;
 import com.codahale.metrics.MetricRegistry;
-import com.google.common.util.concurrent.ThreadFactoryBuilder;
+import com.google.common.collect.Sets;
 import com.hazelcast.core.DistributedObject;
 import com.hazelcast.core.DistributedObjectUtil;
 import com.hazelcast.core.HazelcastInstance;
 import com.hazelcast.core.IAtomicLong;
+import com.hazelcast.core.IMap;
+import com.hazelcast.core.Member;
 import com.openexchange.exception.ExceptionUtils;
+import com.openexchange.exception.OXException;
 import com.openexchange.java.ConcurrentHashSet;
 import com.openexchange.log.LogProperties;
-import com.openexchange.office.rt2.cache.ClusterLockException;
-import com.openexchange.office.rt2.cache.ClusterLockService;
-import com.openexchange.office.rt2.cache.ClusterLockService.ClusterLock;
-import com.openexchange.office.rt2.cache.RT2DocInfo;
-import com.openexchange.office.rt2.config.RT2ConfigItem;
-import com.openexchange.office.rt2.core.doc.IDocProcessorContainer;
-import com.openexchange.office.rt2.core.doc.IRT2DocProcessorManager;
+import com.openexchange.office.rt2.core.cache.ClusterLockException;
+import com.openexchange.office.rt2.core.cache.ClusterLockService;
+import com.openexchange.office.rt2.core.cache.ClusterLockService.ClusterLock;
+import com.openexchange.office.rt2.core.cache.RT2DocInfo;
+import com.openexchange.office.rt2.core.cache.RT2HazelcastHelperService;
+import com.openexchange.office.rt2.core.config.RT2ConfigService;
 import com.openexchange.office.rt2.core.doc.RT2DocProcessor;
 import com.openexchange.office.rt2.core.doc.RT2DocProcessorManager;
+import com.openexchange.office.rt2.core.proxy.EDocProxyState;
+import com.openexchange.office.rt2.core.proxy.RT2DocInfoRegistry;
+import com.openexchange.office.rt2.core.proxy.RT2DocProxy;
+import com.openexchange.office.rt2.core.proxy.RT2DocProxyRegistry;
 import com.openexchange.office.rt2.hazelcast.RT2DocOnNodeMap;
+import com.openexchange.office.rt2.hazelcast.RT2NodeHealth;
+import com.openexchange.office.rt2.hazelcast.RT2NodeHealthMap;
+import com.openexchange.office.rt2.hazelcast.RT2NodeHealthState;
+import com.openexchange.office.rt2.hazelcast.serialization.PortableNodeHealthState;
+//import com.openexchange.office.rt2.protocol.internal.Cause;
 import com.openexchange.office.rt2.protocol.value.RT2DocUidType;
-import com.openexchange.office.rt2.proxy.EDocProxyState;
-import com.openexchange.office.rt2.proxy.RT2DocInfoRegistry;
-import com.openexchange.office.rt2.proxy.RT2DocProxy;
-import com.openexchange.office.rt2.proxy.RT2DocProxyRegistry;
+import com.openexchange.office.rt2.protocol.value.RT2NodeUuidType;
+import com.openexchange.office.tools.annotation.RegisteredService;
+import com.openexchange.office.tools.annotation.ShutdownOrder;
+import com.openexchange.office.tools.common.log.LogMethodCallHelper;
+import com.openexchange.office.tools.common.threading.ThreadFactoryBuilder;
 import com.openexchange.office.tools.common.weakref.WeakRefUtils;
-import com.openexchange.office.tools.logging.annotation.LogMethodCallHelper;
-import com.openexchange.office.tools.osgi.ServiceLookupRegistry;
 
+@Service
+@ShutdownOrder(value=-9)
+@RegisteredService
+public class RT2GarbageCollector implements Runnable, DisposableBean, InitializingBean {
 
-//=============================================================================
-/**
- */
-public class RT2GarbageCollector
-{
-
+	private static final Logger log = LoggerFactory.getLogger(RT2GarbageCollector.class);
 	public static final String REFCOUNT_CLIENT_PREFIX  = "rt2cache.atomic.";
 	public static final String REFCOUNT_CLIENT_POSTFIX = ".refcount.clients.a";
 
     //-------------------------------------------------------------------------
-	private static final Logger log = LoggerFactory.getLogger(RT2GarbageCollector.class);
+	public static final String KEY_GC_FREQUENCY = "rt2.gc.frequency";
 
-	private final RT2DocProcessorManager docProcContainer;
+    //---------------------------Services--------------------------------------
+	@Autowired
+	private RT2DocProcessorManager docProcMngr;
 
-	private final RT2NodeInfoService nodeInfo;
+	@Autowired
+	private ClusterLockService clusterLockService;
 
-	private final ClusterLockService clusterLockService;
+	@Autowired
+	private RT2DocInfoRegistry docInfoRegistry;
 
-	private final ScheduledExecutorService finalRt2DocProcessorRemoveScheduler = Executors.newSingleThreadScheduledExecutor(new RT2ThreadFactoryBuilder("RT2GarbageCollectorFinalProcRemove-%d").build());
+	@Autowired
+	private RT2DocProxyRegistry docProxyRegistry;
 
-	private final HazelcastInstance hazelcastInstance;
+	@Autowired
+	private RT2DocOnNodeMap docOnNodeMap;;
 
-	private final Counter docProxyOfflineCounter;
-	private final Counter docProxyRemovedCounter;
-	private final Counter docProcRemovedCounter;
-	private final Counter refCountClientsRemovedCounter;
-	private final Counter docOnNodeMapEntryRemovedCounter;
+	@Autowired
+	private RT2ConfigService configService;
+
+	@Autowired
+	private MetricRegistry metricRegistry;
+
+	@Autowired
+	private HazelcastInstance hazelcastInstance;
+
+	@Autowired
+	private RT2HazelcastHelperService rt2HazelcastHelperService;
+
+    @Autowired
+    private RT2NodeInfoService rt2NodeInfo;
+
+    @Autowired
+    private RT2NodeHealthMap nodeHealthMap;
+
+    //-------------------------------------------------------------------------
+
+	private final ScheduledExecutorService finalRt2DocProcessorRemoveScheduler = Executors.newSingleThreadScheduledExecutor(new ThreadFactoryBuilder("RT2GarbageCollectorFinalProcRemove-%d").build());
+
+	private ScheduledExecutorService m_aScheduler = null;
+
+	private Counter docProxyOfflineCounter;
+	private Counter docProxyRemovedCounter;
+	private Counter docProcRemovedCounter;
+	private Counter refCountClientsRemovedCounter;
+	private Counter docOnNodeMapEntryRemovedCounter;
 
 	private Pattern docUidOfAtomicLongNamePattern = Pattern.compile("rt2cache.atomic.(.*).refcount.clients.a");
 
 	private Map<RT2DocUidType, LocalDateTime> atomicLongsToGc = new HashMap<>();
 	private Set<RT2DocUidType> atomicLongsToBeVerified = new ConcurrentHashSet<>();
 	private Set<RT2DocUidType> docUidsToClear = new ConcurrentHashSet<>();
+	private Map<RT2NodeUuidType, LocalDateTime> docOnNodeEntriesToGC = new ConcurrentHashMap<>();
 	private long minWaitTimeBeforeGcAtomicLong = 5 * 60; // 5 minutes in seconds
 
-    //-------------------------------------------------------------------------
-	public RT2GarbageCollector (HazelcastInstance hazelcastInstance, RT2DocProcessorManager docProcContainer, MetricRegistry metricRegistry, RT2NodeInfoService nodeInfo, ClusterLockService clusterLockService) {
-		this.docProcContainer = docProcContainer;
-		this.nodeInfo = nodeInfo;
-		this.clusterLockService = clusterLockService;
-		this.hazelcastInstance = hazelcastInstance;
-		this.docProxyOfflineCounter = metricRegistry.counter(MetricRegistry.name("GarbageCollector", "docProxy", "offline"));
-		this.docProxyRemovedCounter = metricRegistry.counter(MetricRegistry.name("GarbageCollector", "docProxy", "removed"));
-		this.docProcRemovedCounter = metricRegistry.counter(MetricRegistry.name("GarbageCollector", "docProcessor", "removed"));
-		this.refCountClientsRemovedCounter = metricRegistry.counter(MetricRegistry.name("GarbageCollector", "refCountClients", "removed"));
-		this.docOnNodeMapEntryRemovedCounter = metricRegistry.counter(MetricRegistry.name("GarbageCollector", "docOnNodeMap", "removed"));
+	public RT2GarbageCollector() {
 	}
 
-    //-------------------------------------------------------------------------
-    RT2GarbageCollector(RT2DocProcessorManager docProcContainer, RT2NodeInfoService nodeInfo, ClusterLockService clusterLockService, HazelcastInstance hazelcastInstance, Counter docProxyOfflineCounter,
-			Counter docProxyRemovedCounter, Counter docProcRemovedCounter, Counter refCountClientsRemovedCounter, Counter docOnNodeMapEntryRemovedCounter,
-			long minWaitTimeBeforeGcAtomicLong) {
-		this.docProcContainer = docProcContainer;
-		this.nodeInfo = nodeInfo;
-		this.clusterLockService = clusterLockService;
-		this.hazelcastInstance = hazelcastInstance;
-		this.docProxyOfflineCounter = docProxyOfflineCounter;
-		this.docProxyRemovedCounter = docProxyRemovedCounter;
-		this.docProcRemovedCounter = docProcRemovedCounter;
-		this.refCountClientsRemovedCounter = refCountClientsRemovedCounter;
-		this.docOnNodeMapEntryRemovedCounter = docOnNodeMapEntryRemovedCounter;
+	public RT2GarbageCollector(long minWaitTimeBeforeGcAtomicLong) {
 		this.minWaitTimeBeforeGcAtomicLong = minWaitTimeBeforeGcAtomicLong;
 	}
 
@@ -176,30 +200,34 @@ public class RT2GarbageCollector
 		return new HashSet<>(atomicLongsToBeVerified);
 	}
 
-	//-------------------------------------------------------------------------
-    public synchronized void start ()
-        throws Exception
-	{
+    @Override
+	public void afterPropertiesSet() throws Exception {
+
 	    if (m_aScheduler != null)
 	        return;
 
+		this.docProxyOfflineCounter = metricRegistry.counter(MetricRegistry.name("GarbageCollector", "docProxy", "offline"));
+		this.docProxyRemovedCounter = metricRegistry.counter(MetricRegistry.name("GarbageCollector", "docProxy", "removed"));
+		this.docProcRemovedCounter = metricRegistry.counter(MetricRegistry.name("GarbageCollector", "docProcessor", "removed"));
+		this.refCountClientsRemovedCounter = metricRegistry.counter(MetricRegistry.name("GarbageCollector", "refCountClients", "removed"));
+		this.docOnNodeMapEntryRemovedCounter = metricRegistry.counter(MetricRegistry.name("GarbageCollector", "docOnNodeMap", "removed"));
+
 	    LogMethodCallHelper.logMethodCall(log, this, "start");
 
         final Runnable aRunner = () -> {impl_doGC ();};
 
-        final long                     nFrequencyInMS = RT2ConfigItem.get().getRT2GCFrequencyInMS();
-
-        ThreadFactory namedThreadFactory = new ThreadFactoryBuilder().setNameFormat("RT2GarbageCollector-%d").build();
-        final ScheduledExecutorService aScheduler     = Executors.newScheduledThreadPool(1, namedThreadFactory);
-        aScheduler.scheduleAtFixedRate(aRunner, nFrequencyInMS, nFrequencyInMS, TimeUnit.MILLISECONDS);
-        m_aScheduler = aScheduler;
+        final long                     nFrequencyInMS = configService.getRT2GCFrequencyInMS();
+        if (nFrequencyInMS > 0) {
+	        ThreadFactory namedThreadFactory = new ThreadFactoryBuilder().setNameFormat("RT2GarbageCollector-%d").build();
+	        final ScheduledExecutorService aScheduler     = Executors.newScheduledThreadPool(1, namedThreadFactory);
+	        aScheduler.scheduleAtFixedRate(aRunner, nFrequencyInMS, nFrequencyInMS, TimeUnit.MILLISECONDS);
+	        m_aScheduler = aScheduler;
+        }
         LogMethodCallHelper.logMethodCallRes(log, this.getClass(), "start", Void.class);
 	}
 
-    //-------------------------------------------------------------------------
-    public synchronized void stop ()
-        throws Exception
-    {
+	@Override
+	public void destroy() throws Exception {
         if (m_aScheduler == null)
             return;
 
@@ -210,16 +238,30 @@ public class RT2GarbageCollector
         aScheduler.shutdownNow();
         finalRt2DocProcessorRemoveScheduler.shutdown();
 
-        final boolean bOK = aScheduler.awaitTermination(30000, TimeUnit.MILLISECONDS);
-        if ( ! bOK) {
-            log.warn("... RT2-GC not stopped in time !");
-            // no exception please - GC is stopped in shutdown of process ...
-            // so thread will be stopped anyway ...
-        } else {
-            LogMethodCallHelper.logMethodCallRes(log, this.getClass(), "stop", Void.class);
+        try {
+	        final boolean bOK = aScheduler.awaitTermination(30000, TimeUnit.MILLISECONDS);
+	        if ( ! bOK) {
+	            log.warn("... RT2-GC not stopped in time !");
+	            // no exception please - GC is stopped in shutdown of process ...
+	            // so thread will be stopped anyway ...
+	        } else {
+	            LogMethodCallHelper.logMethodCallRes(log, this.getClass(), "stop", Void.class);
+	        }
+        } catch (InterruptedException ex) {
+        	Thread.currentThread().interrupt();
         }
     }
 
+	//-------------------------------------------------------------------------
+	@Override
+    public void run ()
+	{
+	    LogMethodCallHelper.logMethodCall(log, this, "start");
+
+        impl_doGC ();
+        LogMethodCallHelper.logMethodCallRes(log, this.getClass(), "start", Void.class);
+	}
+
     //-------------------------------------------------------------------------
 
 	public boolean doGcForDocUid(RT2DocUidType docUid, boolean rememberWhenException) {
@@ -229,8 +271,8 @@ public class RT2GarbageCollector
         try {
             log.debug("Lock called by garbage collector for doc with id [{}]", docUid);
             locked = clusterLock.lock();
-            nodeInfo.deregisterDocOnNode(docUid);
-            final RT2DocInfo aDocInfo = mem_DocInfoRegistry().getDocInfo(docUid);
+            rt2NodeInfo.deregisterDocOnNode(docUid);
+            final RT2DocInfo aDocInfo = docInfoRegistry.getDocInfo(docUid);
             aDocInfo.destroyRefCount4Clients();
             return true;
         } catch (ClusterLockException e) {
@@ -261,12 +303,13 @@ public class RT2GarbageCollector
     private void impl_doGC () {
         try {
             LogProperties.putProperty(LogProperties.Name.RT2_BACKEND_PART, "RT2GarbageCollector");
-            LogProperties.putProperty(LogProperties.Name.RT2_BACKEND_UID, nodeInfo.getNodeUUID());
+            LogProperties.putProperty(LogProperties.Name.RT2_BACKEND_UID, rt2HazelcastHelperService.getHazelcastLocalNodeUuid());
             checkAndGCOfflineOrStaleDocProxies();
             checkAndGCStaleDocResources();
             checkAndGCAtomicLongAsClientRef();
-            checkConsitencyOfDocOnNodeMap();
+            checkAndEnsureConsitencyOfDocOnNodeMapForThisNode();
             checkDetectedDocUids();
+            checkAndEnsureConsistencyOfDocOnNodeMapGlobally();
         } catch (Exception ex) {
             log.error(ex.getMessage(), ex);
         }
@@ -287,9 +330,9 @@ public class RT2GarbageCollector
     private /* no synchronized */ void checkAndGCOfflineOrStaleDocProxies () {
         LogMethodCallHelper.logMethodCall(log, this, "checkAndGCOfflineOrStaleDocProxies");
 
-        final RT2DocProxyRegistry aDocRegistry         = mem_DocProxyRegistry();
+        final RT2DocProxyRegistry aDocRegistry         = docProxyRegistry;
         final List< RT2DocProxy > lDocProxies          = aDocRegistry.listAllDocProxies();
-        final long                nOfflineTresholdInMS = RT2ConfigItem.get().getRT2GCOfflineTresholdInMS();
+        final long                nOfflineTresholdInMS = configService.getRT2GCOfflineTresholdInMS();
         final long                nNow                 = System.currentTimeMillis();
 
         for (final RT2DocProxy aDocProxy : lDocProxies) {
@@ -336,12 +379,12 @@ public class RT2GarbageCollector
     private /* no synchronized */ void checkAndGCStaleDocResources ()
     {
         LogMethodCallHelper.logMethodCall(log, this, "checkAndGCStaleDocResources");
-        final Set<WeakReference<RT2DocProcessor>> aLocalDocProcessors = docProcContainer.getWeakReferenceToDocProcessors();
+        final Set<WeakReference<RT2DocProcessor>> aLocalDocProcessors = docProcMngr.getWeakReferenceToDocProcessors();
 
         if (!aLocalDocProcessors.isEmpty())
         {
             final Set<RT2DocProcessor> aDocProcessorsWOClients = retrieveDocProcessorsWithoutClients(aLocalDocProcessors);
-            final RT2DocInfoRegistry       aDocRegistry        = mem_DocInfoRegistry ();
+            final RT2DocInfoRegistry       aDocRegistry        = docInfoRegistry;
             Set<RT2DocUidType> possibleDocProcessorToRemove = new HashSet<>();
             for (final RT2DocProcessor aDocProc : aDocProcessorsWOClients)
             {
@@ -489,7 +532,6 @@ public class RT2GarbageCollector
     private static String getDocUIDFromClientRefCountName(final IAtomicLong aClientRefCount)
     {
         String sResult = null;
-
         final String sName  = aClientRefCount.getName();
         final int    nStart = REFCOUNT_CLIENT_PREFIX.length();
         final int    nEnd   = sName.indexOf(".", nStart);
@@ -500,41 +542,193 @@ public class RT2GarbageCollector
         return sResult;
     }
 
+    //-------------------------------------------------------------------------
+    private void checkAndEnsureConsitencyOfDocOnNodeMapForThisNode() {
+        LogMethodCallHelper.logMethodCall(log, this, "checkAndEnsureConsitencyOfDocOnNodeMapForThisNode");
+
+        RT2DocOnNodeMap aDocOnNodeMap = docOnNodeMap;
+        Set<String> docIds = aDocOnNodeMap.getDocsOfMember();
+        for (String str : docIds) {
+            RT2DocUidType docUid = new RT2DocUidType(str);
+            if (!docProcMngr.contains(docUid)) {
+                LogProperties.putProperty(LogProperties.Name.RT2_DOC_UID, docUid.getValue());
+                removeDocOnNodeEntryAndAtomicLongForDocUid(docUid, false);
+            }
+        }
+    }
 
     //-------------------------------------------------------------------------
-    private /* no synchronized */ void checkConsitencyOfDocOnNodeMap() {
-    	RT2DocOnNodeMap aDocOnNodeMap = mem_DocOnNodeMap();
-    	Set<String> docIds = aDocOnNodeMap.getDocsOfMember();
-    	IDocProcessorContainer docProcMngr = mem_DocProcessorManager();
-    	for (String str : docIds) {
-    		RT2DocUidType docUid = new RT2DocUidType(str);
-    		if (!docProcMngr.contains(docUid)) {
-				LogProperties.putProperty(LogProperties.Name.RT2_DOC_UID, docUid.getValue());
-				log.info("Removing docOnNodeMap entry with key {}", docUid.getValue());
-				ClusterLock clusterLock = clusterLockService.getLock(docUid);
-        		try {
-    				clusterLock.lock();
-    				if (aDocOnNodeMap.remove(str) == null) {
-    					LogProperties.putProperty(LogProperties.Name.RT2_DOC_UID, str);
-    					log.error("Cannot remove entry with docUid {} from DocOnNodeMap", str);
-    				}
-    				final RT2DocInfo   aDocInfo   = mem_DocInfoRegistry().getDocInfoWithoutCreate(docUid);
-    				if (aDocInfo != null) {
-    					aDocInfo.destroyRefCount4Clients();
-    					docOnNodeMapEntryRemovedCounter.inc();
-    				} else {
-    					LogProperties.putProperty(LogProperties.Name.RT2_DOC_UID, str);
-    					log.warn("No RefCount4Clients for document with id {} fround!", str);
-    				}
-        		} catch (ClusterLockException e) {
-            		// Ignore, try again next time
-            	} finally {
-   					clusterLock.unlock();
-                    LogProperties.removeProperty(LogProperties.Name.RT2_DOC_UID);
-    			}
-    			LogProperties.remove(LogProperties.Name.RT2_DOC_UID);
-    		}
-    	}
+    private void checkAndEnsureConsistencyOfDocOnNodeMapGlobally() {
+        LogMethodCallHelper.logMethodCall(log, this, "checkAndEnsureConsistencyOfDocOnNodeMapGlobally");
+
+        RT2DocOnNodeMap aDocOnNodeMap = docOnNodeMap;
+        final Set<Member> currentMembers = hazelcastInstance.getCluster().getMembers();
+        final Set<String> currentMemberUUIDs = currentMembers.stream().map(m -> m.getUuid()).collect(Collectors.toSet());
+        final Set<String> memberUUIDsWithDocs = aDocOnNodeMap.getMember();
+        if (memberUUIDsWithDocs != null) {
+            final Set<String> unknownMembersWithDocs = Sets.difference(memberUUIDsWithDocs, currentMemberUUIDs);
+            unknownMembersWithDocs.stream().forEach(m -> {
+                try {
+                    final UUID cleanupNode = UUID.fromString(m);
+                    final RT2NodeUuidType cleanupNodeUUID = new RT2NodeUuidType(cleanupNode);
+
+                    if (tryLockForMember(cleanupNodeUUID)) {
+                        log.info("Removing docOnNodeMap entries for unknown member node-uuid {}", m);
+                        final Set<String> docsOnUnknownNode = aDocOnNodeMap.getDocsOfMember(m);
+                        docsOnUnknownNode.stream().forEach(d -> {
+                            RT2DocUidType docUid = new RT2DocUidType(d);
+                            LogProperties.putProperty(LogProperties.Name.RT2_DOC_UID, docUid.getValue());
+                            removeDocOnNodeEntryAndAtomicLongForDocUid(docUid, true);
+                        });
+                        removeCleanedUpMemberFromHealthMap(cleanupNodeUUID);
+                    }
+                } catch (IllegalArgumentException e) {
+                    log.error("Node uuid detected in DocOnNodeMap with illegal uuid " + m, e);
+                } catch (Exception e) {
+                    log.error("Exception caught trying to clean-up documents for unknown member node-uuid " + m, e);
+                }
+            });
+            // in case there are no unknown members we clear our map to remove obsolete entries
+            if (unknownMembersWithDocs.isEmpty()) {
+                docOnNodeEntriesToGC.clear();
+            }
+        }
+    }
+
+    //-------------------------------------------------------------------------
+    private boolean tryLockForMember(RT2NodeUuidType nodeUuid) {
+        boolean result = false;
+
+        try {
+            boolean locked = false;
+            if (shouldThisNodeTryToTakeOverOwnershipForNotMemberNode(nodeUuid)) {
+                RT2NodeHealthState nodeHealthState = nodeHealthMap.get(nodeUuid.toString());
+                final String nodeHealthMapName = nodeHealthMap.getUniqueMapName();
+                final IMap<String, PortableNodeHealthState> hzNodeHealthMap = hazelcastInstance.getMap(nodeHealthMapName);
+
+                try {
+                    int nRetryCount = 2;
+                    while ((nRetryCount > 0) && !locked) {
+                        locked = hzNodeHealthMap.tryLock(nodeUuid.getValue().toString(), 1000, TimeUnit.MILLISECONDS);
+
+                        if (locked) {
+                            final String thisMemberUuidString = hazelcastInstance.getCluster().getLocalMember().getUuid();
+                            final String cleanupUUID = (null != nodeHealthState) ? nodeHealthState.getCleanupUUID(): null;
+                            if (nodeHealthState == null) {
+                                nodeHealthState = new RT2NodeHealthState(nodeUuid.toString(), "Unknown", RT2NodeHealth.RT2_NODE_HEALTH_NOT_MEMBER_ANYMORE, RT2NodeHealth.RT2_NODE_TYPE_LITE_MEMBER, thisMemberUuidString);
+                                nodeHealthMap.set(nodeUuid.toString(), nodeHealthState);
+                                result = true;
+                            } else if (StringUtils.isEmpty(cleanupUUID) || !isActiveHzMember(cleanupUUID)) {
+                                nodeHealthState.setCleanupUUID(thisMemberUuidString);
+                                result = true;
+                            }
+                        }
+                    }
+                } catch (InterruptedException e) {
+                    Thread.currentThread().interrupt();
+                    log.warn("RT2GarbageCollector caught InterruptedException while trying to handle document entries in DocOnNodeMap with unknown member uuid " + nodeUuid.toString(), e);
+                } catch (Exception e) {
+                    log.warn("RT2GarbageCollector caught exception  while trying to handle document entries in DocOnNodeMap with unknown member uuid " + nodeUuid.toString(), e);
+                } finally {
+                    if (locked)
+                        hzNodeHealthMap.unlock(nodeUuid.getValue().toString());
+                }
+            }
+        } catch (Exception e) {
+            log.warn("Trying analyze health map entry or try to lock for node " + nodeUuid.getValue().toString() + " failed with exception", e);
+        }
+
+        return result;
+    }
+
+    //-------------------------------------------------------------------------
+    private boolean shouldThisNodeTryToTakeOverOwnershipForNotMemberNode(RT2NodeUuidType notMemberUuid) {
+        boolean tryToTakeOver = false;
+
+        try {
+            final LocalDateTime now = LocalDateTime.now();
+            final LocalDateTime lastTime = docOnNodeEntriesToGC.get(notMemberUuid);
+
+            if (lastTime != null) {
+                if ((lastTime.plusSeconds(minWaitTimeBeforeGcAtomicLong).isBefore(now))) {
+                    docOnNodeEntriesToGC.remove(notMemberUuid);
+                    tryToTakeOver = true;
+                }
+            } else {
+                final RT2NodeHealthState nodeHealthState = nodeHealthMap.get(notMemberUuid.toString());
+                if (nodeHealthState != null) {
+                    final String nodeState = nodeHealthState.getState();
+                    final String cleanupUUID = nodeHealthState.getCleanupUUID();
+                    if ((RT2NodeHealth.RT2_NODE_HEALTH_SHUTTING_DOWN.equals(nodeState)) ||
+                        StringUtils.isEmpty(cleanupUUID) || !isActiveHzMember(cleanupUUID)) {
+                        docOnNodeEntriesToGC.put(notMemberUuid, now);
+                        log.debug("RT2GarbageCollector marked node {} for gc as node is not member and health state does not indicate that a clean-up process is running", notMemberUuid);
+                    }
+                } else {
+                    docOnNodeEntriesToGC.put(notMemberUuid, now);
+                    log.debug("RT2GarbageCollector marked node {} for gc as node is not member and there is no health state available", notMemberUuid);
+                }
+            }
+        } catch (Exception e) {
+            log.warn("Trying analyze health map entry for clean-up or try to lock for node " + notMemberUuid.toString() + " failed with exception", e);
+        }
+
+        return tryToTakeOver;
+    }
+
+    //-------------------------------------------------------------------------
+    private boolean isActiveHzMember(String nodeUuid) {
+        if (StringUtils.isEmpty(nodeUuid))
+            return false;
+
+        boolean isActive = false;
+        final Set<Member> members = hazelcastInstance.getCluster().getMembers();
+        if (members != null) {
+            isActive = members.stream().anyMatch(m -> nodeUuid.equals(m.getUuid()));
+        }
+        return isActive;
+    }
+
+    //-------------------------------------------------------------------------
+    private void removeDocOnNodeEntryAndAtomicLongForDocUid(RT2DocUidType docUid, boolean destroyRefCountGlobally) {
+        RT2DocOnNodeMap aDocOnNodeMap = docOnNodeMap;
+        log.info("Removing docOnNodeMap entry with key {}", docUid.getValue());
+        ClusterLock clusterLock = clusterLockService.getLock(docUid);
+        try {
+            clusterLock.lock();
+            if (aDocOnNodeMap.remove(docUid.getValue()) == null) {
+                LogProperties.putProperty(LogProperties.Name.RT2_DOC_UID, docUid.getValue());
+                log.error("Cannot remove entry with doc-uid {} from DocOnNodeMap", docUid.getValue());
+            }
+
+            RT2DocInfo aDocInfo = docInfoRegistry.getDocInfoWithoutCreate(docUid);
+            if (destroyRefCountGlobally && (aDocInfo == null)) {
+                // Attention: This is a workaround to destroy the ref count four line later. The RT2DistributedDocInfo
+                // just contains all known document instance that were created on this node. In case of a global
+                // clean-up this node never has an entry, but we need it to destroy it. As we could see in dumps
+                // of other clusters in most cases a AtomicLong instance is present when we need to clean-up the
+                // DocOnNodeMap for a stale groupware node.
+                aDocInfo = new RT2DocInfo(hazelcastInstance, docUid.toString());
+            }
+            if (aDocInfo != null) {
+                aDocInfo.destroyRefCount4Clients();
+                docOnNodeMapEntryRemovedCounter.inc();
+            } else {
+                LogProperties.putProperty(LogProperties.Name.RT2_DOC_UID, docUid.getValue());
+                log.warn("No RefCount4Clients for document with doc-uid {} found!", docUid.getValue());
+            }
+        } catch (ClusterLockException e) {
+            // Ignore, try again next time
+        } finally {
+            clusterLock.unlock();
+            LogProperties.removeProperty(LogProperties.Name.RT2_DOC_UID);
+        }
+    }
+
+    //-------------------------------------------------------------------------
+    private void removeCleanedUpMemberFromHealthMap(final RT2NodeUuidType nodeUuToCleanup) throws OXException {
+        log.info("Removing unknown groupware member {} from NodeHealthMap", nodeUuToCleanup.toString());
+        nodeHealthMap.remove(nodeUuToCleanup.toString());
     }
 
     //-------------------------------------------------------------------------
@@ -547,34 +741,6 @@ public class RT2GarbageCollector
                                   .collect(Collectors.toSet());
     }
 
-    //-------------------------------------------------------------------------
-    private synchronized RT2DocInfoRegistry mem_DocInfoRegistry ()
-    {
-        final RT2DocInfoRegistry aDocRegistry = ServiceLookupRegistry.get ().getService(RT2DocInfoRegistry.class);
-        return aDocRegistry;
-    }
-
-    //-------------------------------------------------------------------------
-    private synchronized RT2DocProxyRegistry mem_DocProxyRegistry ()
-    {
-        final RT2DocProxyRegistry aDocRegistry = ServiceLookupRegistry.get ().getService(RT2DocProxyRegistry.class);
-        return aDocRegistry;
-    }
-
-    //-------------------------------------------------------------------------
-    private synchronized RT2DocOnNodeMap mem_DocOnNodeMap() {
-    	final RT2DocOnNodeMap aDocOnNodeMap = ServiceLookupRegistry.get().getService(RT2DocOnNodeMap.class);
-    	return aDocOnNodeMap;
-    }
-
-    private synchronized IDocProcessorContainer mem_DocProcessorManager() {
-    	final IDocProcessorContainer docProcessorManager = ServiceLookupRegistry.get().getService(IRT2DocProcessorManager.class);
-    	return docProcessorManager;
-    }
-
-    //-------------------------------------------------------------------------
-    private ScheduledExecutorService m_aScheduler = null;
-
     private class FinalRt2DocProcessorRemoveThread implements Runnable {
 
     	private final Set<RT2DocUidType> possibleDocProcessorToRemove;
@@ -585,15 +751,15 @@ public class RT2GarbageCollector
 
 		@Override
 		public void run() {
-			final Set<WeakReference<RT2DocProcessor>> aLocalDocProcessors = docProcContainer.getWeakReferenceToDocProcessors();
+			final Set<WeakReference<RT2DocProcessor>> aLocalDocProcessors = docProcMngr.getWeakReferenceToDocProcessors();
 			final Set<RT2DocProcessor> aDocProcessorsWOClients = retrieveDocProcessorsWithoutClients(aLocalDocProcessors);
-			final RT2DocInfoRegistry       aDocRegistry        = mem_DocInfoRegistry ();
+			final RT2DocInfoRegistry       aDocRegistry        = docInfoRegistry;
 			for (RT2DocProcessor docProc : aDocProcessorsWOClients) {
 				if (possibleDocProcessorToRemove.contains(docProc.getDocUID())) {
 	                final RT2DocUidType     sDocUID   = docProc.getDocUID();
 	                final RT2DocInfo aDocInfo  = aDocRegistry.peekDocInfo(sDocUID);
 					destroyRefCount4Clients(sDocUID, aDocInfo);
-					docProcContainer.docProcessorDisposed(docProc);
+					docProcMngr.docProcessorDisposed(docProc);
 					LogProperties.putProperty(LogProperties.Name.RT2_DOC_UID, sDocUID.getValue());
 					log.info("Removed doc processor with docUid {} because there is no client for the last 5 minutes.", sDocUID);
 					LogProperties.remove(LogProperties.Name.RT2_DOC_UID);
