@@ -28,7 +28,7 @@
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
-*     Copyright (C) 2016-2020 OX Software GmbH
+*     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
@@ -56,24 +56,22 @@ import org.apache.commons.lang3.Validate;
 import org.json.JSONException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+import org.springframework.beans.factory.annotation.Autowired;
 
 import com.openexchange.capabilities.CapabilityService;
 import com.openexchange.capabilities.CapabilitySet;
-import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.OXException;
-import com.openexchange.office.rt2.exception.RT2TypedException;
+import com.openexchange.office.rt2.core.exception.RT2TypedException;
 import com.openexchange.office.rt2.protocol.RT2Message;
 import com.openexchange.office.rt2.protocol.RT2MessageFactory;
 import com.openexchange.office.rt2.protocol.RT2MessageGetSet;
 import com.openexchange.office.rt2.protocol.value.RT2CliendUidType;
 import com.openexchange.office.rt2.protocol.value.RT2MessageType;
 import com.openexchange.office.rt2.protocol.value.RT2OldClientUuidType;
-import com.openexchange.office.tools.error.ErrorCode;
-import com.openexchange.office.tools.logging.annotation.Loggable;
+import com.openexchange.office.tools.common.error.ErrorCode;
+import com.openexchange.office.tools.common.log.Loggable;
 import com.openexchange.office.tools.monitoring.PresenterEvent;
 import com.openexchange.office.tools.monitoring.PresenterEventType;
-import com.openexchange.office.tools.monitoring.Statistics;
-import com.openexchange.office.tools.osgi.ServiceLookupRegistry;
 import com.openexchange.session.Session;
 import com.openexchange.tools.session.ServerSession;
 import com.openexchange.user.User;
@@ -86,13 +84,19 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
     private static final int    MAX_DEFAULT_PARTICIPANTS_FOR_PRESENTATION = 100;
     private static final String DOCTYPE_IDENTIFIER                        = "presenter";
     private static int          MAX_NUMBER_OF_PARTICIPANTS                = MAX_DEFAULT_PARTICIPANTS_FOR_PRESENTATION;
-    private static boolean      MAX_PARTICIPANTS_INITIALIZED              = false;
+
+    @Autowired
+    private CapabilityService capabilityService;
 
     //-------------------------------------------------------------------------
 	public PresenterDocProcessor() throws Exception {
 		super();
+	}
 
-		initMaxParticipants();
+    //-------------------------------------------------------------------------
+	@Override
+	public boolean isOTEnabled() {
+		return false;
 	}
 
     //-------------------------------------------------------------------------
@@ -120,13 +124,12 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
 	// message processing
     //-------------------------------------------------------------------------
 
-    //-------------------------------------------------------------------------
     @Override
     public boolean onJoin(RT2Message request) throws Exception {
         super.onJoin(request);
 
         final RT2Message aResponse = RT2MessageFactory.createResponseFromMessage(request, RT2MessageType.RESPONSE_JOIN);
-        sendMessageWOSeqNrTo (request.getClientUID(), aResponse);
+        messageSender.sendMessageWOSeqNrTo (request.getClientUID(), aResponse);
         return true;
     }
 
@@ -142,12 +145,10 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
         // make sure that a non-presenter client (e.g. presentation) won't receives
         // an error trying to open the document being presented
         if (!getDocTypeIdentifier().equals(sDocType))
-            throw new RT2TypedException(ErrorCode.GENERAL_SYSTEM_BUSY_ERROR, getMsgsAsList());
+            throw new RT2TypedException(ErrorCode.LOADDOCUMENT_PRESENTATION_IS_BEING_PRESENTED_ERROR, rt2MessageLoggerService.getMsgsAsList(getDocUID()));
 
         log.debug("PresenterConnection [onOpenDoc] for client with id {}", sClientUID);
 
-        super.onOpenDoc(aMsg);
-
         final ServerSession aSession = sessionService.getSession4Id(sSessionID);
         impl_handlePresenter(aSession, sClientUID, sOldClientUID);
 
@@ -157,18 +158,24 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
         final PresenterClientsStatus  aClientsStatus = (PresenterClientsStatus)this.getClientsStatusClone();
         MessageHelper.setDocumentStatus(aOpenResponse, aDocStatus);
         MessageHelper.setClientsStatus(aOpenResponse, aClientsStatus, true);
-        sendMessageTo(sClientUID, aOpenResponse);
+        messageSender.sendMessageTo(sClientUID, aOpenResponse);
 
         // send updates to all if document and/or clients status has changed
         impl_broadcastDocumentStatusIfModified(sClientUID);
         impl_broadcastClientsStatusIfModified(sClientUID);
 
-        Statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.OPEN));
+        statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.OPEN));
 
         return true;
 	}
 
     //-------------------------------------------------------------------------
+    @Override
+	public boolean onAdditionalOpenDoc(RT2Message aMsg) throws Exception {
+    	return onOpenDoc(aMsg);
+	}
+
+	//-------------------------------------------------------------------------
 	@Override
 	public boolean onCloseDoc(final RT2Message aMsg) throws Exception
 	{
@@ -186,15 +193,15 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
 
         // send close doc response
         final RT2Message aCloseResponse = RT2MessageFactory.createResponseFromMessage(aMsg, RT2MessageType.RESPONSE_CLOSE_DOC);
-        sendMessageTo(sClientUID, aCloseResponse);
+        messageSender.sendMessageTo(sClientUID, aCloseResponse);
 
         // send updates to all if document and/or clients status has changed
         impl_broadcastDocumentStatusIfModified(sClientUID);
         impl_broadcastClientsStatusIfModified(sClientUID);
 
-        Statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.CLOSE));
+        statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.CLOSE));
 
-		return super.onCloseDoc(aMsg);
+		return true;
 	}
 
     //-------------------------------------------------------------------------
@@ -218,7 +225,7 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
         impl_broadcastDocumentStatusIfModified(sClientUID);
         impl_broadcastClientsStatusIfModified(sClientUID);
 
-        Statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.CLOSE));
+        statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.CLOSE));
 
         // base class sends response to emergency leave
 		return super.onEmergencyLeave(aMsg);
@@ -232,7 +239,7 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
         final RT2Message aSyncResponse = RT2MessageFactory.createResponseFromMessage(aMsg, RT2MessageType.RESPONSE_SYNC);
 
         aSyncResponse.setBody(aDocStatus.toJSON());
-        sendMessageTo(aMsg.getClientUID(), aSyncResponse);
+        messageSender.sendMessageTo(aMsg.getClientUID(), aSyncResponse);
 
 		return true;
 	}
@@ -245,7 +252,7 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
         final RT2Message aSyncResponse = RT2MessageFactory.createResponseFromMessage(aMsg, RT2MessageType.RESPONSE_SYNC_STABLE);
 
         aSyncResponse.setBody(aDocStatus.toJSON());
-        sendMessageTo(aMsg.getClientUID(), aSyncResponse);
+        messageSender.sendMessageTo(aMsg.getClientUID(), aSyncResponse);
 
 		return true;
 	}
@@ -277,7 +284,7 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
 
         log.debug("PresenterConnection [handleUpdateSlide] for client uid {}", sClientUID);
 
-        Statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.OPERATIONS_INCOMING));
+        statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.OPERATIONS_INCOMING));
 
         int countParticipants = 0;
         Set<RT2CliendUidType>   aParticipants    = null;
@@ -285,14 +292,14 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
         synchronized (getStatusSyncObject())
         {
             if ( ! aDocStatus.isPresenter(sClientUID))
-                throw new RT2TypedException (ErrorCode.HANGUP_NO_EDIT_RIGHTS_ERROR, getMsgsAsList());
+                throw new RT2TypedException (ErrorCode.HANGUP_NO_EDIT_RIGHTS_ERROR, rt2MessageLoggerService.getMsgsAsList(getDocUID()));
 
             final int nActiveSlide = MessageHelper.getCurrentSlide(aMsg);
             boolean   bChanged     = aDocStatus.setActiveSlide(nActiveSlide);
 
             // send response to presenter
             final RT2Message aResponse = RT2MessageFactory.createResponseFromMessage(aMsg, RT2MessageType.RESPONSE_APP_ACTION);
-            sendMessageTo(sClientUID, aResponse);
+            messageSender.sendMessageTo(sClientUID, aResponse);
 
             if (bChanged)
             {
@@ -307,7 +314,7 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
 
         if (null != aUpdateDocStatus) {
             impl_broadcastDocumentStatusToParticipants(aParticipants, aUpdateDocStatus);
-            Statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.OPERATIONS_DISTRIBUTED, countParticipants));
+            statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.OPERATIONS_DISTRIBUTED, countParticipants));
         }
 
         return true;
@@ -330,16 +337,15 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
 
         log.debug("PresenterConnection [handleStartPresentation] for client uid {}", sClientUID);
 
-        Statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.OPERATIONS_INCOMING));
+        statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.OPERATIONS_INCOMING));
 
         final ServerSession           aSession           = sessionService.getSession4Id(sSessionID);
-        final CapabilityService       aCapabilityService = ServiceLookupRegistry.get().getService(CapabilityService.class);
-        final CapabilitySet           aCapabilitySet     = (null != aCapabilityService) ? aCapabilityService.getCapabilities(aSession) : null;
+        final CapabilitySet           aCapabilitySet     = (null != capabilityService) ? capabilityService.getCapabilities(aSession) : null;
 
         if ((null == aCapabilitySet) || (!aCapabilitySet.contains("remote_presenter")))
         {
             log.info("PresenterConnection [handleStartPresentation], remote-presentation disabled by capabilities");
-            throw new RT2TypedException (ErrorCode.GENERAL_SERVICE_DISABLED_ERROR, getMsgsAsList());
+            throw new RT2TypedException (ErrorCode.GENERAL_SERVICE_DISABLED_ERROR, rt2MessageLoggerService.getMsgsAsList(getDocUID()));
         }
 
         final int nActiveSlide     = MessageHelper.getCurrentSlide(aMsg);
@@ -361,7 +367,7 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
             if ( ! ClientsStatus.isEmptyUser(aDocStatus.getCurrentPresenterId().getValue()))
             {
                 log.debug("PresenterConnection [handleStartPresentation], remote-presentation already started");
-                throw new RT2TypedException (ErrorCode.PRESENTER_REMOTE_PRESENTATION_ALREADY_RUNNING_ERROR, getMsgsAsList());
+                throw new RT2TypedException (ErrorCode.PRESENTER_REMOTE_PRESENTATION_ALREADY_RUNNING_ERROR, rt2MessageLoggerService.getMsgsAsList(getDocUID()));
             }
 
             try
@@ -379,14 +385,14 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
 
         // send response to presenter
         final RT2Message aResponse = RT2MessageFactory.createResponseFromMessage(aMsg, RT2MessageType.RESPONSE_APP_ACTION);
-        sendMessageTo(sClientUID, aResponse);
+        messageSender.sendMessageTo(sClientUID, aResponse);
 
         // send updates to all if document and/or clients status has changed
         impl_broadcastDocumentStatusIfModified(null);
         impl_broadcastClientsStatusIfModified(null);
 
-        Statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.REMOTE_PRESENTER_START));
-        Statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.OPERATIONS_DISTRIBUTED, countParticipants));
+        statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.REMOTE_PRESENTER_START));
+        statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.OPERATIONS_DISTRIBUTED, countParticipants));
     }
 
     //-------------------------------------------------------------------------
@@ -404,7 +410,7 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
 
         log.debug("PresenterConnection [handleEndPresentation] for client uid {}", sClientUID);
 
-        Statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.OPERATIONS_INCOMING));
+        statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.OPERATIONS_INCOMING));
 
         int countParticipants = 0;
         synchronized (getStatusSyncObject())
@@ -427,14 +433,14 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
 
         // send response to presenter
         final RT2Message aResponse = RT2MessageFactory.createResponseFromMessage(aMsg, RT2MessageType.RESPONSE_APP_ACTION);
-        sendMessageTo(sClientUID, aResponse);
+        messageSender.sendMessageTo(sClientUID, aResponse);
 
         // send updates to all if document and/or clients status has changed
         impl_broadcastDocumentStatusIfModified(null);
         impl_broadcastClientsStatusIfModified(null);
 
-        Statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.OPERATIONS_DISTRIBUTED, countParticipants));
-        Statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.REMOTE_PRESENTER_END));
+        statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.OPERATIONS_DISTRIBUTED, countParticipants));
+        statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.REMOTE_PRESENTER_END));
     }
 
     //-------------------------------------------------------------------------
@@ -449,7 +455,7 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
         final RT2CliendUidType         sClientUID = aMsg.getClientUID();
         final PresenterDocumentStatus  aDocStatus = (PresenterDocumentStatus)this.getDocumentStatus();
 
-        Statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.OPERATIONS_INCOMING));
+        statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.OPERATIONS_INCOMING));
 
         log.debug("PresenterConnection [handlePausePresentation] for client uid {}", sClientUID);
 
@@ -472,12 +478,12 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
 
         // send response to presenter
         final RT2Message aResponse = RT2MessageFactory.createResponseFromMessage(aMsg, RT2MessageType.RESPONSE_APP_ACTION);
-        sendMessageTo(sClientUID, aResponse);
+        messageSender.sendMessageTo(sClientUID, aResponse);
 
         // send update to all participants
         if (null != aUpdateDocStatus) {
             impl_broadcastDocumentStatusToParticipants(aParticipants, aUpdateDocStatus);
-            Statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.OPERATIONS_DISTRIBUTED, countParticipants));
+            statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.OPERATIONS_DISTRIBUTED, countParticipants));
         }
     }
 
@@ -493,7 +499,7 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
         final RT2CliendUidType        sClientUID = aMsg.getClientUID();
         final PresenterDocumentStatus aDocStatus = (PresenterDocumentStatus)this.getDocumentStatus();
 
-        Statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.OPERATIONS_INCOMING));
+        statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.OPERATIONS_INCOMING));
 
         log.debug("PresenterConnection [handleContinuePresentation] for client uid {}", sClientUID);
 
@@ -516,12 +522,12 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
 
         // send response to presenter
         final RT2Message aResponse = RT2MessageFactory.createResponseFromMessage(aMsg, RT2MessageType.RESPONSE_APP_ACTION);
-        sendMessageTo(sClientUID, aResponse);
+        messageSender.sendMessageTo(sClientUID, aResponse);
 
         // send update to all participants
         if (null != aUpdateDocStatus) {
             impl_broadcastDocumentStatusToParticipants(aParticipants, aUpdateDocStatus);
-            Statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.OPERATIONS_DISTRIBUTED, countParticipants));
+            statistics.handlePresenterEvent(new PresenterEvent(PresenterEventType.OPERATIONS_DISTRIBUTED, countParticipants));
         }
     }
 
@@ -543,6 +549,7 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
 
         synchronized (getStatusSyncObject())
         {
+        	initMaxParticipants();
             if (aClientsStatus.getParticipantsCount() < MAX_NUMBER_OF_PARTICIPANTS)
                 aClientsStatus.setParticipantState(aMsg.getClientUID(), true);
             else
@@ -550,7 +557,7 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
         }
 
         // send response to joining client
-        sendMessageTo(aMsg.getClientUID(), aResponse);
+        messageSender.sendMessageTo(aMsg.getClientUID(), aResponse);
 
         // Send joining client a document update to ensure that it receives the latest
         // active slide. Non-participants won't receive updates, therefore the active slide
@@ -582,7 +589,7 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
 
         // send response to presenter
         final RT2Message aResponse = RT2MessageFactory.createResponseFromMessage(aMsg, RT2MessageType.RESPONSE_APP_ACTION);
-        sendMessageTo(sClientUID, aResponse);
+        messageSender.sendMessageTo(sClientUID, aResponse);
 
         impl_broadcastClientsStatusIfModified(null);
     }
@@ -631,7 +638,7 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
     {
         final RT2Message aUpdateDocStatetMsg = RT2MessageFactory.newMessage(RT2MessageType.BROADCAST_UPDATE, clientUID, getDocUID());
         MessageHelper.setDocumentStatus(aUpdateDocStatetMsg, aDocStatus);
-        sendMessageTo(clientUID, aUpdateDocStatetMsg);
+        messageSender.sendMessageTo(clientUID, aUpdateDocStatetMsg);
     }
 
     //-------------------------------------------------------------------------
@@ -641,9 +648,9 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
         if (null != aUpdateDocStatus)
         {
             // broadcast document update message to all other clients in case status has changed
-            final RT2Message aUpdateDocStateBroadcast = RT2MessageFactory.newBroadcastMessage(RT2MessageType.BROADCAST_UPDATE);
+            final RT2Message aUpdateDocStateBroadcast = RT2MessageFactory.newBroadcastMessage(RT2MessageType.BROADCAST_UPDATE, getDocUID());
             MessageHelper.setDocumentStatus(aUpdateDocStateBroadcast, aUpdateDocStatus);
-            broadcastMessageExceptClient (sExceptClientUID, aUpdateDocStateBroadcast, RT2MessageType.BROADCAST_UPDATE);
+            messageSender.broadcastMessageExceptClient (sExceptClientUID, aUpdateDocStateBroadcast, RT2MessageType.BROADCAST_UPDATE);
         }
     }
 
@@ -655,9 +662,9 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
         if (null != aUpdateClientsStatus)
         {
             // broadcast clients update message to all other clients in case status has changed
-            final RT2Message aUpdateDocStateBroadcast = RT2MessageFactory.newBroadcastMessage(RT2MessageType.BROADCAST_UPDATE_CLIENTS);
+            final RT2Message aUpdateDocStateBroadcast = RT2MessageFactory.newBroadcastMessage(RT2MessageType.BROADCAST_UPDATE_CLIENTS, getDocUID());
             MessageHelper.setClientsStatus(aUpdateDocStateBroadcast, aUpdateClientsStatus, false);
-            broadcastMessageExceptClient (sExceptClientUID, aUpdateDocStateBroadcast, RT2MessageType.BROADCAST_UPDATE_CLIENTS);
+            messageSender.broadcastMessageExceptClient (sExceptClientUID, aUpdateDocStateBroadcast, RT2MessageType.BROADCAST_UPDATE_CLIENTS);
         }
     }
 
@@ -669,43 +676,46 @@ public class PresenterDocProcessor extends DocProcessor implements Loggable
         if ((null != aParticipants) && !aParticipants.isEmpty())
         {
 	        // broadcast update message to all other clients
-	        final RT2Message aUpdateDocStateBroadcast = RT2MessageFactory.newBroadcastMessage(RT2MessageType.BROADCAST_UPDATE);
+	        final RT2Message aUpdateDocStateBroadcast = RT2MessageFactory.newBroadcastMessage(RT2MessageType.BROADCAST_UPDATE, getDocUID());
 	        MessageHelper.setDocumentStatus(aUpdateDocStateBroadcast, aUpdatedDocStatus);
-	        broadcastMessageTo(aParticipants, aUpdateDocStateBroadcast, RT2MessageType.BROADCAST_UPDATE);
+	        messageSender.broadcastMessageTo(aParticipants, aUpdateDocStateBroadcast, RT2MessageType.BROADCAST_UPDATE);
         }
     }
 
     //-------------------------------------------------------------------------
     private synchronized void initMaxParticipants()
     {
-        if (!MAX_PARTICIPANTS_INITIALIZED)
-        {
-            try
-            {
-                final ConfigurationService configService = ServiceLookupRegistry.get().getService(ConfigurationService.class);
-                if (null != configService)
-                    MAX_NUMBER_OF_PARTICIPANTS = configService.getIntProperty("com.openexchange.presenter.maxParticipants", MAX_DEFAULT_PARTICIPANTS_FOR_PRESENTATION);
-            }
-            catch (Exception e)
-            {
-                log.warn("Presenter: Unable to retrieve configuration service - using default for maxNumberOfParticipants", e);
-            }
-            finally
-            {
-                MAX_PARTICIPANTS_INITIALIZED = true;
-            }
-        }
+       	MAX_NUMBER_OF_PARTICIPANTS = configurationService.getIntProperty("com.openexchange.presenter.maxParticipants", MAX_DEFAULT_PARTICIPANTS_FOR_PRESENTATION);
     }
 
-	//-------------------------------------------------------------------------
-    @Override
-	public int getPendingOperationsCount() {
-		return 0;
-	}
-
-	//-------------------------------------------------------------------------
+    //-------------------------------------------------------------------------
 	@Override
 	public Logger getLogger() {
 		return log;
 	}
+
+	@Override
+	public boolean onFirstOpenDoc(RT2Message aMsg) throws Exception {
+		return onOpenDoc(aMsg);
+	}
+
+	@Override
+	public boolean onApplyOperations(RT2Message aMsg) throws Exception {
+		return false;
+	}
+
+	@Override
+	public boolean onSaveDoc(RT2Message aMsg) throws Exception {
+		return false;
+	}
+
+	@Override
+	public boolean onEditRights(RT2Message aMsg) throws Exception {
+		return false;
+	}
+
+	@Override
+	public int getPendingOperationsCount() {
+		return 0;
+	}
 }
