@@ -60,16 +60,22 @@ import java.util.Map;
 import org.apache.commons.lang3.Validate;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+import org.springframework.beans.factory.DisposableBean;
+import org.springframework.beans.factory.InitializingBean;
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
+import org.springframework.stereotype.Service;
 
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.ExceptionUtils;
+import com.openexchange.office.rt2.core.config.RT2ConfigService;
+import com.openexchange.office.tools.annotation.ShutdownOrder;
 import com.openexchange.office.tools.common.EasyStopWatch;
+import com.openexchange.office.tools.common.error.ErrorCode;
 import com.openexchange.office.tools.doc.ApplicationType;
-import com.openexchange.office.tools.error.ErrorCode;
 import com.openexchange.office.tools.monitoring.BackgroundSaveEvent;
 import com.openexchange.office.tools.monitoring.BackgroundSaveEventType;
 import com.openexchange.office.tools.monitoring.Statistics;
-import com.openexchange.office.tools.osgi.ServiceLookupRegistry;
 
 /**
  * A class which controls the background save of modified documents according to
@@ -81,8 +87,18 @@ import com.openexchange.office.tools.osgi.ServiceLookupRegistry;
  * @since v7.10.0
  *
  */
-public class RT2BackgroundDocSaveManager implements IDocNotificationHandler, IProcessDocCollection {
-    /**
+@Service
+@ShutdownOrder(value=-10)
+@ConditionalOnProperty(name= {RT2ConfigService.KEY_BACKGROUND_SAVE_DOC}, matchIfMissing=true)
+public class RT2BackgroundDocSaveManager implements IDocNotificationHandler, IProcessDocCollection, InitializingBean, DisposableBean {
+
+	@Autowired
+	private Statistics statistics;
+
+    @Autowired
+    private EmergencySaver emergencySaver;
+
+	/**
      * Internal class to encapsulate the timer based background processing of the
      * document processors.
      *
@@ -124,10 +140,14 @@ public class RT2BackgroundDocSaveManager implements IDocNotificationHandler, IPr
     private Map<String, WeakReference<IBackgroundSavable>> m_savableDocCollection = new HashMap<>();
     private boolean                                        m_clearInsteadOfSave   = false;
 
-    //-------------------------------------------------------------------------
-    public RT2BackgroundDocSaveManager() {
-        final ConfigurationService cfgService = ServiceLookupRegistry.get().getService(ConfigurationService.class);
+    @Autowired
+    private ConfigurationService cfgService;
 
+    @Autowired
+    private RT2ConfigService rt2ConfigService;
+
+    @Override
+	public void afterPropertiesSet() throws Exception {
         int minOperationsForFailSafeSaveText = MIN_OPERATIONS_FOR_FAILSAFESAVE;
         int minOperationsForFailSafeSaveSpreadsheet = MIN_OPERATIONS_FOR_FAILSAFESAVE;
         int minOperationsForFailSafeSavePresentation = MIN_OPERATIONS_FOR_FAILSAFESAVE;
@@ -139,12 +159,11 @@ public class RT2BackgroundDocSaveManager implements IDocNotificationHandler, IPr
             if (m_clearInsteadOfSave) {
                 log.warn("RT2: Warning - fail safe save is configured to clear the operation queue of the documents - this is for sizing tests only!");
             }
-            minOperationsForFailSafeSaveText = ConfigOT.isOTEnabled(cfgService, ApplicationType.APP_TEXT_STRING) ? MIN_OPERATIONS_FOR_FAILSAFESAVE_FOR_OT : MIN_OPERATIONS_FOR_FAILSAFESAVE;
-            minOperationsForFailSafeSaveSpreadsheet = ConfigOT.isOTEnabled(cfgService, ApplicationType.APP_SPREADSHEET_STRING) ? MIN_OPERATIONS_FOR_FAILSAFESAVE_FOR_OT : MIN_OPERATIONS_FOR_FAILSAFESAVE;
-            minOperationsForFailSafeSavePresentation = ConfigOT.isOTEnabled(cfgService, ApplicationType.APP_PRESENTATION_STRING) ? MIN_OPERATIONS_FOR_FAILSAFESAVE_FOR_OT : MIN_OPERATIONS_FOR_FAILSAFESAVE;
+            minOperationsForFailSafeSaveText = rt2ConfigService.isOTEnabled(ApplicationType.APP_TEXT_STRING) ? MIN_OPERATIONS_FOR_FAILSAFESAVE_FOR_OT : MIN_OPERATIONS_FOR_FAILSAFESAVE;
+            minOperationsForFailSafeSaveSpreadsheet = rt2ConfigService.isOTEnabled(ApplicationType.APP_SPREADSHEET_STRING) ? MIN_OPERATIONS_FOR_FAILSAFESAVE_FOR_OT : MIN_OPERATIONS_FOR_FAILSAFESAVE;
+            minOperationsForFailSafeSavePresentation = rt2ConfigService.isOTEnabled(ApplicationType.APP_PRESENTATION_STRING) ? MIN_OPERATIONS_FOR_FAILSAFESAVE_FOR_OT : MIN_OPERATIONS_FOR_FAILSAFESAVE;
         }
 
-        final Statistics statistics = Statistics.get();
         if (null != statistics) {
             statistics.setBackgroundSaveMinNumOfMsgForFasterSaveText(minOperationsForFailSafeSaveText);
             statistics.setBackgroundSaveMinNumOfMsgForFasterSaveSpreadsheet(minOperationsForFailSafeSaveSpreadsheet);
@@ -152,13 +171,6 @@ public class RT2BackgroundDocSaveManager implements IDocNotificationHandler, IPr
             statistics.setBackgroundSaveMinTimeFasterSave(MIN_TIME_FOR_MANY_OPS_FAILSAFESAVE);
             statistics.setBackgroundSaveMaxTimeForSave(MAX_TIME_FOR_MODIFIED_FAILSAFESAVE);
         }
-    }
-
-    //-------------------------------------------------------------------------
-    /**
-     * Starts the document processing on a timer-based scheme.
-     */
-    public synchronized void start() {
         if (m_backgroundThread == null) {
             m_backgroundThread = new Thread(new ProcessingRunnable(this));
             m_backgroundThread.setPriority(Thread.NORM_PRIORITY - 1);
@@ -171,18 +183,21 @@ public class RT2BackgroundDocSaveManager implements IDocNotificationHandler, IPr
     /**
      * Stops a running document processing timer.
      */
-    public synchronized void stop() {
+    public synchronized boolean stop() {
         if (m_backgroundThread != null) {
             try {
                 m_backgroundThread.interrupt();
                 m_backgroundThread.join();
                 m_backgroundThread = null;
+                return true;
             }
             catch (final InterruptedException e) {
                 log.debug("RT2: RT2BackgroundDocSaveManager InterruptedException caught preparing shutdown of the background saving thread", e);
                 Thread.currentThread().interrupt();
             }
         }
+
+        return false;
     }
 
     //-------------------------------------------------------------------------
@@ -271,9 +286,9 @@ public class RT2BackgroundDocSaveManager implements IDocNotificationHandler, IPr
 		                if (numOfDocumentsSaved > 0) {
 			                final long timePerDoc  = (elapsedTime / Math.max(numOfDocumentsSaved, 1));
 
-			                Statistics.handleBackgroundSaveDocEvent(new BackgroundSaveEvent(BackgroundSaveEventType.FSS_LAST_CYCLE_DOC_COUNT, numOfDocumentsSaved));
-			                Statistics.handleBackgroundSaveDocEvent(new BackgroundSaveEvent(BackgroundSaveEventType.FSS_LAST_CYCLE_TIME, elapsedTime));
-			                Statistics.handleBackgroundSaveDocEvent(new BackgroundSaveEvent(BackgroundSaveEventType.FSS_LAST_CYCLE_TIME_PER_DOC, timePerDoc));
+			                statistics.handleBackgroundSaveDocEvent(new BackgroundSaveEvent(BackgroundSaveEventType.FSS_LAST_CYCLE_DOC_COUNT, numOfDocumentsSaved));
+			                statistics.handleBackgroundSaveDocEvent(new BackgroundSaveEvent(BackgroundSaveEventType.FSS_LAST_CYCLE_TIME, elapsedTime));
+			                statistics.handleBackgroundSaveDocEvent(new BackgroundSaveEvent(BackgroundSaveEventType.FSS_LAST_CYCLE_TIME_PER_DOC, timePerDoc));
 
 			                log.debug("RT2: FSS Pool contains {} document(s) to be saved - {} document(s) were saved in {} ms, time per document = {}", aSavableDocList.size(), numOfDocumentsSaved, elapsedTime, timePerDoc);
 		                } else {
@@ -312,9 +327,9 @@ public class RT2BackgroundDocSaveManager implements IDocNotificationHandler, IPr
 
     //-------------------------------------------------------------------------
     private void resetBackgroundSaveMetrics() {
-        Statistics.handleBackgroundSaveDocEvent(new BackgroundSaveEvent(BackgroundSaveEventType.FSS_LAST_CYCLE_DOC_COUNT, 0));
-        Statistics.handleBackgroundSaveDocEvent(new BackgroundSaveEvent(BackgroundSaveEventType.FSS_LAST_CYCLE_TIME, 0));
-        Statistics.handleBackgroundSaveDocEvent(new BackgroundSaveEvent(BackgroundSaveEventType.FSS_LAST_CYCLE_TIME_PER_DOC_RESET));
+        statistics.handleBackgroundSaveDocEvent(new BackgroundSaveEvent(BackgroundSaveEventType.FSS_LAST_CYCLE_DOC_COUNT, 0));
+        statistics.handleBackgroundSaveDocEvent(new BackgroundSaveEvent(BackgroundSaveEventType.FSS_LAST_CYCLE_TIME, 0));
+        statistics.handleBackgroundSaveDocEvent(new BackgroundSaveEvent(BackgroundSaveEventType.FSS_LAST_CYCLE_TIME_PER_DOC_RESET));
     }
 
     //-------------------------------------------------------------------------
@@ -423,13 +438,15 @@ public class RT2BackgroundDocSaveManager implements IDocNotificationHandler, IPr
     }
 
     //-------------------------------------------------------------------------
-    public void shutdown() {
-        stop();
+	@Override
+	public void destroy() throws Exception {
+        if (stop()) {
 
-        // Let the emergency saver decide which document must be
-        // handle via emergencySave. Due to the advisory lock feature
-        // this depends on several more conditions.
-        EmergencySaver.emergencySave();
-    }
+            // Let the emergency saver decide which document must be
+            // handle via emergencySave. Due to the advisory lock feature
+            // this depends on several more conditions.
+            emergencySaver.emergencySave();
+        }
+	}
 
 }
