@@ -276,6 +276,11 @@ public class RT2Message implements Comparable<RT2Message>
         return (T) null;
     }
 
+    //-------------------------------------------------------------------------
+    public <T> T getHeaderUnchecked(final String header) {
+        return impl_getHeader(header, null);
+    }
+
     //-------------------------------------------------------------------------
     public < T > void setHeader (final String sHeader, final T      aValue ) {
         final int nFlags = RT2Protocol.get().getFlag4Header(sHeader);
