@@ -53,7 +53,7 @@ import java.util.List;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.commons.lang3.Validate;
 import com.openexchange.office.rt2.protocol.internal.EDocState;
-import com.openexchange.office.tools.error.ErrorCode;
+import com.openexchange.office.tools.common.error.ErrorCode;
 
 //=============================================================================
 public class RT2MessageGetSet
@@ -242,6 +242,18 @@ public class RT2MessageGetSet
         setOptionalHeader (aMessage, RT2Protocol.HEADER_FAST_EMPTY_OSN, nFastEmptyOSN);
     }
 
+    //-------------------------------------------------------------------------
+    public static String getUserAgent (final RT2Message aMessage)
+    {
+        return getOptionalHeader (aMessage, RT2Protocol.HEADER_USERAGENT, null);
+    }
+
+    //-------------------------------------------------------------------------
+    public static void setUserAgent (final RT2Message aMessage, final String userAgent )
+    {
+        setOptionalHeader (aMessage, RT2Protocol.HEADER_USERAGENT, userAgent);
+    }
+
     //-------------------------------------------------------------------------
     public static String getAuthCode (final RT2Message aMessage)
     {
@@ -403,6 +415,11 @@ public class RT2MessageGetSet
         setOptionalHeader (aMessage, RT2Protocol.HEADER_INTENAL_BACKEND_PROCESSING_NODE, backId);
     }
 
+    //-------------------------------------------------------------------------
+    public static boolean hasError(RT2Message msg) {
+        final Integer errorCode = getOptionalHeader(msg, RT2Protocol.HEADER_ERROR_CODE, null);
+        return (errorCode != null);
+    }
 
     //-------------------------------------------------------------------------
     public static void setError (final RT2Message aMessage,
