@@ -1,6 +1,6 @@
 package com.openexchange.office.rt2.protocol.value;
 
-import com.openexchange.office.tools.error.ErrorCode;
+import com.openexchange.office.tools.common.error.ErrorCode;
 
 public class RT2ErrorCodeType extends RT2ValueType<ErrorCode> {
 
