@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,9 +53,9 @@ import java.util.UUID;
 
 import org.apache.commons.lang3.Validate;
 import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.hazelcast.core.HazelcastInstance;
-import com.openexchange.office.tools.logging.LogFactory;
 
 //=============================================================================
 /** implements a cache on top of Hazelcast.
@@ -77,7 +77,7 @@ import com.openexchange.office.tools.logging.LogFactory;
 public class HazelcastCache implements ICache
 {
 	//-------------------------------------------------------------------------
-	private static final Logger LOG = LogFactory.getSlfLog(HazelcastCache.class);
+	private static final Logger LOG = LoggerFactory.getLogger(HazelcastCache.class);
 
 	//-------------------------------------------------------------------------
 	public static final String ATTR_VALUE = "value";
