@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,10 +49,6 @@
 
 package com.openexchange.office.tools.common.system;
 
-import java.lang.management.ManagementFactory;
-import java.lang.management.MemoryMXBean;
-import java.lang.management.MemoryUsage;
-
 /**
  * Helper class to access system specific information of the JVM.
  *
@@ -68,7 +64,7 @@ public class SystemInfoHelper {
     public static class MemoryInfo {
         public long usedHeapSize = 0;
         public long maxHeapSize = 0;
-        public long committedHeapSize = 0;
+        public long freeHeapSize = 0;
     }
 
     /**
@@ -80,19 +76,33 @@ public class SystemInfoHelper {
      *  values are zero in case the information could not be retrieved.
      */
     static public MemoryInfo getMemoryInfo() {
-        MemoryInfo memInfo = new MemoryInfo();
+    	MemoryInfo memInfo = new MemoryInfo();
+        memInfo.maxHeapSize = maxMemory();
+        memInfo.usedHeapSize = totalMemory();
+        memInfo.freeHeapSize = freeMemory();
 
-        final MemoryMXBean memoryMXBean = ManagementFactory.getMemoryMXBean();
-        final MemoryUsage heapMemoryUsage = memoryMXBean.getHeapMemoryUsage();
-
-        if (null != heapMemoryUsage) {
-            memInfo.maxHeapSize = heapMemoryUsage.getMax();
-            memInfo.usedHeapSize = heapMemoryUsage.getUsed();
-            memInfo.committedHeapSize = heapMemoryUsage.getCommitted();
-        }
         return memInfo;
     }
 
+    static public long maxMemory() {
+    	return Runtime.getRuntime().maxMemory();
+    }
+
+    static public long totalMemory() {
+    	return Runtime.getRuntime().totalMemory();
+    }
+
+    static public long freeMemory() {
+    	// Determine the current free heap space by using the possible
+    	// extension for the Java VM to allocate up to max heap space (-Xmx)
+    	// and the amount of free memory which only uses the current total
+    	// memory size as the limit. The addition of both values should
+    	// give a good assumption of the possible free heap space.
+        final long freeHeapSize1 = Runtime.getRuntime().freeMemory();
+        final long freeHeapSize2 = Runtime.getRuntime().maxMemory() - Runtime.getRuntime().totalMemory();
+        return freeHeapSize1 + freeHeapSize2;
+    }
+
     /**
      * Calculates the minimal JVM heap size we need to load a specific
      * document.
