@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,7 +50,6 @@ package com.openexchange.office.tools.doc;
 
 import java.util.HashMap;
 import java.util.Map;
-import com.openexchange.documentconverter.Properties;
 
 
 public class DocumentFormatHelper {
@@ -76,9 +75,11 @@ public class DocumentFormatHelper {
         ODF_DOCUMENT_IMPRESS_TEMPLATE
     }
 
-    public final static String PROP_MIME_TYPE         = "MimeType";
-    public final static String PROP_INPUT_TYPE        = "InputType";
-    public final static String PROP_FILTER_SHORT_NAME = "FilterShortName";
+    public static final String PROP_MIME_TYPE         = "MimeType";
+    public static final String PROP_INPUT_TYPE        = "InputType";
+    public static final String PROP_FILTER_SHORT_NAME = "FilterShortName";
+    public static final String PROP_DOCUMENT_TYPE     = "DocumentType";
+    public static final String PROP_DOCUMENT_FORMAT   = "DocumentFormat";
 
     /**
      * Provides conversion format info for mime type and extension type,
@@ -154,7 +155,8 @@ public class DocumentFormatHelper {
             data.put(PROP_MIME_TYPE, MimeTypeHelper.MIMETYPE_VND_OPENXMLFORMATS_OFFICEDOCUMENT_WORDPROCESSING);
             data.put(PROP_INPUT_TYPE, "docx");
             data.put(PROP_FILTER_SHORT_NAME, "ooxml");
-            data.put("DocumentType", DocumentType.TEXT.toString());
+            data.put(PROP_DOCUMENT_TYPE, DocumentType.TEXT.toString());
+            data.put(PROP_DOCUMENT_FORMAT, DocumentFormat.DOCX.toString());
             break;
         }
 
@@ -162,7 +164,8 @@ public class DocumentFormatHelper {
             data.put(PROP_MIME_TYPE, MimeTypeHelper.MIMETYPE_VND_OPENXMLFORMATS_OFFICEDOCUMENT_SPREADSHEET);
             data.put(PROP_INPUT_TYPE, "xlsx");
             data.put(PROP_FILTER_SHORT_NAME, "ooxml");
-            data.put("DocumentType", DocumentType.SPREADSHEET.toString());
+            data.put(PROP_DOCUMENT_TYPE, DocumentType.SPREADSHEET.toString());
+            data.put(PROP_DOCUMENT_FORMAT, DocumentFormat.XLSX.toString());
             break;
         }
 
@@ -170,7 +173,8 @@ public class DocumentFormatHelper {
             data.put(PROP_MIME_TYPE, MimeTypeHelper.MIMETYPE_VND_OPENXMLFORMATS_OFFICEDOCUMENT_PRESENTATION);
             data.put(PROP_INPUT_TYPE, "pptx");
             data.put(PROP_FILTER_SHORT_NAME, "ooxml");
-            data.put("DocumentType", DocumentType.PRESENTATION.toString());
+            data.put(PROP_DOCUMENT_TYPE, DocumentType.PRESENTATION.toString());
+            data.put(PROP_DOCUMENT_FORMAT, DocumentFormat.PPTX.toString());
             break;
         }
 
@@ -178,7 +182,8 @@ public class DocumentFormatHelper {
             data.put(PROP_MIME_TYPE, MimeTypeHelper.MIMETYPE_VND_OASIS_OPENDOCUMENT_TEXT);
             data.put(PROP_INPUT_TYPE, "odt");
             data.put(PROP_FILTER_SHORT_NAME, "odf");
-            data.put("DocumentType", DocumentType.TEXT.toString());
+            data.put(PROP_DOCUMENT_TYPE, DocumentType.TEXT.toString());
+            data.put(PROP_DOCUMENT_FORMAT, DocumentFormat.ODT.toString());
             break;
         }
 
@@ -186,7 +191,8 @@ public class DocumentFormatHelper {
             data.put(PROP_INPUT_TYPE, "ods");
             data.put(PROP_MIME_TYPE, MimeTypeHelper.MIMETYPE_VND_OASIS_OPENDOCUMENT_SPREADSHEET);
             data.put(PROP_FILTER_SHORT_NAME, "odf");
-            data.put("DocumentType", DocumentType.SPREADSHEET.toString());
+            data.put(PROP_DOCUMENT_TYPE, DocumentType.SPREADSHEET.toString());
+            data.put(PROP_DOCUMENT_FORMAT, DocumentFormat.ODS.toString());
             break;
         }
 
@@ -194,7 +200,8 @@ public class DocumentFormatHelper {
             data.put(PROP_INPUT_TYPE, "odp");
             data.put(PROP_MIME_TYPE, MimeTypeHelper.MIMETYPE_VND_OASIS_OPENDOCUMENT_PRESENTATION);
             data.put(PROP_FILTER_SHORT_NAME, "odf");
-            data.put("DocumentType", DocumentType.PRESENTATION.toString());
+            data.put(PROP_DOCUMENT_TYPE, DocumentType.PRESENTATION.toString());
+            data.put(PROP_DOCUMENT_FORMAT, DocumentFormat.ODP.toString());
             break;
         }
 
@@ -225,7 +232,8 @@ public class DocumentFormatHelper {
             data.put(PROP_MIME_TYPE, MimeTypeHelper.MIMETYPE_VND_OPENXMLFORMATS_OFFICEDOCUMENT_WORDPROCESSING_TEMPLATE);
             data.put(PROP_INPUT_TYPE, "dotx");
             data.put(PROP_FILTER_SHORT_NAME, "ooxml");
-            data.put("DocumentType", DocumentType.TEXT.toString());
+            data.put(PROP_DOCUMENT_TYPE, DocumentType.TEXT.toString());
+            data.put(PROP_DOCUMENT_FORMAT, DocumentFormat.DOCX.toString());
             break;
         }
 
@@ -233,7 +241,8 @@ public class DocumentFormatHelper {
             data.put(PROP_MIME_TYPE, MimeTypeHelper.MIMETYPE_VND_OPENXMLFORMATS_OFFICEDOCUMENT_SPREADSHEET_TEMPLATE);
             data.put(PROP_INPUT_TYPE, "xltx");
             data.put(PROP_FILTER_SHORT_NAME, "ooxml");
-            data.put("DocumentType", DocumentType.SPREADSHEET.toString());
+            data.put(PROP_DOCUMENT_TYPE, DocumentType.SPREADSHEET.toString());
+            data.put(PROP_DOCUMENT_FORMAT, DocumentFormat.XLSX.toString());
             break;
         }
 
@@ -241,7 +250,8 @@ public class DocumentFormatHelper {
             data.put(PROP_MIME_TYPE, MimeTypeHelper.MIMETYPE_VND_OPENXMLFORMATS_OFFICEDOCUMENT_PRESENTATION_TEMPLATE);
             data.put(PROP_INPUT_TYPE, "potx");
             data.put(PROP_FILTER_SHORT_NAME, "ooxml");
-            data.put("DocumentType", DocumentType.PRESENTATION.toString());
+            data.put(PROP_DOCUMENT_TYPE, DocumentType.PRESENTATION.toString());
+            data.put(PROP_DOCUMENT_FORMAT, DocumentFormat.PPTX.toString());
             break;
         }
 
@@ -249,7 +259,8 @@ public class DocumentFormatHelper {
             data.put(PROP_MIME_TYPE, MimeTypeHelper.MIMETYPE_VND_OASIS_OPENDOCUMENT_TEXT_TEMPLATE);
             data.put(PROP_INPUT_TYPE, "ott");
             data.put(PROP_FILTER_SHORT_NAME, "odf");
-            data.put("DocumentType", DocumentType.TEXT.toString());
+            data.put(PROP_DOCUMENT_TYPE, DocumentType.TEXT.toString());
+            data.put(PROP_DOCUMENT_FORMAT, DocumentFormat.ODT.toString());
             break;
         }
 
@@ -257,7 +268,8 @@ public class DocumentFormatHelper {
             data.put(PROP_INPUT_TYPE, "ots");
             data.put(PROP_MIME_TYPE, MimeTypeHelper.MIMETYPE_VND_OASIS_OPENDOCUMENT_SPREADSHEET_TEMPLATE);
             data.put(PROP_FILTER_SHORT_NAME, "odf");
-            data.put("DocumentType", DocumentType.SPREADSHEET.toString());
+            data.put(PROP_DOCUMENT_TYPE, DocumentType.SPREADSHEET.toString());
+            data.put(PROP_DOCUMENT_FORMAT, DocumentFormat.ODS.toString());
             break;
         }
 
@@ -265,7 +277,8 @@ public class DocumentFormatHelper {
             data.put(PROP_INPUT_TYPE, "otp");
             data.put(PROP_MIME_TYPE, MimeTypeHelper.MIMETYPE_VND_OASIS_OPENDOCUMENT_PRESENTATION_TEMPLATE);
             data.put(PROP_FILTER_SHORT_NAME, "odf");
-            data.put("DocumentType", DocumentType.PRESENTATION.toString());
+            data.put(PROP_DOCUMENT_TYPE, DocumentType.PRESENTATION.toString());
+            data.put(PROP_DOCUMENT_FORMAT, DocumentFormat.ODP.toString());
             break;
         }
 
@@ -352,6 +365,103 @@ public class DocumentFormatHelper {
         return result;
     }
 
+    /**
+     * Provides the document format info using the mime type
+     * or extension type. 
+     *
+     * @param mimeType
+     *  The mime type of a document file. First used to find a match.
+     *
+     * @param extensionType
+     *  The extension type of a document file. Is used if the mime type
+     *  doesn't have a match.
+     *
+     * @return
+     *  The document format info or null if there is no known mapping.
+     */
+    static public Map<String, String> getFormatInfoForMimeTypeOrExtension(String mimeType, String extensionType) {
+        Map<String, String> result = null;
+
+        if (null != mimeType) {
+            if (null == result) {
+                // Spreadsheet
+                if (mimeType.equalsIgnoreCase(MimeTypeHelper.MIMETYPE_VND_OPENXMLFORMATS_OFFICEDOCUMENT_SPREADSHEET)) {
+                    result = getFormatData(OfficeDocumentType.MS_DOCUMENT_SPREADSHEET);
+                } else if (mimeType.equalsIgnoreCase(MimeTypeHelper.MIMETYPE_VND_OPENXMLFORMATS_OFFICEDOCUMENT_SPREADSHEET_MACRO)) {
+                    result = getFormatData(OfficeDocumentType.MS_DOCUMENT_SPREADSHEET);
+                } else if (mimeType.equalsIgnoreCase(MimeTypeHelper.MIMETYPE_VND_OASIS_OPENDOCUMENT_SPREADSHEET)) {
+                    result = getFormatData(OfficeDocumentType.ODF_DOCUMENT_CALC);
+                } else if (mimeType.equalsIgnoreCase(MimeTypeHelper.MIMETYPE_VND_OPENXMLFORMATS_OFFICEDOCUMENT_SPREADSHEET_TEMPLATE)) {
+                    result = getFormatData(OfficeDocumentType.MS_DOCUMENT_SPREADSHEET);
+                } else if (mimeType.equalsIgnoreCase(MimeTypeHelper.MIMETYPE_VND_OPENXMLFORMATS_OFFICEDOCUMENT_SPREADSHEET_TEMPLATE_MACRO)) {
+                    result = getFormatData(OfficeDocumentType.MS_DOCUMENT_SPREADSHEET);
+                } else if (mimeType.equalsIgnoreCase(MimeTypeHelper.MIMETYPE_VND_OASIS_OPENDOCUMENT_SPREADSHEET_TEMPLATE)) {
+                    result = getFormatData(OfficeDocumentType.ODF_DOCUMENT_CALC);
+                }
+            }
+
+            if (null == result) {
+                // Text
+                if (mimeType.equalsIgnoreCase(MimeTypeHelper.MIMETYPE_VND_OPENXMLFORMATS_OFFICEDOCUMENT_SPREADSHEET)) {
+                    result = getFormatData(OfficeDocumentType.MS_DOCUMENT_WORD);
+                } else if (mimeType.equalsIgnoreCase(MimeTypeHelper.MIMETYPE_VND_OPENXMLFORMATS_OFFICEDOCUMENT_SPREADSHEET_MACRO)) {
+                    result = getFormatData(OfficeDocumentType.MS_DOCUMENT_WORD);
+                } else if (mimeType.equalsIgnoreCase(MimeTypeHelper.MIMETYPE_VND_OASIS_OPENDOCUMENT_TEXT)) {
+                    result = getFormatData(OfficeDocumentType.ODF_DOCUMENT_WRITER);
+                } else if (mimeType.equalsIgnoreCase(MimeTypeHelper.MIMETYPE_VND_OPENXMLFORMATS_OFFICEDOCUMENT_SPREADSHEET_TEMPLATE)) {
+                    result = getFormatData(OfficeDocumentType.MS_DOCUMENT_WORD);
+                } else if (mimeType.equalsIgnoreCase(MimeTypeHelper.MIMETYPE_VND_OPENXMLFORMATS_OFFICEDOCUMENT_SPREADSHEET_TEMPLATE_MACRO)) {
+                    result = getFormatData(OfficeDocumentType.MS_DOCUMENT_WORD);
+                } else if (mimeType.equalsIgnoreCase(MimeTypeHelper.MIMETYPE_VND_OASIS_OPENDOCUMENT_TEXT_TEMPLATE)) {
+                    result = getFormatData(OfficeDocumentType.ODF_DOCUMENT_WRITER);
+                }
+            }
+
+            if (null == result) {
+                // Presentation
+                if (mimeType.equalsIgnoreCase(MimeTypeHelper.MIMETYPE_VND_OPENXMLFORMATS_OFFICEDOCUMENT_PRESENTATION)) {
+                    result = getFormatData(OfficeDocumentType.MS_DOCUMENT_PRESENTATION);
+                } else if (mimeType.equalsIgnoreCase(MimeTypeHelper.MIMETYPE_VND_OPENXMLFORMATS_OFFICEDOCUMENT_PRESENTATION_MACRO)) {
+                    result = getFormatData(OfficeDocumentType.MS_DOCUMENT_PRESENTATION);
+                } else if (mimeType.equalsIgnoreCase(MimeTypeHelper.MIMETYPE_VND_OASIS_OPENDOCUMENT_TEXT)) {
+                    result = getFormatData(OfficeDocumentType.ODF_DOCUMENT_IMPRESS);
+                } else if (mimeType.equalsIgnoreCase(MimeTypeHelper.MIMETYPE_VND_OPENXMLFORMATS_OFFICEDOCUMENT_PRESENTATION_TEMPLATE)) {
+                    result = getFormatData(OfficeDocumentType.MS_DOCUMENT_PRESENTATION);
+                } else if (mimeType.equalsIgnoreCase(MimeTypeHelper.MIMETYPE_VND_OPENXMLFORMATS_OFFICEDOCUMENT_PRESENTATION_TEMPLATE_MACRO)) {
+                    result = getFormatData(OfficeDocumentType.MS_DOCUMENT_PRESENTATION);
+                } else if (mimeType.equalsIgnoreCase(MimeTypeHelper.MIMETYPE_VND_OASIS_OPENDOCUMENT_TEXT_TEMPLATE)) {
+                    result = getFormatData(OfficeDocumentType.ODF_DOCUMENT_IMPRESS);
+                }
+            }
+        }
+
+        if ((null == result) && (null != extensionType)) {
+        	switch (extensionType) {
+        	case "xlsx":
+        	case "xlsm":
+        	case "xltx":
+        	case "xltm": result = getFormatData(OfficeDocumentType.MS_DOCUMENT_SPREADSHEET); break;
+        	case "ods":
+        	case "ots": result = getFormatData(OfficeDocumentType.ODF_DOCUMENT_CALC); break;
+        	case "docx":
+        	case "docm":
+        	case "dotx":
+        	case "dotm": result = getFormatData(OfficeDocumentType.MS_DOCUMENT_WORD); break;
+        	case "odt":
+        	case "ott": result = getFormatData(OfficeDocumentType.ODF_DOCUMENT_WRITER); break;
+        	case "pptx":
+        	case "pptm":
+        	case "potx":
+        	case "potm": result = getFormatData(OfficeDocumentType.MS_DOCUMENT_PRESENTATION); break;
+        	case "odp":
+        	case "otp": result = getFormatData(OfficeDocumentType.ODF_DOCUMENT_IMPRESS); break;
+        	default: // unknown
+            }
+        }
+
+        return result;
+    }
+
     /**
      * Provides the mapping from a normal document format to a pre-defined
      * document template format. The mapping uses the mime type and the
