@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,11 +51,12 @@ package com.openexchange.office.tools.doc;
 import java.io.Closeable;
 import java.io.IOException;
 import java.io.InputStream;
-import org.apache.commons.logging.Log;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import com.openexchange.exception.OXException;
 import com.openexchange.file.storage.File;
 import com.openexchange.file.storage.composition.IDBasedFileAccess;
-import com.openexchange.office.tools.error.ErrorCode;
+import com.openexchange.office.tools.common.error.ErrorCode;
 import com.openexchange.tx.TransactionAware;
 
 /**
@@ -67,10 +68,10 @@ import com.openexchange.tx.TransactionAware;
  * @since v7.6.2
  */
 public class StreamInfo implements Closeable {
+    private static final Logger LOG = LoggerFactory.getLogger(StreamInfo.class);
 
-    private static final Log   LOG         = com.openexchange.log.Log.loggerFor(StreamInfo.class);
     public static final String NO_USERNAME = "";
-    public static final int    NO_USERID   = -1;
+    public static final int NO_USERID   = -1;
 
     private ErrorCode errorCode = ErrorCode.NO_ERROR;
     private InputStream documentStream = null;
