@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,23 +59,24 @@ import java.util.Map;
 import java.util.Timer;
 import java.util.TimerTask;
 import java.util.concurrent.atomic.AtomicLong;
-import org.apache.commons.logging.Log;
-import com.openexchange.log.LogFactory;
-import com.openexchange.office.document.AdvisoryLockInfoService;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import org.springframework.beans.factory.DisposableBean;
+import org.springframework.beans.factory.InitializingBean;
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.stereotype.Service;
+import com.openexchange.office.document.api.AdvisoryLockInfoService;
+import com.openexchange.office.tools.annotation.RegisteredService;
 import com.openexchange.office.tools.doc.DocumentType;
-import com.openexchange.office.tools.osgi.ServiceLookupRegistryService;
 
-/**
- * {@link Statistics
- *
- * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
- */
 /**
  * {@link Statistics}
  *
  * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
  */
-public class Statistics {
+@Service
+@RegisteredService
+public class Statistics implements InitializingBean, DisposableBean {
 
     // set period of reset task to 5min, which equals to the munin standard period
     private final long RESET_TIMER_PERIOD_MILLISECONDS = 5 * 60 * 1000;
@@ -84,25 +85,16 @@ public class Statistics {
     // span before the next external and periodic retrieval
     private final long RESET_TIMER_AHEAD_TIME = 30 * 1000;
 
+    @Autowired
+    protected AdvisoryLockInfoService advisoryLockInfoService;
+
     /**
      * Logger
      */
-    protected static final Log LOG = LogFactory.getLog(Statistics.class);
-
-    /**
-     * Initializes a new {@link Statistics}.
-     */
-    public Statistics() {
-        super();
-
-        if (null != m_statistics) {
-            LOG.warn("Statistics object has already been initialized, please check callers.");
-        } else {
-            m_statistics = this;
-        }
-
-        // initialize members
+    protected static final Logger LOG = LoggerFactory.getLogger(Statistics.class);
 
+	@Override
+	public void afterPropertiesSet() throws Exception {
         for (DocumentType documentType : DocumentType.values()) {
             // correctly initialize all maps and sub maps
             m_documentsCreated.put(documentType, new AtomicLong());
@@ -148,88 +140,52 @@ public class Statistics {
 
             // otTransformationCounts
             m_otTransformationCounts.put(documentType, new AtomicLong());
+            m_otUnresolvableTransformationCounts.put(documentType, new AtomicLong());
+            m_otUnresolvableTransformationReloadCounts.put(documentType, new AtomicLong());
         }
 
         // Restore Document
         for (RestoreDocEventType curRestoreDocEventType : RestoreDocEventType.values()) {
-            this.m_restoreDocEvents.put(curRestoreDocEventType, new AtomicLong());
+            m_restoreDocEvents.put(curRestoreDocEventType, new AtomicLong());
         }
 
         // Background Save
         for (BackgroundSaveEventType cur : BackgroundSaveEventType.values()) {
-            this.m_fssDocEvents.put(cur, new AtomicLong());
+            m_fssDocEvents.put(cur, new AtomicLong());
         }
     }
 
     /**
      * @param event
      */
-    static public synchronized void handleDocumentEvent(DocumentEvent event) {
-        if (null != m_statistics) {
-            m_statistics.implHandleDocumentEvent(event);
-        } else {
-            LOG.warn("Statistics object has not been initialized yet, please check proper initialization.");
-        }
+    public synchronized void handleDocumentEvent(DocumentEvent event) {
+    	implHandleDocumentEvent(event);
     }
 
-    static public synchronized void handleRestoreDocEvent(RestoreDocEvent event) {
-        if (null != m_statistics) {
-            m_statistics.implHandleRestoreDocEvent(event);
-        } else {
-            LOG.warn("Statistics object has not been initialized yet, please check proper initialization.");
-        }
+    public synchronized void handleRestoreDocEvent(RestoreDocEvent event) {
+    	implHandleRestoreDocEvent(event);
     }
 
-    static public synchronized void handleBackgroundSaveDocEvent(BackgroundSaveEvent event) {
-        if (null != m_statistics) {
-            m_statistics.implHandleBackgroundSaveDocEvent(event);
-        } else {
-            LOG.warn("Statistics object has not been initialized yet, please check proper initialization.");
-        }
+    public synchronized void handleBackgroundSaveDocEvent(BackgroundSaveEvent event) {
+    	implHandleBackgroundSaveDocEvent(event);
     }
 
-    static public synchronized void handlePresenterEvent(PresenterEvent event) {
-        if (null != m_statistics) {
-            m_statistics.implHandlePresenterEvent(event);
-        } else {
-            LOG.warn("Statistics object has not been initialized yet, please check proper initialization.");
-        }
+    public synchronized void handlePresenterEvent(PresenterEvent event) {
+    	implHandlePresenterEvent(event);
     }
 
-    static public synchronized void handleTransformation(DocumentType documentType) {
-        if (null != m_statistics) {
-            m_statistics.implHandleTransformation(documentType);
-        } else {
-            LOG.warn("Statistics object has not been initialized yet, please check proper initialization.");
-        }
+    public synchronized void handleTransformation(OTEvent event) {
+    	implHandleTransformation(event);
     }
 
-
-    /**
-     * @return The 'real' implementation object
-     */
-    static public Statistics get() {
-        return m_statistics;
-    }
-
-    /**
-     * shutdown statistic processing
-     */
-    public synchronized void shutdown() {
+    @Override
+	public void destroy() throws Exception {
         m_resetTimer.cancel();
         m_resetTimer.purge();
         if (null != m_resetTask) {
             m_resetTask.cancel();
         }
-    }
-
-    /**
-     * @return
-     */
-    public synchronized String getAdvisoryLockInfoMode() {
-        final AdvisoryLockInfoService advisoryLockInfoService = ServiceLookupRegistryService.getInstance().getService(AdvisoryLockInfoService.class);
-        return advisoryLockInfoService.getAdvisoryLockMode().toString();
-    }
+	}
 
     /**
      * @return
@@ -248,6 +204,13 @@ public class Statistics {
         return ret;
     }
 
+    /**
+     * @return
+     */
+    public synchronized String getAdvisoryLockInfoMode() {
+        return advisoryLockInfoService.getAdvisoryLockMode().toString();
+    }
+
     /**
      * @return
      */
@@ -332,7 +295,7 @@ public class Statistics {
     }
 
     public long getRestoreDocCurrent() {
-        return this.m_restoreDocCurrent.get();
+        return m_restoreDocCurrent.get();
     }
 
     public long getRestoreDocRestoredSuccess() {
@@ -429,10 +392,6 @@ public class Statistics {
 
     // - OT -------------------------------------------------------------------
 
-    /**
-     * @param documentType
-     * @return
-     */
     public long getTransformationCount(DocumentType documentType) {
         if (null == documentType) {
             final AtomicLong accumulatedLong = new AtomicLong();
@@ -447,6 +406,34 @@ public class Statistics {
         return m_otTransformationCounts.get(documentType).get();
     }
 
+	public long getUnresolvableTransformations(DocumentType documentType) {
+        if (null == documentType) {
+            final AtomicLong accumulatedLong = new AtomicLong();
+
+            m_otUnresolvableTransformationCounts.keySet().stream().forEach((curDocumentType)-> {
+                accumulatedLong.addAndGet(m_otUnresolvableTransformationCounts.get(curDocumentType).get());
+            });
+
+            return accumulatedLong.get();
+        }
+
+        return m_otUnresolvableTransformationCounts.get(documentType).get();
+	}
+
+    public long getUnresolvableTransformationReloads(DocumentType documentType) {
+        if (null == documentType) {
+            final AtomicLong accumulatedLong = new AtomicLong();
+
+            m_otUnresolvableTransformationReloadCounts.keySet().stream().forEach((curDocumentType) -> {
+                accumulatedLong.addAndGet(m_otUnresolvableTransformationReloadCounts.get(curDocumentType).get());
+            });
+
+            return accumulatedLong.get();
+        }
+
+        return m_otUnresolvableTransformationReloadCounts.get(documentType).get();
+    }
+
     // - Implementation --------------------------------------------------------
 
     private void implHandleRestoreDocEvent(RestoreDocEvent event) {
@@ -615,10 +602,20 @@ public class Statistics {
         }
     }
 
-    private void implHandleTransformation(DocumentType documentType) {
-        if (null != documentType) {
-            m_otTransformationCounts.get(documentType).incrementAndGet();
-        }
+    private void implHandleTransformation(OTEvent event) {
+    	if (null != event) {
+    		final DocumentType documentType = event.getDocumentType();
+    		if (documentType != DocumentType.NONE) {
+    			final OTEventType eventType = event.getEventType();
+    			if (eventType == OTEventType.TRANSFORMATION) {
+                    m_otTransformationCounts.get(documentType).incrementAndGet();
+    			} else if (eventType == OTEventType.UNRESOLVABLE_TRANSFORMATION) {
+    				m_otUnresolvableTransformationCounts.get(documentType).incrementAndGet();
+                } else if (eventType == OTEventType.UNRESOLVABLE_TRANSFORMATION_RELOAD) {
+                    m_otUnresolvableTransformationReloadCounts.get(documentType).incrementAndGet();
+                }
+    		}
+    	}
     }
 
     /**
@@ -779,8 +776,6 @@ public class Statistics {
 
     // - Members ---------------------------------------------------------------
 
-    static Statistics m_statistics = null;
-
     private final Timer m_resetTimer = new Timer("Office statistics", true);
 
     private TimerTask m_resetTask = null;
@@ -850,4 +845,8 @@ public class Statistics {
     private final AtomicLong m_fssMinTimeForFasterSave = new AtomicLong(0);
 
     private final Map<DocumentType, AtomicLong> m_otTransformationCounts = new EnumMap<>(DocumentType.class);
+
+    private final Map<DocumentType, AtomicLong> m_otUnresolvableTransformationCounts = new EnumMap<>(DocumentType.class);
+
+    private final Map<DocumentType, AtomicLong> m_otUnresolvableTransformationReloadCounts = new EnumMap<>(DocumentType.class);
 }
